import React from 'react';
import { Form, Modal, Input, Button } from "antd";
import styled from 'styled-components';
import { useDispatch } from "react-redux";
import { changePassword } from "containers/App/actions";
import { injectIntl } from "react-intl";
import messages from "translations/messages";
import FloatLabel from 'components/FormatInput/FloatLabel';

const FormWrapper = styled.div`
  display: flex;
  flex-direction: column;
  align-items: stretch;
  justify-content: space-between;
  text-align: center;
  padding: 6px;
  h3 {
    margin-bottom: 1.5em;
    font-family: Muli;
    font-size: 16px;
    font-weight: 600;
  }
  button {
    height: 44px;
  }
  .ant-input, .ant-input-password {
    border-radius: 22px;
    border: solid 1px #e6e6e6;
    min-height: 44px;
    align-items: center;
  }
  .ant-input-password .ant-input {
    min-height: initial;
  }
`;

function ChangePasswordModal(props) {
  const dispatch = useDispatch();
  const { id, visible, onOk, onCancel, intl } = props;
  const [form] = Form.useForm();

  const onFinish = (values) => {
    dispatch(changePassword({id, values}));
    onOk();
  }

  return (
    <Modal
      title={null}
      visible={visible}
      onCancel={onCancel}
      width="330px"
      centered
      footer={null}>
      <Form
        form={form}
        onFinish={onFinish}>
        <FormWrapper>
          <h3>{intl.formatMessage(messages.changePass)}</h3>
          <Form.Item name="newPassword" rules={[{ required: true, message: intl.formatMessage(messages.requiredPassword)}]}>
            <FloatLabel label={intl.formatMessage(messages.passwordPh)} typeInput="password"/>
          </Form.Item>
          <Form.Item
            name="verifyPassword"
            dependencies={['newPassword']}
            rules={[
              { required: true, message: intl.formatMessage(messages.confirmPassword)},
              ({ getFieldValue }) => ({
                validator(rule, value) {
                  if (!value || getFieldValue('newPassword') === value) {
                    return Promise.resolve();
                  }
                  return Promise.reject(intl.formatMessage(messages.invalidPassword));
                },
              }),
            ]}
          >
            <FloatLabel label={intl.formatMessage(messages.retypePasswordPh)} typeInput="password"/>
          </Form.Item>
          <Button
            type="primary"
            htmlType="submit">
            {intl.formatMessage(messages.sendBtn)}
          </Button>
        </FormWrapper>
      </Form>
    </Modal>
  )
}
export default injectIntl(ChangePasswordModal);