import React, { useState, useEffect } from 'react';
import { Input, DatePicker, Select, InputNumber, AutoComplete } from 'antd';

import './index.scss';

const FloatLabel = props => {
  const [focus, setFocus] = useState(false);
  const {
    value,
    children,
    label,
    addonBefore,
    typeInput = 'input',
    items,
    prefix,
    defaultValue
  } = props;

  let labelClass = '';
  if (focus || ((value || value === 0) && value.length !== 0) || ((value || value === 0)  && value === '') || defaultValue || defaultValue === 0) {
    labelClass += 'label-orgin-input label-float'
    if (typeInput === 'TextArea') {
      labelClass += ' label-float-textArea';
    }
  } else {
    labelClass +=  'label-orgin-input'
    if (typeInput === 'TextArea') {
      labelClass += ' label-textArea';
    }
  }
  if (addonBefore) {
    labelClass += ' label-before';
  }
  if (prefix) {
    labelClass += ' label-prefix';
  }
  return (
    <div
      className="float-label"
      onBlur={() => setFocus(false)}
      onFocus={() => setFocus(true)}
      style={{ height: typeInput === 'TextArea' ? '100%' : 'auto' }}
    >
      {typeInput === 'input' && <Input {...props} value={value} />}
      {typeInput === 'password' && <Input.Password {...props} value={value} />}
      {typeInput === 'TextArea' && <Input.TextArea {...props} value={value} />}
      {typeInput === 'datepicker' && (
        <DatePicker {...props} value={value} placeholder="" />
      )}
      {typeInput === 'autocomplete' && (
        <AutoComplete {...props} value={value} placeholder="" />
      )}
      {typeInput === 'selectMutil' && (
        <Select {...props} value={value} placeholder="">
          {items.map(item => (
            <Select.Option value={item.id}>{item.name}</Select.Option>
          ))}
        </Select>
      )}
      {typeInput === 'number' && <InputNumber {...props} value={value} />}
      <label className={labelClass}>{label}</label>
    </div>
  );
};

export default FloatLabel;
