import React,{ useCallback } from 'react';
import {
  Page,
  Text,
  View,
  Document,
  StyleSheet,
  PDFDownloadLink,
  Font,
  Image,
} from '@react-pdf/renderer';
import BUBBLE_LOGO from '../../images/bubbles.png';
import moment from 'moment';
Font.register({
  family: 'Roboto',
  src: `https://cdnjs.cloudflare.com/ajax/libs/ink/3.1.10/fonts/Roboto/roboto-medium-webfont.ttf`,
});
// Create styles
const styles = StyleSheet.create({
  page: {
    flexDirection: 'row',
    backgroundColor: '#E4E4E4',
    fontFamily: 'Roboto',
    margin: 20,
  },
  section: {
    margin: 10,
    padding: 10,
    flexGrow: 1,
  },
  image: {
    height: 100,
    width: 200,
    marginBottom: 30,
    marginTop: 30,
    marginLeft: 300,
    justifyContent: 'center',
  },
  header: {
    fontSize: 30,
    color: 'grey',
    marginBottom: 15,
    textAlign: 'center',
  },
  title: {
    fontSize: 18,
    textAlign: 'center',
  },
  text: {
    fontSize: 14,
    fontFamily: 'Roboto',
    textAlign: 'justify',
    marginLeft: 150,
  },
  footer: {
    position: 'absolute',
    fontSize: 12,
    bottom: 25,
    left: 35,
    right: 0,
    textAlign: 'center',
    color: 'grey',
    fontFamily: 'Roboto',
  },
  breakLine: {
    marginBottom: 20
  },
  totalBill: {
    fontSize: 20,
    fontFamily: 'Roboto',
    textAlign: 'justify',
    marginLeft: 150,
  },
  underLine: {
    backgroundColor: 'black',
    height: 1,
    width: '100%',
    marginLeft: 150,
    marginBottom: 20
  }
});

// Create Document Component
const MyDocument = props => {
  const { data } = props;
  const description = data.description ? JSON.parse(data.description) : null;
  const totalBillCallBack = useCallback((description) => description.reduce((totalData, current) => totalData + current.amountRes, 0),[]);
  const totalBill = totalBillCallBack(description);
  return (
    <Document>
      <Page size="A3" style={styles.page}>
        <View>
          <Image style={styles.image} src={BUBBLE_LOGO} />
          <Text style={styles.header} fixed>
            BUBBLE BILL
          </Text>
          <Text style={styles.title}>
            Kính chào quí khách cảm ơn đã sử dụng dịch vụ của bubble
          </Text>
          <Text style={styles.title}>{data.billName}</Text>
          {description &&
            description.map(res => (
              <>
                <Text style={styles.text}>Tên điểm kinh doanh : {res.res_name}</Text>
                <Text style={styles.text}>
                  Ngày mở cửa: {' '}
                  {moment(res.res_created_time).format('DD/MM/YYYY')}
                </Text>
                <Text style={styles.text}>
                  Thời gian sử dụng: {' '}{`${res.diffDate} ngày`}
                </Text>
                <Text style={styles.text}>Thuế: {res.tax}</Text>
                <Text style={styles.text}>
                  Chi phí sau thuế: {res.amountRes}
                </Text>
                <Text style={styles.breakLine}></Text>
              </>
            )
            )}
            <Text style={styles.underLine}>
            </Text>
            <Text style={styles.totalBill}>
              Tổng chi phí là : {totalBill}
            </Text>
          <Text style={styles.footer}>
            Vui lòng liên hệ Long Nguyen nếu có bất kì thắc mắc nào
          </Text>
        </View>
      </Page>
    </Document>
  );
};

export const PdfDocument = ({ data }) => {
  return (
    <PDFDownloadLink
      document={<MyDocument data={data} />}
      fileName={`BILL.pdf`}
    >
      {({ url, loading, error }) => {
        if (loading) {
          return <span>generating document...</span>;
        }
        if (!loading && url) {
          return (
            <a href={url} download>
              - Download {data.billName} (PDF)
            </a>
          );
        }
        if (error) {
          console.error(error);
          return <p>An error occurred</p>;
        }
        return null;
      }}
    </PDFDownloadLink>
  );
};
