import { callApi, success } from "../../utils/apiUtils";
import { put, takeLatest } from "redux-saga/effects";
import {
  addPromotionFail,
  addPromotionSuccess,
  getPromotionSubjectsFail,
  getPromotionSubjectsSuccess
} from "./actions";
import ActionTypes from "./constants";
import { push } from "connected-react-router";
import { RoutePaths } from "../App/routes";
import { apiError } from "../App/actions";

export function* addPromotion({payload: promotion}) {
  try {
    const { code, data, message } = yield callApi(`/promotions`, 'POST', promotion, { isFormData: true});
    if (success(code)) {
      yield put(addPromotionSuccess(data));
      yield put(push(RoutePaths.promotion));
    } else {
      yield put(addPromotionFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(addPromotionFail(error.message));
    yield put(apiError(error.message));
  }
}

export function* getPromotionSubjects() {
  try {
    const { code, data, message } = yield callApi(`/promotions/promotions-subjects`, 'GET');
    if (success(code)) {
      data.sort((a, b) => (a.id > b.id ? 1 : -1));
      yield put(getPromotionSubjectsSuccess(data));
    } else {
      yield put(getPromotionSubjectsFail(message));
    }
  } catch (error) {
    yield put(getPromotionSubjectsFail(error.message));
  }
}

// Individual exports for testing
export default function* addPromotionSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.ADD_PROMOTION, addPromotion);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PROMOTION_SUBJECTS, getPromotionSubjects);
}
