/**
 *
 * App.js
 *
 * This component is the skeleton around the actual pages, and should only
 * contain code that should be seen on all pages. (e.g. navigation bar)
 *
 */

import * as React from 'react';
import { Switch, Route } from 'react-router-dom';
import { hot } from 'react-hot-loader/root';

import { Layout } from 'containers/Layout/layout';
import { ThinkNRoutes, RoutePaths } from './routes';
import Login from 'containers/Auth/login';
import ResetPassword from 'containers/ResetPassword/resetPassword';
import { createStructuredSelector } from 'reselect';
import { makeSelectUserInfo } from 'containers/Auth/authSelectors';
import { makeSelectReload } from './selectors';
import { useDispatch, useSelector } from "react-redux";
import { useEffect } from "react";
import { getMenus, getRestaurants, getRoles, setReload, getSetting, getPhoneCountries } from "./actions";
import cacheUtils from "../../utils/cacheUtils";
import { useInjectReducer, useInjectSaga } from "utils/redux-injectors";
import reducer from "./reducer";
import saga from "./saga";
// boostrap
// import "bootstrap/dist/css/bootstrap.min.css";

const stateSelector = createStructuredSelector({
  userInfo: makeSelectUserInfo(),
  isReload: makeSelectReload(),
});

function App(props) {
  useInjectReducer({ key: 'app', reducer: reducer });
  useInjectSaga({ key: 'app', saga: saga });
  const { userInfo, isReload } = useSelector(stateSelector);

  const dispatch = useDispatch();

  useEffect(() => {
    if (userInfo && userInfo.token) {
      const merchantId = cacheUtils.getMerchantId();
      dispatch(getRestaurants(merchantId));
      dispatch(getMenus(merchantId));
      dispatch(getRoles());
      dispatch(getPhoneCountries());
      //Getting new setting for language and currency in case reload page
      if (isReload) {
        dispatch(getSetting());
        dispatch(setReload());
      }
    }
  }, [userInfo]);
  if (window.location.pathname === RoutePaths.resetPassword) {
    const resetPasswordRoute =   {
      path: `${RoutePaths.resetPassword}`,
      layout: 'FULL',
      component: <ResetPassword />
    }
    return (
      <Layout type="FULL">
        { resetPasswordRoute.component }
      </Layout>
    )
  }
  if (!userInfo || !userInfo.token) {
    return (
      <Layout type="FULL">
        <Login />
      </Layout>
    );
  }

  return (
    <Switch>
      {
        ThinkNRoutes.map(
          thinkRoute => {
            const RouteComponent =
              <Layout type={thinkRoute.layout} header={thinkRoute.header}>
                {thinkRoute.component}
              </Layout>
            return (
              <Route exact path={thinkRoute.path} key={thinkRoute.path}>
                {RouteComponent}
              </Route>
            );
          }
        )
      }
    </Switch>
  );
}
export default hot(App);
