import React, { ReactElement } from 'react';
import { LayoutType } from 'containers/Layout/layout';
import { BackButton } from 'containers/Layout/components/backButton';
import { RestaurantList, RestaurantDetails, RestaurantAddMenu } from 'containers/Restaurant';
import StaffList from 'containers/StaffList';
import StorageList from 'containers/Storage';
import CustomerList from '../CustomerList';
import CustomerDetail from '../CustomerDetail';
import { DashBoard } from 'containers/Dashboard';
import Setting from 'containers/Setting';
import { ServiceList } from 'containers/Service';
import ServiceEdit from 'containers/Service/ServiceEdit/serviceEdit';
import { MenuList } from 'containers/Menu';
import MenuEdit from 'containers/Menu/MenuEdit/menuEdit';
import ComboEdit from 'containers/Menu/ComboEdit/comboEdit';
import PaymentList from '../PaymentList';
import PayrollList from '../Payroll';
import { Report } from 'containers/Report';
import messages from 'translations/messages';
import { FormattedMessage } from 'react-intl';
import AddPromotion from "../AddPromotion";
import PromotionList from "../PromotionList";
import PromotionDetail from "../PromotionDetail";
import GiftCardDetail from "../GiftCardDetail";
import { Profile } from '../Profile';
import StaffDetail from "../StaffDetail";
import StaffAddNew from "../StaffAddNew";
import { Type } from "../PaymentList/types";

export enum RoutePaths {
  '/' = '/',
  home = '/home',
  about = '/about',
  login = '/login',
  restaurantDetail = '/shop/details',
  staff = '/staff',
  staffDetail = '/staff/details',
  staffAddNew = '/staff/add',
  customer = '/customer',
  customerDetail = '/customer/details',
  restaurant = '/shop',
  setting = '/setting',
  serviceDetail = '/service/detail',
  serviceEdit = '/service/edit/:id',
  serviceAdd = '/service/add',
  service = '/service',
  serviceCombo = '/service/combo',
  serviceComboEdit = '/service/combo/edit/:id',
  serviceComboList = '/service/combo/list',
  serviceComboAdd = '/service/combo/add',
  menuDetail = '/product/detail',
  menuEdit = '/product/edit/:id',
  menuAdd = '/product/add',
  menu = '/product',
  menuCombo = '/product/combo',
  menuComboEdit = '/product/combo/edit/:id',
  menuComboList = '/product/combo/list',
  menuComboAdd = '/product/combo/add',
  dashboard = '/dashboard',
  promotion = '/promotion',
  promotionAddnew = '/promotion/add',
  giftCardAddnew = '/promotion/giftCard/add',
  promotionDetail = '/promotion/details',
  giftCardDetail = '/promotion/giftCard/details',
  giftCard = '/promotion/giftCard',
  payment = '/billing',
  unpayment = '/billing/unpay',
  payroll = '/payroll',
  payrollUnpaid = '/payroll/unpay',
  report = '/report',
  profile = '/profile',
  resetPassword = '/resetpwd',
  storage = '/warehouse'
}

interface ThinkRoutes {
  path: RoutePaths | string;
  layout: LayoutType;
  component: ReactElement;
  header?: ReactElement;
}
export const ThinkNRoutes: ThinkRoutes[] = [
  {
    path: RoutePaths["/"],
    layout: 'MAIN',
    component: <DashBoard />,
  },
  {
    path: RoutePaths.dashboard,
    layout: 'MAIN',
    component: <DashBoard />,
  },
  {
    path: `${RoutePaths.restaurant}`,
    layout: 'MAIN',
    component: <RestaurantList />,
  },
  {
    path: `${RoutePaths.restaurantDetail}/:id`,
    layout: 'MAIN',
    component: <RestaurantDetails />,
    header:
      (<FormattedMessage {...messages.restaurantList}>
        {
          restaurantList =>
            <BackButton title={restaurantList} link={RoutePaths.restaurant} />
        }
      </FormattedMessage>)
  },
  {
    path: `${RoutePaths.restaurantDetail}/:id/product`,
    layout: 'MAIN',
    component: <RestaurantAddMenu />,
    header: <BackButton title="restaurantMenu" link={'restaurantMenu'} />
  },
  {
    path: RoutePaths.staff,
    layout: 'MAIN',
    component: <StaffList />,
  },
  {
    path: `${RoutePaths.staffDetail}/:id`,
    layout: 'MAIN',
    component: <StaffDetail />,
    header: <BackButton title={<FormattedMessage {...messages.staffList} />} link={RoutePaths.staff} />
  },
  {
    path: RoutePaths.staffAddNew,
    layout: 'MAIN',
    component: <StaffAddNew />,
    header: <BackButton title={<FormattedMessage {...messages.staffList} />} link={RoutePaths.staff} />
  },
  {
    path: RoutePaths.customer,
    layout: 'MAIN',
    component: <CustomerList />,
  },
  {
    path: `${RoutePaths.customerDetail}/:id`,
    layout: 'MAIN',
    component: <CustomerDetail />,
    header: <BackButton title={<FormattedMessage {...messages.customerList} />} link={RoutePaths.customer} />
  },
  {
    path: RoutePaths.setting,
    layout: 'MAIN',
    component: <Setting />,
  },
  {
    path: `${RoutePaths.service}`,
    layout: 'MAIN',
    component: <ServiceList type="menu" />,
  },
  {
    path: `${RoutePaths.serviceCombo}`,
    layout: 'MAIN',
    component: <ServiceList type="combo" />,
  },
  {
    path: `${RoutePaths.serviceEdit}`,
    layout: 'MAIN',
    component: <ServiceEdit />,
    header: <BackButton title={<FormattedMessage {...messages.service} />} link={RoutePaths.service} params={['categoryId']}/>
  },
  {
    path: `${RoutePaths.serviceAdd}`,
    layout: 'MAIN',
    component: <ServiceEdit />,
    header: <BackButton title={<FormattedMessage {...messages.service} />} link={RoutePaths.service} params={['categoryId']}/>
  },
  {
    path: RoutePaths.payment,
    layout: 'MAIN',
    component: <PaymentList type={Type.paid} />,
    header: <></>,
  },
  {
    path: RoutePaths.unpayment,
    layout: 'MAIN',
    component: <PaymentList type={Type.unpaid} />,
    header: <></>,
  },
  {
    path: `${RoutePaths.report}`,
    layout: 'MAIN',
    component: <Report />,
  },
  {
    path: `${RoutePaths.promotion}`,
    layout: 'MAIN',
    component: <PromotionList type={1} />,
  },
  {
    path: `${RoutePaths.promotionAddnew}`,
    layout: 'MAIN',
    component: <AddPromotion />,
    header: <BackButton title={<FormattedMessage {...messages.promotionList} />} link={RoutePaths.promotion}/>
  },
  {
    path: `${RoutePaths.promotionDetail}/:id`,
    layout: 'MAIN',
    component: <PromotionDetail />,
    header: <BackButton title={<FormattedMessage {...messages.promotionList} />} link={RoutePaths.promotion}/>
  },
  {
    path: `${RoutePaths.giftCardAddnew}`,
    layout: 'MAIN',
    component: <GiftCardDetail isCreate={true}/>,
    header: <BackButton title={<FormattedMessage {...messages.giftCardList} />} link={RoutePaths.giftCard}/>
  },
  {
    path: `${RoutePaths.giftCardDetail}/:id`,
    layout: 'MAIN',
    component: <GiftCardDetail isCreate={false}/>,
    header: <BackButton title={<FormattedMessage {...messages.giftCardList} />} link={RoutePaths.giftCard}/>
  },
  {
    path: `${RoutePaths.giftCard}`,
    layout: 'MAIN',
    component: <PromotionList type={0} />,
  },
  {
    path: `${RoutePaths.profile}`,
    layout: 'MAIN',
    component: <Profile />,
    header: <BackButton title="" link="" />
  },
  {
    path: `${RoutePaths.menu}`,
    layout: 'MAIN',
    component: <MenuList type="menu" />,
  },
  {
    path: `${RoutePaths.menuCombo}`,
    layout: 'MAIN',
    component: <MenuList type="combo" />,
  },
  {
    path: `${RoutePaths.menuEdit}`,
    layout: 'MAIN',
    component: <MenuEdit />,
    header: <BackButton title={<FormattedMessage {...messages.product} />} link={RoutePaths.menu} params={['categoryId']}/>
  },
  {
    path: `${RoutePaths.menuAdd}`,
    layout: 'MAIN',
    component: <MenuEdit />,
    header: <BackButton title={<FormattedMessage {...messages.product} />} link={RoutePaths.menu} params={['categoryId']}/>
  },
  {
    path: `${RoutePaths.menuComboEdit}`,
    layout: 'MAIN',
    component: <ComboEdit />,
    header: <BackButton title={<FormattedMessage {...messages.combo} />} link={RoutePaths.menuCombo} />
  },
  {
    path: `${RoutePaths.menuComboAdd}`,
    layout: 'MAIN',
    component: <ComboEdit />,
    header: <BackButton title={<FormattedMessage {...messages.combo} />} link={RoutePaths.menuCombo} />
  },
  {
    path: `${RoutePaths.storage}`,
    layout: 'MAIN',
    component: <StorageList />
  },
  {
    path: RoutePaths.payroll,
    layout: 'MAIN',
    component: <PayrollList type={Type.paid} />,
    header: <></>,
  },
  {
    path: RoutePaths.payrollUnpaid,
    layout: 'MAIN',
    component: <PayrollList type={Type.unpaid} />,
    header: <></>,
  },
];
