import { callApi, success } from 'utils/apiUtils';
import { call, put, takeLatest, takeEvery } from 'redux-saga/effects';
import {
  apiError,
  getMenusFail,
  getMenusSuccess,
  getRestaurantsFail,
  getRestaurantsSuccess,
  getRolesFail,
  getRolesSuccess,
  getSettingFail,
  getSettingSuccess,
  getPhoneCountriesSuccess,
  getPhoneCountriesFail
} from './actions';
import ActionTypes from './constants';
import LangActionTypes from '../LanguageProvider/constants';
import { notification } from 'antd';
import { changePasswordSuccess } from './actions';
import { LANGUAGE, LANGUAGE_API } from 'utils/constants';
import cacheUtils from "utils/cacheUtils";

export function* getRestaurants({ payload: merchantId }) {
  try {
    const { code, data, message } = yield callApi(
      `/restaurants/restaurants?merchantId=${merchantId}`,
      'GET',
    );
    if (success(code)) {
      yield put(getRestaurantsSuccess(data));
    } else {
      yield put(getRestaurantsFail(message));
    }
  } catch (error) {
    yield put(getRestaurantsFail(error.message));
  }
}

export function* getMenus() {
  try {
    const { code, data, message } = yield callApi(
      `/menus/merchant-menu`,
      'GET',
    );
    if (success(code)) {
      yield put(getMenusSuccess(data));
    } else {
      yield put(getMenusFail(message));
    }
  } catch (error) {
    yield put(getMenusFail(error.message));
  }
}

export function* getRoles() {
  try {
    const { code, data, message } = yield callApi(
      `/admin/setting/roles?type=4`,
      'GET',
    );
    if (success(code)) {
      yield put(getRolesSuccess(data));
    } else {
      yield put(getRolesFail(message));
    }
  } catch (error) {
    yield put(getRolesFail(error.message));
  }
}

export function* getSetting() {
  try {
    const { code, data, message } = yield callApi(
      `/users/profile`,
      'GET',
    );
    if (success(code)) {
      yield put(getSettingSuccess(data));
      yield put({
        type: LangActionTypes.CHANGE_LOCALE,
        payload:LANGUAGE[data.profile.merchant.setting.language.id],
      });
      const userInfo = cacheUtils.getUserInfo();
      if (userInfo) {
        const userInfoJson = JSON.parse(userInfo);
        cacheUtils.setUserInfo(
          JSON.stringify({
            ...userInfoJson,
            profile: data.profile,
          }),
        );
      }
    } else {
      yield put(getSettingFail(message));
    }
  } catch (error) {
    yield put(getSettingFail(error.message));
  }
}

function* showErrorPopup({ payload: message }) {
  yield call(notification.error, { message });
}

function* showSuccessPopup({ payload: message }) {
  yield call(notification.success, { message });
}

export function* changePassword({ payload: { id, values } }) {
  const param = {
    password: values.newPassword,
    verifyPassword: values.verifyPassword,
  };
  try {
    const { code, data, message } = yield callApi(
      `/users/change-password/${id}`,
      'PUT',
      param,
    );
    if (success(code)) {
      yield put(changePasswordSuccess(data));
    } else {
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(apiError(error.message));
  }
}

export function* getPhoneCountryCode() {
  try {
    const { code, data, message } = yield callApi(
      `/admin/setting/countries`,
      'GET'
    );
    if (success(code)) {
      yield put(getPhoneCountriesSuccess(data))
    } else {
      yield put(getPhoneCountriesFail(message))
    }
  } catch (error) {
    yield put(getPhoneCountriesFail(error.message));
  }
}


export default function* appSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_RESTAURANTS, getRestaurants);
  yield takeLatest(ActionTypes.GET_MENUS, getMenus);
  yield takeLatest(ActionTypes.GET_ROLES, getRoles);
  yield takeLatest(ActionTypes.GET_SETTING, getSetting);
  // @ts-ignore
  yield takeEvery(ActionTypes.API_ERROR, showErrorPopup);
  // @ts-ignore
  yield takeEvery(ActionTypes.API_SUCCESS, showSuccessPopup);
  // @ts-ignore
  yield takeLatest(ActionTypes.CHANGE_PASSWORD, changePassword);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PHONE_COUNTRY, getPhoneCountryCode)
}
