import React, { useEffect, useState } from 'react';
import { Button, DatePicker, Form, Input, Select, Row, Col } from 'antd';
import moment from 'moment';
import { useDispatch } from 'react-redux';
import { CardSeviceWrapper } from '../Styles';
import { injectIntl } from 'react-intl';
import NumberFormat from 'react-number-format';
import { GiftTieIcon, ArrowTotalIcon } from 'styles/icon-components';
import messages from 'translations/messages';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';

function CardGift(props) {
  const dispatch = useDispatch();
  const currencyMemoi = useCurrencyHook();
  const { giftCard, intl } = props;

  const amount = parseInt(giftCard.amount);
  const currentAmount = parseInt(giftCard.currentAmount);
  const expiredCheck = moment(giftCard.expiredTime).isAfter(moment());
  const userAmount = amount - currentAmount;

  return (
    <CardSeviceWrapper style={{ padding: '5px 0px 20px 0px' }}>
      <div className="service-card__tie">
        <GiftTieIcon />
      </div>

      <Row className="service-card__amount title-global">
        <span>
          <NumberFormat
            value={amount}
            displayType={'text'}
            thousandSeparator={'.'}
            renderText={value => `${value} ${currencyMemoi}`}
            decimalSeparator={','}
          />
        </span>
      </Row>
      <Row className="service-card__quanity">
        {/* <Col className="total"><span><TotalIcon name={`x${giftCard.total}`}/></span></Col> */}
        <Col className="used">
          <span>
            <ArrowTotalIcon />
            <NumberFormat
              value={userAmount == 0 ? userAmount : `-${userAmount}`}
              displayType={'text'}
              thousandSeparator={'.'}
              renderText={value => value}
              decimalSeparator={','}
            />
          </span>
        </Col>
        <Col className="remain">
          <span>
            <NumberFormat
              value={
                currentAmount === 0 ? Math.round(currentAmount) : currentAmount
              }
              displayType={'text'}
              thousandSeparator={'.'}
              renderText={value => value}
              decimalSeparator={','}
            />
          </span>
        </Col>
      </Row>
      <Row className="service-card__time">
        <span>{`${intl.formatMessage(messages.duration)}: ${moment(giftCard.createdTime).format(
          'DD/MM/YYYY',
        )} - ${moment(giftCard.expiredTime).format('DD/MM/YYYY')}`}</span>
      </Row>
      <Row
        className={`service-card__status ${
          expiredCheck
            ? giftCard.status === 2
              ? ' active'
              : ' gifted'
            : ' inactive'
        }`}
      >
        {expiredCheck
                ? giftCard.status === 2
                  ? intl.formatMessage(messages.valid)
                  : giftCard.status === 3
                  ? intl.formatMessage(messages.gifted)
                  : intl.formatMessage(messages.waitConfirm)
                : intl.formatMessage(messages.expired)}
      </Row>
    </CardSeviceWrapper>
  );
}

export default injectIntl(CardGift);
