import React, { useState, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { useParams } from 'react-router-dom';
import { ModalGiftWrapper } from '../Styles';
import { getCustomer, getOrderHistory, resetStaff } from '../actions';
import { Spin, Tabs, Button, Modal, Form, Row, Col } from 'antd';
import { PUBLIC_API } from 'containers/App/urls';
import { initials } from 'utils/string';
import { injectIntl } from 'react-intl';
import Avatar from 'react-avatar';
import DEFAULT_AVATAR from '../../../images/defaultAvatar.png';
import NumberFormat from 'react-number-format';
import messages from 'translations/messages';
import moment from 'moment';
import {
  TotalIcon,
  ArrowTotalIcon,
  PaperIcon,
  CardDetailIcon,
} from 'styles/icon-components';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function ModalGift(props) {
  const { intl, onCancel, openService, gift } = props;
  const photo = 'public/user/avatar-96-1597035523963.png';
  const dispatch = useDispatch(); // eslint-disable-line @typescript-eslint/no-unused-vars
  const amount = parseInt(gift.amount);
  const currencyMemoi = useCurrencyHook();
  const expiredCheck = moment(gift.expiredTime).isAfter(moment());
  useEffect(() => {
    return () => {
      dispatch(resetStaff());
    };
  }, []);
  return (
    <>
      <Modal
        title={null}
        visible={openService}
        onCancel={onCancel}
        width="600px"
        centered
        footer={null}
      >
        {' '}
        <ModalGiftWrapper>
          <Row className="service-card__title title-global">
            <span>{intl.formatMessage(messages.giftCard)}</span>
          </Row>
          <Row className="service-card__name">
            <span>
              <NumberFormat
                value={amount}
                displayType={'text'}
                thousandSeparator={'.'}
                renderText={value => `${value} ${currencyMemoi}`}
                decimalSeparator={','}
              />
            </span>
          </Row>
          <Row className="service-card__time">
            <Col className="code">
              <PaperIcon /> {gift.code}
            </Col>
            <Col className="time">
              {moment(gift.createdTime).format('DD/MM/YYYY - HH:MM')}
            </Col>
            <Col
              className={`service-card__status ${
                expiredCheck
                  ? gift.status === 2
                    ? ' active'
                    : gift.status === 3
                    ? 'gifted'
                    : ''
                  : ' inactive'
              }`}
            >
              <span>
                <CardDetailIcon />
              </span>
              {expiredCheck
                ? gift.status === 2
                  ? intl.formatMessage(messages.valid)
                  : gift.status === 3
                  ? intl.formatMessage(messages.gifted)
                  : intl.formatMessage(messages.waitConfirm)
                : intl.formatMessage(messages.expired)}
            </Col>
          </Row>
          {expiredCheck && gift.status === 3 && (
            <Row className="service-card__receiver">
              <div className="information">
                <Col>
                  {photo ? (
                    <img className="image" src={`${PUBLIC_API}/${photo}`} />
                  ) : gift.transferTo.user.firstName ||
                    gift.transferTo.user.lastName ? (
                    <Avatar
                      className="image"
                      name={`${gift.transferTo.user.firstName ? gift.transferTo.user.firstName : ''}${
                        gift.transferTo.user.lastName ? ' ' + gift.transferTo.user.lastName : ''
                      }`}
                      size="70"
                      initials={initials}
                    />
                  ) : (
                    <img className="image" src={DEFAULT_AVATAR} />
                  )}
                </Col>
                <Col className="name">
                  <span>
                    {gift.transferTo.user.firstName
                      ? gift.transferTo.user.firstName
                      : ''}
                    {gift.transferTo.user.lastName
                      ? ' ' + gift.transferTo.user.lastName
                      : ''}
                  </span>
                </Col>
              </div>
              <div>
                <Col className="time">
                  {intl.formatMessage(messages.dateGift)}:{' '}
                  {moment(gift.transferTo.createdTime).format('DD/MM/YYYY - h:mm a')}
                </Col>
              </div>
            </Row>
          )}

          {gift.histories.map((h, index) => {
            const giftCardAmount = parseInt(h.giftCardAmount);
            const amount = parseInt(h.amount);
            return (
              <Row
                className={`service-card__history${
                  index === 0 ? ' first-row' : ''
                }${index === gift.histories.length - 1 ? ' last-row' : ''}`}
              >
                <Row className="service-card__row-name">
                  <Col className="service-name">
                    <div>{h.order.orderItems[0].name}</div>
                  </Col>
                  <Col className="spa-name">
                    <div>{h.order.restaurantName}</div>
                  </Col>
                </Row>
                <Row className="service-card__row-infor">
                  <Col className="information">
                    <Row>
                      <Col className="used">
                        <span>
                          <ArrowTotalIcon />
                          {giftCardAmount == 0
                            ? giftCardAmount
                            : `-${giftCardAmount}`}
                        </span>
                      </Col>
                      <Col className="remain">
                        <span>{amount}</span>
                      </Col>
                    </Row>
                  </Col>
                  <Col className="information">
                    <div>
                      {h.order.placedTime &&
                        moment(h.placedTime).format('DD/MM/YYYY')}
                    </div>
                  </Col>
                </Row>
              </Row>
            );
          })}
        </ModalGiftWrapper>
      </Modal>
    </>
  );
}

export default injectIntl(ModalGift);
