import React, { useState, useEffect } from 'react';
import { Modal, Button, Form, Input } from 'antd';
import { InputWrapper } from 'styles/custom-styled-components';
import { StaffModel } from 'containers/StaffList/types';
import { FormattedMessage, injectIntl } from 'react-intl';
import { useDispatch, useSelector } from 'react-redux';
import { addNote } from '../actions';
import { createStructuredSelector } from 'reselect';
import makeSelectCustomerDetail from '../selectors';
import messages from 'translations/messages';
import styled from 'styled-components';
import _ from 'lodash';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createStructuredSelector({
  customerDetail: makeSelectCustomerDetail(),
});

const ModalAddWrapper = styled.div`
  #add-note {
    text-align: center;
    .text-center {
      font-size: 15px;
      margin-bottom: 25px;
      
    }
    .content-notes {
      .label-textArea {
        left: 20px;
      }
    }
    div {
      > textarea {
        width: 270px;
        height: 150px;
        border-radius: 8px !important;
      }
    }
  }
`;

interface Props {
  visible: boolean;
  onCancel: () => void;
  staffList: StaffModel[];
  intl: any;
}

const AddNote = (props: Props) => {
  const { visible, onCancel, intl } = props;
  const [form] = Form.useForm();
  const { customerDetail } = useSelector(stateSelector);
  const dispatch = useDispatch();
  const { isFetching, customer } = customerDetail;
  const onFinish = async value => {
    dispatch(addNote(customer?.id, value.note));
    onCancel();
  };
  return (
    <Modal
      visible={visible}
      width={330}
      onCancel={onCancel}
      centered
      footer={null}
    >
      <ModalAddWrapper>
        <Form form={form} name="add-note" onFinish={onFinish}>
          <h2 className="text-center">
            <FormattedMessage {...messages.note} />
          </h2>
          <InputWrapper>
            <Form.Item
              name="note"
              rules={[
                {
                  required: true,
                  message: <FormattedMessage {...messages.requiredInput} />,
                },
              ]}
              className="content-notes"
            >
              <FloatLabel label={intl.formatMessage(messages.note)} typeInput="TextArea"/>
            </Form.Item>
          </InputWrapper>
          <Button
          type="primary"
          htmlType="submit"
          className="w-100"
        >
          <FormattedMessage {...messages.save} />
        </Button>
        </Form>
      </ModalAddWrapper>
    </Modal>
  );
};
export default injectIntl(AddNote);
