import React from 'react';
import { Table } from 'antd';
import moment from 'moment';
import { WorkingHistoryWrapper } from '../Styles';
import NumberFormat from 'react-number-format';
import { injectIntl } from 'react-intl';
import messages from '../messages';
import messagesGlobal from 'translations/messages';
import { DATE_FORMAT } from '../../../utils/constants';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';

function formatOrderItems(orderItems) {
  const joinStr = orderItems.map(item => item.name).join(', ');
  return joinStr;
}

function Orders(props) {
  const currencyMemoi = useCurrencyHook();
  const { orderHistory, intl } = props;
  const columns = [
    {
      title: intl.formatMessage(messages.date),
      dataIndex: 'createdTime',
      key: 'createdTime',
      width: '12%',
      render: text => <span>{moment.utc(text).format(DATE_FORMAT)}</span>,
    },
    {
      title: intl.formatMessage(messages.orderNumber),
      dataIndex: 'qrCode',
      key: 'qrCode',
      width: '12%',
      render: qrCode => <span>{qrCode.substring(18, 26)}</span>,
    },
    {
      title: intl.formatMessage(messagesGlobal.productAndService),
      dataIndex: 'orderItems',
      key: 'orderItems',
      width: '61%',
      render: orderItems => <span>{formatOrderItems(orderItems)}</span>,
    },
    {
      title: intl.formatMessage(messagesGlobal.amount),
      dataIndex: 'total',
      key: 'total',
      width: '15%',
      render: total => (
        <p className="txt_red">
          <NumberFormat
            value={total}
            displayType={'text'}
            thousandSeparator={','}
            renderText={value => {
              return (
                `${
                  Math.round(parseFloat(total) / 1000) < 1
                    ? parseFloat(total)
                    : Math.round(parseFloat(total) / 1000)
                        .toString()
                        .replace(/(\d)(?=(\d{3})+(?!\d))/g, '$1,') + ',000'
                }` + ` ${currencyMemoi}`
              );
            }}
          />
        </p>
      ),
    },
  ];
  return (
    <WorkingHistoryWrapper>
      <div className="order-history_header title-global">
        <h3>{intl.formatMessage(messages.orderHistory)}</h3>
        <div>
          <span style={{ marginRight: '10px' }}>
            {intl.formatMessage(messages.orderNumbers)}
          </span>
          <span className="order-history_header_order-numbers">
            {orderHistory ? orderHistory.length : 0}
          </span>
        </div>
      </div>
      <div className="order-history_main">
        <Table dataSource={orderHistory} columns={columns} />
      </div>
    </WorkingHistoryWrapper>
  );
}

export default injectIntl(Orders);
