import React, { useState, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { useParams } from 'react-router-dom';
import { ModalServiceWrapper } from '../Styles';
import { Spin, Tabs, Button, Modal, Form, Row, Col } from 'antd';
import { injectIntl } from 'react-intl';
import styled from 'styled-components';
import messages from 'translations/messages';
import moment from 'moment';
import {
  TotalIcon,
  ArrowTotalIcon,
  PaperIcon,
  CardDetailIcon,
} from 'styles/icon-components';

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function ModalService(props) {
  const { intl, serviceItem, openService, onCancel } = props;
  const status = moment(serviceItem.expiredTime).isAfter(moment());
  return (
    <Modal
      title={null}
      visible={openService}
      onCancel={onCancel}
      width={600}
      centered
      footer={null}
    >
      <ModalServiceWrapper>
        <Row className="service-card__title title-global">
          <span>{intl.formatMessage(messages.detail)}</span>
        </Row>
        <Row className="service-card__name">
          <span>{serviceItem.productName}</span>
        </Row>
        <Row className="service-card__time">
          <Col className="code">
            <PaperIcon /> {serviceItem.qrCode.substring(serviceItem.qrCode.length - 9, serviceItem.qrCode.length)}
          </Col>
          <Col className="time">
            {moment(serviceItem.placedTime).format('DD/MM/YYYY - h:mm a')}
          </Col>
          <Col
            className={`service-card__status${
              status? ' active' : ' inactive'
            }`}
          >
            <span>
              <CardDetailIcon />
            </span>
            {status ? intl.formatMessage(messages.valid) : intl.formatMessage(messages.expired)}
            <span className="remain">{serviceItem.serviceItemQuantity}</span>
          </Col>
        </Row>
        {serviceItem.serves.map((s, index) => (
          <Row className={`service-card__history ${
            index === 0 ? ' first-row' : ''
          }${index === serviceItem.serves.length - 1 ? ' last-row' : ''}`}>
          <Col className="information">
            <div>{s.restaurantName}</div>
            <div>{moment(s.createdTime).format('DD/MM/YYYY')}</div>
          </Col>
          <Col className="quantity">
            <Row className="service-card__quantity">
              <Col className="used">
                <span>
                  <ArrowTotalIcon />
                  {s.quantity == 0 ? s.quantity : `-${s.quantity}`}
                </span>
              </Col>
            </Row>
          </Col>
        </Row>
        ))}
      </ModalServiceWrapper>
    </Modal>
  );
}

export default injectIntl(ModalService);
