import React, { useState } from 'react';
import styled from 'styled-components';
import { useDispatch } from 'react-redux';
import { useParams } from 'react-router-dom';
import _ from 'lodash';
import { ExclamationCircleOutlined } from '@ant-design/icons';
import { Button, Space, Modal } from 'antd';
import Avatar from 'react-avatar';
import { PUBLIC_API } from 'containers/App/urls';
import { Card as StyledCard } from 'styles/custom-styled-components';
import { RemoveIcon } from 'styles/icon-components';
import { initials } from 'utils/string';
import NumberFormat from 'react-number-format';
import { injectIntl } from "react-intl";
import DEFAULT_AVATAR from '../../../images/defaultAvatar.png';
import messages from "translations/messages";
import { extractPhoneNumber } from "utils/common";
import {
  removeStaffAssign
} from '../actions';


const HovereddCard = styled.div`
  position: relative;
  top: calc(-100px / 2 - 10px);
  text-align: center;
`;

interface Props {
  staff: any;
  roles: any;
  intl?: any;
}

const HoveredCard = injectIntl((props: Props) => {
  const { staff, intl } = props;
    // @ts-ignore
  const { id } = useParams();
  const dispatch = useDispatch();
  const handleClickRemove = () => {
    dispatch(removeStaffAssign(id, staff.id));
  }
  const confirm = () => {
    Modal.confirm({
      title: intl.formatMessage(messages.deleteConfirmMess),
      icon: <ExclamationCircleOutlined />,
      content: intl.formatMessage(messages.deleteConfirmContent, {name: `${staff.firstName ? staff.firstName : ''}${staff.lastName ? ' ' + staff.lastName : ''}`}),
      okText: intl.formatMessage(messages.deleteBtn),
      cancelText: intl.formatMessage(messages.cancelBtn),
      maskClosable: true,
      onOk: handleClickRemove
    });
  }
  return (
    <HovereddCard>
      <Space>
        <Button
          shape="circle"
          style={{ width: 50, height: 50 }}
          onClick={confirm}
        ><RemoveIcon /></Button>
      </Space>
    </HovereddCard >
  )
})

function CardDetail(props) {
  const { staff, roles } = props;
  const [code, number] = extractPhoneNumber(staff.phoneNumber, staff.phoneCountryCode);
  const {
    photo,
    phoneNumber,
    phoneCountryCode,
    firstName,
    lastName,
    roleIds = [],
  } = staff;
  const rolesNames = [...roleIds].map((id) => {
    const role = _.find(roles, role => role.id === id);
    return role ? role.name : null;
  }).filter(role => role !== null);
  return (
    <>
      <div className="restaurant-card__header">
        {photo ? <img className="image" src={`${PUBLIC_API}/${photo}`} /> : (firstName || lastName ? <Avatar className="image" name={`${firstName ? firstName : ''}${lastName ? ' ' + lastName : ''}`} size="70" initials={initials} /> : <img className="image" src={DEFAULT_AVATAR} />)}
        <div style={{ display: 'flex', flexDirection: 'column', justifyContent: 'space-between'}}>
          <span className="name title" style={{ alignSelf: 'flex-start' }}>{firstName ? firstName : ''}{lastName ? ' ' + lastName : ''}</span>
          {(rolesNames && rolesNames.length > 0  )&& <span className="role">{rolesNames.join(', ')}</span>}
          <span className="phone">{phoneNumber ? <NumberFormat value={number} displayType={'text'} format={ phoneCountryCode === "+84" ? "## ### ####" : "### ### ####"} renderText={value => `${phoneCountryCode} ${value}`}/> : ''}</span>
        </div>
      </div>
    </>
  )
}

export default function CardStaff(props: Props) {
  const { staff, roles } = props;
  const [ isHovered, setHovered ] = useState(false);

  return (
    <StyledCard
      isHovered={isHovered}
      onMouseOver={() => setHovered(true)}
      onMouseLeave={() => setHovered(false)}
      height="100px"
      className="touch-card"
    >
      <CardDetail staff={staff} roles={roles}/>
      {isHovered && <HoveredCard staff={staff} />}
    </StyledCard >
  )
}
