import React, { useState, useEffect } from 'react';
import { Modal, Button, Form, Select } from 'antd';
import { InputWrapper } from 'styles/custom-styled-components';
import { StaffModel } from 'containers/StaffList/types';
import { FormattedMessage, injectIntl } from 'react-intl';
import { useDispatch, useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import makeSelectCustomerDetail from '../selectors';
import { addStaffAssign } from '../actions';
import messages from 'translations/messages';
import _ from 'lodash';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createStructuredSelector({
  customerDetail: makeSelectCustomerDetail(),
});

interface Props {
  visible: boolean;
  onCancel: () => void;
  staffList: StaffModel[];
  intl: any;
}

const StaffAssign = (props: Props) => {
  const { visible, onCancel, intl } = props;
  const { customerDetail } = useSelector(stateSelector);
  const { isFetching, staffAssigns, customer } = customerDetail;
  const [form] = Form.useForm();
  const dispatch = useDispatch();
  const onFinish = async value => {
    form.resetFields();
    dispatch(addStaffAssign(customer?.id, value.staffIds));
    onCancel();
  };
  return (
    <Form form={form} name="restaurant-staff" onFinish={onFinish}>
      <Modal
        visible={visible}
        width={380}
        onCancel={onCancel}
        centered
        footer={[
          <Button
            type="primary"
            htmlType="submit"
            className="w-100"
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {});
            }}
          >
            <FormattedMessage {...messages.save} />
          </Button>,
        ]}
      >
        <>
          <h2 className="text-center">
            <FormattedMessage {...messages.addStaff} />
          </h2>
          <InputWrapper>
            <Form.Item
              name="staffIds"
              rules={[
                {
                  required: true,
                  message: <FormattedMessage {...messages.requiredStaff} />,
                },
              ]}
              className="mutil-select"
            >
              <FloatLabel
                className="padding-mutil-select"
                size="middle"
                label={intl.formatMessage(messages.staffPlaceHolder)}
                showSearch
                mode="multiple"
                showArrow
                filterOption={(inputValue, option) =>
                  option.props.children
                    .toUpperCase()
                    .indexOf(inputValue.toUpperCase()) !== -1
                }
                maxTagCount={2}
                typeInput="selectMutil"
                items={
                  staffAssigns.length
                    ? staffAssigns.filter(e => e && e.status && e.status.statusId !== 3).map(staff => {
                        const name = `${staff.firstName || ''} ${
                          staff.lastName || ''
                        } (${_.join(staff.roleNames, ', ')})`;
                        return { id: staff.id, name: name };
                      })
                    : []
                }
              />
            </Form.Item>
          </InputWrapper>
        </>
      </Modal>
    </Form>
  );
};
export default injectIntl(StaffAssign);
