import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import makeSelectCustomerDetail from './selectors';
import reducer from './reducer';
import saga from './saga';
import { useParams } from 'react-router-dom';
import Reputation from './Reputation';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import Information from './Information';
import Service from './Service';
import Gift from './Gift';
import Orders from './Orders';
import Staffs from './Staff';
import Notes from './Note';
import { PlusCharacter } from 'styles/icon-components';
import { CustomerDetailsWrapper } from './Styles';
import {
  getCustomer,
  getOrderHistory,
  resetStaff,
  getServiceItemHistory,
  getGiftCards,
  getStaffs,
  getNotes,
  getStaffAssigns,
} from './actions';
import cacheUtils from '../../utils/cacheUtils';
import StaffAssign from './Staff/staffAssign';
import AddNote from './Note/addNote';
import { Spin, Tabs, Button } from 'antd';
const { TabPane } = Tabs;
const stateSelector = createStructuredSelector({
  customerDetail: makeSelectCustomerDetail(),
});

interface Props {}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function CustomerDetail(props: Props) {
  useInjectReducer({ key: 'customerDetail', reducer: reducer });
  useInjectSaga({ key: 'customerDetail', saga: saga });

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const { customerDetail } = useSelector(stateSelector);
  const {
    isFetching,
    customer,
    orders,
    serviceItemHistories,
    giftCards,
    staffs,
    notes,
  } = customerDetail;
  const [ showPopUpStaff, setShowPopUpStaff] = useState(false);
  const [ showPopUpNote, setShowPopUpNote] = useState(false);
  const [ active, setActive] = useState<string>("1");
  const dispatch = useDispatch(); // eslint-disable-line @typescript-eslint/no-unused-vars
  // @ts-ignore
  const { id } = useParams();

  const handleChangeTab = (value) => {
    setActive(value);
  }
  const handleClickPlus = () => {
    console.log(" vào plus click ", active);
    active ===  '5' ? setShowPopUpStaff(true) : setShowPopUpNote(true);
  }
  const operationsSlot = ['5','6'].includes(active) ? (
    <Button size="large" type="primary" shape="circle" style={{ padding: 0 }} onClick={handleClickPlus}>
      <PlusCharacter />
    </Button>) : <></>;

  useEffect(() => {
    dispatch(getCustomer(id));
    dispatch(getServiceItemHistory(id));
    dispatch(getGiftCards(id));
    dispatch(getStaffs(id));
    dispatch(getNotes(id));
    dispatch(getOrderHistory(id, cacheUtils.getMerchantId()));
    return () => {
      dispatch(resetStaff());
    };
  }, []);

  return (
    <CustomerDetailsWrapper>
      <Spin spinning={isFetching}>
        {customer && (
          <>
            <Reputation customer={customer} />
            <div className="customer-tab">
              <Tabs
                className="tabCustorm"
                defaultActiveKey="1"
                tabBarExtraContent={operationsSlot}
                onChange={handleChangeTab}
              >
                <TabPane
                  tab={<FormattedMessage {...messages.information} />}
                  key="1"
                >
                  <Information customer={customer} />
                </TabPane>
                <TabPane
                  tab={<FormattedMessage {...messages.service} />}
                  key="2"
                >
                  <Service
                    serviceItemHistories={serviceItemHistories}
                    customer={customer}
                  />
                </TabPane>
                <TabPane
                  tab={<FormattedMessage {...messages.giftCard} />}
                  key="3"
                >
                  <Gift giftCards={giftCards} />
                </TabPane>
                <TabPane
                  tab={<FormattedMessage {...messages.purchasedHistory} />}
                  key="4"
                >
                  <Orders orderHistory={orders} />
                </TabPane>
                <TabPane
                  tab={<FormattedMessage {...messages.staffTakeCare} />}
                  key="5"
                >
                  <Staffs staffs={staffs} />
                </TabPane>
                <TabPane tab={<FormattedMessage {...messages.note} />} key="6">
                  <Notes notes={notes} />
                </TabPane>
              </Tabs>
            </div>
          </>
        )}
      <StaffAssign onCancel={() => setShowPopUpStaff(false)} visible={showPopUpStaff}/>
      <AddNote onCancel={() => setShowPopUpNote(false)} visible={showPopUpNote}/>
      </Spin>
    </CustomerDetailsWrapper>
  );
}

export default CustomerDetail;
