import { callApi, success } from '../../utils/apiUtils';
import { put, takeLatest, all, select } from 'redux-saga/effects';
import {
  getCustomersFail,
  getCustomersSuccess,
  getOrderHistoryFail,
  getOrderHistorySuccess,
  updateCustomerFail,
  updateCustomerSuccess,
  getPhoneCountriesSuccess,
  getPhoneCountriesFail,
  getServiceItemHistoryFail,
  getServiceItemHistorySuccess,
  getGiftCardsFail,
  getGiftCardsSuccess,
  getStaffs,
  getStaffsFail,
  getStaffsSuccess,
  getNotesSuccess,
  getNotesFail,
  getGiftCardFail,
  getGiftCardSuccess,
  getStaffAssignsFail,
  getStaffAssignsSuccess,
  removeStaffAssignSuccess,
  removeStaffAssignFail,
  addNoteSuccess,
  addNoteFail,
  getNotes,
  addStaffAssignFail,
  addStaffAssignSuccess
} from './actions';
import ActionTypes from './constants';
import { makeSelectLocale } from '../LanguageProvider/selectors';
import { apiError, apiSuccess } from '../App/actions';

const messages = [
  {"vi": "Cập nhật khách hàng thành công",
  "en": "Update customer successfully"},
  {"vi": "Cập nhật khách hàng thất bại",
  "en": "Update failed"},
]

export function* getCustomer({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${id}`,
      'GET',
    );
    if (success(code)) {
      yield put(getCustomersSuccess(data));
    } else {
      yield put(getCustomersFail(message));
    }
  } catch (error) {
    yield put(getCustomersFail(error.message));
  }
}

export function* updateCustomer({ payload: { id, customer } }) {
  const language = yield select(makeSelectLocale());
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${id}`,
      'PUT',
      customer,
      { isFormData: true },
    );
    if (success(code)) {
      yield put(updateCustomerSuccess(data));
      yield put(apiSuccess(messages[0][language]));
    } else {
      yield put(updateCustomerFail(message));
      yield put(apiError(messages[1][language]));
    }
  } catch (error) {
    yield put(updateCustomerFail(error.message));
    yield put(apiError(messages[1][language]));
  }
}

export function* addNote({ payload: { customerId, note } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${customerId}/note`,
      'POST',
      {note: note},
      { isFormData: true },
    );
    if (success(code)) {
      yield put(addNoteSuccess(data));
      yield put(getNotes(customerId));
    } else {
      yield put(addNoteFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(addNoteFail(error.message));
    yield put(apiError(error.message));
  }
}

export function* getOrderHistory({ payload: { customerIds, merchantId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/orders/user/order-history?userId=${customerIds}&merchantId=${merchantId}&status=7&limit=1000`,
      'GET',
    );
    if (success(code)) {
      yield put(getOrderHistorySuccess(data));
    } else {
      yield put(getOrderHistoryFail(message));
    }
  } catch (error) {
    yield put(getOrderHistoryFail(error.message));
  }
}

export function* getServiceItemHistory({ payload: { customerId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/orders/user/service-item-history?userId=${customerId}`,
      'GET',
    );
    if (success(code)) {
      yield put(getServiceItemHistorySuccess(data));
    } else {
      yield put(getServiceItemHistoryFail(message));
    }
  } catch (error) {
    yield put(getServiceItemHistoryFail(error.message));
  }
}

export function* getGiftCards({ payload: { customerId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/gift-cards/gift-card-users?userId=${customerId}`,
      'GET',
    );
    if (success(code)) {
      yield put(getGiftCardsSuccess(data.list));
    } else {
      yield put(getGiftCardsFail(message));
    }
  } catch (error) {
    yield put(getGiftCardsFail(error.message));
  }
}

export function* getGiftCard({ payload: { giftId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/gift-cards/gift-card-user/${giftId}`,
      'GET',
    );
    if (success(code)) {
      yield put(getGiftCardSuccess(data));
    } else {
      yield put(getGiftCardFail(message));
    }
  } catch (error) {
    yield put(getGiftCardFail(error.message));
  }
}

export function* getStaffLists({ payload: { customerId } }) {
  try {
    const [staffAssigns, staffs] = yield all ([
      callApi(`/users/customer/${customerId}/staffs`, 'GET'),
      callApi(`/users/staff-user?limit=1000`, 'GET'),
    ]);
    // yield put(getStaffsSuccess(fakeStaffs));
    if (success(staffAssigns.code)) {
      yield put(getStaffsSuccess(staffAssigns.data));
    } else {
      yield put(getStaffsFail(staffAssigns.message));
    }
    // yield put(getStaffsSuccess(fakeStaffs));
    if (success(staffs.code)) {
      const newList = staffs.data.list.filter(
        s => !staffAssigns.data.some(ss => ss.id === s.id),
      );
      yield put(getStaffAssignsSuccess(newList));
    } else {
      yield put(getStaffAssignsFail(staffAssigns.message));
    }
  } catch (error) {
    yield put(getStaffsFail(error.message));
  }
}

export function* addAssign({ payload: { customerId, staffIds } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${customerId}/assgin-staff`,
      'POST',
      {staffIds: staffIds}

    );
    if (success(code)) {
      yield put(addStaffAssignSuccess(message));
      yield put(getStaffs(customerId));
    } else {
      yield put(addStaffAssignFail(message));
    }
  } catch (error) {
    yield put(addStaffAssignFail(error.message));
  }
}

export function* removeStaffAssign({ payload: { customerId, staffId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${customerId}/staff/${staffId}`,
      'DELETE',
    );
    if (success(code)) {
      yield put(getStaffs(customerId));
    } else {
      yield put(removeStaffAssignFail(message));
    }
  } catch (error) {
    yield put(removeStaffAssignFail(error.message));
  }
}

export function* getNoteList({ payload: { customerId } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${customerId}/notes`,
      'GET',
    );
    // yield put(getNotesSuccess(fakeNotes));
    if (success(code)) {
      yield put(getNotesSuccess(data));
    } else {
      yield put(getNotesFail(message));
    }
  } catch (error) {
    yield put(getNotesFail(error.message));
  }
}

export function* getPhoneCountryCode() {
  try {
    const { code, data, message } = yield callApi(
      `/admin/setting/countries`,
      'GET',
    );
    if (success(code)) {
      yield put(getPhoneCountriesSuccess(data));
    } else {
      yield put(getPhoneCountriesFail(message));
    }
  } catch (error) {
    yield put(getPhoneCountriesFail(error.message));
  }
}

export default function* watchCustomerDetail() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_CUSTOMER, getCustomer);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_CUSTOMER, updateCustomer);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_ORDER_HISTORY, getOrderHistory);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_SERVICE_TIME_HISTORY, getServiceItemHistory);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_GIFT_CARD, getGiftCards);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_GIFT_CARD_DETAIL, getGiftCard);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFFS, getStaffLists);
  // @ts-ignore
  yield takeLatest(ActionTypes.ADD_STAFF_ASSIGN, addAssign);
  // @ts-ignore
  yield takeLatest(ActionTypes.REMOVE_STAFF_ASSIGN, removeStaffAssign);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_NOTES, getNoteList);
  // @ts-ignore
  yield takeLatest(ActionTypes.ADD_NOTES, addNote);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PHONE_COUNTRY, getPhoneCountryCode);
}
