import React, { useState } from "react";
import { useHistory } from "react-router-dom";
import { Button, Space, Modal } from "antd";
import { PUBLIC_API } from "containers/App/urls";
import { RoutePaths } from "containers/App/routes";
import { Card as StyledCard } from "styles/custom-styled-components";
import { EditIcon, RemoveIcon } from "styles/icon-components";
import NumberFormat from 'react-number-format';
import Avatar from "react-avatar";
import { initials } from "utils/string";
import { Customer } from "../types";
import { HovereddCard } from "../styles";
import { ExclamationCircleOutlined } from '@ant-design/icons';
import { FormattedMessage } from "react-intl";
import DEFAULT_AVATAR from '../../../images/defaultAvatar.png';
import messages from "translations/messages";
import { extractPhoneNumber } from "utils/common";


interface Props {
  customer: Customer;
  onClickRemove: any;
}

function HoveredCard(props: Props) {
  const { customer, onClickRemove } = props;
  const history = useHistory();
  const handleOnClickEdit = () => history.push(`${RoutePaths.customerDetail}/${customer.id}`);
  const handleClickRemove = () => {
    onClickRemove(customer.id);
  }
  const confirm = () => {
    Modal.confirm({
      title: <FormattedMessage {...messages.deleteConfirmMess}/>,
      icon: <ExclamationCircleOutlined />,
      content: <FormattedMessage {...messages.deleteConfirmCustomer}/>,
      okText: <FormattedMessage {...messages.deleteBtn}/>,
      cancelText: <FormattedMessage {...messages.cancelBtn}/>,
      maskClosable: true,
      onOk: handleClickRemove
    });
  }
  return (
    <HovereddCard>
      <Space>
        <Button
          shape="circle"
          style={{ width: 50, height: 50 }}
          onClick={handleOnClickEdit}
        ><EditIcon /></Button>
        <Button
          shape="circle"
          style={{ width: 50, height: 50 }}
          onClick={confirm}
        ><RemoveIcon /></Button>
      </Space>
    </HovereddCard >
  )
}

function CardDetail(props) {
  const { customer } = props;
  const [code, number] = extractPhoneNumber(customer.phoneNumber, customer.phoneCountryCode);
  const {
    photo,
    firstName,
    lastName,
    score
  } = customer;
  return (
    <>
      <div className="restaurant-card__header">
      {photo ? <img className="image" src={`${PUBLIC_API}/${photo}`} /> : (firstName || lastName ? <Avatar className="image" name={`${firstName ? firstName : ''}${lastName ? ' ' + lastName : ''}`} size="70" initials={initials} /> : <img className="image" src={DEFAULT_AVATAR} />)}
        <div style={{ display: 'flex', flexDirection: 'column', justifyContent: 'space-between' }}>
          <span className="name title" style={{ alignSelf: 'flex-start' }}>{[firstName, lastName].join(' ')}</span>
          <span className="score">{`${score} `}<FormattedMessage {...messages.points}/></span>
          <span className="phone">{number ? <NumberFormat value={number} displayType={'text'} format={code === "+84" ? "## ### ####" : "### ### ####"} renderText={value => `${code} ${value}`}/> : ''}</span>
        </div>
      </div>
    </>
  )
}

export default function Card(props: Props) {
  const { customer, onClickRemove } = props;
  const [ isHovered, setHovered ] = useState(false);

  return (
    <StyledCard
      isHovered={isHovered}
      onMouseOver={() => setHovered(true)}
      onMouseLeave={() => setHovered(false)}
      height="100px"
      className="touch-card"
    >
      <CardDetail customer={customer} />
      {isHovered && <HoveredCard customer={customer} onClickRemove={onClickRemove} />}
    </StyledCard >
  )
}
