import React from "react";
import { Button, Form, Input, Select } from "antd";
import { SearchOutlined } from "@ant-design/icons";
import { CustomerListHeaderWrapper } from "../styles";
import { injectIntl } from "react-intl";
import messages from "translations/messages";
import FloatLabel from 'components/FormatInput/FloatLabel';

function Header(props) {
  const { onClickSearch, mode, intl } = props;
  const [ form ] = Form.useForm();

  const handleOnClickSearch = (values) => {
    onClickSearch(values);
  }
  return (
    <CustomerListHeaderWrapper>
      <Form className="form" form={form} onFinish={handleOnClickSearch}>
        <h3 className="title-global-header">{intl.formatMessage(messages.customer)}</h3>
        <div className="filter">
          <Form.Item className="filter__mode" name="mode" initialValue="all">
            <FloatLabel className="customer-filters__restaurant" size="large" items={[...mode, {id: 'all', name: `${intl.formatMessage(messages.allSelect)} ${intl.formatMessage(messages.customer).toLowerCase()}`}]} typeInput="selectMutil"
              label={intl.formatMessage(messages.customer)}
            />
          </Form.Item>
          <div className="filter__search">
            <Form.Item className="filter__input" name="search">
              <FloatLabel  size="large" width={300} label={intl.formatMessage(messages.search)} prefix={<SearchOutlined />} />
            </Form.Item>
            <Button className="filter__submit" size="large" type="primary" htmlType="submit">{intl.formatMessage(messages.search)}</Button>
          </div>
        </div>
      </Form>
    </CustomerListHeaderWrapper>
  )
}
export default injectIntl(Header);
