
/*
 *
 * CustomerList reducer
 *
 */

import ActionTypes from './constants';
import { ContainerState, ContainerActions } from "./types";
import _ from "lodash";

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  loadMore: false,
  message: '',
  customers: [],
  mode: [
    { id: 'top10', name: 'Top 10' },
    { id: 'top30', name: 'Top 30' },
    { id: 'top50', name: 'Top 50' },
  ],
  filter: {
    mode: 'all',
    search: ''
  },
  paging: {
    page: 1,
    limit: 40,
    total: 0,
  }
};

function customerListReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_CUSTOMERS:
      const { loadMore } = action.payload;
      if (loadMore) {
        return { ...state, loadMore };
      } else {
        return { ...state, isFetching: true };
      }
    case ActionTypes.SET_PAGING:
      return { ...state, paging: action.payload };
    case ActionTypes.SET_FILTER:
      return { ...state, filter: action.payload  };
    case ActionTypes.GET_CUSTOMERS_SUCCESS:
      if (state.loadMore) {
        return { ...state, customers: state.customers.concat(action.payload.list), loadMore: false };
      } else {
        return { ...state, customers: action.payload.list, isFetching: false };
      }
    case ActionTypes.GET_CUSTOMERS_FAIL:
      return { ...state, message: action.payload, isFetching: false, loadMore: false };
    case ActionTypes.DELETE_CUSTOMER:
      return { ...state, isFetching: true };
    case ActionTypes.DELETE_CUSTOMER_SUCCESS: {
      _.remove(state.customers, { id: action.payload });
      return { ...state, isFetching: false, customers: state.customers };
    }
    case ActionTypes.DELETE_CUSTOMER_FAIL:
      return { ...state, isFetching: false };
    default:
      return state;
  }
}

export default customerListReducer;
