import { callApi } from "../../utils/apiUtils";
import { HTTP_STATUS_ACCEPTED } from "../../utils/constants";
import { put, takeLatest } from "redux-saga/effects";
import { deleteCustomerFail, deleteCustomerSuccess, getCustomersFail, getCustomersSuccess, setPaging } from "./actions";
import ActionTypes from "./constants";

export function* getCustomers({ payload: {mode, searchText, page = 1, limit = 30} }) {
  try {
    const searchParams = new URLSearchParams();
    if (mode) {
      searchParams.append('mode', mode);
    }
    if (searchText) {
      searchParams.append('searchText', searchText);
    }
    searchParams.append('page', page.toString());
    searchParams.append('limit', limit.toString());
    const { code, data, message } = yield callApi(
      `/users/customers?${searchParams.toString()}`,
      'GET'
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      yield put(getCustomersSuccess(data));
      yield put(setPaging(page, limit, +data.total));
    } else {
      yield put(getCustomersFail(message));
    }
  } catch (error) {
    yield put(getCustomersFail(error.message));
  }
}

export function* removeCustomer({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/customer/${id}`,
      'DELETE'
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      yield put(deleteCustomerSuccess(id))
    } else {
      yield put(deleteCustomerFail(message))
    }
  } catch (error) {
    yield put(deleteCustomerFail(error.message));
  }
}

export default function* watchCustomer() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_CUSTOMERS, getCustomers);
  // @ts-ignore
  yield takeLatest(ActionTypes.DELETE_CUSTOMER, removeCustomer)
}
