import React, { useRef } from 'react';
import { Line } from 'react-chartjs-2';
import { Card,Typography, Tabs, Space } from 'antd';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';

export function RevenueLineChart(props) {
  const { lineChartRevenueList } = props;
  let refContainer = useRef(null);
  const { Title } = Typography;
  return (
    <Card >
      <div className="line-chart__title">
        <Space align='center'>
        <Title level={4}><FormattedMessage {...messages.titleRevenueLineChart} /></Title>
        </Space>
      </div>
      <Line
        ref={refContainer}
        data={{
          labels: lineChartRevenueList.labels,
          datasets: lineChartRevenueList.datasets,
        }}
        height={300}
        width={500}
        options={{
          responsive: true,
          maintainAspectRatio: true,
          title: {
            display: false,
            text: 'Doanh thu',
          },
          legend: {
            display: false,
            position: 'bottom',
          },
          elements: {
            point:{
                radius: 0
            }
          },
          scales: {
            xAxes: [{ 
                display: true,
                gridLines: {
                    borderDash: [2,2],
                    display: true,
                    fontColor: "#CCC",
                },
                ticks: {
                  stepSize: 1,
                  fontColor: "#CCC",
                  autoSkip: false,
                  maxRotation: 0,
                  minRotation: 0,
                },
            }],
            yAxes: [{
                display: true,
                gridLines: {
                    borderDash: [2,2],
                    display: true,
                    fontColor: "#CCC",
                },
                ticks: {
                  callback: function(value, index, values) {
                    return new Intl.NumberFormat().format(value);
                  }
                },
            }],
        }
        }}
      />
    </Card>
  );
}
