import React, { useRef, useEffect } from 'react';
import { RevenueItemModel } from '../revenueModels';
import styled from 'styled-components';
import { Card, Table, Typography } from 'antd';
import NumberFormat from 'react-number-format';
import { FormattedMessage } from 'react-intl';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import messages from 'translations/messages';
interface Props {
  itemList: RevenueItemModel;
}
const RevenueItemWrapper = styled.div`
.ant-card-body {
  padding: 24px 0px 24px 0px;
}
.ant-table-thead th{
  font-weight: 600;
}
.ant-table-wrapper {
  font-size: 13px;
}
.ant-spin-container, .ant-spin-nested-loading, .ant-table, .ant-table-container, .ant-table-content, table, ant-table-tbody, .ant-table-tbody .ant-table-cell, .ant-table-row {
  font-size: 1em !important;
  line-height: 1.0625em;
}
`;

const { Title } = Typography;

export function RevenueItem(props) {
  const currencyMemoi = useCurrencyHook();
  const { itemList } = props;

  const columns = [
    {
      title: <FormattedMessage {...messages.titleItemTableMenuNm} />,
      dataIndex: 'itemName',
      colSpan: 1,
      width: '60%',
      render: (text, row, index) => {
        return {
          children: <span>{text}</span>,
          props: {
            colSpan: 1,
          },
        };
      },
    },
    {
      title: <FormattedMessage {...messages.titleItemTableQuantity} />,
      dataIndex: 'quantity',
      colSpan: 1,
      width: '20%',
      render: (text, row, index) => {
        return {
          children: <span><NumberFormat value={text} displayType={'text'} thousandSeparator={true} renderText={value => value} >{text}</NumberFormat></span>,
          props: {
            colSpan: 1,
          },
        };
      },
    },
    {
      title: <FormattedMessage {...messages.titleItemTableRevenue} />,
      dataIndex: 'revenue',
      colSpan: 1,
      width: '20%',
      render: (text, row, index) => {
        return {
          children: <span style={{color: '#DC5454'}}><NumberFormat value={text} displayType={'text'} thousandSeparator={true} renderText={value => `${value} ${currencyMemoi}`} >{text}</NumberFormat></span>,
          props: {
            colSpan: 1,
          },
        };
      },
    },
  ];

  useEffect(() => {}, []);
  return (
    <RevenueItemWrapper>
        <Card>
          <div className="item-list__title">
            <Title level={4}><FormattedMessage {...messages.titleMainItemTable} /></Title>
          </div>
          <Table
            rowClassName={(record, index) => index === 0 ? 'header-row' : 'cell-row' }
            columns={columns}
            dataSource={itemList}
            pagination={false}
            bordered={false}
          />
        </Card>
    </RevenueItemWrapper>
  );
}
