import React, { useState, useRef, useEffect } from 'react';
import { Doughnut } from 'react-chartjs-2';
import { Card, Row, Col, Space, Typography } from 'antd';
import 'chartjs-plugin-labels';
import NumberFormat from 'react-number-format';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import NODATA_PIE_CHART from '../../../images/pie-chart.svg';

export function RevenueMethod(props) {
  const { doughnutChartMethodList, isEmptyChart } = props;
  // const { revenueBranch } = props;
  let refContainer = useRef();
  const [legend, setLegend] = useState(<> no legend </>);

  const valueAsPercentage = (value, total) => {
    return ((value / total) * 100);
  };
  const createMarkup = () => {
    return legend;
  };

  const { Title } = Typography;

  useEffect(() => {
    const leg = isEmptyChart ? '' : generateLegend();
    setLegend(leg);
  }, []);

  const generateLegend = () => {
    if (!refContainer) return null;
    return (refContainer as any).chartInstance.generateLegend();
  };
  const setTextInputRef = element => {
    refContainer = element;
  };

  return (
    <Card>
      <div className="pie-method-chart__title">
        <Space align="center">
          <Title level={4}>
            <FormattedMessage {...messages.titleRevenueMethod} />
          </Title>
          {/* <TabsLine /> */}
        </Space>
      </div>
      {isEmptyChart && <>
          <div style={{textAlign: 'center', paddingBottom: '20px'}}><img src={NODATA_PIE_CHART} style={{ width: '80%' }} /></div>
          <Row gutter={[0, 20]} justify="space-around">
                      <Col offset={3} />
                      <Col span={9}>
                        <span style={{ color: '#333333' }}> <FormattedMessage {...messages.service} /></span>
                      </Col>
                      <Col offset={3} />
                      <Col span={9}>
                        <span style={{ color: '#333333' }}> <FormattedMessage {...messages.product} /></span>
                      </Col>
                </Row>
                <Row gutter={[0, 20]} justify="space-around">
                  <>
                      <Col offset={3} />
                      <Col span={9}>
                        <span className='revenue-chart-method'

                        >
                          <NumberFormat
                            value={0}
                            displayType={'text'}
                            thousandSeparator={true}
                            renderText={value => value}
                          />
                        </span>
                      </Col>
                    </>
                    <>
                      <Col offset={3} />
                      <Col span={9}>
                        <span className='revenue-chart-method'

                        >
                          <NumberFormat
                            value={0}
                            displayType={'text'}
                            thousandSeparator={true}
                            renderText={value => value}
                          />
                        </span>
                      </Col>
                    </>
                </Row>
      </>}
      {!isEmptyChart && <><Doughnut
        ref={element => setTextInputRef(element)}
        data={{
          labels: [...(doughnutChartMethodList['label'] || [])],
          datasets: [
            {
              label: 'Doanh thu mang đi với chuỗi kinh doanh',
              backgroundColor: ['#09A9F3', '#BD10E0'],
              data: [...(doughnutChartMethodList['data'] || [])],
              pointStyle: 'circle',
            },
          ],
        }}
        height={200}
        width={327}
        options={{
          responsive: true,
          maintainAspectRatio: true,
          legend: {
            display: false,
          },
          legendCallback: function (chart) {
            return (
              <>
                <Row gutter={[0, 20]} justify="space-around">
                  {chart.data.labels.map(label => (
                    <>
                      <Col offset={3} />
                      <Col span={9}>
                        <span style={{ color: '#333333' }}>{label}</span>
                      </Col>
                    </>
                  ))}
                </Row>
                <Row gutter={[0, 20]} justify="space-around">
                  {chart.data.datasets[0].data.map((data, index) => (
                    <>
                      <Col offset={3} />
                      <Col span={9}>
                        <span className='revenue-chart-method'
                          style={{
                            color:
                              chart.data.datasets[0].backgroundColor[index]
                          }}
                        >
                          <NumberFormat
                            value={data ? Math.round(data) : 0}
                            displayType={'text'}
                            thousandSeparator={true}
                            renderText={value => value}
                          />
                        </span>
                      </Col>
                    </>
                  ))}
                </Row>
              </>
            );
          },
          plugins: {
            labels: {
              render: 'percentage',
              fontColor: ['white', 'white'],
              precision: 1,
            },
          },
          cutoutPercentage: 30,
        }}
      />
      <div className="legend-doughnut">{createMarkup()}</div>
      </>}
    </Card>
  );
}
