import React from 'react';
import { RevenueReviewModel } from '../revenueModels';
import { Card, Col, Space } from 'antd';
import { ArrowUpOutlined, ArrowDownOutlined } from '@ant-design/icons';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import NumberFormat from 'react-number-format';
interface Props {
  revenueReview: RevenueReviewModel;
}

export function RevenueReviewCard(props: Props) {
  const currencyMemoi = useCurrencyHook();
  const { revenueReview } = props;
  const { revenueTitle, totalAmountCurrent, percentAmount, totalAmountPrevious } = revenueReview;
  return (
    <Col xl={6} lg={12} md={12} sm={12} xs={12}>
      <Card bodyStyle={{ padding: 12 }}>
        <div className="revenue-card__info">
          <span className="revenue-card__date__info--title">
            {revenueTitle}
          </span>
        </div>
        <div className="revenue-card__info">
          <span className="revenue-card__info--revenue">
            <NumberFormat
              value={totalAmountCurrent}
              decimalScale={1}
              displayType={'text'}
              thousandSeparator={true}
              renderText={value => `${value} ${currencyMemoi}`}
            />
          </span>
        </div>
        <div className="revenue-card__info">
          <Space align="end">
            <span className="revenue-card__info--stroke">
              {totalAmountPrevious !== 0 && percentAmount < 0 &&
                <ArrowDownOutlined style={{ color: 'red'}} />
              }
              {totalAmountPrevious !== 0 && percentAmount >= 0 &&
                <ArrowUpOutlined style={{ color: percentAmount === 0 ? 'gray' : 'green'}} />
              }
            </span>
            <span className="revenue-card__info--percent" style={{color: percentAmount < 0 ? 'red' : (percentAmount === 0 ? 'gray' : 'green'),}}>
              {totalAmountPrevious !== 0 && `${Math.abs(percentAmount)}%`}
            </span>
          </Space>
        </div>
      </Card>
    </Col>
  );
}
