import React, { useEffect, useState } from 'react';
import { RevenueChart } from './revenueChart';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import makeSelectDashboard from './selectors';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from './reducer';
import saga from './saga';

import { RevenueReview } from './revenueReview';
import { RevenueBranch } from './revenueBranch';
import { RevenueMethodItem } from './revenueMethodItem';
import { USER_INFO_KEY } from 'containers/App/constants';
import styled from 'styled-components';
import _ from 'lodash';
import { Spin } from 'antd';
import moment from 'moment-timezone';
import { formatMomentMinDate, formatMomentMaxDate } from 'utils/common'
import { getMerchantRevenue, getStoreRevenue } from './actions';
const stateSelector = createStructuredSelector({
  dashboard: makeSelectDashboard(),
});

const Chart = require('react-chartjs-2').Chart;
const DashBoardWrapper = styled.div`
background: #ececec;
  padding: 20px;
  font-family: Muli !important;
  font-size: 13px;
  font-weight: 400;
  line-height: 20px;
  text-align: left !important;
  .ant-card {
    color: #333333;
    line-height: 1.25em;
    border-radius: 0px;
  }
  .list-store-revenue {
    display: flex;
    flex-wrap: wrap;
    padding-left: 0;
    .store {
      text-align: left;
    }
    div.store-detail {
      margin-top: 30px;
      position: relative;
      display: flex;
    }
    .revenue-card{
        &__info {
          padding 5px;
          text-align: center;
        }
      }
    }
  }
  .list-branch-revenue {
    display: flex;
    flex-wrap: wrap;
    padding-left: 0;
    .store {
      text-align: left;
    }
    .revenue-card{
        &__info {
          padding: 10px;
          padding-top: 15px;
          text-align: center;
          white-space: break-spaces;
          &--title {
            line-height: 20px;
          }
        }
      }
    }
  }
`;

export function DashBoard(props) {
  const userInfoString = localStorage.getItem(USER_INFO_KEY);
  const userInfo = JSON.parse(userInfoString!);
  const { merchantId } = userInfo.profile!;
  useInjectReducer({ key: 'dashboard', reducer: reducer });
  useInjectSaga({ key: 'dashboard', saga: saga });

  const { dashboard } = useSelector(stateSelector);
  const {
    isFetching,
    isFetchingReview,
    donutRevenueResChart,
    reviewTab,
    LineRevenueResChart,
    branchList,
    message,
  } = dashboard;
  const dispatch = useDispatch();
  useEffect(() => {
    const dateTo = formatMomentMaxDate(moment());
    const dateFrom = formatMomentMinDate(moment()
      .startOf('month'));
    const dateRage = { dateFrom: dateFrom, dateTo: dateTo };
    dispatch(getMerchantRevenue(dateRage, merchantId));
    dispatch(getStoreRevenue(dateRage, merchantId));
  }, []);
  return (
    <DashBoardWrapper>
      {isFetchingReview && isFetching && (
        <div
          style={{
            flex: 1,
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
            justifyContent: 'center',
            height: '50px',
          }}
        >
          <Spin />
        </div>
      )}
    {!isFetchingReview && !isFetching && (
        <>
          <div className="list-store-revenue">
            <RevenueReview merchantId={merchantId} reviewTab={reviewTab} />
          </div>
          <div className="chart-revenue">
            <RevenueChart
              merchantId={merchantId}
              donutRevenueResChart={donutRevenueResChart}
              lineRevenueResChart={LineRevenueResChart}
            />
          </div>
          <div className="list-branch-revenue">
            <RevenueBranch merchantId={merchantId} branchList={branchList} />
          </div>
          <div className="method-item-revenue">
            <RevenueMethodItem merchantId={merchantId} />
          </div>
        </>
      )}
    </DashBoardWrapper>
  );
}
