/*
 *
 * CustomerList reducer
 *
 */

import ActionTypes from './constants';
import { ContainerState, ContainerActions } from './types';
import _ from 'lodash';

export const initialState: ContainerState = {
  default: null,
  isFetchingReview: true,
  isFetching: true,
  isFetchingItem: true,
  isFetchingMethod: true,
  donutRevenueResChart: [],
  reviewTab: null,
  LineRevenueResChart: null,
  branchList: [],
  message: '',
  item: [],
  method: [],
};

function dashboardReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_MERCHANT_REVENUE:
      return { ...state, isFetching: true };
    case ActionTypes.GET_MERCHANT_REVENUE_SUCCESS:
      return {
        ...state,
        LineRevenueResChart: action.payload,
        isFetching: false,
      };
    case ActionTypes.GET_MERCHANT_REVENUE_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_STORE_REVENUE:
      return { ...state, isFetchingReview: true, };
    case ActionTypes.GET_STORE_REVENUE_SUCCESS: {
      return {
        ...state,
        isFetchingReview: false,
        donutRevenueResChart: action.payload.avgMonth.dataRevenueFrom,
        reviewTab: action.payload,
        branchList: action.payload.avgMonth.dataRevenueFrom,
      };
    }
    case ActionTypes.GET_STORE_REVENUE_FAIL:
      return { ...state, isFetchingReview: false };
    case ActionTypes.GET_METHOD:
      return { ...state, isFetchingMethod: true, };
    case ActionTypes.GET_METHOD_SUCCESS: {
      return {
        ...state,
        isFetchingMethod: false,
        method: action.payload,
      };
    }
    case ActionTypes.GET_METHOD_FAIL:
      return { ...state, isFetchingMethod: false };
    case ActionTypes.GET_ITEM:
      return { ...state, isFetchingItem: true, };
    case ActionTypes.GET_ITEM_SUCCESS: {
      return {
        ...state,
        isFetchingItem: false,
        item: action.payload,
      };
    }
    case ActionTypes.GET_ITEM_FAIL:
      return { ...state, isFetchingItem: false };
    default:
      return state;
  }
}

export default dashboardReducer;
