import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import { COLOR_CHART } from 'containers/App/constants';
import NODATA_CHART from '../../images/nodata.svg';
import NODATA_PIE_CHART from '../../images/pie-chart.svg';
import { Row, Col } from 'antd';
import * as Moment from 'moment';
import { extendMoment } from 'moment-range';
import { DatasetModel } from './types';
const _ = require('lodash');

const moment = extendMoment(Moment);
import { RevenueLineChart, RevenuePieChart } from './RevenueChart/index';
const RevenueChartWrapper = styled.div`
  font-size: 1vw;
  .ant-col.ant-col-8 .ant-card-body {
    padding: 1.5em 1.25em;
  }
  .ant-card {
    line-height: 0.9375em;
    font-size: 13px;
    .ant-card-body {
      font-size: 13px;
    }
  }
  .line-chart__title {
    position: relative;
    h4 {
      color: #333333;
      font-size: 1.46em;
      font-weight: 600;
      padding-left: 2.5em;
      text-align: left;
    }
    .ant-tabs.ant-tabs-top {
      position: absolute;
      right: 0px;
      top: -25px;
    }
  }
  .legend-doughnut {
    margin-top: 2.875em;
    div.doughnut-legend {
      padding: 0px;
      list-style: none;
    }
    div.doughnut-legend div.wrapper-legend {
      margin: 0.3em 0;
    }
    div.doughnut-legend div.wrapper-legend {
      display: inline-flex;
      flex-flow: wrap;
      width: 100%;
      div {
        text-align: end;
      }
      .bullet-doughnut {
        border-radius: 100%;
        width: 0.625em;
        height: 0.625em;
        float: left;
        margin-right: 1em;
        position: relative;
        top: 0.125em;
      }
      .branch-doughnut {
        display: -webkit-box;
        max-width: 50%;
        width: 50%;
        -webkit-line-clamp: 1;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
        text-align: left;
      }
      .percent-data {
        width: 35%;
      }
    }
    div {
      text-align: center;
      button.ant-btn-link {
        font-size: 0.87em;
        height: 2em;
        padding: 0.5em 0.9375em;
        border-radius: 1.25em;
        span {
          font-size: 0.87em;
        }
      }
    }
  }
  @media only screen and (min-width: 200px) {
    font-size: 3vw;
    .ant-col.ant-col-7,
    .ant-col.ant-col-17 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      margin-bottom: 15px;
    }
  }
  @media only screen and (min-width: 425px) {
    font-size: 2.5vw;
    .ant-col.ant-col-7,
    .ant-col.ant-col-17 {
      flex: none;
      max-width: none;
      width: 100%;
      margin-bottom: 15px;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 785px) {
    font-size: 1.3vw;
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 876px) {
    font-size: 1.2vw;
  }
  @media only screen and (min-width: 1325px) {
    font-size: 1vw;
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 1680px) {
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
`;

export function RevenueChart(props) {
  const { lineRevenueResChart = [], donutRevenueResChart = [] } = props;
  const [loading, setLoading] = useState(true);
  const [isOnly, setIsOnly] = useState(false);
  const [lineChartRevenueList, setLineChartRevenueList] = useState({
    labels: [] as string[],
    datasets: [] as DatasetModel[],
  });
  const [pieChartRevenueList, setPieChartRevenueList] = useState({
    label: [],
    data: [],
    color: [],
    indexResColor: [],
  });
  const getChartRevenueList = async type => {
    let indexColor;
    let pieChartFormat = {} as any;
    if (!_.isEmpty(donutRevenueResChart)) {
      const sortData = donutRevenueResChart.sort((a, b) => {
        return b.amount - a.amount;
      });
      pieChartFormat = sortData.reduce(
        (accumulator, currentValue, currentIndex) => {
          indexColor = currentIndex % COLOR_CHART.length;
          accumulator['label'].push(currentValue.name);
          accumulator['data'].push(currentValue.amount);
          accumulator['color'].push(COLOR_CHART[indexColor].borderColor);
          accumulator['indexResColor'].push({
            name: currentValue.name,
            indexColor: indexColor,
          });
          return accumulator;
        },
        { label: [], data: [], color: [], indexResColor: [] },
      );
      if (donutRevenueResChart.length > 1) {
        setPieChartRevenueList(pieChartFormat);
      }
      if (donutRevenueResChart.length === 1) {
        setIsOnly(true);
      }
    }

    let dateLabelList = [] as any;

    const lineChartFormat = lineRevenueResChart.restaurantData.reduce(
      (accumulator, currentValue, currentIndex) => {
        // indexColor = currentIndex % COLOR_CHART.length;
        const datasetFormat =
          currentValue.revenues.length === 0
            ? { dataList: dateLabelList.map(ele => 0), indexArr: [] }
            : currentValue.revenues.reduce(
                (accumulatorDate, currentValueDate, currentIndexDate) => {
                  const index = dateLabelList.findIndex(
                    ele => ele === Object.keys(currentValueDate)[0],
                  );
                  if (currentIndex === 0) {
                    dateLabelList.push(Object.keys(currentValueDate)[0]);
                  }
                  if (index !== -1) {
                    accumulatorDate.indexArr.push(index);
                    accumulatorDate.dataList[index] = Object.values(
                      currentValueDate,
                    )[0];
                  }
                  return accumulatorDate;
                },
                { dataList: [...dateLabelList], indexArr: [] },
              );
        const indexColor = _.isEmpty(donutRevenueResChart)
          ? currentIndex % COLOR_CHART.length
          : pieChartFormat.indexResColor.filter(
              idx => idx.name === currentValue.restaurant.name,
            )[0].indexColor;
        const dataset = {
          data: datasetFormat.dataList.map((data, index) =>
            datasetFormat.indexArr.includes(index) ? data : 0,
          ),
          label: currentValue.restaurant.id,
          borderColor: COLOR_CHART[indexColor].borderColor,
          backgroundColor: COLOR_CHART[indexColor].backgroundColor,
          borderWidth: 0,
          pointBackgroundColor: 'rgba(19, 247, 228,1)',
          pointBorderColor: 'rgba(19, 247, 228,1)',
          pointBorderWidth: 2,
          fill: 'origin',
        };
        accumulator.push(dataset);
        return accumulator;
      },
      [],
    );
    let dateCountList;
    const formatLabel = div => {
      const divNumber = Math.floor(dateLabelList.length / div);
      return dateLabelList.map((d, index, array) =>
        index % divNumber === 0 || index === array.length - 1 ? d : '',
      );
    };
    if (
      !moment().isSame(moment().startOf('month'), 'day')
    ) {
      if (dateLabelList.length > 15) {
        dateCountList = formatLabel(5);
      } else {
        dateCountList = dateLabelList
      }
    } else {
      dateCountList = dateLabelList;
    }
    const dateLabelListPlusDate = dateCountList;
    const sortResData = lineChartFormat.sort((resA, resB) => {
      return (
        resA.data.reduce((a, b) => a + b, 0) -
        resB.data.reduce((a, b) => a + b, 0)
      );
    });
    const dataLineChart = {
      labels: dateLabelListPlusDate,
      datasets: sortResData,
    };
    setLineChartRevenueList(dataLineChart);
    setLoading(false);
  };

  useEffect(() => {
    getChartRevenueList('day');
  }, []);
  const spanLineByResCount = isOnly ? 24 : 17;
  return (
    <RevenueChartWrapper>
      {!loading && (
        <Row gutter={[6, 6]}>
          <>
            {!_.isEmpty(lineChartRevenueList.datasets) &&
            !_.isEmpty(lineChartRevenueList.labels) &&
            !lineChartRevenueList.datasets.every(data =>
              data.data.every(d => Number(d) === 0),
            ) ? (
              <Col span={spanLineByResCount}>
                <RevenueLineChart lineChartRevenueList={lineChartRevenueList} />
              </Col>
            ) : (
              <Col span={spanLineByResCount}>
                <img src={NODATA_CHART} style={{ width: '100%' }} />
              </Col>
            )}
            {!_.isEmpty(pieChartRevenueList.data) &&
            !_.isEmpty(pieChartRevenueList.label) &&
            !pieChartRevenueList.data.every(data => data == 0) ? (
              !isOnly ? (
                <Col span={24 - spanLineByResCount}>
                  <RevenuePieChart pieChartRevenueList={pieChartRevenueList} />
                </Col>
              ) : (
                <></>
              )
            ) : (
              <Col span={24 - spanLineByResCount}>
                <div style={{ height: '100%', backgroundColor: 'white', textAlign: 'center', paddingBottom:'20px'}}>
                  <img src={NODATA_PIE_CHART} style={{ width: '65%' }} />
                </div>
              </Col>
            )}
          </>
        </Row>
      )}
    </RevenueChartWrapper>
  );
}
