import React, { useState, useEffect } from 'react';

import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import makeSelectDashboard from './selectors';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from './reducer';
import saga from './saga';
import NODATA_PIE_CHART from "../../images/nodata-method.svg";
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';

import styled from 'styled-components';
import { Row, Col, Spin } from 'antd';
import { RevenueItem, RevenueMethod } from './RevenueMethodItem/index';
import { getMethod, getItem } from "./actions";

const stateSelector = createStructuredSelector({
  dashboard: makeSelectDashboard(),
});



const _ = require('lodash');
// import { FormattedMessage } from 'react-intl';
// import messages from 'translations/messages';
const RevenueMethodItemWrapper = styled.div`
font-size: 1vw; 
  .ant-card {
    font-size: 13px;
    .ant-card-body {
      font-size: 13px;
    }
  }
  .item-list__title {
    font-size: 1.15em;
    font-weight: 700;
    padding: 16px;
  }
  .legend-doughnut {
    margin: 5px;
    padding-top: 15px
  }
  .pie-method-chart__title {
    h4 {
      font-size: 1.36em;
      font-weight: 700;
      line-height: 19px;
      margin-bottom: 1.5em;
    }
  }
  @media only screen and (min-width: 200px){
    font-size: 2.5vw;
    .item-list__title {
      .ant-typography {
        font-size: 1.15em;
        font-weight: 700;
        line-height: 1.25em;
        padding: 1em;
      }
    }
    .ant-col.ant-col-8, .ant-col.ant-col-16 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .revenue-chart-method {
      font-size: small;
      font-weight: 600;
      line-height: 1.5em;
    }
  }
  @media only screen and (min-width: 425px){
    .ant-col.ant-col-8, .ant-col.ant-col-16 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .revenue-chart-method {
      font-size: x-large;
      font-weight: 600;
      line-height: 1.5em;
    }
  }
  }
  @media only screen and (min-width: 785px){
    font-size: 1.3vw;
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        .ant-col.ant-col-9 {
          font-size: 0.9375em;
          line-height: 1.0625em;
        }
        .revenue-chart-method {
          font-size: 0.9375em;
        }
        height: 435px;
      }
    }
    .ant-col.ant-col-16 {
      font-size: 0.9375em;
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 435px;
      }
    }
  }
  @media only screen and (min-width: 876px) {
    font-size: 1.2vw;
  }
  @media only screen and (min-width: 1325px){
    font-size: 1vw;
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 500px;
      }
    }
    .ant-col.ant-col-16 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 500px;
      }
    }
  }
  @media only screen and (min-width: 1680px){
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 800px;
      }
    }
    .ant-col.ant-col-16 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 800px;
      }
    }
  }
`;

export function RevenueMethodItem(props) {
  const { merchantId } = props;
  const [isEmptyChart, setEmptyChart] = useState(true);
  const [doughnutChartMethodList, setDoughnutChartMethodList] = useState(
    {} as any,
  );
  useInjectReducer({ key: 'dashboard', reducer: reducer });
  useInjectSaga({ key: 'dashboard', saga: saga });

  const { dashboard } = useSelector(stateSelector);
  const { isFetchingItem, isFetchingMethod, item, method } = dashboard;
  const dispatch = useDispatch();
  const setMethodItem = async () => {
    if (method) {
      const chartFormat = _.isEmpty(method) ? [] : method.reduce(
        (accumulator, currentValue, currentIndex) => {
          const orderTyNm =
            currentValue.orderType == 'service' ? (
              <FormattedMessage {...messages.service} />
            ) : (
              <FormattedMessage {...messages.product} />
            );
          accumulator['label'].push(orderTyNm);
          accumulator['data'].push(currentValue.amount);
          return accumulator;
        },
        { label: [] as string [], data: [] as number []} as any,
      );
      if (!_.isEmpty(chartFormat.data) && 
        !chartFormat.data.every(d => parseFloat(d) === 0)) {
          setEmptyChart(false);
      } else {
        setEmptyChart(true);
      }
      setDoughnutChartMethodList(chartFormat);
    }
  };

  useEffect(() => {
      dispatch(getItem(merchantId));
      dispatch(getMethod(merchantId));
  }, []);

  useEffect(() => {
    setMethodItem();
  }, [method, item]);

  return (
    <RevenueMethodItemWrapper>
      {/*{isFetchingItem|| isFetchingMethod && (*/}
      {/*  <div style={{ textAlign: 'center', top: '20px', position: 'relative' }}>*/}
      {/*    <Spin spinning />*/}
      {/*  </div>*/}
      {/*)}*/}
      {
        (isFetchingItem || isFetchingMethod) && <div className='d-flex column align-item-center'><Spin spinning/></div>
      }


      {!isFetchingItem && !isFetchingMethod && (
        <Row gutter={6}>
          <Col span={16}>
            <RevenueItem itemList={item} />
          </Col>
          <Col span={8}>
            {<RevenueMethod doughnutChartMethodList={doughnutChartMethodList} isEmptyChart={isEmptyChart}/>}
          </Col>
        </Row>
      )}
    </RevenueMethodItemWrapper>
  );
}
