import React, { useState, useEffect } from 'react';
import {
  RevenueReviewCard,
  RevenueStoreCard,
} from './RevenueReview/index';
import styled from 'styled-components';
import { RevenueReviewModel } from './revenueModels';
import { Row, Col, Spin } from 'antd';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
const RevenueReviewsWrapper = styled.div`
  width: 100%;
  .ant-card {
    font-size: 13px;
    font-weight: 400;
    height: 100%;
  }
  @media only screen and (min-width:100px){
    .ant-col.ant-col-12 {
      .ant-card.ant-card-bordered {
        .revenue-card__date__info--title {
          span {
            font-size: medium;
          }
        }
        width: 220px;
        margin-bottom : 15px;
      }
    }
    .ant-col {
      .revenue-card__info {
        &--revenue{
          color: #DC5454;
          font-weight: 600;
          font-size: medium;
        }
        &--percent {
          font-size: 0.9375em;
          font-weight: 600;
          line-height: large;
        }
        &--stroke {
          .anticon-arrow-down, .anticon-arrow-up {
            font-size: 18px;
          }
        }
      }
      div.store {
        text-align: center; 
      }
      div.store-detail {
        justify-content: center;
        .storeNumber {
          font-size: 40px;
          font-weight: 600;
          line-height: 60px;
        }
        div.combined-shape {
          display: none;
        }
      }

    }
  }
  @media only screen and (min-width:425px) {
    .ant-col.ant-col-8 {
      .ant-card.ant-card-bordered {
        width: 320px;
      }
    }
    .ant-col {
      .revenue-card {
        &__info {
          &--revenue{
            color: #DC5454;
            font-size: 30px;
            font-weight: 600;
            line-height: 42px;
          }
          &--percent {
            font-size: 18px;
            font-weight: 600;
            line-height: 24px;
          }
          &--stroke {
            .anticon-arrow-down, .anticon-arrow-up {
              font-size: 18px;
            }
          }
        }
      }
      div.store {
        text-align: center; 
      }
      div.store-detail {
        flex-flow: nowrap;
        .storeNumber{
          font-size: 60px;
          font-weight: 600;
          line-height: 60px;
          text-align: left;
        }
        div.combined-shape {
          display: inline-flex;
        }
      }
    }
  }
  @media only screen and (min-width:576px) {
    .ant-col {
      .revenue-card {
        &__info {
          &--revenue{
            color: #DC5454;
            font-size: 24px;
            font-weight: 600;
            line-height: 42px;
          }
          &--percent {
            font-size: 18px;
            font-weight: 600;
            line-height: 24px;
          }
          &--stroke {
            .anticon-arrow-down, .anticon-arrow-up {
              font-size: 20px;
            }
          }
        }
      }
      div.store {
        text-align: left; 
      }
      div.store-detail {
        text-align: justify;
        justify-content: end;
        .storeNumber{
          font-size: 60px;
          font-weight: 600;
          line-height: 60px;
          text-align: left;
        }
        div.combined-shape {
       display: inline-flex;
        }
      }
    }
  }
`;

export function RevenueReview(props) {
  const { merchantId, reviewTab } = props;
  const [avgDate, setAvgDate] = useState<RevenueReviewModel>({} as any);
  const [avgWeek, setAvgWeek] = useState<RevenueReviewModel>({} as any);
  const [avgMonth, setAvgMonth] = useState<RevenueReviewModel>({} as any);
  const [storeRevenueReview, setStoreRevenueReview] = useState({});
  const getStoreRevenue = async () => {
      setAvgDate({...reviewTab.avgDate, revenueTitle: (<FormattedMessage {...messages.titleRevenueDate} />)});
      setAvgWeek({...reviewTab.avgWeek, revenueTitle: (<FormattedMessage {...messages.titleRevenueWeek} />)});
      setAvgMonth({...reviewTab.avgMonth, revenueTitle: (<FormattedMessage {...messages.titleRevenueMonth} />)});
      setStoreRevenueReview({storeNumber: reviewTab.totalCount[0].count < 10 ? `0${reviewTab.totalCount[0].count}` : reviewTab.totalCount[0].count});
  };

  useEffect(() => {
    getStoreRevenue();
  }, []);

  return (
    <RevenueReviewsWrapper>
      <Row gutter={[6,6]}>
      <Col xl={6} lg={12} md={12} sm={12} xs={12}>
          <RevenueStoreCard revenueStore={storeRevenueReview} />
        </Col>
            <RevenueReviewCard revenueReview={avgDate} />
            <RevenueReviewCard revenueReview={avgWeek} />
            <RevenueReviewCard revenueReview={avgMonth} />
      </Row>
    </RevenueReviewsWrapper>
  );
}
