import { callApi } from '../../utils/apiUtils';
import { put, takeLatest } from 'redux-saga/effects';
import {
  getMerchantRevenueSuccess,
  getMerchantRevenueFail,
  getStoreRevenueFail,
  getStoreRevenueSuccess,
  getMethodFail,
  getMethodSuccess,
  getItemFail,
  getItemSuccess
} from './actions';
import _ from 'lodash';
import { replaceUrl } from 'utils/fetchAPI';
import ActionTypes from './constants';

export function* getStoreRevenue({ payload: {dateRange, merchantId} }) {
  try {
    const result = yield callApi(
      `/report/average/dashboard?merchantId=${merchantId}`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getStoreRevenueSuccess(result.data)); // should be remove list
    } else {
      yield put(getStoreRevenueFail(result.success));
    }
  } catch (error) {
    yield put(getStoreRevenueFail(error.message));
  }
}

export function* getMerchantRevenue({ payload: {dateRange, merchantId} }) {
  try {
    const result = yield callApi(
      `${replaceUrl('/report/revenueByMerchant/:merchantId', {
        merchantId,
      })}?from=${dateRange.dateFrom}&to=${dateRange.dateTo}&type=day`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getMerchantRevenueSuccess({dateRange, restaurantData: result.data})); // should be remove list
    } else {
      yield put(getMerchantRevenueFail(result.success));
    }
  } catch (error) {
    yield put(getMerchantRevenueFail(error.message));
  }
}

export function* getItem({ payload: merchantId }) {
  try {
    const result = yield callApi(
      `/report/menu/dashboard?merchantId=${merchantId}`,
      'GET',
    );
    if (result.message === "success") {
      const itemListData = _.isEmpty(result.data) ? [] : result.data;
      yield put(getItemSuccess(itemListData)); // should be remove list
    } else {
      yield put(getItemFail(result.success));
    }
  } catch (error) {
    yield put(getItemFail(error.message));
  }
}

export function* getMethod({payload: merchantId}) {
  try {
    const result = yield callApi(
      `/report/method/dashboard?merchantId=${merchantId}`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getMethodSuccess(result.data)); // should be remove list
    } else {
      yield put(getMethodFail(result.success));
    }
  } catch (error) {
    yield put(getMethodFail(error.message));
  }
}

export default function* watchDashboard() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_MERCHANT_REVENUE, getMerchantRevenue);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STORE_REVENUE, getStoreRevenue);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_METHOD, getMethod);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_ITEM, getItem);
}
