import { ActionType } from 'typesafe-actions';
import * as actions from './actions';

export interface LineChartModel {
  readonly restaurantData: LinePointModel;
  readonly dateRange: DateRageModel;
}

export interface DateRageModel {
  readonly dateFrom: string | null;
  readonly dateTo: string | null;
}

export interface LinePointModel {
  readonly restaurant: RestaurantPointModel[];
  readonly revenues: RevenuePointModel[];
}

export interface DatasetModel {
  readonly data: number[];
  readonly label: number | string;
  readonly borderColor: string;
  readonly backgroundColor: string;
  readonly borderWidth: number,
  readonly pointBackgroundColor: string;
  readonly pointBorderColor: string;
  readonly pointBorderWidth: number;
  readonly fill:string;
}

export interface RestaurantPointModel {
  readonly id: number;
  readonly name: string;
}

export interface RevenuePointModel {
  readonly x: string;
}

export interface DataRevenueModel {
  readonly amount: string;
  readonly name: string;
  readonly restaurant_id: string;
}

export interface MenuListModel {
  readonly menuCategoryId: string;
  readonly menuTopList: MenuModel[];
}

export interface MenuModel {
  readonly itemNm: string;
  readonly menuCategoryId: string;
  readonly quantity: number;
  readonly revenue: number;
}

export interface MethodModel {
  readonly amount: number;
  readonly orderType: string;
}

/* --- STATE --- */
interface DashboardState {
  readonly default: any;
  readonly isFetchingReview: boolean;
  readonly isFetching: boolean;
  readonly isFetchingItem: boolean;
  readonly isFetchingMethod: boolean;
  readonly donutRevenueResChart: DataRevenueModel[];
  readonly reviewTab: any;
  readonly LineRevenueResChart: LinePointModel | null;
  readonly branchList: DataRevenueModel[];
  readonly message: string;
  readonly item: MenuListModel[];
  readonly method: MethodModel[];
}

/* --- ACTIONS --- */
type DashboardActions = ActionType<typeof actions>;

/* --- EXPORTS --- */
type ContainerState = DashboardState;
type ContainerActions = DashboardActions;

export { ContainerState, ContainerActions };
