/*
 *
 * PromotionDetail reducer
 *
 */

import ActionTypes from "./constants";
import { ContainerActions, ContainerState } from "./types";
import moment from "moment";

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  message: '',
  gift: null
};

function promotionDetailReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_GIFT:
      return { ...state, isFetching: true };
    case ActionTypes.GET_GIFT_SUCCESS:
      const gift = action.payload;
      gift.startDate = gift.startDate ? moment(gift.startDate) : undefined;
      gift.endDate = gift.endDate ? moment(gift.endDate) : undefined;
      gift.daysOfWeek = gift.daysOfWeek || [];
      gift.menuItemIds = gift.menuItems ? gift.menuItems.map(menu => +menu.menuItemId) : [];
      return { ...state, isFetching: false, gift };
    case ActionTypes.GET_GIFT_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.UPDATE_GIFT:
      return { ...state, isFetching: true };
    case ActionTypes.UPDATE_GIFT_SUCCESS:
      return { ...state, isFetching: false };
    case ActionTypes.UPDATE_GIFT_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    default:
      return state;
  }
}

export default promotionDetailReducer;
