
import { callApi, success } from "../../utils/apiUtils";
import { put, takeLatest } from "redux-saga/effects";
import { getGiftFail, getGiftSuccess, updateGiftFail, updateGiftSuccess } from "./actions";
import ActionTypes from "./constants";
import { TIME_FORMAT } from "../../utils/constants";
import { push } from "connected-react-router";
import { RoutePaths } from "../App/routes";
import { apiError } from "../App/actions";

export function* getGift({payload: id}) {
  try {
    const { code, data, message } = yield callApi(`/gift-cards/${id}`, 'GET');
    if (success(code)) {
      yield put(getGiftSuccess(data));
    } else {
      yield put(getGiftFail(message));
    }
  } catch (error) {
    yield put(getGiftFail(error.message));
  }
}

export function* updateGift({ payload: { id, gift } }) {
  try {
    let values = gift;
    values.startDate = values.startDate ? values.startDate!.toISOString() : values.startDate;
    values.endDate = values.endDate ? values.endDate!.toISOString() : values.endDate;
    const { code, data, message } = yield callApi(`/gift-cards/${id}`, 'PUT', values);
    if (success(code)) {
      yield put(updateGiftSuccess(data));
      yield put(push(RoutePaths.giftCard));
    } else {
      yield put(updateGiftFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(updateGiftFail(error.message));
    yield put(apiError(error.message));
  }
}

export function* addGift({ payload: { gift } }) {
  try {
    let values = { ...gift};
    console.log("saga photo ", values.photo)
    values.startDate = values.startDate ? values.startDate!.toISOString() : values.startDate;
    values.endDate = values.endDate ? values.endDate!.toISOString() : values.endDate;
    const { code, data, message } = yield callApi(`/gift-cards`, 'POST', values, { isFormData: true});
    if (success(code)) {
      yield put(getGiftSuccess(data));
      yield put(push(RoutePaths.giftCard));
    } else {
      yield put(updateGiftFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(updateGiftFail(error.message));
    yield put(apiError(error.message));
  }
}

// Individual exports for testing
export default function* giftDetailSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_GIFT, getGift);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_GIFT, updateGift);
  // @ts-ignore
  yield takeLatest(ActionTypes.ADD_GIFT, addGift);
}
