import React, { useState, useEffect, ReactComponentElement, ReactNode } from 'react';
import { useHistory, useParams } from 'react-router';
import { HEADER_HEIGHT } from '../../../styles/constants';
import styled from 'styled-components';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { makeSelectCategoryId } from '../../Menu/Store/selectors';

import { RoutePaths } from 'containers/App/routes';
import { BackButtonIcon } from '../../../styles/custom-styled-components';
import { RestaurantModel } from 'containers/Restaurant/Store/types';
import { RESTAURANT_BY_ID_URL } from 'containers/App/urls';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';

const stateSelector = createStructuredSelector({
  params: makeSelectCategoryId(),
});

interface Props {
  title: string | ReactNode;
  link: RoutePaths | string;
  params?: string[];
}

const BackButtonWrapper = styled.div`
  display: flex;
  line-height: ${HEADER_HEIGHT};
  font-size: 18px;
  .anticon {
    line-height: ${HEADER_HEIGHT};
    margin: 0px 20px 0px 10px;
  }
`;

function getRestaurantMenuTitle(): Props {
  // @ts-ignore
  const { id } = useParams();
  const [restaurantDetails, setRestaurantDetails] = useState<RestaurantModel>();
  const getRestaurantDetail = async () => {
    const response = await fetchAPI({
      method: 'GET',
      url: replaceUrl(RESTAURANT_BY_ID_URL, { id }),
    });
    if (response) {
      setRestaurantDetails(response);
    }
  };
  useEffect(() => {
    getRestaurantDetail();
  }, []);
  if (restaurantDetails) {
    return {
      title: restaurantDetails.name!,
      link: `${RoutePaths.restaurantDetail}/${restaurantDetails.id}`,
    };
  }
  return { title: '', link: `${RoutePaths.restaurant}` };
}

export function BackButton(props: Props) {
  const history = useHistory();
  const { params } = useSelector(stateSelector);
  let backObject: Props = props;
  if (props.title === 'restaurantMenu') {
    backObject = getRestaurantMenuTitle();
  }
  if (props.params && props.params.includes('categoryId')) {
    backObject = {
      title: '',
      link: `${backObject.link}${
        params.categoryId ? `?categoryId=${params.categoryId}` : ''
      }`,
    };
  }
  const { link, title } = backObject;
  return (
    <BackButtonWrapper>
      <BackButtonIcon
        onClick={() => (link ? history.push(link) : history.goBack())}
      />
      {title}
    </BackButtonWrapper>
  );
}
