import React, { useState, useEffect } from 'react';
import {
  Form,
  Input,
  Button,
  Checkbox,
  InputNumber,
  Upload,
  Modal,
  notification,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import _ from 'lodash';
import { InputNumber as RoundInputNumber } from 'components/InputNumber';
import { LoadingOutlined } from '@ant-design/icons';
import {
  EditUploadImageIcon,
  MenuItemIcon,
  AddIcon,
  PlusCharacter,
} from 'styles/icon-components';
import IMG_RES_DEFAULT from '../../../images/restaurant-placeholder.svg';
import { MenuEditWrapper, MenuWrapper, MenuListWrapper } from './styles';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import {
  MENUS_MENU_ITEM_URL,
  MENUS_MENU_ITEM_UPLOAD_PHOTO_URL,
  PUBLIC_API,
  MENUS_MENU_ITEM_BY_ID_URL,
} from 'containers/App/urls';
import { useHistory, useParams } from 'react-router-dom';
import { RoutePaths } from 'containers/App/routes';
import MenuListMenuTab from '../MenuList/menuListMenuTab';
import messagesGlobal from 'translations/messages';
import { MENUS_MENU_ITEMS_MERCHANT_URL } from 'containers/App/urls';
import { validateNumberPrice, fileValidation } from 'utils/validation';
import { digits } from 'utils/number';
import { FormatInput } from 'components/FormatInput';
import { formatCurrency } from 'utils/common';
import FloatLabel from 'components/FormatInput/FloatLabel';
import { useCallback } from 'react';

const { TextArea } = Input;

function ComboEdit({ intl }) {
  // @ts-ignore
  const { id } = useParams();
  const [loading, setLoading] = useState(false);
  const [form] = Form.useForm();
  const [imageUrl, setImageUrl] = useState<any>();
  const [products, setProducts] = useState<any[]>([]);
  const [combo, setCombo] = useState<any>();
  const [menuList, setMenuList] = useState<any>();
  const [showMenu, setShowMenu] = useState<boolean>(false);
  const uploadButton = (
    <div>
      {loading ? <LoadingOutlined /> : <img src={IMG_RES_DEFAULT} />}
      <div className="ant-upload-text" style={{ marginTop: '10px' }}>
        <FormattedMessage {...messagesGlobal.image} />
      </div>
      <span className="img-hint">
        <FormattedMessage
          {...messagesGlobal.encourageCondition}
          values={{ height: 345, width: 180 }}
        />
      </span>
    </div>
  );
  const history = useHistory();

  const beforeUpload = file => {
    if (!fileValidation(file.name)) {
      notification.error({
        message: intl.formatMessage(messagesGlobal.invalidFile),
      });
      return false;
    }
    const reader = new FileReader();
    reader.onloadend = e => {
      setImageUrl(reader.result!);
    };
    reader.readAsDataURL(file);
    return false;
  };
  const handleSave = async values => {
    try {
      setLoading(true);
      values = formatCurrency(values);
      let photo = combo?.photo || '';
      const { files } = values;
      if (!products.length) {
        requiredMenuList();
        return;
      } else if (products.length < 2) {
        invalidMenuList();
        return;
      }
      const imageFile = files?.file;
      if (imageFile) {
        const formData = new FormData();
        formData.append('photo', imageFile!);
        photo = await fetchAPI({
          method: 'POST',
          url: MENUS_MENU_ITEM_UPLOAD_PHOTO_URL,
          formData: true,
          data: formData,
        });
        delete values.files;
      }

      let response;
      if (id) {
        response = await fetchAPI({
          method: 'PUT',
          url: replaceUrl(MENUS_MENU_ITEM_BY_ID_URL, { id }),
          data: { ...values, photo, products },
        });
      } else {
        response = await fetchAPI({
          method: 'POST',
          url: MENUS_MENU_ITEM_URL,
          data: { ...values, photo, products, type: 1 },
        });
      }

      if (response) {
        history.push(RoutePaths.menuCombo);
      }
    } finally {
      setLoading(false);
    }
  };

  const handleChange = (id, value) => {
    if (value > 0) {
      const updated = products.find(product => product.id === id);
      updated.quantity = value;
      setProducts([...products]);
    } else {
      _.remove(products, product => product.id === id);
      setProducts([...products]);
    }
  };

  const handleShowMenuClick = () => {
    setShowMenu(true);
  };

  const handleSelectedMenuList = values => {
    const selectedMenuList = menuList.reduce((accumalate, current) => {
      let menuItems = current.menuItems.filter(
        menu =>
          _.get(menu, 'products').length < 2 &&
          values.includes(_.get(menu, 'products[0]')),
      );
      return accumalate.concat(menuItems);
    }, []);
    const selectedProducts = selectedMenuList.map((menu, index) => {
      const { name, description, photo } = menu;
      const productsCur = products;
      let num = 1;
      productsCur.filter(product => {
        if (product.id == _.get(menu, 'products[0]')) {
          num = product.quantity || 1;
        }
      });
      return {
        id: _.get(menu, 'products[0]'),
        name,
        description,
        photo,
        quantity: num,
      };
    });
    setProducts([...selectedProducts]);
    setShowMenu(false);
  };

  const invalidMenuList = () => {
    Modal.confirm({
      content: <FormattedMessage {...messagesGlobal.requiredProductNumber} />,
      okText: <FormattedMessage {...messagesGlobal.ok} />,
      cancelText: <FormattedMessage {...messagesGlobal.cancel} />,
    });
  };

  const requiredMenuList = () => {
    Modal.confirm({
      content: <FormattedMessage {...messagesGlobal.requiredProduct} />,
      okText: <FormattedMessage {...messagesGlobal.ok} />,
      cancelText: <FormattedMessage {...messagesGlobal.cancel} />,
    });
  };

  useEffect(() => {
    if (id) {
      fetchAPI({
        method: 'GET',
        url: `${MENUS_MENU_ITEM_URL}/${id}`,
      }).then(response => {
        if (response) {
          setCombo(response);
        }
      });
    }
  }, [id]);

  useEffect(() => {
    // console.log(combo)
    if (combo?.photo) {
      setImageUrl(`${PUBLIC_API}/${combo?.photo}`);
    }
    if (combo?.products && combo?.products?.length) {
      setProducts(
        combo?.products.map(product => {
          const { id, name, description, photo, quantity } = product;
          return { id, name, description, photo, quantity };
        }),
      );
    }
    if (combo?.price) {
      combo.price = parseInt(combo?.price);
    }
    form.resetFields();
  }, [combo]);

  useEffect(() => {
    fetchAPI({
      method: 'GET',
      url: `${MENUS_MENU_ITEMS_MERCHANT_URL}?type=1`,
    }).then(response => {
      response.reduce(
        (accumulate, category) =>
          accumulate.concat(
            _.remove(
              category.menuItems,
              (menuItem: any) => menuItem.products.length > 2,
            ),
          ),
        [],
      );
      setMenuList(response);
    });
  }, []);

  return (
    <MenuEditWrapper>
      {!showMenu ? (
        <div className="menu-edit">
          <div className="menu-edit__info">
            <Form form={form} initialValues={combo}>
              <div className="info__title">
                <FormattedMessage {...messagesGlobal.newInfo} />
              </div>
              <div className="info__form">
                <div className="form-field__group">
                  <div className="form-field__row">
                    <div className="form-field__col pr-10">
                      <Form.Item
                        name="name"
                        rules={[
                          {
                            required: true,
                            message: (
                              <FormattedMessage
                                {...messagesGlobal.requiredInput}
                              />
                            ),
                          },
                          ({ getFieldValue }) => ({
                            validator(rule, value) {
                              const name = getFieldValue('name').length;
                              if (name > 250) {
                                return Promise.reject(
                                  intl.formatMessage(
                                    messagesGlobal.requiredNameLength,
                                  ),
                                );
                              }
                              return Promise.resolve();
                            },
                          }),
                        ]}
                      >
                        <FloatLabel
                          label={intl.formatMessage(messagesGlobal.namePh)}
                        />
                      </Form.Item>
                    </div>
                    <div className="form-field__col">
                      <Form.Item
                        name="price"
                        rules={[
                          {
                            required: true,
                            message: (
                              <FormattedMessage
                                {...messagesGlobal.requiredPrice}
                              />
                            ),
                          },
                          validateNumberPrice,
                        ]}
                      >
                        <FormatInput
                          placeholder={`${intl.formatMessage(
                            messagesGlobal.price,
                          )}*`}
                          formatter={digits}
                        />
                      </Form.Item>
                    </div>
                  </div>
                  <div className="form-field__row">
                    <Form.Item name="description">
                      <FloatLabel
                        rows={4}
                        label={intl.formatMessage(messagesGlobal.description)}
                        typeInput="TextArea"
                      />
                    </Form.Item>
                  </div>
                </div>
                <div>
                  <div className="form-field__photo">
                    <Form.Item name="files">
                      <Upload
                        name="avatar"
                        listType="picture-card"
                        className="avatar-uploader"
                        showUploadList={false}
                        action="https://www.mocky.io/v2/5cc8019d300000980a055e76"
                        beforeUpload={beforeUpload}
                        accept="image/*"
                      >
                        {imageUrl ? (
                          <img
                            src={imageUrl}
                            alt="avatar"
                            style={{ width: '100%', objectFit: 'cover' }}
                          />
                        ) : (
                          uploadButton
                        )}
                        {imageUrl && (
                          <div className="edit-upload-image-icon">
                            <EditUploadImageIcon />
                          </div>
                        )}
                      </Upload>
                    </Form.Item>
                  </div>
                </div>
              </div>
              <div></div>
              <div>
                <Form.Item
                  name="applyAllRestaurants"
                  valuePropName="checked"
                  style={{ marginTop: '15px' }}
                >
                  <Checkbox value={true}>
                    {intl.formatMessage(messagesGlobal.applyAll)}
                  </Checkbox>
                </Form.Item>
              </div>
              <div className="info__button">
                <Button
                  type="primary"
                  htmlType="submit"
                  onClick={() => {
                    form
                      .validateFields()
                      .then(values => {
                        handleSave(values);
                      })
                      .catch(info => {
                        console.log('Validate Failed:', info);
                      });
                  }}
                >
                  {intl.formatMessage(messagesGlobal.save)}
                </Button>
              </div>
            </Form>
          </div>
          <div className="menu-edit__extra">
            <div className="extra__component">
              <MenuWrapper>
                <div className="menu">
                  <div className="menu__header">
                    <div className="menu__title">
                      {intl.formatMessage(messagesGlobal.productPh)}
                    </div>
                    <Button
                      type="primary"
                      shape="circle"
                      onClick={handleShowMenuClick}
                    >
                      {' '}
                      <PlusCharacter />{' '}
                    </Button>
                  </div>
                  <div className="menu__content">
                    {products && products.length ? (
                      products.map(product => {
                        const {
                          id,
                          photo,
                          name,
                          description,
                          quantity,
                        } = product;
                        return (
                          <div className="item">
                            {photo ? (
                              <img
                                src={`${PUBLIC_API}/${photo}`}
                                className="item__img"
                                onError={event =>
                                  (event.target as any).setAttribute(
                                    'src',
                                    'https://images.pexels.com/photos/1640777/pexels-photo-1640777.jpeg?cs=srgb&dl=pexels-ella-olsson-1640777.jpg&fm=jpg',
                                  )
                                }
                              />
                            ) : (
                              <MenuItemIcon />
                            )}
                            <div className="item__info">
                              <p className="item__title">{name}</p>
                              <p className="item__description">{description}</p>
                            </div>
                            <span className="item__quantity">
                              <RoundInputNumber
                                id={id}
                                value={Number(quantity)}
                                onChange={handleChange}
                              />
                            </span>
                          </div>
                        );
                      })
                    ) : (
                      <div style={{ height: '100%' }}>
                        {intl.formatMessage(
                          messagesGlobal.reuiredChooseProduct,
                        )}
                      </div>
                    )}
                  </div>
                </div>
              </MenuWrapper>
            </div>
          </div>
          <div className="info__button--mobile">
            <Button
              type="primary"
              htmlType="submit"
              loading={loading}
              onClick={() => {
                form
                  .validateFields()
                  .then(values => {
                    handleSave(values);
                  })
                  .catch(info => {
                    console.log('Validate Failed:', info);
                  });
              }}
            >
              {intl.formatMessage(messagesGlobal.save)}
            </Button>
          </div>
        </div>
      ) : (
        <MenuListWrapper>
          <div className="menu-list">
            <div className="menu-list__title">
              {intl.formatMessage(messagesGlobal.productList)}
            </div>
            <MenuListMenuTab
              type="menu"
              loading={loading}
              menuList={menuList}
              products={products}
              handleSubmit={handleSelectedMenuList}
              editable
            />
          </div>
        </MenuListWrapper>
      )}
    </MenuEditWrapper>
  );
}
export default injectIntl(ComboEdit);
