import React from 'react';
import styled from 'styled-components';
import { InputNumber } from 'components/InputNumber';
import { AddIcon } from 'styles/icon-components';
import { PUBLIC_API } from 'containers/App/urls';
import {MenuItemIcon} from 'styles/icon-components';
import { FormattedMessage } from "react-intl";
import messagesGlobal from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';

const MenuWrapper = styled.div`
  .menu {
    &__title {
      color: #333333;
      font-size: 18px;
      padding-bottom: 20px;
    }
  
    &__header {
      display: flex;
      flex-direction: row;
      justify-content: space-between;
    }
  
    &__add {
      cursor: pointer;
      margin-right: -5px;
    }

    .item {
      display: flex;
      align-items: flex-start;
      &__img {
        width: 70px;
        height: auto;
        object-fit: cover;
      }
      &__info {
        padding: 0 20px;
        flex-grow: 1;
      }
      &__title {
        font-size: 15px;
        font-weight: bold;
        color: #333333;
      }
      &__description {
        font-size: 13px;
        color: #9c9696;
        display: -webkit-box;
        max-width: 200px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
      }
      &__quantity {
        align-self: center;
      }
    }
  }
`;
interface Props {
  products?: any[];
  setProducts?: Function
}

export function Menu (props: Props) {
  const { products = [], setProducts }  = props;
  const handleOnChangeQuantity = (id, value) => {
    const updated = products?.find(product => product.id === id);
    updated.quantity = value;
    if (setProducts) {
      setProducts(products);
    }
  }
  return (
    <MenuWrapper>
      <div className="menu">
        <div className="menu__header">
          <div className="menu__title"><FormattedMessage {...messagesGlobal.product}/></div>
          <div className="menu__add" onClick={() => { console.log('Click add menu')}}><AddIcon/></div>
        </div>
        <div className="menu__content">
          {
            products.map(product => {
              const { id, photo, name, description, quantity } = product;
              return (
                <div className="item">
                 {photo ? <img src={`${PUBLIC_API}/${photo}`} style={{objectFit: 'cover'}}/> : <MenuItemIcon/>}
                  <div className="item__info">
                    <p className="item__title">{name}</p>
                    <p className="item__description">{description}</p>
                  </div>
                  <span className="item__quantity">
                    <FloatLabel id={id} onChange={handleOnChangeQuantity} value={quantity} typeInput="number"/>  
                  </span>
                </div>
              )
            })
          }
        </div>
      </div>
    </MenuWrapper>
  )
}