import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {
  Input,
  Modal,
  Button,
  Form,
  InputNumber
} from 'antd';
import _ from 'lodash';
import { EditItem } from './editItem';
import {PlusCharacter} from 'styles/icon-components';
import {PRODUCTS_ADD_ONS_URL, PRODUCTS_ADD_ONS_BY_ID_URL} from "containers/App/urls";
import {fetchAPI, replaceUrl} from 'utils/fetchAPI';
import { digits } from 'utils/number';
import { FormatInput } from 'components/FormatInput';

const AddonsWrapper = styled.div`
 .ant-input {
  padding: 7px 15px !important;
  height: 32px !important;
  border-radius: 16px;
  border: solid 1px #dddddd;
}
.ant-btn {
  padding: 0;
}

.addons {
  &__title {
    color: #333333;
    font-size: 13px;
    padding-bottom: 20px;
    font-weight: 700;
  }

  &__header {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
  }

  &__content {
    height: 140px;
    overflow: auto;
  }

  &__add {
    cursor: pointer;
    margin-right: -5px;
  }

  .item {
    display: inline-block;
    width: max-content;
    cursor: pointer;
    padding-right: 10px;
    padding-bottom: 10px;
    height: 44px;
    overflow: hidden;
    font-size: 14px;
    color: #4a4a4a;
    .view-mode {
      display: block;
      padding: 7px 15px !important;
      height: 32px !important;
      border-radius: 16px;
      border: solid 1px #dddddd;
      cursor: pointer;
      font-size: 14px;
    }
    .edit-mode {
      display: none;
    }
    &.active {
      padding-right: 0;
      width: 100%;

      .view-mode {
        display: none;
      }
      .edit-mode {
        display: block;
      }
    }
  }
}


`;

const ModalWrapper = styled.div`
 .container {
  display: flex;
	flex-direction: column;
	flex-wrap: nowrap;
	justify-content: space-between;
	align-items: center;
	align-content: stretch;
  
  padding: 6px;
 .title {
  color: #333333;
  font-size: 16px;
  font-weight: 600;
  line-height: 19px;
  text-align: center;
  padding-bottom: 20px;
 } 
 .name {
  color: #333333;
  font-size: 16px;
  font-weight: 600;
  margin-bottom: 20px;
 }
.add-button {
   width: 270px;
   height: 44px;
   margin-top: 20px;
   font-weight: 600;
 }
 
 }
 
 .addon-name, .addon-price {
  width: 270px;
  height: 44px;
  border-radius: 22px;
  border: solid 1px #e6e6e6;
 }
 .addon-price {
   padding-top: 4px;
 }
 
`;

export function Addons(props) {
  const {title, menuDetails, setAddonsIdList} = props;
  const {addons: initAddons} = menuDetails;
  const [active, setActive] = useState<any>();
  const [visible, setVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  const [addons, setAddons] = useState<any[]>([]);
  const [form] = Form.useForm();

  const showModal = () => {
    setVisible(true);
    form.resetFields();
  };
  const handleCancel = () => {
    setVisible(false);
  };

  const handleOk = async (values) => {
    try {
      setLoading(true);
      if (active) {
        const response = await fetchAPI({
          method: 'PUT',
          url: replaceUrl(`${PRODUCTS_ADD_ONS_BY_ID_URL}`, { id: active }),
          data: values
        });
        if (response) {
          const index = _.findIndex(addons, addon => addon.id === active);
          addons.splice(index, 1, response);
          setAddons([...addons]);
        }
        setActive(0);
      } else {
        const response = await fetchAPI({
          method: 'POST',
          url: PRODUCTS_ADD_ONS_URL,
          data: values
        })
        if (response) {
          const newAddons = [ ...addons, response ];
          setAddons(newAddons);
          setAddonsIdList(newAddons.map(addon => addon.id));
        }
      }
      setVisible(false);
    } finally {
      setLoading(false);
    }
  };

  const handleEdit = (id) => {
    setActive(id);
    const addon = addons.find(addon => addon.id === id);
    form.setFieldsValue(addon);
    setVisible(true);
  };

  const handleDelete = async (id) => {
    const response = await fetchAPI({
      method: 'DELETE',
      url: replaceUrl(`${PRODUCTS_ADD_ONS_BY_ID_URL}`, {id})
    });
    if (response) {
      const newAddons = addons && addons.filter(addon => addon.id != id);
      setAddons(newAddons);
      setAddonsIdList(newAddons.map(addon => addon.id));
    }
    setActive(0);
  };

  useEffect(() => {
    setAddons(initAddons || []);
  }, []);

  return (
    <AddonsWrapper>
      <div className="addons">
        <div className="addons__header">
          <div className="addons__title">{title}</div>
          <Button type="primary" shape="circle" onClick={() => showModal()}> <PlusCharacter /> </Button>
          <Modal
            visible={visible}
            onOk={handleOk}
            onCancel={handleCancel}
            okText="Thêm"
            centered
            footer={null}
            width={330}
          >
            <ModalWrapper>
              <Form form={form} onFinish={handleOk}>
                <div className="container">
                  <div className="title">Món thêm</div>
                  <Form.Item name="name" rules={[{ required: true, message: "Vui lòng nhập tên món" }]}>
                    <Input className="addon-name" placeholder="Tên món*" value=""/>
                  </Form.Item>
                  <Form.Item name="price" rules={[{ required: true, message: "Vui lòng nhập giá tiền" }]}>
                    <FormatInput className="addon-price" placeholder="Giá*" formatter={digits} />
                  </Form.Item>
                  <Button className="add-button" type="primary" htmlType="submit" loading={loading}>Thêm</Button>
                </div>
              </Form>
            </ModalWrapper>
          </Modal>
        </div>
        <div className="addons__content">
          {
            addons && addons.length > 0 && addons.map(item => {
              if(!item){
                return null;
              }
              return (
                <div className="item">
                  <div className="view-mode">
                    <EditItem item={item} handleEdit={handleEdit} handleDelete={handleDelete} />
                  </div>
                </div>
              )
            })
          }
        </div>

      </div>
    </AddonsWrapper>
  )

}
