import React, { useState } from 'react';
import styled from 'styled-components';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import { BLACK_COLOR } from 'styles/constants';
import { Form, Input, Upload, Button, Checkbox, message } from 'antd';
import { EditUploadImageIcon } from 'styles/icon-components';
import { LoadingOutlined, PlusOutlined } from '@ant-design/icons';
import TextArea from 'antd/lib/input/TextArea'
import { digits } from 'utils/number';
import FloatLabel from 'components/FormatInput/FloatLabel';

const ComboFormWrapper = styled.div`
  padding: 20px;
  background: #fff;
  height: 100%;
  .combo {
    &__form {
      display: flex;
      &__info {
        margin-right: 20px;
        &__header {
          font-size: 16px;
          font-weight: bolder;
          color: ${BLACK_COLOR};
          margin-bottom: 20px;
          width: 100%;
        }
        &__body {
          width: 100%;
          display: flex;
          flex-wrap: wrap;
          &__first-part {
            margin-right: 20px;
            margin-bottom: 15px;
            display: flex;
            flex-direction: column;
            &__first-line {
              margin-bottom: 15px;
              min-width: 400px;
              display: flex;
              align-items: center;
              justify-content: space-between; 
              .ant-form-item  {
                margin: 0 !important;
              }
              &__name {
                flex-grow: 1;
                margin-right: 10px!important;
              }
            }
            &__second-line {
              flex-grow: 1;
              margin: 0!important;
              textarea, .ant-form-item-control-input, .ant-form-item-control-input-content {
                height: 100%!important;
              }
            }
          }

          &__photo {
          width: 230px;
          min-width: 230px;
          height: 230px;
          min-height: 230px;
          border-radius: 8px;
          background: #fff;
          border: solid 1px #e6e6e6;
          position: relative;
          cursor: pointer;
          margin-bottom: 15px;
          .ant-upload.ant-upload-select-picture-card {
            width: 230px;
            height: 230px;
            border: 0;
            background: none;
    
            .ant-upload {
              padding: 0;
            }
    
            img {
              border-radius: 8px;
            }
          }
          .edit-upload-image-icon {
            position: absolute;
            top: 15px;
            right: 10px;
            display: none;
            opacity: 0.6;
          }
          .edit-upload-image-icon:hover {
            opacity: 1;
          }
          :hover {
            img {
              opacity: 0.2;
            }
            .edit-upload-image-icon {
              display: block;
            }
          }
        }
        }
        &__check-box {

        }
        &__save {
          button {
            width: 100px;
          }
        }
      }
      &__menu {
        flex-grow: 1;
        display: flex;
        justify-content: space-between;
        &__header {
          font-size: 15px;
          font-weight: bolder;
          color: ${BLACK_COLOR};
          margin-bottom: 20px;
          width: 100%;
        }
      }
    }
  }
`;
export const ComboForm = () => {
  const [imageUrl, setImageUrl] = useState<any>('');
  const [loading, setLoading] = useState(false);

  const [form] = Form.useForm();
  const uploadButton = (
    <div>
      {loading ? <LoadingOutlined /> : <><PlusOutlined /></>}

    </div>
  );

  const beforeUpload = (file) => {
    const reader = new FileReader();
    reader.onloadend = e => {
      setImageUrl(reader.result!);
    }
    reader.readAsDataURL(file);
    return false;
  };
  return (
    <ComboFormWrapper>
      <Form
        form={form}
        name="comboForm"
      // onFinish={}
      // initialValues={restaurantDetails as any}
      >
        <div className="combo__form">
          <div className="combo__form__info">
            <div className="combo__form__info__header"><FormattedMessage {...messages.menuInfo} /></div>
            <div className="combo__form__info__body">
              <div className="combo__form__info__body__first-part">
                <div className="combo__form__info__body__first-part__first-line">
                  <FormattedMessage {...messages.name}>
                    {
                      name =>
                        <Form.Item
                          name="name"
                          rules={[{ required: true, message: <FormattedMessage {...messages.requiredInput} /> }]}
                          className="combo__form__info__body__first-part__first-line__name"
                        >
                          <FloatLabel  label={`${name}*`} />
                        </Form.Item>
                    }
                  </FormattedMessage>
                  <FormattedMessage {...messages.price}>
                    {
                      price =>
                        <Form.Item
                          name="name"
                          rules={[{ required: true, message: <FormattedMessage {...messages.requiredPrice} /> }]}
                        >
                          <FloatLabel label={`${digits(price)}*`} />
                        </Form.Item>
                    }
                  </FormattedMessage>
                </div>
                <Form.Item
                  name="description"
                  className="combo__form__info__body__first-part__second-line"
                >
                   <FormattedMessage {...messages.description}>
                     {
                       description =>  <FloatLabel rows={4} label={description} className="h-100" typyInput="TextArea"/>
                     }
                   </FormattedMessage>
                 
                </Form.Item>
              </div>
              <div className="combo__form__info__body__photo">
                <Form.Item name="files">
                  <Upload
                    name="avatar"
                    listType="picture-card"
                    className="avatar-uploader"
                    showUploadList={false}
                    action="https://www.mocky.io/v2/5cc8019d300000980a055e76"
                    beforeUpload={beforeUpload}
                    accept="image/*"
                  >
                    {imageUrl ?
                      <img src={imageUrl} alt="avatar" style={{ width: '100%', objectFit: 'cover' }} /> : uploadButton}
                    {imageUrl && <div className="edit-upload-image-icon"><EditUploadImageIcon /></div>}
                  </Upload>
                </Form.Item>
                <span className="img-hint"><FormattedMessage
          {...messages.encourageCondition}
          values={{ height: 345,
            width: 180, }}
        /></span>
              </div>
            </div>
            <div className="combo__form__info__check-box">
              <Form.Item name="applyAllRestaurants">
                <Checkbox.Group>
                  <Checkbox value={true}><FormattedMessage {...messages.applyAll} /></Checkbox>
                </Checkbox.Group>
              </Form.Item>
            </div>
            <div className="combo__form__info__save">
              <Button type="primary"><FormattedMessage {...messages.save} /></Button>
            </div>
          </div>
          <div className="combo__form__menu">
            <div className="combo__form__info__header"><FormattedMessage {...messages.product} /></div>
            <div>
              <Button type="primary" shape="circle" icon={<PlusOutlined />} style={{ padding: 0 }}></Button>
            </div>
          </div>
        </div>
      </Form>
    </ComboFormWrapper>
  )
}