import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import {
  Input,
  Modal,
  Button,
  Form,
  Spin
} from 'antd';

import { EditIcon, RemoveIcon, AddIcon, PlusIcon, PlusCharacter } from 'styles/icon-components';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import {
  PRODUCTS_INGREDIENTS_URL,
  PRODUCTS_INGREDIENTS_BY_ID_URL
} from 'containers/App/urls';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';
import { IngredientModel } from './menuDetailModels';

const IngredientWrapper = styled.div`
 .ant-input {
  padding: 7px 15px !important;
  height: 32px !important;
  border-radius: 16px;
  border: solid 1px #dddddd;
}

.ant-btn {
  padding: 0;
}

.ingredient {
  &__title {
    color: #333333;
    font-size: 13px;
    padding-bottom: 20px;
    font-weight: 600;
  }

  &__header {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
  }

  &__content {
    height: 140px;
    overflow: auto;
  }

  &__add {
    cursor: pointer;
    margin-right: -5px;
  }

  .item {
    display: inline-block;
    width: max-content;
    cursor: pointer;
    padding-right: 10px;
    padding-bottom: 10px;
    height: 44px;
    overflow: hidden;
    font-size: 14px;
    color: #4a4a4a;
    .view-mode {
      display: block;
      padding: 7px 15px !important;
      height: 32px !important;
      border-radius: 16px;
      border: solid 1px #dddddd;
      cursor: pointer;
    }
    .edit-mode {
      display: none;
    }
    &.active {
      padding-right: 0;
      width: 100%;

      .view-mode {
        display: none;
      }
      .edit-mode {
        display: block;
      }
    }
  }
}

`;

const ModalWrapper = styled.div`
 .container {
  display: flex;
	flex-direction: column;
	flex-wrap: nowrap;
	justify-content: space-between;
	align-items: center;
	align-content: stretch;
  
  padding: 6px;
 .title {
  color: #333333;
  font-size: 16px;
  font-weight: 700;
  line-height: 19px;
  text-align: center;
  padding-bottom: 20px;
 } 
.add-button {
   width: 270px;
   height: 44px;
   margin-top: 20px;
   font-weight: 600;
 }
 
 }
 
 input {
  width: 270px;
  height: 44px;
  border-radius: 22px;
  border: solid 1px #e6e6e6;
 }
 
`;

const Icons = (props) => {
  const { id, handleEdit, handleDelete } = props;

  const handleEditClick = () => {
    handleEdit(id);
  };

  const handleDeletelick = () => {
    handleDelete(id);
  };

  return (
    <div className="icons"><span onClick={handleEditClick}><EditIcon /></span>|<span
      onClick={handleDeletelick}><RemoveIcon /></span></div>
  )
};

export function Ingredient(props) {
  const { title, menuDetails, setIngredientsIdList } = props;
  const { products } = menuDetails;
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [active, setActive] = useState(0);
  const [ingredients, setIngredients] = useState<IngredientModel[]>([]);
  const [form] = Form.useForm();

  const showModal = () => {
    setVisible(true);
  };
  const handleCancel = () => {
    setVisible(false);
  };

  const handleOk = async (values) => {
    try {
      setLoading(true);
      const { name } = values;
      setVisible(false);
      const response = await fetchAPI({
        method: 'POST',
        url: PRODUCTS_INGREDIENTS_URL,
        data: {
          name,
        }
      });

      if (response) {
        const dataList = [...ingredients, { id: response.id, name: response.name }];
        setIngredients(dataList);
        setIngredientsIdList(() => dataList.map(x => x.id));
      }
    } finally {
      setLoading(false);
    }
  };

  const handleEdit = async (id) => {
    setLoading(true);
    const ingredient = ingredients.find(ingredient => ingredient.id === active);

    if (ingredient && ingredient.name) {
      const { name } = ingredient;
      await fetchAPI({
        method: 'PUT',
        url: replaceUrl(`${PRODUCTS_INGREDIENTS_BY_ID_URL}`, { id }),
        data: {
          name,
        }
      });
    }
    setActive(0);
    setLoading(false);
  };

  const handleDelete = async (id) => {

    Modal.confirm({
      content: <FormattedMessage {...messages.deleteConfirmCustomer}/>,
      okText: <FormattedMessage {...messages.ok} />,
      cancelText: <FormattedMessage {...messages.cancel} />,
      keyboard: true,
      onOk: async () => {
        const response = await fetchAPI({
          method: 'DELETE',
          url: replaceUrl(`${PRODUCTS_INGREDIENTS_BY_ID_URL}`, { id })
        });

        if (response) {
          setIngredients(ingredients && ingredients.filter(ingredient => ingredient.id != id));
          setIngredientsIdList(() => ingredients.filter(ingredient => ingredient.id != id).map(x => x.id));
        }
      },
    });



    setActive(0);
  };

  const onChange = (e) => {
    const name = e.target.value;
    ingredients && ingredients.map(ingredient => {

      if (ingredient.id === active) {
        ingredient.name = name
      }
      return ingredient;
    });

    setIngredients(ingredients);

  };

  useEffect(() => {
    setLoading(true);
    const ingredients = products && products[0] && products[0].ingredients ? products[0].ingredients : [];
    setIngredients(ingredients);
    setLoading(false);
  }, []);

  return (
    <IngredientWrapper>
      <Spin spinning={loading}>
        <div className="ingredient">
          <div className="ingredient__header">
            <div className="ingredient__title">{title}</div>
            <Button type="primary" shape="circle" onClick={() => showModal()}> <PlusCharacter /> </Button>
            <Modal
              visible={visible}
              onOk={handleOk}
              onCancel={handleCancel}
              okText="Thêm"
              centered
              footer={null}
              width={330}
            >
              <ModalWrapper>
                <Form
                  form={form}
                >
                  <div className="container">

                    <div className="title">Thêm thành phần</div>
                    <Form.Item name="name">
                      <FloatLabel label="Tên thành phần" />
                    </Form.Item>
                    <Button className="add-button" type="primary" loading={loading}
                      onClick={() => {
                        form
                          .validateFields()
                          .then(values => {
                            handleOk(values);
                            form.resetFields();
                          })
                          .catch(info => {
                            console.log('Validate Failed:', info);
                          });
                      }}
                    >Thêm</Button>
                  </div>
                </Form>
              </ModalWrapper>
            </Modal>
          </div>
          <div className="ingredient__content">
            {
              ingredients && ingredients.length > 0 && ingredients.map(ingredient => {
                if (!ingredient) {
                  return null;
                }
                const { id, name } = ingredient;
                return (
                  <div className={`item ${id === active ? 'active' : ''}`}>
                    <div className="view-mode" onClick={() => {

                      if (id) {
                        setActive(id);
                      }

                    }}>{name}</div>
                    <FloatLabel className="edit-mode"
                      addonAfter={<Icons id={id}
                        handleEdit={handleEdit}
                        handleDelete={handleDelete} />}
                      defaultValue={name} onChange={onChange} />
                  </div>
                );
              })
            }

          </div>

        </div>
      </Spin>
    </IngredientWrapper>
  )

}
