import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {
  Input,
  Modal,
  Button,
  Form,
  InputNumber
} from 'antd';
import _ from 'lodash';
import { EditItem } from './editItem';
import {EditIcon, RemoveIcon, AddIcon, PlusCharacter} from 'styles/icon-components';
import {fetchAPI, replaceUrl} from 'utils/fetchAPI';
import {
  PRODUCTS_SIZES,
  PRODUCTS_SIZES_BY_ID_URL
} from 'containers/App/urls';
import { digits } from 'utils/number';
import FloatLabel from 'components/FormatInput/FloatLabel';

const AddonsWrapper = styled.div`
 .ant-input {
  padding: 7px 15px !important;
  height: 32px !important;
  border-radius: 16px;
  border: solid 1px #dddddd;
}
.ant-btn {
  padding: 0;
}

.addons {
  &__title {
    color: #333333;
    font-size: 15px;
    padding-bottom: 20px;
    font-weight: 600;
  }

  &__header {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
  }

  &__add {
    cursor: pointer;
    margin-right: -5px;
  }

  &__content {
    height: 140px;
    overflow: auto;
  }

  .item {
    display: inline-block;
    width: max-content;
    cursor: pointer;
    padding-right: 10px;
    padding-bottom: 10px;
    height: 44px;
    overflow: hidden;
    font-size: 14px;
    color: #4a4a4a;
    .view-mode {
      display: block;
      padding: 7px 15px !important;
      height: 32px !important;
      border-radius: 16px;
      border: solid 1px #dddddd;
      cursor: pointer;
      font-size: 14px;
    }
    .edit-mode {
      display: none;
    }
    &.active {
      padding-right: 0;
      width: 100%;

      .view-mode {
        display: none;
      }
      .edit-mode {
        display: block;
      }
    }
  }
}


`;

const ModalWrapper = styled.div`
 .container {
  display: flex;
	flex-direction: column;
	flex-wrap: nowrap;
	justify-content: space-between;
	align-items: center;
	align-content: stretch;
  
  padding: 6px;
 .title {
  color: #333333;
  font-size: 18px;
  font-weight: 600;
  line-height: 19px;
  text-align: center;
  padding-bottom: 20px;
 } 
 .name {
  color: #333333;
  font-size: 16px;
  font-weight: 600;
  margin-bottom: 20px;
 }
.add-button {
   width: 270px;
   height: 44px;
   margin-top: 20px;
   font-weight: 600;
 }
 
 }
 
 .size-name, .size-price {
  width: 270px;
  height: 44px;
  border-radius: 22px;
  border: solid 1px #e6e6e6;
 }

 .size-price {
   padding-top: 4px;
 }
 
`;

const Icons = (props) => {
  const {id, handleEdit, handleDelete} = props;

  const handleEditClick = () => {
    handleEdit(id);
  };

  const handleDeletelick = () => {
    handleDelete(id);
  };

  return (
    <div className="icons"><span onClick={handleEditClick}><EditIcon/></span>|<span
      onClick={handleDeletelick}><RemoveIcon/></span></div>
  )
};

export function Size(props) {
  const {title, menuDetails, setSizesIdList} = props;
  const {products} = menuDetails;
  const [active, setActive] = useState(0);
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [sizes, setSizes] = useState<any[]>([]);
  const [form] = Form.useForm();

  const showModal = () => {
    setVisible(true);
    form.resetFields();
  };
  const handleCancel = e => {
    setVisible(false);
  };

  const handleOk = async (values) => {
    setLoading(true);
    if (active) {
      const response = await fetchAPI({
        method: 'PUT',
        url: replaceUrl(`${PRODUCTS_SIZES_BY_ID_URL}`, {id: active}),
        data: values
      });
      if (response) {
        const index = _.findIndex(sizes, size => size.id === active);
        sizes.splice(index, 1, response);
        setSizes([...sizes]);
      }
      setActive(0);
    } else {
      const response = await fetchAPI({
        method: 'POST',
        url: PRODUCTS_SIZES,
        data: values
      })
      if (response) {
        const newSizeList = [ ...sizes, response ];
        setSizes(newSizeList);
        setSizesIdList(newSizeList.map(size => size.id));
      }
    }
    setVisible(false);
    setLoading(false); 
  };

  const handleEdit = async (id) => {
    setActive(id);
    const size = sizes.find(size => size.id === id);
    form.setFieldsValue(size);
    setVisible(true);
  };

  const handleDelete = async (id) => {
    const response = await fetchAPI({
      method: 'DELETE',
      url: replaceUrl(`${PRODUCTS_SIZES_BY_ID_URL}`, {id})
    });
    if (response) {
      const newSizeList = sizes && sizes.filter(size => size.id != id);
      setSizes(newSizeList);
      setSizesIdList(newSizeList.map(size => size.id));
    }
    setActive(0);
  };

  useEffect(() => {
    const sizes = products && products[0] && products[0].sizes ? products[0].sizes : [];
    setSizes(sizes);
  }, []);

  return (
    <AddonsWrapper>
      <div className="addons">
        <div className="addons__header">
          <div className="addons__title">{title}</div>
          <Button type="primary" shape="circle" onClick={() => showModal()}> <PlusCharacter /> </Button>
          <Modal
            visible={visible}
            onOk={handleOk}
            onCancel={handleCancel}
            okText="Thêm"
            centered
            footer={null}
            width={330}
          >
            <ModalWrapper>
              <Form form={form} onFinish={handleOk}>
                <div className="container">
                  <div className="title">Thêm kích cỡ</div>
                  <Form.Item name="name" rules={[{ required: true, message: "Vui lòng nhập tên kích cỡ" }]}>
                    <FloatLabel  className="size-name" label="Tên kích cỡ*" value=""/>
                  </Form.Item>
                  <Form.Item name="price" rules={[{ required: true, message: "Vui lòng nhập giá tiền" }]}>
                    <FloatLabel className="size-price"  label="Giá*" min={0} formatter={digits} />
                  </Form.Item>
                  <Button className="add-button" type="primary" htmlType="submit" loading={loading}>Thêm</Button>
                </div>
              </Form>
            </ModalWrapper>
          </Modal>
        </div>
        <div className="addons__content">
          {
            sizes && sizes.length > 0 && sizes.map(item => {
              if(!item || /tiêu\schuẩn/i.test(item.name)){
                return null;
              }
              return (
                <div className="item">
                  <div className="view-mode">
                    <EditItem item={item} handleEdit={handleEdit} handleDelete={handleDelete} />
                  </div>
                </div>
              )
            })
          }
        </div>

      </div>
    </AddonsWrapper>
  )

}
