import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import { Input, Modal, Button, Spin, Select, Form } from 'antd';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import {
  EditIcon,
  RemoveIcon,
  AddIcon,
  PlusCharacter,
} from 'styles/icon-components';
import {
  PRODUCTS_COOKING_REQUEST_GROUPS,
  PRODUCTS_COOKING_REQUEST_GROUP_BY_ID_URL,
} from 'containers/App/urls';

const IngredientWrapper = styled.div`
  .ant-input {
    padding: 7px 15px !important;
    height: 32px !important;
    border-radius: 16px;
    border: solid 1px #dddddd;
  }

  .ant-btn {
    padding: 0;
  }

  .ingredient {
    &__title {
      color: #333333;
      font-size: 15px;
      padding-bottom: 20px;
      font-weight: 600;
    }

    &__header {
      display: flex;
      flex-direction: row;
      justify-content: space-between;
    }

    &__content {
      height: 140px;
      overflow: auto;
    }

    &__add {
      cursor: pointer;
      margin-right: -5px;
    }

    .item {
      display: inline-block;
      width: max-content;
      cursor: pointer;
      padding-right: 10px;
      padding-bottom: 10px;
      height: 44px;
      overflow: hidden;
      font-size: 14px;
      color: #4a4a4a;
      .view-mode {
        display: block;
        padding: 7px 15px !important;
        height: 32px !important;
        border-radius: 16px;
        border: solid 1px #dddddd;
        cursor: pointer;
        font-size: 14px;
      }
      .edit-mode {
        display: none;
      }
      &.active {
        padding-right: 0;
        width: 100%;

        .view-mode {
          display: none;
        }
        .edit-mode {
          display: block;
        }
      }
    }
  }
`;

const ModalWrapper = styled.div`
  .container {
    display: flex;
    flex-direction: column;
    flex-wrap: nowrap;
    justify-content: space-between;
    align-items: center;
    align-content: stretch;

    padding: 6px;
    .title {
      color: #333333;
      font-size: 18px;
      font-weight: 600;
      line-height: 19px;
      text-align: center;
      padding-bottom: 20px;
    }
    .add-button {
      width: 270px;
      height: 44px;
      margin-top: 20px;
      font-weight: 600;
    }
  }

  select {
    width: 270px;
    height: 44px;
    border-radius: 22px;
    border: solid 1px #e6e6e6;
  }
`;

const Icons = props => {
  const { id, handleEdit, handleDelete } = props;

  const handleEditClick = () => {
    handleEdit(id);
  };

  const handleDeletelick = () => {
    handleDelete(id);
  };

  return (
    <div className="icons">
      <span onClick={handleEditClick}>
        <EditIcon />
      </span>
      |
      <span onClick={handleDeletelick}>
        <RemoveIcon />
      </span>
    </div>
  );
};

export function Style(props) {
  const { title, menuDetails, setCookingRequestGroupsList } = props;
  const { products } = menuDetails;
  const [visible, setVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  const [active, setActive] = useState(0);
  const [originCookingRequestGroups, setOriginCookingRequestGroups] = useState<
    any[]
  >([]);
  const [cookingRequestGroups, setCookingRequestGroups] = useState<any[]>([]);
  const [form] = Form.useForm();

  const showModal = () => {
    setVisible(true);
  };
  const handleCancel = () => {
    setVisible(false);
  };
  const handleOk = async values => {
    setLoading(true);
    const { cookingRequests } = values;
    const newCookingRequestGroups = originCookingRequestGroups.filter(request =>
      cookingRequests.includes(request.id),
    );
    setCookingRequestGroups(newCookingRequestGroups);
    setCookingRequestGroupsList(
      newCookingRequestGroups.map(request => request.id),
    );
    setVisible(false);
    setLoading(false);
  };

  const handleEdit = async id => {
    try {
      setLoading(true);
      const request = cookingRequestGroups.find(
        request => request.id === active,
      );

      if (request && request.name) {
        const { name } = request;
        await fetchAPI({
          method: 'PUT',
          url: replaceUrl(`${PRODUCTS_COOKING_REQUEST_GROUP_BY_ID_URL}`, {
            id,
          }),
          data: {
            name,
          },
        });
      }
      setActive(0);
    } finally {
      setLoading(false);
    }
  }

  const handleDelete = async id => {
    Modal.confirm({
      content: `Bạn có muốn xóa ${name} ?`,
      okText: 'Đồng ý',
      cancelText: `Huỷ`,
      keyboard: true,
      onOk: () => {
        const newCookingRequestGroups =
          cookingRequestGroups &&
          cookingRequestGroups.filter(request => request.id != id);
        setCookingRequestGroups(newCookingRequestGroups);
        setCookingRequestGroupsList(
          newCookingRequestGroups.map(request => request.id),
        );
      },
    });
    setActive(0);
  };

  const onChange = e => {
    const name = e.target.value;
    cookingRequestGroups &&
      cookingRequestGroups.map(cookingRequestGroup => {
        if (cookingRequestGroup.id === active) {
          cookingRequestGroup.name = name;
        }
        return cookingRequestGroup;
      });
    setCookingRequestGroups(cookingRequestGroups);
  };

  useEffect(() => {
    setLoading(true);
    fetchAPI({
      method: 'GET',
      url: PRODUCTS_COOKING_REQUEST_GROUPS,
    })
      .then(response => {
        if (response) {
          setOriginCookingRequestGroups(response);
          setLoading(false);
        }
      })
      .catch(error => {
        setLoading(false);
      });
  }, []);

  useEffect(() => {
    const cookingRequestGroups =
      products && products[0] && products[0].cookingRequestGroups
        ? products[0].cookingRequestGroups
        : [];
    setCookingRequestGroups(cookingRequestGroups);
  }, []);

  return (
    <IngredientWrapper>
      <Spin spinning={loading}>
        <div className="ingredient">
          <div className="ingredient__header">
            <div className="ingredient__title">{title}</div>
            <Button type="primary" shape="circle" onClick={() => showModal()}>
              {' '}
              <PlusCharacter />{' '}
            </Button>
            <Modal
              visible={visible}
              onOk={handleOk}
              onCancel={handleCancel}
              okText="Thêm"
              centered
              footer={null}
              width={330}
            >
              <ModalWrapper>
                <Form form={form}>
                  <div className="container">
                    <div className="title">Thêm cách pha chế</div>
                    <Form.Item
                      name="cookingRequests"
                      initialValue={cookingRequestGroups.map(
                        request => request.id,
                      )}
                    >
                      <Select
                        placeholder="Tên cách pha chế"
                        mode="multiple"
                        showArrow
                        style={{ width: '270px' }}
                      >
                        {originCookingRequestGroups.map(request => (
                          <Select.Option value={request.id}>
                            {request.name}
                          </Select.Option>
                        ))}
                      </Select>
                    </Form.Item>
                    <Button
                      className="add-button"
                      type="primary"
                      loading={loading}
                      onClick={() => {
                        form
                          .validateFields()
                          .then(values => {
                            handleOk(values);
                            form.resetFields();
                          })
                          .catch(info => {
                            console.log('Validate Failed:', info);
                          });
                      }}
                    >
                      Thêm
                    </Button>
                  </div>
                </Form>
              </ModalWrapper>
            </Modal>
          </div>
          <div className="ingredient__content">
            {cookingRequestGroups &&
              cookingRequestGroups.length > 0 &&
              cookingRequestGroups.map(request => {
                if (!request) {
                  return null;
                }
                const { id, name } = request;
                return (
                  <div className={`item ${id === active ? 'active' : ''}`}>
                    <div
                      className="view-mode"
                      onClick={() => {
                        if (id) {
                          setActive(id);
                        }
                      }}
                    >
                      {name}
                    </div>
                    <Input
                      className="edit-mode"
                      addonAfter={
                        <Icons
                          id={id}
                          handleEdit={handleEdit}
                          handleDelete={handleDelete}
                        />
                      }
                      defaultValue={name}
                      onChange={onChange}
                    />
                  </div>
                );
              })}
          </div>
        </div>
      </Spin>
    </IngredientWrapper>
  );
}
