import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {Popover, Modal, Typography, notification} from 'antd';
import {Link} from "react-router-dom";
import { FormattedMessage, injectIntl } from 'react-intl';

import {ThreeDotsIcon, EditIcon, RemoveIcon} from '../../../styles/icon-components';
import {fetchAPI} from 'utils/fetchAPI';
import {MENUS_MENU_ITEM_URL} from 'containers/App/urls';
import messagesGlobal from 'translations/messages';

const { Title } = Typography;

const MenuListActionWrapper = styled.div`
    .menu-list-action {
    padding: 10px 15px;
    
    &__edit {
     border-bottom: 1px solid #4c4c4c;
     padding-bottom: 15px;
     cursor: pointer;
     > span {
      padding: 0;
     }
     svg {
     margin-right: 10px;
      g {
       fill: #fff;
      }
     }
    }
    
    &__delete {
     padding-top: 15px;
     cursor: pointer;
     > span {
      padding: 0;
     }
     svg {
     margin-right: 10px;
      g {
       fill: #fff;
      }
     }
    }
    
    }
    
    a {
     text-decoration: none;
     color: inherit;
    }
    
`;


const actionContent = (props) => {
  const {type, menuItem, getMenus} = props;
  const {id, name} = menuItem;

  const handleDelete = async () => {
    const response = await fetchAPI({
      method: 'DELETE',
      url: `${MENUS_MENU_ITEM_URL}/${id}`,
    });
    if (response) {
      getMenus()
      notification.success({ message: <FormattedMessage {...messagesGlobal.successDeleted}/> });
    }
  };

  return (<MenuListActionWrapper>
    <div className="menu-list-action">
      <div className="menu-list-action__edit">
        <Link to={type === 'menu' ? `/product/edit/${id}` : `/product/combo/edit/${id}`}>
          <EditIcon/> <FormattedMessage {...messagesGlobal.edit}/>
        </Link>
      </div>
      <div className="menu-list-action__delete" onClick={handleDelete}>
        <RemoveIcon/> <FormattedMessage {...messagesGlobal.deleteBtn}/>
      </div>
    </div>
  </MenuListActionWrapper>);
};

export function MenuListAction(props){
  return (
    <Popover placement="top"  content={actionContent(props)} trigger="click">
      <div style={{ width: '100%', height: '100%'}}>
        <div style={{ position: "absolute", right: '50px'}}>
          <ThreeDotsIcon/>
        </div>
      </div>
    </Popover>
  );
}
