import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {SearchOutlined} from '@ant-design/icons';
import { PUBLIC_API } from 'containers/App/urls';
import {Spin} from 'antd';

import {MenuItemIcon} from 'styles/icon-components';
import {MenuListAction} from "./menuListAction";

const MenuListComboTabWrapper = styled.div`
    .menu-tab {
      width: calc(100% + 50px);
      @media only screen and (max-width: 736px) {
         width: calc(100% + 15px);
        }
        
        @media only screen 
        and (min-device-width: 768px) 
        and (max-device-width: 1024px) 
        and (-webkit-min-device-pixel-ratio: 1) {
         width: calc(100% + 15px);
        }
	    &__section {
        display: block;
      
	    }
	    
	    .section {
	     &__content {
	      display: flex;
	      flex-wrap: wrap;
	      padding-top: 30px;
	     }
	    }
	    
      .item {
        display: flex;
	      flex-direction: row; 
	      justify-content: flex-start;
	      align-items: flex-start;
        width: 33%;
        min-height: 90px;
        padding-right: 49px;
        padding-bottom: 20px;
        position: relative;
        @media only screen and (max-width: 736px) {
         width: 100%;
         padding-right: 15px;
        }
        @media only screen 
        and (min-device-width: 768px) 
        and (max-device-width: 1024px) 
        and (-webkit-min-device-pixel-ratio: 1) {
         padding-right: 15px;
        }
       &__image {
        display: flex;
	      flex-direction: row; 
	      justify-content: center;
	      align-items: center;
         height: 62px; 
         width: 70px;
         margin-right: 20px;       
         background-color: #ECECEC;
         
         img{
          width: 70px;
          height: 62px; 
         }
       }
       
       &__title {
        font-size: 15px;
        margin-right:15px;
        font-weight: bold;
        font-stretch: normal;
        color: #333333;
        padding-bottom: 5px;
       }
       
       &__description {
        font-size: 13px;
        color: #9c9696;
        display: -webkit-box;
        max-width: 200px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
       }
       
       &__actions {
         position: absolute;
         width: 100%;
         height: 100%;
         cursor: pointer;
         @media only screen and (max-width: 736px) {
          right: 0px;
         }
         
         @media only screen 
        and (min-device-width: 768px) 
        and (max-device-width: 1024px) 
        and (-webkit-min-device-pixel-ratio: 1) {
         right: 5px;
        }
       }
       
      }
    }
`;

export function MenuListComboTab(props) {
  const {loading, comboList, getMenus} = props;
  return (<MenuListComboTabWrapper>
    <div className="menu-tab">
      {loading && <div style={{textAlign: "center", top: '20px', position: "relative"}}><Spin/></div>}
      <div className="section__content">
        {comboList.map(comboItem => {
          const {id, photo, name, description} = comboItem;
          return (
            <div className="item" key={'menuItem_' + id}>
              <div className="item__image">
                {photo ? <img src={`${PUBLIC_API}/${photo}`} style={{objectFit: 'cover'}}/> : <MenuItemIcon/>}
              </div>
              <div className="item__content">
                <div className="item__title">{name}</div>
                <div className="item__description">{description}</div>

              </div>
              <div className="item__actions">
                <MenuListAction type="combo" menuItem={comboItem} getMenus={getMenus}/>
              </div>
            </div>
          );
        })}
      </div>
    </div>
  </MenuListComboTabWrapper>);
}
