import React, { useState } from "react";
import IMG_PAYMENT_EDIT from "../../../images/payment-edit.svg";
import IMG_PAYMENT_EDIT_1 from "../../../images/payment-edit-1.svg";
import IMG_PAYMENT_DEL from "../../../images/payment-del.svg";
import IMG_PAYMENT_PDF from "../../../images/payment-pdf.svg";
import { Space, Modal } from "antd";
import moment from 'moment';
import { Card as StyledCard } from "styles/custom-styled-components";
import { CardDetailWrapper, HoveredCardWrapper, PaymentCardContainer } from "../styles";
import { Type } from "../types";
import { deletePayment, showPaymentModal } from "../actions";
import { useDispatch } from "react-redux";
import { DATE_FORMAT } from "../../../utils/constants";
import messages from "../messages";
import { injectIntl } from "react-intl";
import { PdfDocument } from "components/GeneralPdf/billTemplate";
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import NumberFormat from 'react-number-format';

function HoveredCard(props) {
  const { type, payment } = props;
  const dispatch = useDispatch();
  const editBtnStyle = {
    width: 60,
    height: 60,
    borderRadius: '50%',
  };
  const handleEdit = () => {
    dispatch(showPaymentModal(payment));
  }

  const handleDelete = () => {
    dispatch(deletePayment(payment.id));
  }


  return (
    <HoveredCardWrapper>
      <Space>
        <img src={IMG_PAYMENT_EDIT_1} alt="" style={editBtnStyle} onClick={handleEdit}/>
      </Space>
    </HoveredCardWrapper>
  );
}

function CardDetail(props) {
  const currencyMemoi = useCurrencyHook();
  const {
    intl,
    payment: {  billName, merchantName, amount, createdTime, paymentTime, serialNumber, expiredPayTime, paidAmount },
    type
  } = props;
  const handleClickPdf = () => {
    Modal.info({
      title: billName,
      content: <PdfDocument data={props.payment}/>,
    });
  }
  return (
    <CardDetailWrapper>
      <div className="card-header">
        <div className="card-header__title">
        <div className="card-header__serial-number">{serialNumber ? serialNumber.substring(17) : ''}</div>
          <div className="card-header__name">{billName}</div>
        </div>
        <img className="card-header__img" src={IMG_PAYMENT_PDF} alt="" style={{width: '38px', height: '49px'}} onClick={() => handleClickPdf()}/>
      </div>
      <hr />
      <div className="card-content">
        <div className="card-content__item">
          <span className="card-content__name">{intl.formatMessage(messages.amount)}</span>
          <div className="card-content__value--red"><NumberFormat value={Math.round(type === Type.unpaid ? paidAmount ? paidAmount : 0 : amount)} displayType={'text'} thousandSeparator={true} renderText={value => `${value} ${currencyMemoi}`} >{amount}</NumberFormat></div>
        </div>
        <div className="card-content__item">
          <span className="card-content__name">{intl.formatMessage(messages.createdTime)}</span>
          <div className="card-content__value">{moment(createdTime).format(DATE_FORMAT)}</div>
        </div>
        <div className="card-content__item">
          <span className="card-content__name">{type === Type.paid ? intl.formatMessage(messages.expiredPayTime) : intl.formatMessage(messages.paymentTime)}</span>
          <div className="card-content__value">{type === Type.paid ? (expiredPayTime ? moment(expiredPayTime).format(DATE_FORMAT) : 'N/A') : (paymentTime ? moment(paymentTime).format(DATE_FORMAT) : 'N/A')}</div>
        </div>
      </div>
    </CardDetailWrapper>
  );
}

function Card(props) {
  const { payment, type, intl } = props;
  const [isHovered, setHovered] = useState(false);
  return (
    <PaymentCardContainer>
      <StyledCard
        isHovered={isHovered}
        height="200px"
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
        style={{padding: '20px 15px 20px'}}
        className="touch-card"
        >
        <CardDetail payment={payment} intl={intl} type={type}/>
        {isHovered && ( <HoveredCard type={type} payment={payment}/> )}
      </StyledCard>
    </PaymentCardContainer>
  );
}

export default injectIntl(Card);
