import React, { useEffect } from 'react';
import { DatePicker, Button, Form, Input, Radio, Space } from 'antd';
import moment from 'moment';
import { PaymentEditContainer } from '../styles';
import { updatePayment } from '../actions';
import { useDispatch } from 'react-redux';
import { Type } from '../types';
import { DATE_FORMAT } from '../../../utils/constants';
import messages from '../messages';
import { injectIntl } from 'react-intl';
import NumberFormat from 'react-number-format';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import FloatLabel from 'components/FormatInput/FloatLabel';

const { TextArea } = Input;

function Detail(props) {
  const dispatch = useDispatch();
  const currencyMemoi = useCurrencyHook();
  const [form] = Form.useForm();

  const { initialValues, type, intl } = props;

  const onFinish = values => {
    values.paymentTime = values.paymentTime.format('YYYY-MM-DD');
    dispatch(updatePayment(initialValues.id, values));
  };

  useEffect(() => {
    if (initialValues?.paymentTime) {
      initialValues.paymentTime = initialValues.paymentTime
        ? moment(initialValues.paymentTime)
        : undefined;
    }
    form.setFieldsValue(initialValues);
  }, [initialValues]);

  return (
    <PaymentEditContainer>
      <div style={{ textAlign: 'center' }}>
        <h2 className="title-global-sub-header">{initialValues?.merchantName}</h2>
        <h3 className="title-global">{initialValues?.billName}</h3>
      </div>
      <div
        style={{
          fontSize: '13px',
          fontWeight: 600,
          backgroundColor: '#FAFAFA',
          padding: '10px 5px',
          marginTop: '15px',
          display: 'flex',
          justifyContent: 'space-between',
        }}
      >
        <span>
          {' '}
          {initialValues?.serialNumber
            ? initialValues?.serialNumber.substring(17)
            : ''}
        </span>
        <span style={{ color: '#DC5454' }}>
          <NumberFormat
            value={Math.round(initialValues?.amount)}
            displayType={'text'}
            thousandSeparator={true}
            renderText={value => `${value} ${currencyMemoi}`}
          />
        </span>
      </div>
      <Form form={form} onFinish={onFinish}>
        <div className="content">
          <div className="content__info">
            <div className="pd">
              <Form.Item
                name="type"
                rules={[
                  {
                    required: true,
                    message: intl.formatMessage(messages.requirePaymentType),
                  },
                ]}
              >
                <Radio.Group name="type" disabled={true}>
                  <Space size={40}>
                    <Radio value={1}>{intl.formatMessage(messages.cash)}</Radio>
                    <Radio value={2}>
                      {intl.formatMessage(messages.transfer)}
                    </Radio>
                  </Space>
                </Radio.Group>
              </Form.Item>
            </div>
            <div className="paymentTime">
              <Form.Item name="paymentTime">
                <FloatLabel
                  label={intl.formatMessage(messages.paymentTime)}
                  format={DATE_FORMAT}
                  style={{ width: '100%' }}
                  disabled={true}
                  typeInput="datepicker"
                />
              </Form.Item>
            </div>
            <div className="form-field__row">
              <Form.Item name="receiptNumber">
                <FloatLabel
                  label={intl.formatMessage(messages.receiptNumber)}
                  disabled={true}
                />
              </Form.Item>
            </div>
            <div className="form-field__row">
              <Form.Item
                name="note"
                rules={[
                  {
                    required: true,
                    message: intl.formatMessage(messages.requireNote),
                  },
                ]}
              >
                <FloatLabel
                  rows={4}
                  label={intl.formatMessage(messages.note)}
                  disabled={true}
                  typeInput="TextArea"
                />
              </Form.Item>
            </div>
          </div>
        </div>
      </Form>
    </PaymentEditContainer>
  );
}

export default injectIntl(Detail);
