import React, { useState } from "react";
import { Link } from "react-router-dom";
import { roundNumber } from "utils/number";
import { Type } from "../types";
import { getPayments } from "../actions";
import { useDispatch } from "react-redux";
import { PaymentListHeaderWrapper } from "../styles";
import messages from "../messages";
import { injectIntl } from "react-intl";
import NumberFormat from 'react-number-format';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';

function Header(props) {
  const dispatch = useDispatch();
  const { type, amount, intl, paidAmount } = props;
  const [searchValue, setSearchValue] = useState('');
  const currencyMemoi = useCurrencyHook();

  const handleSearchVal = () => {
    dispatch(getPayments(type, searchValue.trim()));
  }

  return (
    <PaymentListHeaderWrapper>
      <div className="header__toolbar">
        <div className="tabs">
          <Link
            to="/billing"
            className={`tabs__promotion ${type === Type.paid ? 'active' : ''}`}>
            {intl.formatMessage(messages.unpaid)}
          </Link>
          <Link
            to="/billing/unpay"
            className={`tabs__promotion ${type === Type.unpaid ? 'active' : ''}`}>
            {intl.formatMessage(messages.paid)}
          </Link>
        </div>
        <div className="filter">
          {(type === Type.paid)  ? (
            <div style={{ marginRight: '25px', marginTop: '10px', fontSize: '15px', }}>
              {intl.formatMessage(messages.unpaidAmount)}
              <span
                style={{
                  color: '#DC5454',
                  fontWeight: 600,
                  fontSize: '18px',
                  paddingLeft: '7px',
                }}>
                  <NumberFormat value={roundNumber(amount)} displayType={'text'} thousandSeparator={true} renderText={value => `${value} ${currencyMemoi}`} >{amount}</NumberFormat>
              </span>
            </div>
          ) : (
              <div style={{ marginRight: '25px', marginTop: '10px', fontSize: '15px' }}>
              {intl.formatMessage(messages.paidAmount)}
              <span
                style={{
                  color: '#35A211',
                  fontWeight: 600,
                  fontSize: '18px',
                  paddingLeft: '7px',
                }}>
                <NumberFormat value={roundNumber(paidAmount)} displayType={'text'} thousandSeparator={true} renderText={value => `${value} ${currencyMemoi}`} >{paidAmount}</NumberFormat>
              </span>
            </div>
          )}
        </div>
      </div>
    </PaymentListHeaderWrapper>
  );
}

export default injectIntl(Header);
