import React, { useEffect } from "react";
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import makeSelectPaymentList from './selectors';
import reducer from './reducer';
import saga from './saga';
import Header from "./Header";
import Card from "./Card";
import { Modal, Spin } from "antd";
import Detail from "./Detail";
import { PaymentListWrapper } from "./styles";
import { Type } from "./types";
import { closePaymentModal, getPayments } from "./actions";

const stateSelector = createStructuredSelector({
  paymentList: makeSelectPaymentList(),
});

interface Props {
  readonly type: Type;
}

function PaymentList(props: Props) {
  useInjectReducer({ key: 'paymentList', reducer: reducer });
  useInjectSaga({ key: 'paymentList', saga: saga });

  const { paymentList } = useSelector(stateSelector);
  const { isFetching, amount, payments, showModal, payment, paidAmount } = paymentList;
  const dispatch = useDispatch();

  const { type } = props;

  const handleCancel = () => {
    dispatch(closePaymentModal())
  }

  useEffect(() => {
    dispatch(getPayments(type, ''))
  }, [type]);
  
  return (
    <PaymentListWrapper>
      <Spin spinning={isFetching}>
        <div className="payment-header">
          <Header type={type} amount={amount} paidAmount={paidAmount}/>
        </div>
        <div className="list">
          {payments &&
            payments.map(payment => (
              <div className="card">
                <Card type={type} payment={payment} />
              </div>
            ))
          }
        </div>
      </Spin>
      <Modal
        visible={showModal}
        width={350}
        centered
        footer={null}
        onCancel={handleCancel}>
        <Detail type={type} initialValues={payment} />
      </Modal>
    </PaymentListWrapper>
  );
}

export default PaymentList;
