import ActionTypes from './constants';
import { ContainerState, ContainerActions } from './types';
import _ from "lodash";

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  message: '',
  amount: 0,
  paidAmount: 0,
  payments: [],
  showModal: false,
  payment: null,
};

function paymentListReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_PAYMENTS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PAYMENTS_SUCCESS:
      const { amount, paidAmount, bills } = action.payload;
      return { ...state, isFetching: false, payments: bills, amount, paidAmount };
    case ActionTypes.GET_PAYMENTS_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.UPDATE_PAYMENT_SUCCESS:
      return { ...state, showModal: false };
    case ActionTypes.UPDATE_PAYMENT_FAIL:
      return { ...state, message: action.payload, showModal: false };
    case ActionTypes.DELETE_PAYMENT:
      return { ...state, isFetching: true };
    case ActionTypes.DELETE_PAYMENT_SUCCESS:
      _.remove(state.payments, payment => payment.id === action.payload);
      return { ...state, isFetching: false, payments: state.payments};
    case ActionTypes.DELETE_PAYMENT_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.SHOW_PAYMENT_MODAL:
      return { ...state, showModal: true, payment: action.payload };
    case ActionTypes.CLOSE_PAYMENT_MODAL:
      return { ...state, showModal: false, payment: null };
    default:
      return state;
  }
}

export default paymentListReducer;
