import { callApi, success } from "../../utils/apiUtils";
import { put, takeLatest } from "redux-saga/effects";
import {
  deletePaymentFail,
  deletePaymentSuccess,
  getPaymentFail,
  getPaymentsSuccess, updatePaymentFail, updatePaymentSuccess
} from "./actions";
import ActionTypes from "./constants";

export function* getPayments({payload: { type, searchText}}) {
  try {
    const searchParams = new URLSearchParams();
    if (type) {
      searchParams.append('status', type);
    }
    if (searchText) {
      searchParams.append('searchText', searchText);
    }
    const { code, data, message } = yield callApi(`/admin/bills?${searchParams.toString()}`, 'GET');
    if (success(code)) {
      yield put(getPaymentsSuccess(data));
    } else {
      yield put(getPaymentFail(message));
    }
  } catch (error) {
    yield put(getPaymentFail(error.message));
  }
}

export function* updatePayment({ payload: {id, payment}}) {
  try {
    const { code, data, message } = yield callApi(`/admin/bill/${id}`, 'PUT', payment, { isFormData: true});
    if (success(code)) {
      yield put(updatePaymentSuccess(data));
    } else {
      yield put(updatePaymentFail(message));
    }
  } catch (error) {
    yield put(updatePaymentFail(error.message));
  }
}

export function* deletePayment({payload: id}) {
  try {
    const { code, data, message } = yield callApi(`/admin/bill/${id}`, 'DELETE');
    if (success(code)) {
      yield put(deletePaymentSuccess(id));
    } else {
      yield put(deletePaymentFail(message));
    }
  } catch (error) {
    yield put(deletePaymentFail(error.message));
  }
}

// Individual exports for testing
export default function* paymentListSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PAYMENTS, getPayments);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_PAYMENT, updatePayment);
  // @ts-ignore
  yield takeLatest(ActionTypes.DELETE_PAYMENT, deletePayment);
}
