import styled from "styled-components";
import { CARD_HEIGHT } from "../../styles/constants";

export const PaymentListWrapper = styled.div`
  padding-left: 30px;
  padding-right: 30px;

  .list {
    display: flex;
    flex-wrap: wrap;
    padding-left: 0;
    .card {
      list-style: none;
      flex: 0 0 33.333333%;
      padding: 10px;
      background-color: transparent;
      border: none;
    }
  }

  @media only screen and (max-width: 1050px) {
    .list {
      .card {
        flex: 0 0 50%;
      }
    }
  }

  @media only screen and (max-width: 620px) {
    .list {
      .card {
        flex: 0 0 100%;
      }
    }
  }

  .payment-header {
    margin-bottom: 19px;
  }
`

export const PaymentEditContainer = styled.div`
  background-color: #ffffff;
  font-family: Muli;

  .form-field {
    &__row {
      textarea {
        border-radius: 0px !important;
      }
    }
  }

  input.ant-input {
    border-radius: 22px;
  }

  .ant-select-selector,
  div.ant-picker {
    min-height: 44px !important;
    align-items: center;
  }

  div.ant-picker {
    border-radius: 22px;
  }

  span.ant-input-group-addon {
    border-bottom-left-radius: 20px;
    border-top-left-radius: 20px;
  }

  span.ant-input-group-addon + input.ant-input {
    border-bottom-left-radius: 0px !important;
    border-top-left-radius: 0px !important;
  }

  .header {
    display: flex;
    justify-content: space-between;
    padding: 0 20px;
    &__title {
      font-size: 16px;
      font-weight: bold;
      color: #333333;
    }
  }

  .content {
    margin-top: 20px;
    &__info {
      padding: 0 10px 0 20px;
    }
    &__avatar {
      display: flex;
      flex-direction: column;
      align-items: center;
      padding: 0 20px 0 10px;
    }
    &__thumnail {
      opacity: 0.2;
      border-radius: 8px;
      background-color: #000000;
    }
    &__desc {
      font-size: 13px;
      color: #a8a8a8;
      margin-top: 14px;
      text-align: center;
    }

    @media screen and (min-width: 1200px) {
      display: flex;
      flex-direction: row-reverse;
      justify-content: space-between;
      &__info {
        flex: 2;
      }
      &__avatar {
        flex: 1;
      }
    }
  }

  .ur,
  .pd,
  .name {
    display: flex;
    > div {
      &:nth-child(1) {
        flex: 1;
        margin-right: 5px;
      }
      &:nth-child(2) {
        flex: 1;
        margin-left: 5px;
      }
    }
  }

  .btn {
    width: 100%;
    height: 44px;
    border-radius: 22px;
    background-color: #9cd339;
    color: white;
  }
`;


export const PaymentCardContainer = styled.div`
  .payment-name {
    font-size: 18px;
    color: #333;
    font-weight: 600;
  }

  .payment-name-desc {
    font-size: 15px;
    color: #4a4a4a;
    font-weight: 400;
  }
`
export const HoveredCardWrapper = styled.div`
  position: relative;
  top: calc(-${CARD_HEIGHT} / 2);
  text-align: center;
`;
export const CardDetailWrapper = styled.div`
  .card-header {
    display: flex;
    justify-content: space-between;
    padding-right: 10px;
    &__serial-number {
      font-size: 13px;
      font-weight: 600;
      color: #333333;
    }
    &__name {
      color: #4a4a4a;
      margin-top: 7px;
    }
  }
  .card-content {
    padding-right: 10px;
    &__item {
      display: flex;
      justify-content: space-between;
      margin: 16px 0;
    }
    &__name {
      color: #646464;
    }
    &__value {
      text-align: right;
      color: #333333;
    }
    &__value--red {
      font-weight: 600;
      text-align: right;
      color: #dc5454;
    }
  }
`;
export const PaymentListHeaderWrapper = styled.div`
  .header {
    &__title {
      font-size: 18px;
      font-weight: normal;
      color: #333333;
      padding-bottom: 10px;
    }
    &__toolbar {
      display: flex;
      @media only screen and (max-width: 480px) {
        flex-wrap: wrap;
      }
      @media only screen and (min-device-width: 0px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
        flex-wrap: wrap;
      }
    }
  }
  .ant-select-selection-item {
    line-height: 38px !important;
  }
  .tabs {
    display: flex;
    flex-direction: row;
    flex-wrap: nowrap;
    justify-content: flex-start;
    list-style: none;
    padding: 0;
    margin: 0;
    &__promotion {
      font-size: 15px;
      padding: 17px 10px;
      margin-right: 15px;
      border-bottom: 1px solid #ccc;
      cursor: pointer;
      color: inherit;
      &.active {
        color: #9cd339;
        border-bottom: 2px solid #9cd339;
      }
    }
  }

  .filter {
    display: flex;
    margin-left: auto;
    margin-top: 15px;

    @media only screen and (max-width: 480px) {
      display: block;
      margin: 15px 0 !important;
    }

    @media only screen and (min-device-width: 0px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
      margin: 15px;
      margin-left: 0 !important;
    }

    &__all {
      width: 220px;
      margin-right: 10px;
      > div {
        width: 100%;
      }
      @media only screen and (max-width: 480px) {
        margin: 0;
        width: 100% !important;
      }
    }

    &__search {
      @media only screen and (max-width: 480px) {
        margin-top: 15px;
        width: 100%;
      }
    }
    @media only screen and (min-device-width: 0px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
      width: 100%;
    }
  }
`;
