import React, { useState, useEffect, useCallback } from 'react';
import {
  DatePicker,
  Button,
  Form,
  Select,
  Divider,
  Input,
  Row,
  Col,
  Spin,
  Modal,
  Card,
} from 'antd';
import moment from 'moment';
import styled from 'styled-components';
import { updatePayroll, closePayrollModal } from '../actions';
import { useDispatch, useSelector } from 'react-redux';
import messages from 'translations/messages';
import { FormattedMessage, injectIntl } from 'react-intl';
import { digits } from 'utils/number';
import { DATE_FORMAT } from 'utils/constants';
import { PUBLIC_API } from 'containers/App/urls';
import DEFAULT_AVATAR from '../../../images/defaultAvatar.png';
import { FormatInput } from 'components/FormatInput';
import NumberFormat from 'react-number-format';
import messagesLocal from '../messages';
import { makePayroll, makeIsFetching, makeShowModal } from '../selectors';
import { createStructuredSelector } from 'reselect';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  initialValues: makePayroll(),
  isFetching: makeIsFetching(),
  showModal: makeShowModal(),
});

const ModalWrapper = styled.div`
  .container {
    display: flex;
    flex-direction: column;
    flex-wrap: nowrap;
    justify-content: space-between;
    align-items: baseline;
    align-content: stretch;
    margin: auto;
    .ant-row {
      width: 100%;
    }
    div.ant-picker {
      border-radius: 22px;
    }
    .ant-input-group-wrapper {
      .ant-input-group {
        input {
          border-right: none;
        }
        .ant-input-group-addon:last-child {
          border-radius: 22px;
          border-top-left-radius: 0;
          border-bottom-left-radius: 0;
          width: 53px;
          background: white;
          border-left: none;
        }
        .ant-input-disabled + .ant-input-group-addon{
          background: #f5f5f5;
        }
      }
    }
    .header {
      width: 100%;
      &__title {
        font-size: 18px;
        font-weight: 500;
        margin-bottom: 20px;
        text-align: center;
      }
      @media screen and (max-width: 576px) {
        .header {
          &__desc {
            display: inline-block;
          }
          &__img {
            margin-right: 0px;
            margin: auto;
          }
        }
      }
      &__desc {
        display: flex;
        flex-direction: row;
        justify-content: space-between;
        align-items: start;
        .quantity {
          width: 53px;
          height: 44px;
          display: flex;
          align-items: center;
          border-radius: 22px;
          background-color: #dc3b7f;
          span {
            margin: auto;
            color: white;
          }
        }
        &__right {
          display: flex;
          flex-direction: row;
          padding-top: 20px;
          .payPeriod {
            padding-right: 20px;
            text-align: end;
            &__title {
              color: #9c9696;
              margin-bottom: 13px;
            }
            &__time {
              font-weight: 600;
            }
          }
          .hours {
            &__title {
              color: #9c9696;
              margin-bottom: 13px;
            }
            &__number {
              text-align: end;
              font-weight: 600;
            }
          }
        }
      }
      &__infor {
        padding-top: 20px;
        &__staff {
          display: flex;
          align-items: center;
          margin-bottom: 13px;
        }
        &__name {
          font-weight: 600;
          font-size: 13px;
          color: #333333;
          line-height: 15px;
        }
        &__tax {
          margin-left: 15px;
          font-size: 10px;
          color: #9c9696;
          border-radius: 22px;
          border: solid 1px #9c9696;
          padding: 5px;
        }
        &__sku {
          color: #9c9696;
          line-height: 13px;
        }
        &__spa {
          text-align: start;
          &--name {
            color: #9c9696;
          }
          &--role {
            font-style: italic;
            color: #9cd339;
          }
        }
      }
      &__img {
        border-radius: 4px;
        height: 100px;
        width: 100px;
        text-align: center;
        margin-right: 20px;
        background-color: #ececec;
        img {
          border-radius: 4px;
          height: 100px;
          width: 100px;
          object-fit: cover;
        }
      }
    }
    .body-modal {
      margin-top: 20px;
      > .ant-col {
        .elements-row {
          @media screen and (max-width: 576px) {
            margin-top: 20px;
          }
          padding: 18px;
          background: #f7f7f7;
          border: 1px solid #ededed;
          box-shadow: 0 0 2px 0 rgba(0, 0, 0, 0.2);
          border-top-left-radius: 10px;
          border-top-right-radius: 10px;
          .ant-row {
            padding-bottom: 15px;
            .ant-col {
              line-height: 13px;
            }
            .amount-row {
              font-weight: 600;
              text-align: end;
            }
          }
        }
        .amount-row-last {
          padding: 18px;
          background: #de377f;
          color: #ffffff;
          box-shadow: 0 0 2px 0 rgba(0, 0, 0, 0.2);
          border-bottom-left-radius: 10px;
          border-bottom-right-radius: 10px;
          .amount-row {
            font-weight: 600;
            text-align: end;
          }
        }
      }
    }
    .title {
      color: #333333;
      font-size: 16px;
      font-weight: 700;
      line-height: 19px;
      text-align: center;
      padding-bottom: 20px;
    }
    .btn-wrapper {
      width: 100%;
      text-align: center;
      .add-button {
        width: 70%;
        height: 44px;
        margin-top: 20px;
        font-weight: 600;
      }
    }
  }

  .first-row-input {
    border-top: solid 1px #e6e6e6;
    padding-top: 20px;
    margin-bottom: 0px !important;
  }
  .element-input-wrapper {
    width: 100%;
    input.element-input,
    div.element-input {
      width: 100%;
      height: 44px;
      border-radius: 22px;
      border: solid 1px #e6e6e6;
    }
  }

  .form-field {
    width: 100%;
    &__row {
      display: flex;
      flex-direction: row;
    }
    &__col {
      display: flex;
      flex-direction: row;
      flex: 0 1 90%;
      .ant-row {
        &:nth-child(1) {
          flex: 0 1 25%;
          margin-right: 2%;
        }
        &:nth-child(2) {
          flex: 0 1 70%;
        }
      }
    }
    &__plus {
      flex: 0 1 10%;
    }
  }
  .table {
    margin: auto;
    width: 100%;
    .ant-typography-ellipsis-single-line {
      font-size: 14px;
      font-weight: 600;
      overflow: unset;
      white-space: normal;
    }
    @media screen and (max-width: 576px) {
      .ant-table-thead > tr > th,
      .ant-table-tbody > tr > td,
      .ant-table tfoot > tr > th,
      .ant-table tfoot > tr > td {
        padding: 10px 10px;
      }
    }
    margin-top: 25px;
    .txt_green {
      color: #35a211;
      text-align: center;
    }
    .txt_red {
      color: #dc5454;
      text-align: center;
    }
  }
`;

function Detail(props) {
  const dispatch = useDispatch();
  const [form] = Form.useForm();
  const [isDisplayPay, setIsDisplayPay] = useState(false);

  const currencyMemoi = useCurrencyHook();
  const { type, intl } = props;
  const { initialValues, isFetching, showModal } = useSelector(stateSelector);

  const callbackDisplay = useCallback(
    status => {
      status === 2 ? setIsDisplayPay(true) : setIsDisplayPay(false);
    },
    [status],
  );
  const handleCancel = () => {
    dispatch(closePayrollModal());
  };

  const handleChangePayStatus = key => {
    callbackDisplay(key);
  };
  const onFinish = values => {
    for (var key in values) {
      if (typeof values[key] === 'string') {
        values[key] = values[key].trim();
        if (/^[0-9,]+$/.test(values[key])) {
          values[key] = values[key].replace(/,/g, '');
        }
      }
      if ( Array.isArray(values[key])) {
        values[key] = values[key].map(subKey => {
          if (/^[0-9,]+$/.test(subKey.amount)) {
            subKey.amount = subKey.amount.replace(/,/g, '');
          }
          return subKey;
        });
      }
    }
    dispatch(updatePayroll(initialValues.id, values));
  };

  useEffect(() => {
    if (initialValues?.paymentTime) {
      initialValues.paymentTime = initialValues.paymentTime
        ? moment(initialValues.paymentTime)
        : undefined;
    }
    callbackDisplay(initialValues.status);
    form.setFieldsValue(initialValues);
  }, [initialValues]);
  return (
    <Spin spinning={isFetching}>
      (
      <Modal
        visible={showModal}
        onCancel={handleCancel}
        okText="Thêm"
        centered
        footer={null}
        width={750}
      >
        <ModalWrapper>
          <div className="container">
            <div style={{ textAlign: 'center', width: '100%' }}>
              <div className="header">
                <div className="title-global">
                  {intl.formatMessage(messages.payroll)}
                </div>
                <div className="header__desc wrapper-header">
                  <div className="header__desc">
                    <div className="header__img">
                      {initialValues.user.photo ? (
                        <img
                          src={`${PUBLIC_API}/${initialValues.user.photo}`}
                        />
                      ) : (
                        <img className="image" src={DEFAULT_AVATAR} />
                      )}
                    </div>
                    <div className="header__infor">
                      <div className="header__infor__staff">
                        <div className="header__infor__name">
                          {initialValues
                            ? `${initialValues.user.firstName || ''} ${
                                initialValues.user.lastName || ''
                              }`
                            : 'N/A'}
                        </div>
                        {initialValues.user.mst && (
                          <div className="header__infor__tax">
                            {initialValues.user.mst}
                          </div>
                        )}
                      </div>
                      <div className="header__infor__spa">
                        <span className="header__infor__spa--name">{`${
                          initialValues.user.restaurant
                            ? initialValues.user.restaurant.name
                            : 'N/A'
                        }`}</span>
                        {initialValues.user.roles && (
                          <span className="header__infor__spa--role">{` - ${initialValues.roleName}`}</span>
                        )}
                      </div>
                    </div>
                  </div>
                  <div className="header__desc__right">
                    <div className="payPeriod">
                      <div className="payPeriod__title">
                        <span>{intl.formatMessage(messages.payPeriod)}</span>
                      </div>
                      <div className="payPeriod__time">
                        <span>
                          {initialValues ? initialValues.payPeriod : 'N/A'}
                        </span>
                      </div>
                    </div>
                    <div className="hours">
                      <div className="hours__title">
                        <span>{intl.formatMessage(messages.workingHours)}</span>
                      </div>
                      <div className="hours__number">
                        <span>
                          {initialValues && initialValues.totalHours
                            ? initialValues.totalHours
                            : 'N/A'}
                        </span>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            <Row className="body-modal" gutter={[12, 0]}>
              <Col xl={14} lg={14} md={14} sm={12} xs={24}>
                <Form form={form} className="body-form">
                  <Form.List name="options">
                    {(fields) => {
                      const length = fields.length;
                      return (
                      <Form.Item className="first-row-input">
                        {fields.map((field, index) => {
                          return (
                          <Form.Item
                          name={[field.name, 'amount']}
                          className="element-input-wrapper"
                          rules={[
                            {
                              pattern: new RegExp('^[0-9,]*$'),
                              message: (
                                <FormattedMessage
                                  {...messages.requiredInputNumber}
                                />
                              ),
                            },
                          ]}
                          style={{
                            display: 'inline-block',
                            width: `${index % 2 === 0 && index === (length - 1) ? '100%' : 'calc(50% - 8px)'}`,
                            marginLeft: `${index % 2 === 1 ? '16px' : '0px' }`,
                          }}
                        >
                          <FormatInput
                            addonAfter={currencyMemoi}
                            formatter={digits}
                            placeholder={initialValues.options[index].name}
                            className="element-input"
                            disabled={initialValues.status === 2}
                          ></FormatInput>
                        </Form.Item>)
                        })}
                      </Form.Item>
                      )}}
                  </Form.List>
                  <Form.Item
                    className="product-units-select"
                    name="status"
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messages.requiredChoose} />
                        ),
                      },
                    ]}
                  >
                    <FloatLabel
                      size="large"
                      label={intl.formatMessage(messages.payrollType)}
                      onSelect={handleChangePayStatus}
                      disabled={initialValues.status === 2}
                      items={[{id: 1, name: intl.formatMessage(messagesLocal.notPaid)}, {id:2 , name: intl.formatMessage(messagesLocal.paid)}]}
                      typeInput="selectMutil"
                    />
                  </Form.Item>
                  {isDisplayPay && (
                    <>
                      <Form.Item
                        className="product-units-select"
                        name="paymentMethod"
                        rules={[
                          {
                            required: true,
                            message: (
                              <FormattedMessage {...messages.requiredChoose} />
                            ),
                          },
                        ]}
                      >
                        <FloatLabel
                          size="large"
                          label={intl.formatMessage(
                            messages.transferType,
                          )}
                          disabled={initialValues.status === 2}
                          items={[{id: 1, name: intl.formatMessage(messages.wireTransfer)}, 
                            {id:2 , name: intl.formatMessage(messages.cheque)},
                            {id:3 , name: intl.formatMessage(messages.cash)}]}
                            typeInput="selectMutil"
                        />
                      </Form.Item>
                      <Form.Item
                        className="product-units-select"
                        name="paymentTime"
                        rules={[
                          {
                            required: true,
                            message: (
                              <FormattedMessage {...messages.requiredChoose} />
                            ),
                          },
                        ]}
                      >
                        <FloatLabel
                          format={DATE_FORMAT}
                          style={{ width: '100%' }}
                          label={intl.formatMessage(messages.time)}
                          disabled={initialValues.status === 2}
                          typeInput="datepicker"
                        />
                      </Form.Item>
                    </>
                  )}
                  <Form.Item name="note">
                    <FloatLabel label={intl.formatMessage(messages.note)} disabled={initialValues.status === 2} />
                  </Form.Item>
                  <div className="btn-wrapper" hidden={initialValues.status === 2}>
                    <Button
                      className="add-button"
                      type="primary"
                      onClick={() => {
                        form
                          .validateFields()
                          .then(values => {
                            onFinish(values);
                          })
                          .catch(info => {
                            console.log('Validate Failed:', info);
                          });
                      }}
                    >
                      {intl.formatMessage(messages.save)}
                    </Button>
                  </div>
                </Form>
              </Col>
              <Col
                xl={{ span: 9, offset: 1 }}
                lg={{ span: 9, offset: 1 }}
                md={{ span: 10, offset: 0 }}
                sm={12}
                xs={24}
              >
                <Row className="elements-row">
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.basicSalary)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(initialValues.payAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.commission)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(initialValues.commissionAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.allowance)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(initialValues.extraAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  {initialValues.options.filter(op => op.type ===1).map(op => <Row>
                    <Col className="title-row" span={14}>
                      {op.name}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(op.amount ? op.amount : 0)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>)}
                  <Divider />
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.totalEarnings)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(initialValues.subAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  {initialValues.options.filter(op => op.type === 2).map(op => <Row>
                    <Col className="title-row" span={14}>
                      {op.name}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(op.amount ? op.amount : 0)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value !== "0" ? '-' + value : 0} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>)}
                </Row>
                <Row className="amount-row-last">
                  <Col className="title-row" span={14}>
                    {intl.formatMessage(messages.netPay)}
                  </Col>
                  <Col className="amount-row" span={10}>
                    <NumberFormat
                      value={Math.round(initialValues.totalAmount)}
                      displayType={'text'}
                      thousandSeparator={true}
                      renderText={value => `${value} ${currencyMemoi}`}
                    />
                  </Col>
                </Row>
              </Col>
            </Row>
          </div>
        </ModalWrapper>
      </Modal>
      )
    </Spin>
  );
}

export default injectIntl(Detail);
