import React from 'react';
import styled from 'styles/styled-components';
import { useHistory } from 'react-router-dom';
import { Link } from 'react-router-dom';
import { Select, Button, Form } from 'antd';
import { Type } from '../types';
import { FormattedMessage, injectIntl } from 'react-intl';
import { PayrollListHeaderWrapper } from '../styles';
import messages from 'translations/messages';
import messagesLocal from '../messages';
import FloatLabel from 'components/FormatInput/FloatLabel';

function Header(props) {
  const { type, filter, onClickSearch, intl } = props;
  const { stores = [], staffs = [] } = filter;
  const history = useHistory();
  const [form] = Form.useForm();

  const handleOnClickSearch = values => {
    onClickSearch(values);
  };
  return (
    <PayrollListHeaderWrapper>
      <div className="tabs">
        <Link
          to="/payroll"
          className={`tabs__promotion ${type === Type.unpaid ? 'active' : ''}`}
        >
          {intl.formatMessage(messagesLocal.unpaid)}
        </Link>
        <Link
          to="/payroll/unpay"
          className={`tabs__promotion ${type === Type.paid ? 'active' : ''}`}
        >
          {intl.formatMessage(messagesLocal.paid)}
        </Link>
      </div>
      <Form className="form" form={form} onFinish={handleOnClickSearch}>
        <div className="filter">
          <div className="filter__common">
            <Form.Item className="filter__restaurant" name="restaurant">
              <FloatLabel
                defaultValue="0"
                className="staff-filters__restaurant"
                size="large"
                items={[
                  ...stores,
                  {
                    id: '0',
                    name: `${intl.formatMessage(
                      messages.allSelect,
                    )} ${intl
                      .formatMessage(messages.restaurant)
                      .toLowerCase()}`,
                  },
                ]}
                typeInput="selectMutil"
                label={intl.formatMessage(messages.restaurant)}
              />
            </Form.Item>
            <Form.Item className="filter__role" name="category">
              <FloatLabel
                defaultValue="0"
                className="staff-filters__role"
                size="large"
                items={[
                  ...staffs.map(staff => {
                    return {
                      id: staff.id,
                      name: `${staff.firstName ? staff.firstName : ''}${
                        staff.lastName ? ' ' + staff.lastName : ''
                      }`,
                    };
                  }),
                  {
                    id: '0',
                    name: `${intl.formatMessage(
                      messages.allSelect,
                    )} ${intl.formatMessage(messages.staff).toLowerCase()}`,
                  },
                ]}
                typeInput="selectMutil"
                label={intl.formatMessage(messages.staff)}
              />
            </Form.Item>
          </div>
          <div className="filter__search">
            <Button
              className="filter__search__submit"
              size="large"
              type="primary"
              htmlType="submit"
            >
              <FormattedMessage {...messages.search} />
            </Button>
          </div>
        </div>
      </Form>
    </PayrollListHeaderWrapper>
  );
}
export default injectIntl(Header);
