import React, { useEffect } from "react";
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import { makePayrolls, makeIsFetching, makeShowModal, makeSearch, makeStaffs } from './selectors';
import reducer from './reducer';
import saga from './saga';
import messages from './messages';
import Header from "./Header";
import { Modal, Spin } from "antd";
import Detail from "./Detail";
import { List } from "./PayrollList";
import { PayrollListWrapper } from "./styles";
import { Type } from "./types";
import { makeSelectRestaurants } from "../App/selectors";
import { closePayrollModal, getPayrolls, setSearch, getStaffs} from "./actions";

const stateSelector = createStructuredSelector({
  isFetching: makeIsFetching(),
  showModal: makeShowModal(),
  searchGl: makeSearch(),
  staffs: makeStaffs(),
});

const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
});

interface Props {
  readonly type: Type;
}

function PayrollList(props: Props) {
  useInjectReducer({ key: 'payroll', reducer: reducer });
  useInjectSaga({ key: 'payroll', saga: saga });

  const { searchGl, isFetching, showModal, staffs } = useSelector(stateSelector);
  const { restaurants } = useSelector(globalSelector);
  const dispatch = useDispatch();

  const { type } = props;
  useEffect(() => {
    // @ts-ignore
    dispatch(getPayrolls({ typePayroll: type , page: 1, limit: 10 }));
    dispatch(setSearch({ ...searchGl, typePayroll: type }))
    dispatch(getStaffs());
  }, [type]);
  
  const onClickSearch = (filterValues) => {
    const { restaurant, search, category } = filterValues;
    // @ts-ignore
    dispatch(getPayrolls({ typePayroll: type, restaurantId: restaurant, staffId: category, searchText: search ? search.trim() : '', page: 1, limit: searchGl.limit ? searchGl.limit : 10 }));
    dispatch(setSearch({ typePayroll: type, restaurantId: restaurant, categoryId: category, searchText: search ? search.trim() : '', page: 1, limit: searchGl.limit ? searchGl.limit : 10 }))
  }

  return (
    <PayrollListWrapper>
      <Spin spinning={isFetching}>
        <div className="payroll-header">
          <Header type={type} filter={{stores: restaurants, staffs: staffs}} onClickSearch={onClickSearch}/>
        </div>
        <div className="list">
          <List search={searchGl}/>
        </div>
      </Spin>
      {showModal && <Detail/>}
    </PayrollListWrapper>
  );
}

export default PayrollList;
