import ActionTypes from './constants';
import { ContainerState, ContainerActions } from './types';
import _ from "lodash";
import { Type } from "./types";

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  message: '',
  amount: 0,
  paidAmount: 0,
  payrolls: {count: 0, list: <any>[]},
  showModal: false,
  payroll: null,
  staffs: [],
  search: { typePayroll: Type.unpaid, page: 1, limit: 10 },
};

function payrollListReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_PAYROLLS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PAYROLLS_SUCCESS:
      return { ...state, isFetching: false, payrolls: action.payload};
    case ActionTypes.GET_PAYROLLS_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_PAYROLL:
      return { ...state, 
        payroll: state.payrolls.list.find(i => i.id === action.payload),
      };
    case ActionTypes.GET_PAYROLL_SUCCESS:
      return { ...state, isFetching: false, payroll: action.payload};
    case ActionTypes.GET_PAYROLL_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_STAFFS:
      return {
        ...state,
        isFetching: true,
      };
    case ActionTypes.GET_STAFFS_SUCCESS:
      return {
        ...state,
        staffs: action.payload,
        isFetching: false,
      };
    case ActionTypes.GET_STAFFS_FAIL:
      return {
        ...state,
        message: action.payload,
        isFetching: false,
      };
    case ActionTypes.UPDATE_PAYROLL:
      return { ...state, isFetching: true };
    case ActionTypes.UPDATE_PAYROLL_SUCCESS:
      return { ...state, showModal: false, isFetching: false };
    case ActionTypes.UPDATE_PAYROLL_FAIL:
      return { ...state, message: action.payload, showModal: false, isFetching: false };
    case ActionTypes.SET_SEARCH:
      return {
        ...state,
        search: action.payload
      };
    case ActionTypes.DELETE_PAYROLL:
      return { ...state, isFetching: true };
    case ActionTypes.DELETE_PAYROLL_SUCCESS:
      _.remove(state.payrolls.list, payroll => payroll.id === action.payload);
      return { ...state, isFetching: false, payrolls: state.payrolls};
    case ActionTypes.DELETE_PAYROLL_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.SHOW_PAYROLL_MODAL:
      return { ...state, showModal: true };
    case ActionTypes.CLOSE_PAYROLL_MODAL:
      return { ...state, showModal: false, payroll: null };
    default:
      return state;
  }
}

export default payrollListReducer;
