import { callApi, success } from '../../utils/apiUtils';
import { put, takeLatest, select } from 'redux-saga/effects';
import {
  deletePayrollFail,
  deletePayrollSuccess,
  getPayrollsFail,
  getPayrollsSuccess,
  updatePayrollFail,
  updatePayrollSuccess,
  getStaffsSuccess,
  getStaffsFail,
} from './actions';
import ActionTypes from './constants';
import { apiError, apiSuccess } from '../App/actions';
import { makeSearch } from './selectors';
import moment from 'moment';

export function* getPayrolls({
  payload: { typePayroll, restaurantId, staffId, page, limit },
}) {
  try {
    // to be refactored
    const searchParams = new URLSearchParams();
    if (+restaurantId > 0) {
      searchParams.append('restaurantId', restaurantId);
    }
    if (+staffId > 0) {
      searchParams.append('userId', staffId);
    }
    searchParams.append('status', typePayroll);
    searchParams.append('page', page);
    searchParams.append('limit', limit);
    // const subList = PAYROLL.slice((page - 1) * limit, page * limit);
    const { code, data, message } = yield callApi(
      `/users/payrolls?${searchParams.toString()}`,
      'GET',
    );
    // yield put(getPayrollsSuccess({count: PAYROLL.length, list: subList}));
    if (success(code)) {
      data.list = data.list.map(d => {
        d.fullName = `${d.user.firstName ? d.user.firstName : ''}${d.user.lastName ? ' ' + d.user.lastName : ''}`
        d.roleName = d.user.roles.map(r => r.name).join('/');
        d.payPeriod = `${
          d.startPayTime ? moment(d.startPayTime).format('DD/MM') : 'N/A'
        } - ${
          d.endPayTime ? moment(d.endPayTime).format('DD/MM/YYYY') : 'N/A'
        }`;
        delete d.startPayTime;
        delete d.endPayTime;
        return d;
      });
      yield put(getPayrollsSuccess({ ...data }));
    } else {
      yield put(getPayrollsFail(message));
    }
  } catch (error) {
    yield put(getPayrollsFail(error.message));
  }
}

export function* updatePayroll({ payload: { id, payroll } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/payroll/${id}`,
      'PUT',
      payroll,
    );
    if (success(code)) {
      yield put(updatePayrollSuccess(data));
      yield put(apiSuccess('Change payroll success!'));
      const payload = yield select(makeSearch());
      yield put({
        type: ActionTypes.GET_PAYROLLS,
        payload: payload
      });
      yield put({ type: ActionTypes.CLOSE_PAYROLL_MODAL });
    } else {
      yield put(updatePayrollFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(updatePayrollFail(error.message));
    yield put(apiError(error.message));
  }
}

export function* deletePayroll({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/admin/bill/${id}`,
      'DELETE',
    );
    if (success(code)) {
      yield put(deletePayrollSuccess(id));
    } else {
      yield put(deletePayrollFail(message));
    }
  } catch (error) {
    yield put(deletePayrollFail(error.message));
  }
}

export function* getStaffs() {
  try {
    // to be refactored
    const searchParams = new URLSearchParams();
    const { code, data, message } = yield callApi(
      `/users/staff-user?${searchParams.toString()}`,
      'GET',
    );
    if (success(code)) {
      yield put(getStaffsSuccess(data.list)); // should be remove list
    } else {
      yield put(getStaffsFail(message));
    }
  } catch (error) {
    yield put(getStaffsFail(error.message));
  }
}

// Individual exports for testing
export default function* payrollListSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PAYROLLS, getPayrolls);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_PAYROLL, updatePayroll);
  // @ts-ignore
  yield takeLatest(ActionTypes.DELETE_PAYROLL, deletePayroll);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFFS, getStaffs);
}