import React, { useState, useRef, useEffect } from 'react';
import styled from 'styled-components';
import { useHistory } from 'react-router-dom';
import { Button, Input, Form, Select, Row, Col, notification } from 'antd';
import { ShopLogoIcon, EditIcon } from 'styles/icon-components';
import { useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { makeSelectPhoneCountries } from '../../App/selectors';
import { fetchAPI, JsonToFormData, replaceUrl } from 'utils/fetchAPI';
import { RoutePaths } from 'containers/App/routes';
import { USER_INFO_KEY } from 'containers/App/constants';
import { FormattedMessage, injectIntl } from 'react-intl';
import messagesGlobal from 'translations/messages';
import { fileValidation } from 'utils/validation';
import { usePhoneAddon } from '../../../components/CustomHook/usePhoneAddon';
import { extractPhoneNumber } from 'utils/common';
import {
  API_URL,
  USER_PROFILE,
  PUBLIC_API,
  ADMIN_MERCHANT_BY_ID_URL,
} from 'containers/App/urls';
const { Option } = Select;
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  phoneCountries: makeSelectPhoneCountries(),
});

const MerchantFormWrapper = styled.div`
span.ant-input-group-addon {
  border-bottom-left-radius: 20px;
  border-top-left-radius: 20px;
}
span.ant-input-group-addon + .ant-input {
  border-bottom-left-radius: 0px !important;
  border-top-left-radius: 0px !important;
}
div[class^='col'] {
  padding-left: 5px;
  padding-right: 5px;
}
.row {
  margin-left: -5px;
  margin-right: -5px;
}
h2.title {
  font-size: 16px;
}
.restaurant-add {
  margin: 1.5% 2%;
  &__header {
    display: flex;
    justify-content: space-between;
    padding-right: 10px;
  }
  &__title{
    color: #333333;
    font-size: 13px;
    font-weight: 600;
    margin-bottom: 20px;
  }

  &__map {
    width: 60%;
    margin-left: 20px;
    border-radius: 22px;
    overflow: hidden;
  }
  &__submit{
    display: flex;
    align-items: center;
    &__code{
      text-align: center;
     }
  }
}
.header-row {
  margin-bottom: 20px;
  margin-top: 10px;
  .title {
    margin-top: 10px;
    margin-left: 10px;
    .title-header {
      font-size: 13px;
      line-height: 16px;
      margin-bottom: 18px;
    }
    .sub-title-header{
      align-items: baseline;
      margin-left: 0px;
      margin-right: 0px;
      &__code {
        color: #333333;
        margin-right: 30px;
      }
      &__status {
      color: #7ACB2E;
      line-height: 16px;
      font-family: Helvetica;
      }
      &__dot {
        height: 11px;
        width: 11px;
        border-radius: 50%;
        display: inline-block;
        margin-right: 10px;
      }
    }
  }
  .right-header {
    margin-top: 10px;
    display: inline-flex;
    align-items: baseline;
    justify-content: flex-end;
    &__info {
      display: flex;
      align-items: center;
      margin-right: 20%;
      .title-quantity {
        font-size: 16px;
        line-height: 16px;
      }
      .circle-quantity {
        margin-left: 12px;
        height: 44px;
        width: 40px;
        background-color: #7ACB2E;
        border-radius: 50%;
        display: inline-flex;
        justify-content: center;
        align-items: center;
        span {
          font-size: 16px;
          color: #FFFFFF;
          line-height: 14px;
        }
      }
    }
  }
}
.first-row {
  margin-bottom: 1.5%;
  &__info {
    padding-top: 20px;
    padding-left: 20px !important;
    padding-right: 20px !important;
    flex: 0 0 49.25% !important;
    max-width: 49.25% !important;
    margin-right: 1.5%;
    background-color: #fff;
    background-clip: border-box;
    border: 1px solid rgba(0, 0, 0, 0.125);
    border-radius: 0.25rem;
  }
  &__contact {
    padding-top: 20px;
    padding-left: 20px !important;
    padding-right: 20px !important;
    flex: 0 0 49.25% !important;
    max-width: 49.25% !important;
    background-color: #fff;
    background-clip: border-box;
    border: 1px solid rgba(0, 0, 0, 0.125);
    border-radius: 0.25rem;
  }
  &__contact-staff {
    padding-top: 20px;
    padding-left: 20px !important;
    padding-right: 20px !important;
    background-color: #fff;
    background-clip: border-box;
    border: 1px solid rgba(0, 0, 0, 0.125);
    border-radius: 0.25rem;
  }
}
.second-row {
  &__bankInfo, &__service, &__account {
    padding-top: 20px;
    padding-left: 20px !important;;
    padding-right: 20px !important;;
    padding-bottom: 20px;
    background-color: #fff;
    background-clip: border-box;
    border: 1px solid rgba(0, 0, 0, 0.125);
    border-radius: 0.25rem;
    h2 {
      margin-left: 10px;;
    }
  }
  &__row-add {
    flex: 0 0 32.33333% !important;
    max-width: 32.33333% !important;
  }
  &__row-edit {
    flex: 0 0 49.25% !important;
    max-width: 49.25% !important;
  }
}
.m-r-p {
  margin-right: 1.5%;
}
@media screen and (max-width: 576px) {
  .right-header {
    justify-content: space-between !important;
  }
  .customer-upload {
    width: 100%;
    .custormUpload__upload {
      margin: auto;
    }
  }
  .second-row {
    &__row-add {
      flex: 0 0 100% !important;
      max-width: 100% !important;
    }
    &__row-edit {
      flex: 0 0 100% !important;
      max-width: 100% !important;
    }
    &__bankInfo, &__service, &__account {
      margin-bottom: 1.5%;
    }
  }
  .first-row {
    &__info, &__contact {
      flex: 0 0 100% !important;
      max-width: 100% !important;
      margin-right: 0%;
    }
    &__info {
      margin-bottom: 1.5%;
    }
  }
  .m-r-p {
    margin-right: 0%;
  }
}
@media screen and (max-width: 576px) {
  .right-header {
    justify-content: space-between !important;
    margin-left: 5px;
  }
}
@media screen and (max-width: 768px) {
  .restaurant-add {
    &__submit{

      &__code{
        text-align: left;
       }

    }

  }
}

  padding: 29px 10px;
  input.ant-input, .ant-select-selector {
    align-items: center;
  }
  @media screen and (min-width: 1200px) {
    .form {
      display: flex;
      >div {
        &:nth-child(1), &:nth-child(3), &:nth-child(4) {
          flex: 0.8;
          margin: 0 5px;
        }
        &:nth-child(2) {
          flex: 1.2;
          margin: 0 10px;
        }
      }
      .row {
        display: flex;
        > * {
          flex: 1;
          &:nth-child(1) {
            margin-right: 5px;
          }
          &:nth-child(2) {
            margin-left: 5px;
          }
        }
      }
    }
  }
  .ant-input-affix-wrapper {
    padding: 0 11px;
  }
  .title {
    color: #333333;
    margin-bottom: 30px;
  }
  .custormUpload {
    &__upload {
      width: 90px;
      border: 1px solid #eaeaea;
      border-radius: 8px;
      width: 90px;
      height: 90px;
      .ant-upload {
        width: 100% !important;
        margin-bottom: 20px;
      }
      &__image {
        text-align: center;
        width: 100%;
        cursor: pointer;
        position: relative;
        img {
          border-radius: 8px;
          width: 100%;
          height: 90px;
          object-fit: cover;
        }
        &__default {
          display: flex;
          flex-flow: column;
          justify-content: center;
          align-items: center;
          height: 90px;
        }
  
        &__text {
          color: #a8a8a8;
          margin-top: 10px;
        }
        &__edit {
          background-color: white;
          border-radius: 100%;
          opacity: 0.05;
          width: 40px;
          height: 44px;
          position: absolute;
          top: 25px;
          right: 25px;
          padding: 10px;
          &:hover {
            opacity: 0.3497721354166667;
          }
        }
      }
    }
  }
  .upload {
    width: 100%;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: center;
    margin-bottom: 24px;
  }
  .upload-image--default {
    display: flex;
    flex-flow: column;
    justify-content: center;
    align-items: center;
    height 190px;
  }
  .upload-image {
    position: relative;
    max-width: 208px;
    height: 205px;
    border: 1px solid #EAEAEA ;
    border-radius: 8px;
    :hover {
      opacity: 0.2;
      .upload-image__edit {
        display: block;
      }
    }
    &__text {
      color: #A8A8A8;
      margin-top: 10px;
    }
    &__edit {
       // background-color: #000000;
       border-radius: 100%;
       opacity: 0.3497721354166667;
       width: 40px;
       height: 44px;
       position: absolute;
       top: 10px;
       right: 10px;
       padding: 4px;
       display: none;
    }
    &__img {
      border-radius: 22px;
      width: 100%;
      height: 200px;
      object-fit: cover;
    }
  }
  .ant-btn {
    color: #ffffff;
    width: 100px;
    height: 44px;
    border-radius: 22px;
    background-color: #9cd339;
  }
  .service-policy {
    .ant-select-selection-item {
      padding-top: 15px !important;
    }
  }
`;
const STATUS = [
  {
    value: 1,
    label: <FormattedMessage {...messagesGlobal.freeStatus} />,
    color: '#9CD339',
  },
  {
    value: 2,
    label: <FormattedMessage {...messagesGlobal.trial} />,
    color: '#DC5454',
  },
  {
    value: 4,
    label: <FormattedMessage {...messagesGlobal.stopUsing} />,
    color: '#9C9696',
  },
  {
    value: 3,
    label: <FormattedMessage {...messagesGlobal.hasFee} />,
    color: '#4DA34D',
  },
];
const DURATION_TYPE = [
  {
    value: 1,
    label: <FormattedMessage {...messagesGlobal.pricePerMonth} />,
  },
  {
    value: 2,
    label: <FormattedMessage {...messagesGlobal.pricePerYear} />,
  },
];
function MerchantForm(props) {
  const { intl } = props;
  const userInfoString = localStorage.getItem(USER_INFO_KEY);
  if (!userInfoString) {
    return <span>...</span>;
  }
  const userInfo = JSON.parse(userInfoString);
  const { roleIds = [] } = userInfo.profile;

  const isOwner = roleIds.includes(2);
  const { phoneCountries } = useSelector(stateSelector);
  const prefixSelector = usePhoneAddon(phoneCountries);
  const [profile, setProfile] = useState<any>({});
  const [imageUrl, setImageUrl] = useState<any>();
  const [imageFile, setImageFile] = useState('');
  const [durationType, setDurationType] = useState<any>(1);
  const [free, setFree] = useState<any>(1);
  const [loading, setLoading] = useState(false);
  const inputRef = useRef<{ files: any; click: any }>();
  const [form] = Form.useForm();
  const history = useHistory();

  function handleChangeUploadImage() {
    const file = inputRef.current ? inputRef.current.files[0] : '';
    if (file) {
      if (!fileValidation(file.name))
        return notification.error({
          message: intl.formatMessage(messagesGlobal.invalidFile),
        });
      const reader = new FileReader();
      const url = reader.readAsDataURL(file);
      reader.onloadend = function (e) {
        setImageUrl(reader.result!);
      };
      setImageFile(file);
    }
  }
  const onFinish = async values => {
    try {
      setLoading(true);
      if (imageFile) {
        values.files = imageFile;
      }
      values.owner.username = values.owner.email;
      values.owner.phoneNumber = `${values.phoneCountryCode}${values.owner.phoneNumber}`;
      values.owner = JSON.stringify(values.owner);
      values.payment = JSON.stringify(values.payment);
      let response;
      if (isOwner) {
        response = await fetchAPI({
          method: 'PUT',
          url: replaceUrl(ADMIN_MERCHANT_BY_ID_URL, { id: profile.id }),
          formData: true,
          data: JsonToFormData(values),
        });
        if (response) {
          // redudant field in api
          if (response.photo) {
            response.avatar = response.photo;
          }
          if (response.owner) {
            response.firstName = response.owner.firstName;
            response.lastName = response.owner.lastName;
          }
          const newUserInfo = { profile: { ...userInfo.profile, ...response } };
          localStorage.setItem(USER_INFO_KEY, JSON.stringify(newUserInfo));
          history.push(RoutePaths.dashboard);
        }
      } else {
        response = await fetchAPI({
          method: 'PUT',
          url: `${API_URL}/users/staff-user/${profile.id}`,
          formData: true,
          data: JsonToFormData(values),
        });
        if (response) {
          history.push(RoutePaths.dashboard);
        }
      }
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    isOwner
      ? fetchAPI({
          method: 'GET',
          url: replaceUrl(ADMIN_MERCHANT_BY_ID_URL, {
            id: userInfo.profile.merchantId,
          }),
        }).then(response => {
          if (response) {
            if (response.photo) {
              setImageUrl(`${PUBLIC_API}/${response.photo}`);
            }
            if (response.status) {
              setFree(+response.status || 1);
            }
            setProfile(response);
          }
        })
      : fetchAPI({
          method: 'GET',
          url: USER_PROFILE,
        }).then(response => {
          if (response) {
            if (response.profile.avatar) {
              setImageUrl(`${PUBLIC_API}/${response.profile.avatar}`);
            }
            if (response.status) {
              setFree(+response.status || 1);
            }
            response.owner = {
              firstName: response.profile.firstName,
              lastName: response.profile.lastName,
              phoneNumber: response.profile.phone,
              email: response.profile.email,
            };
            response.id = response.profile.id;
            const [code, number] = extractPhoneNumber(
              response.owner.phoneNumber,
              response.owner.phoneCountryCode,
            );
            response.owner.phoneNumber = number;
            response.owner.phoneCountryCode = code;
            setProfile(response);
          }
        });
  }, []);

  useEffect(() => {
    if (profile.fullAddress || profile.address) {
      profile.address = profile.fullAddress || profile.address;
    }
    form.setFieldsValue(profile);
  }, [profile]);

  const suffix = (
    <>
      <div className="custormInput__suffix custormInput-second__suffix">
        {durationType === 1 ? (
          <FormattedMessage {...messagesGlobal.month} />
        ) : (
          <FormattedMessage {...messagesGlobal.year} />
        )}
      </div>
    </>
  );

  const responsiveCol = isOwner ? 12 : 24;
  const statusObj = STATUS.find(st => st.value == profile.status);

  return (
    <MerchantFormWrapper>
      <div className={`restaurant-add`}>
        <h2 className="title">
          <FormattedMessage {...messagesGlobal.generalInfo} />
        </h2>
        <Form name="basic" onFinish={onFinish} form={form}>
          <Row className="header-row">
            <Col xl={12} lg={12} md={9} sm={8}>
              <Row>
                <div className="customer-upload">
                  <div className="custormUpload__upload">
                    <input
                      type="file"
                      ref={inputRef as any}
                      accept="image/*"
                      onChange={() => {
                        handleChangeUploadImage();
                      }}
                      style={{ display: 'none' }}
                    />
                    <div
                      onClick={() => inputRef.current!.click()}
                      className="custormUpload__upload__image"
                    >
                      {!imageUrl && imageUrl !== '' ? (
                        <div className="custormUpload__upload__image__default">
                          <ShopLogoIcon className="custormUpload__upload__image__icon" />
                          <div className="custormUpload__upload__image__text">
                            <FormattedMessage
                              {...messagesGlobal.logoMerchant}
                            />
                          </div>
                          <span className="img-hint">
                            <FormattedMessage
                              {...messagesGlobal.encourageCondition}
                              values={{ height: 150, width: 150 }}
                            />
                          </span>
                        </div>
                      ) : (
                        <>
                          <img src={imageUrl} />
                          <div className="custormUpload__upload__image__edit">
                            <EditIcon color={'#FFFFFF'}></EditIcon>
                          </div>
                        </>
                      )}
                    </div>
                  </div>
                </div>
                <div className="title">
                  <div className="title-header">{profile.name}</div>
                  <div className="row sub-title-header">
                    <span className="sub-title-header__code">
                      {profile.code}
                    </span>
                    <span
                      className="sub-title-header__dot"
                      style={{ backgroundColor: `${statusObj?.color}` }}
                    ></span>
                    <span
                      className="sub-title-header__status"
                      style={{ color: `${statusObj?.color}` }}
                    >
                      {statusObj?.label}
                    </span>
                  </div>
                </div>
              </Row>
            </Col>
          </Row>
          <Row className="first-row">
            {isOwner && (
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                className="first-row__info card"
              >
                <div className="restaurant-add__header">
                  <h2 className="restaurant-add__title ">
                    <FormattedMessage {...messagesGlobal.merInfo} />
                  </h2>
                </div>
                {/* First card */}
                <Row>
                  <Form.Item
                    style={{ width: '100%' }}
                    name="name"
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messagesGlobal.requiredMerNm} />
                        ),
                      },
                    ]}
                  >
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.merchantNm)}
                    />
                  </Form.Item>
                </Row>
                <Row gutter={12}>
                  <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                    <Form.Item name="taxCode">
                      <FloatLabel
                        className="custormInput custormInput-second"
                        label={intl.formatMessage(messagesGlobal.taxCode)}
                      />
                    </Form.Item>
                  </Col>
                  <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                    <Form.Item name="delegateName">
                      <FloatLabel
                        className="custormInput custormInput-second"
                        label={intl.formatMessage(messagesGlobal.delegateName)}
                      />
                    </Form.Item>
                  </Col>
                </Row>
                <Row>
                  <Form.Item
                    name="address"
                    style={{ width: '100%' }}
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messagesGlobal.requiredAddr} />
                        ),
                      },
                    ]}
                  >
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.address)}
                      maxLength={150}
                    />
                  </Form.Item>
                </Row>
              </Col>
            )}
            {/* Second card */}

            <Col
              xl={responsiveCol}
              lg={responsiveCol}
              md={responsiveCol}
              sm={responsiveCol}
              className={`${
                isOwner ? 'first-row__contact' : 'first-row__contact-staff'
              } card`}
            >
              <div className="restaurant-add__header">
                <h2 className="restaurant-add__title ">
                  <FormattedMessage {...messagesGlobal.contact} />
                </h2>
              </div>
              <Row gutter={12}>
                <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                  <Form.Item name={['owner', 'firstName']}>
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.firstNm)}
                    />
                  </Form.Item>
                </Col>
                <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                  <Form.Item name={['owner', 'lastName']}>
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.lastNm)}
                    />
                  </Form.Item>
                </Col>
              </Row>
              <Row gutter={12}>
                <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                  <Form.Item name={['owner', 'email']}>
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.email)}
                      disabled={true}
                    />
                  </Form.Item>
                </Col>
                <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                  <Form.Item name={['owner', 'phoneNumber']}>
                    <FloatLabel
                      addonBefore={prefixSelector}
                      className="custormInput custormInput-second"
                      label={intl.formatMessage(messagesGlobal.phoneNumber)}
                    />
                  </Form.Item>
                </Col>
                <Col span={24}>
                  <Form.Item name="website">
                    <FloatLabel
                      className="custormInput custormInput-second"
                      label="Website"
                    />
                  </Form.Item>
                </Col>
              </Row>
            </Col>
          </Row>
          {isOwner && (
            <Row className="second-row">
              <div
                className={`second-row__bankInfo card second-row__row-edit m-r-p `}
              >
                <Row>
                  <div className="restaurant-add__header">
                    <h2 className="restaurant-add__title ">
                      {intl.formatMessage(messagesGlobal.bankInfo)}
                    </h2>
                  </div>
                </Row>
                <Row gutter={12}>
                  <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                    <Form.Item name={['payment', 'bankName']}>
                      <FloatLabel
                        className="custormInput custormInput-second"
                        label={intl.formatMessage(messagesGlobal.bank)}
                      />
                    </Form.Item>
                  </Col>
                  <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                    <Form.Item name={['payment', 'bankNumber']}>
                      <FloatLabel
                        className="custormInput custormInput-second"
                        label={`${intl.formatMessage(
                          messagesGlobal.accountNo,
                        )}`}
                      />
                    </Form.Item>
                  </Col>
                  <Col span={24}>
                    <Form.Item name={['payment', 'bankArea']}>
                      <FloatLabel
                        className="custormInput custormInput-second"
                        label={intl.formatMessage(messagesGlobal.branch)}
                      />
                    </Form.Item>
                  </Col>
                </Row>
              </div>
              <div className={`second-row__service card second-row__row-edit`}>
                <Row gutter={12}>
                  <Col span={24}>
                    <div className="restaurant-add__header">
                      <h2 className="restaurant-add__title ">
                        {intl.formatMessage(messagesGlobal.serviceUsing)}
                      </h2>
                    </div>
                  </Col>
                  <Col span={24}>
                    <Form.Item name="status" initialValue={free}>
                      <FloatLabel
                        onChange={value => {
                          setFree(value);
                        }}
                        label={intl.formatMessage(messagesGlobal.policy)}
                        className={`custormSelect `}
                        disabled={true}
                        items={STATUS.map(item => {
                          return {
                            id: item.value,
                            name: item.label,
                          };
                        })}
                        typeInput="selectMutil"
                      />
                    </Form.Item>
                  </Col>
                  {free !== 1 ? (
                    <>
                      <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                        <Form.Item name={['payment', 'trialDate']}>
                          <FloatLabel
                            suffix={suffix}
                            className="custormInput custormInput-second "
                            disabled={true}
                          />
                        </Form.Item>
                      </Col>
                      <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                        <Form.Item name={['payment', 'durationType']}>
                          <FloatLabel
                            onChange={value => {
                              setDurationType(value);
                            }}
                            className={`custormSelect `}
                            disabled={true}
                            items={STATUS.map(item => {
                              return {
                                id: item.value,
                                name: item.label,
                              };
                            })}
                            typeInput="selectInput"
                          />
                        </Form.Item>
                      </Col>
                    </>
                  ) : (
                    <></>
                  )}
                </Row>
              </div>
            </Row>
          )}
          <Row>
            <Col style={{ textAlign: 'right', marginTop: '30px' }} span={24}>
              <Button htmlType="submit" className="custormButton">
                {intl.formatMessage(messagesGlobal.save)}
              </Button>
            </Col>
          </Row>
        </Form>
      </div>
    </MerchantFormWrapper>
  );
}
export default injectIntl(MerchantForm);
