import React, { useEffect, useState, useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import makeSelectPromotionDetail from './selectors';
import reducer from './reducer';
import saga from './saga';
import { useHistory, useParams } from 'react-router-dom';
import {
  Button,
  DatePicker,
  Form,
  Input,
  Select,
  Upload,
  Radio,
  notification,
  Row,
  Col,
  Switch,
} from 'antd';
import IMG_RES_DEFAULT from '../../images/restaurant-placeholder.svg';
import { LoadingOutlined } from '@ant-design/icons';
import { TOKEN_KEY } from '../App/constants';
import { digits, timeDigits } from 'utils/number';
import { PROMOTION_DETAIL, PUBLIC_API } from '../App/urls';
import { RoutePaths } from '../App/routes';
import {
  EditUploadImageIcon,
  PromotionIcon,
} from '../../styles/icon-components';
import BG_QR_CODE from '../../images/qr_code.svg';
import {
  validatePercent,
  validateFormatNumber,
  fileValidation,
  validateTimeFormat,
} from '../../utils/validation';
import { PromotionAddNewWrapper } from './styles';
import { getBase64 } from '../../utils/common';
import { getPromotion, updatePromotion } from './actions';
import { getPromotionSubjects } from './actions';
import { DATE_FORMAT } from '../../utils/constants';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from './messages';
import messagesGlobal from 'translations/messages';
import { makeSelectMenus, makeSelectRestaurants } from '../App/selectors';
import { FormatInput, FormatTimeInput } from 'components/FormatInput';
import cacheUtils from 'utils/cacheUtils';
import { parseInt } from 'lodash';
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  promotionDetail: makeSelectPromotionDetail(),
});

interface Props {
  readonly intl: any;
}

const menuSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
  menus: makeSelectMenus(),
});
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function PromotionDetail(props: Props) {
  useInjectReducer({ key: 'promotionDetail', reducer: reducer });
  useInjectSaga({ key: 'promotionDetail', saga: saga });

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const { promotionDetail } = useSelector(stateSelector);
  const { menus, restaurants } = useSelector(menuSelector);
  const dispatch = useDispatch(); // eslint-disable-line @typescript-eslint/no-unused-vars
  const { promotion, subjects, isFetching } = promotionDetail;

  const userInfo = cacheUtils.getUserInfo();
  const currency = useCallback(
    userInfo => {
      if (userInfo) {
        const userInfoJson = JSON.parse(userInfo);
        if (userInfoJson.profile?.merchant?.setting) {
          return userInfoJson.profile?.merchant?.setting.currency;
        }
        return 'VND';
      } else {
        return 'VND';
      }
    },
    [userInfo],
  );
  const currencyMemoi = currency(userInfo);
  // @ts-ignore
  const { id } = useParams();
  const [imageUrl, setImageUrl] = useState<any>();
  const [discountBy, setDiscountBy] = useState(1);
  const [promotionType, setPromotionType] = useState(1);
  const [status, setStatus] = useState(false);
  const { intl } = props;
  const listDate = [
    { id: 1, name: intl.formatMessage(messages.monday) },
    { id: 2, name: intl.formatMessage(messages.tuesday) },
    { id: 3, name: intl.formatMessage(messages.wednesday) },
    { id: 4, name: intl.formatMessage(messages.thursday) },
    { id: 5, name: intl.formatMessage(messages.friday) },
    { id: 6, name: intl.formatMessage(messages.sevenday) },
    { id: 0, name: intl.formatMessage(messages.sunday) },
  ];
  const [form] = Form.useForm();
  const history = useHistory();
  const token = localStorage.getItem(TOKEN_KEY);

  useEffect(() => {
    dispatch(getPromotionSubjects());
    dispatch(getPromotion(id));
  }, []);

  useEffect(() => {
    // @ts-ignore
    if (promotion) {
      setImageUrl(
        promotion && promotion.photo
          ? `${PUBLIC_API}/${promotion?.photo}`
          : null,
      );
      setDiscountBy(promotion?.discountTypeId ? promotion?.discountTypeId : 1);
      setPromotionType(
        promotion?.discountRedeemTypeId ? promotion?.discountRedeemTypeId : 1,
      );
      const res = promotion.restaurantIds
        ? promotion.restaurantIds.map(r => parseInt(r))
        : [];
      setStatus(!!promotion.status);
      form.setFieldsValue({ ...promotion, restaurantIds: res });
    }
  }, [promotion]);

  const handleChangeDiscountBy = value => {
    setDiscountBy(value);
  };

  const changeStatus = async value => {
    setStatus(value);
  };

  const handleChangeType = e => {
    setPromotionType(e.target.value);
    form.setFieldsValue({ discountTypeId: 2 });
    setDiscountBy(2);
  };

  const beforeUpload = file => {
    if (!fileValidation(file.name)) {
      notification.error({ message: intl.formatMessage(messages.invalidFile) });
      return false;
    }
    const reader = new FileReader();
    reader.onloadend = e => {
      setImageUrl(reader.result!);
    };
    reader.readAsDataURL(file);
    return false;
  };

  const onFinish = async values => {
    console.log(values)

    let photo = promotion && promotion.photo ? promotion.photo : '';
    const { files } = values;
    const imageFile = files?.file;
    if (imageFile) {
      const formData = new FormData();
      formData.append('photo', imageFile!);
      photo = await fetchAPI({
        method: 'PUT',
        url: replaceUrl(PROMOTION_DETAIL, { id })   ,
        formData: true,
        data: formData,
      });
      delete values.files
    }
    for (var key in values) {
      if (typeof values[key] === 'string') {
        if (values[key] === '') {
          values[key]='';
          continue;
        }
        values[key] = values[key].trim();
        if (/^[0-9,]+$/.test(values[key])) {
          values[key] = values[key].replace(/,/g, '');
        }
      }
    }
    values.quantity = values.quantity ? values.quantity : null;
    values.maxTotalApplied = values.maxTotalApplied
      ? values.maxTotalApplied
      : null;
    values.status = values.status ? 1 : 0;
    const { restaurantIds = [] } = values;
    if (restaurantIds === '') {
      values.restaurantIds = [];
    }
    values.restaurantIds = JSON.stringify(
      restaurantIds.map(restaurantId => restaurantId),
    );
    dispatch(updatePromotion({ id, promotion: values }));
  };

  const uploadButton = (
    <div>
      {isFetching ? <LoadingOutlined /> : <img src={IMG_RES_DEFAULT} />}
      <div className="ant-upload-text" style={{ marginTop: '15px' }}>
        <FormattedMessage {...messagesGlobal.image} />
      </div>
      <span className="img-hint">
        {intl.formatMessage(messagesGlobal.encourageCondition, {
          height: 345,
          width: 140,
        })}
      </span>
    </div>
  );

  return (
    <PromotionAddNewWrapper>
      <Form
        form={form}
        className="form"
        style={{ height: '100%' }}
        onFinish={onFinish}
      >
        <div className="promo-header">
          <div className="promo-header__img">
          <Form.Item name="files">
            <Upload
              name="photo"
              listType="picture-card"
              className="promo-header__upload"
              showUploadList={false}
              beforeUpload={beforeUpload}
              accept="image/*"
            >
              {imageUrl ? (
                <img src={imageUrl} alt="avatar" className="photo-promotion" />
              ) : (
                uploadButton
              )}
              {imageUrl && (
                <div className="edit-upload-image-icon">
                  <EditUploadImageIcon />
                </div>
              )}
            </Upload>
            </Form.Item>
          </div>
          <div className="promo-header__info">
            <h3 className="promo-header__info-name">
              {promotion ? promotion!.name : ''}
            </h3>
            <span className="promo-header__info-time">
              {promotionType === 1 || promotionType === 2 &&
              !!promotion?.startDate &&
              promotion?.endDate
                ? intl.formatMessage(messages.duration, {
                    from: promotion?.startDate?.format(DATE_FORMAT),
                    to: promotion?.endDate?.format(DATE_FORMAT),
                  })
                : intl.formatMessage(messagesGlobal.noExpiredDay)}
            </span>
            <div className="promo-header__info-status">
              <Form.Item name="status" noStyle>
                <Switch
                  style={{ marginRight: '15px' }}
                  checked={status}
                  onChange={changeStatus}
                />
              </Form.Item>
              <span style={{ color: status ? '#9CD339' : '#9C9696' }}>
                {status ? (
                  <FormattedMessage {...messagesGlobal.activating} />
                ) : (
                  <FormattedMessage {...messagesGlobal.stop} />
                )}
              </span>
            </div>
          </div>
          <div className="promo-header__qr-code">
            {promotion?.qrcode ? (
              <img
                className="promo-header__qr-image"
                src={`data:image/svg+xml,${escape(promotion.qrcode)}`}
              />
            ) : (
              <img src={BG_QR_CODE}></img>
            )}
            <div className="promo-header__code">{promotion?.code}</div>
          </div>
        </div>
        {promotionType === 1 ? (
          <div className="body-detail">
            <Row className="first-promotion-row">
              <Col
                className="general-card"
                xl={16}
                lg={16}
                md={16}
                sm={24}
                xs={24}
              >
                <div className="form-header">
                  {intl.formatMessage(messagesGlobal.general)}
                </div>
                <Form.Item
                  name="status"
                  initialValue={1}
                  style={{ display: 'none' }}
                ></Form.Item>
                <div className="form-content-exchange__promo-type">
                  <p>{intl.formatMessage(messages.promotionType)}</p>
                  <Form.Item name="discountRedeemTypeId" initialValue={1}>
                    <Radio.Group onChange={handleChangeType}>
                      <Radio value={1}>
                        {intl.formatMessage(messages.free)}
                      </Radio>
                      <Radio value={2}>
                        {intl.formatMessage(messages.exchange)}
                      </Radio>
                    </Radio.Group>
                  </Form.Item>
                </div>
                <Row>
                  <Col
                    span={12}
                    className="general-card__firs-col--free-detail"
                  >
                    <Form.Item
                      name="name"
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messages.requirePromotionName,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        label={`${intl.formatMessage(messages.promotionName)}*`}
                      />
                    </Form.Item>
                    <Row className="general-card__discount">
                      <Col span={12}>
                        <Form.Item
                          name="discountTypeId"
                          style={{ display: 'inline-block' }}
                          initialValue={1}
                        >
                          <Select
                            size="large"
                            placeholder={intl.formatMessage(
                              messages.discountBy,
                            )}
                            onChange={handleChangeDiscountBy}
                          >
                            <Select.Option value={1}>
                              {intl.formatMessage(messages.percent)}
                            </Select.Option>
                            <Select.Option value={2}>
                              {intl.formatMessage(messages.amount)}
                            </Select.Option>
                            <Select.Option value={3}>
                              {intl.formatMessage(messages.attachment)}
                            </Select.Option>
                          </Select>
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        {discountBy === 1 ? (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[
                              validatePercent,
                              {
                                pattern: new RegExp('^[0-9]*$'),
                                message: intl.formatMessage(
                                  messages.requireNumberInput,
                                ),
                              },
                            ]}
                          >
                            <FloatLabel addonAfter="%" />
                          </Form.Item>
                        ) : discountBy === 2 ? (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[
                              {
                                required: true,
                                message: intl.formatMessage(
                                  messages.requireDiscount,
                                ),
                              },
                              {
                                pattern: new RegExp('^[0-9,]*$'),
                                message: intl.formatMessage(
                                  messages.requireNumberInput,
                                ),
                              },
                            ]}
                          >
                            <FormatInput
                              formatter={digits}
                              addonAfter={currencyMemoi}
                            />
                          </Form.Item>
                        ) : (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[validatePercent]}
                          >
                            <FloatLabel addonAfter="SL" />
                          </Form.Item>
                        )}
                      </Col>
                    </Row>
                    <Form.Item
                      name="description"
                      className="form-content__desc free-detail last-item"
                    >
                      <FloatLabel
                        label={intl.formatMessage(messages.description)}
                        rows={6}
                        typeInput="TextArea"
                      />
                    </Form.Item>
                  </Col>
                  <Col span={12} className="general-card__second-col">
                    <Col>
                      <Row>
                        <Form.Item name="rules" className="form-content__cond">
                          <FloatLabel
                            label={intl.formatMessage(messages.terms)}
                            rows={6}
                            typeInput="TextArea"
                          />
                        </Form.Item>
                      </Row>
                    </Col>
                  </Col>
                </Row>
              </Col>
              <Col
                xl={8}
                lg={8}
                md={8}
                sm={24}
                xs={24}
                className="general-right-card"
              >
                <Row className="conditions-card">
                  <Row>
                    <div className="form-header">
                      {intl.formatMessage(messages.condition)}
                    </div>
                  </Row>
                  <Row>
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          className="input-addon"
                          name="minimumTotalApplied"
                          rules={[
                            {
                              pattern: new RegExp('^[0-9,]*$'),
                              message: intl.formatMessage(
                                messages.requireNumberInput,
                              ),
                            },
                          ]}
                        >
                          <FormatInput
                            formatter={digits}
                            addonAfter={currencyMemoi}
                            placeholder={intl.formatMessage(
                              messagesGlobal.minimumAmount,
                            )}
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          className="input-addon"
                          name="quantity"
                          rules={[
                            {
                              pattern: new RegExp('^[0-9,]*$'),
                              message: intl.formatMessage(
                                messages.requireNumberInput,
                              ),
                            },
                          ]}
                        >
                          <FloatLabel
                            label={intl.formatMessage(
                              messagesGlobal.minimumQuantity,
                            )}
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Form.Item
                      className="input-addon last-item"
                      name="maxTotalApplied"
                      rules={[
                        {
                          pattern: new RegExp('^[0-9]*$'),
                          message: intl.formatMessage(
                            messages.requireNumberInput,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        label={intl.formatMessage(messagesGlobal.totalApplied)}
                      />
                    </Form.Item>
                  </Row>
                </Row>
                <Row className="time-card">
                  <Row>
                    <div className="form-header">
                      {intl.formatMessage(messagesGlobal.time)}
                    </div>
                  </Row>
                  <Row className="time-card__content">
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          name="startDate"
                          rules={[
                            ({ getFieldValue }) => ({
                              validator(rule, value) {
                                const endDateValue = getFieldValue('endDate');
                                if (
                                  !value ||
                                  !endDateValue ||
                                  endDateValue.isAfter(value)
                                ) {
                                  return Promise.resolve();
                                }
                                return Promise.reject(
                                  intl.formatMessage(
                                    messages.startDateBeforeEndDate,
                                  ),
                                );
                              },
                            }),
                          ]}
                        >
                          <FloatLabel
                            label={intl.formatMessage(messages.fromDate)}
                            className="fw"
                            format={DATE_FORMAT}
                            typeInput="datepicker"
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          name="endDate"
                          rules={[
                            ({ getFieldValue }) => ({
                              validator(rule, value) {
                                const startDateValue = getFieldValue(
                                  'startDate',
                                );
                                if (
                                  !value ||
                                  !startDateValue ||
                                  startDateValue.isBefore(value)
                                ) {
                                  return Promise.resolve();
                                }
                                return Promise.reject(
                                  intl.formatMessage(
                                    messages.endDateAfterStartDate,
                                  ),
                                );
                              },
                            }),
                          ]}
                        >
                          <FloatLabel
                            label={intl.formatMessage(messages.toDate)}
                            className="fw"
                            format={DATE_FORMAT}
                            typeInput="datepicker"
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          name="startHour"
                          rules={[
                            validateTimeFormat(
                              form,
                              intl.formatMessage(messages.requireFormatTime, {
                                format: 'HH:MM:SS',
                              }),
                            ),
                          ]}
                        >
                          <FormatTimeInput
                            formatter={timeDigits}
                            placeholder={intl.formatMessage(messages.fromTime)}
                            className="fw"
                            maxLength={8}
                            showSecond={true}
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          name="endHour"
                          rules={[
                            validateTimeFormat(
                              form,
                              intl.formatMessage(messages.requireFormatTime, {
                                format: 'HH:MM:SS',
                              }),
                            ),
                          ]}
                        >
                          <FormatTimeInput
                            formatter={timeDigits}
                            placeholder={intl.formatMessage(messages.toTime)}
                            className="fw"
                            maxLength={8}
                            showSecond={true}
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Form.Item
                      name="daysOfWeek"
                      className="last-item mutil-select"
                    >
                      <FloatLabel
                        className="padding-mutil-select"
                        size="middle"
                        label={intl.formatMessage(messages.promotionDays)}
                        mode="multiple"
                        showArrow
                        items={listDate}
                        typeInput="selectMutil"
                      />
                    </Form.Item>
                  </Row>
                </Row>
              </Col>
            </Row>
            <Row className="second-promotion-row">
              <Col xl={12} lg={12} md={12} sm={24} xs={24}>
                <Row className="conditions-card">
                  <Row>
                    <div className="form-header">
                      {intl.formatMessage(messagesGlobal.applyFor)}
                    </div>
                  </Row>
                  <Row className="time-card__content">
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          name="restaurantIds"
                          className="mutil-select"
                        >
                          <FloatLabel
                            className="padding-mutil-select"
                            size="middle"
                            label={intl.formatMessage(
                              messagesGlobal.restaurant,
                            )}
                            mode="multiple"
                            showArrow
                            typeInput="selectMutil"
                            items={restaurants}
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          name="subjectsId"
                          rules={[
                            {
                              required: true,
                              message: intl.formatMessage(
                                messages.requirePromotionSubjects,
                              ),
                            },
                          ]}
                          className="customerGroup orgin-select"
                        >
                          <FloatLabel
                            size="large"
                            label={intl.formatMessage(
                              messages.promotionSubjects,
                            )}
                            items={subjects}
                            typeInput="selectMutil"
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Form.Item
                      name="menuItemIds"
                      className="last-item mutil-select"
                    >
                      <FloatLabel
                        className="padding-mutil-select"
                        size="middle"
                        label={intl.formatMessage(messages.product)}
                        mode="multiple"
                        showArrow
                        items={menus}
                        typeInput="selectMutil"
                      />
                    </Form.Item>
                  </Row>
                </Row>
              </Col>
            </Row>
            <Button
              className="btn-submit"
              type="primary"
              shape="round"
              size="large"
              htmlType="submit"
            >
              {intl.formatMessage(messages.save)}
            </Button>
          </div>
        ) : (
          <div className="body-detail">
            <Row className="first-promotion-row">
              <Col
                xl={16}
                lg={16}
                md={16}
                sm={24}
                xs={24}
                className="general-card"
              >
                <div className="form-header">
                  {intl.formatMessage(messagesGlobal.general)}
                </div>
                <Form.Item
                  name="status"
                  initialValue={1}
                  style={{ display: 'none' }}
                ></Form.Item>
                <div className="form-content-exchange__promo-type">
                  <p>{intl.formatMessage(messages.promotionType)}</p>
                  <Form.Item name="discountRedeemTypeId" initialValue={1}>
                    <Radio.Group onChange={handleChangeType}>
                      <Radio value={1}>
                        {intl.formatMessage(messages.free)}
                      </Radio>
                      <Radio value={2}>
                        {intl.formatMessage(messages.exchange)}
                      </Radio>
                    </Radio.Group>
                  </Form.Item>
                </div>
                <Row>
                  <Col
                    span={12}
                    className="general-card__firs-col--point-detail"
                  >
                    <Form.Item
                      name="name"
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messages.requirePromotionName,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        label={`${intl.formatMessage(messages.promotionName)}*`}
                      />
                    </Form.Item>
                    <Form.Item
                      name="redeemPoints"
                      className="input-addon"
                      rules={[
                        {
                          pattern: new RegExp('^[0-9]*$'),
                          message: intl.formatMessage(
                            messages.requireNumberInput,
                          ),
                        },
                        {
                          required: true,
                          message: intl.formatMessage(
                            messages.requirePoints,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        addonAfter={intl.formatMessage(messages.point)}
                        label={`${intl.formatMessage(messages.points)}*`}

                      />
                    </Form.Item>
                    <Row className="general-card__discount">
                      <Col span={12}>
                        <Form.Item
                          name="discountTypeId"
                          style={{ display: 'inline-block' }}
                          initialValue={1}
                        >
                          <Select
                            size="large"
                            placeholder={intl.formatMessage(
                              messages.discountBy,
                            )}
                            onChange={handleChangeDiscountBy}
                          >
                            <Select.Option value={1}>
                              {intl.formatMessage(messages.percent)}
                            </Select.Option>
                            <Select.Option value={2}>
                              {intl.formatMessage(messages.amount)}
                            </Select.Option>
                            <Select.Option value={3}>
                              {intl.formatMessage(messages.attachment)}
                            </Select.Option>
                          </Select>
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        {discountBy === 1 ? (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[
                              validatePercent,
                              {
                                pattern: new RegExp('^[0-9]*$'),
                                message: intl.formatMessage(
                                  messages.requireNumberInput,
                                ),
                              },
                            ]}
                          >
                            <FloatLabel addonAfter="%" />
                          </Form.Item>
                        ) : discountBy === 2 ? (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[
                              {
                                required: true,
                                message: intl.formatMessage(
                                  messages.requireDiscount,
                                ),
                              },
                              {
                                pattern: new RegExp('^[0-9,]*$'),
                                message: intl.formatMessage(
                                  messages.requireNumberInput,
                                ),
                              },
                            ]}
                          >
                            <FormatInput
                              formatter={digits}
                              addonAfter={currencyMemoi}
                            />
                          </Form.Item>
                        ) : (
                          <Form.Item
                            name="discountValue"
                            className="input-addon orgin-input"
                            rules={[validatePercent]}
                          >
                            <FloatLabel addonAfter="SL" />
                          </Form.Item>
                        )}
                      </Col>
                    </Row>
                    <Form.Item
                      name="description"
                      className="form-content__desc point-detail last-item"
                    >
                      <FloatLabel
                        label={intl.formatMessage(messages.description)}
                        rows={6}
                        typeInput="TextArea"
                      />
                    </Form.Item>
                  </Col>
                  <Col span={12} className="general-card__second-col">
                    <Col>
                      <Row>
                        <Form.Item name="rules" className="form-content__cond">
                          <FloatLabel
                            label={intl.formatMessage(messages.terms)}
                            rows={6}
                            typeInput="TextArea"
                          />
                        </Form.Item>
                      </Row>
                    </Col>
                  </Col>
                </Row>
              </Col>
              <Col
                xl={8}
                lg={8}
                md={8}
                sm={24}
                xs={24}
                className="general-right-card"
              >
                <Row className="conditions-card">
                  <Row>
                    <div className="form-header">
                      {intl.formatMessage(messagesGlobal.applyFor)}
                    </div>
                  </Row>
                  <Row>
                    <Row className="time-card__content--firstRow ">
                      <Form.Item name="restaurantIds" className="mutil-select">
                        <FloatLabel
                          className="padding-mutil-select"
                          size="middle"
                          label={intl.formatMessage(messagesGlobal.restaurant)}
                          mode="multiple"
                          showArrow
                          typeInput="selectMutil"
                          items={restaurants}
                        />
                      </Form.Item>
                      <Form.Item
                        name="subjectsId"
                        rules={[
                          {
                            required: true,
                            message: intl.formatMessage(
                              messages.requirePromotionSubjects,
                            ),
                          },
                        ]}
                        className="customerGroup orgin-select"
                      >
                        <FloatLabel
                          size="middle"
                          label={intl.formatMessage(messages.promotionSubjects)}
                          typeInput="selectMutil"
                          items={subjects}
                        />
                      </Form.Item>
                    </Row>
                    <Form.Item
                      name="daysOfWeek"
                      className="last-item mutil-select"
                    >
                      <FloatLabel
                        className="padding-mutil-select"
                        size="middle"
                        label={intl.formatMessage(messages.promotionDays)}
                        mode="multiple"
                        showArrow
                        typeInput="selectMutil"
                        items={listDate}
                      />
                    </Form.Item>
                  </Row>
                </Row>
                <Row className="time-card">
                  <Row>
                    <div className="form-header">
                      {intl.formatMessage(messagesGlobal.time)}
                    </div>
                  </Row>
                  <Row className="time-card__content">
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          name="startDate"
                          rules={[
                            ({ getFieldValue }) => ({
                              validator(rule, value) {
                                const endDateValue = getFieldValue('endDate');
                                if (
                                  !value ||
                                  !endDateValue ||
                                  endDateValue.isAfter(value)
                                ) {
                                  return Promise.resolve();
                                }
                                return Promise.reject(
                                  intl.formatMessage(
                                    messages.startDateBeforeEndDate,
                                  ),
                                );
                              },
                            }),
                          ]}
                        >
                          <FloatLabel
                            label={intl.formatMessage(messages.fromDate)}
                            className="fw"
                            format={DATE_FORMAT}
                            typeInput="datepicker"
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          name="endDate"
                          rules={[
                            ({ getFieldValue }) => ({
                              validator(rule, value) {
                                const startDateValue = getFieldValue(
                                  'startDate',
                                );
                                if (
                                  !value ||
                                  !startDateValue ||
                                  startDateValue.isBefore(value)
                                ) {
                                  return Promise.resolve();
                                }
                                return Promise.reject(
                                  intl.formatMessage(
                                    messages.endDateAfterStartDate,
                                  ),
                                );
                              },
                            }),
                          ]}
                        >
                          <FloatLabel
                            label={intl.formatMessage(messages.toDate)}
                            className="fw"
                            format={DATE_FORMAT}
                            typeInput="datepicker"
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Row className="time-card__content--firstRow">
                      <Col span={12}>
                        <Form.Item
                          name="startHour"
                          rules={[
                            validateTimeFormat(
                              form,
                              intl.formatMessage(messages.requireFormatTime, {
                                format: 'HH:MM:SS',
                              }),
                            ),
                          ]}
                        >
                          <FormatTimeInput
                            formatter={timeDigits}
                            placeholder={intl.formatMessage(messages.fromTime)}
                            className="fw"
                            maxLength={8}
                            showSecond={true}
                          />
                        </Form.Item>
                      </Col>
                      <Col span={12}>
                        <Form.Item
                          name="endHour"
                          rules={[
                            validateTimeFormat(
                              form,
                              intl.formatMessage(messages.requireFormatTime, {
                                format: 'HH:MM:SS',
                              }),
                            ),
                          ]}
                        >
                          <FormatTimeInput
                            formatter={timeDigits}
                            placeholder={intl.formatMessage(messages.toTime)}
                            className="fw"
                            maxLength={8}
                            showSecond={true}
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                    <Form.Item
                      name="menuItemIds"
                      className="last-item mutil-select"
                    >
                      <FloatLabel
                        className="padding-mutil-select"
                        size="middle"
                        label={`${intl.formatMessage(messages.product)}`}
                        mode="multiple"
                        showArrow
                        typeInput="selectMutil"
                        items={menus}
                      />
                    </Form.Item>
                  </Row>
                </Row>
              </Col>
            </Row>
            <Button
              className="btn-submit"
              type="primary"
              shape="round"
              size="large"
              htmlType="submit"
            >
              {intl.formatMessage(messages.save)}
            </Button>
          </div>
        )}
      </Form>
    </PromotionAddNewWrapper>
  );
}

export default injectIntl(PromotionDetail);
