/*
 *
 * PromotionDetail reducer
 *
 */

import ActionTypes from "./constants";
import { ContainerActions, ContainerState } from "./types";
import moment from "moment";
import { TIME_FORMAT } from "../../utils/constants";

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  message: '',
  promotion: null,
  subjects: []
};

function promotionDetailReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_PROMOTION:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PROMOTION_SUCCESS:
      const promotion = action.payload;
      promotion.startDate = promotion.startDate ? moment(promotion.startDate) : undefined;
      promotion.endDate = promotion.endDate ? moment(promotion.endDate) : undefined;
      promotion.daysOfWeek = promotion.daysOfWeek || [];
      promotion.menuItemIds = promotion.menuItems ? promotion.menuItems.map(menu => +menu.menuItemId) : [];
      return { ...state, isFetching: false, promotion };
    case ActionTypes.GET_PROMOTION_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_PROMOTION_SUBJECTS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PROMOTION_SUBJECTS_SUCCESS:
      return { ...state, isFetching: false, subjects: action.payload };
    case ActionTypes.GET_PROMOTION_SUBJECTS_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.UPDATE_PROMOTION:
      return { ...state, isFetching: true };
    case ActionTypes.UPDATE_PROMOTION_SUCCESS:
      return { ...state, isFetching: false };
    case ActionTypes.UPDATE_PROMOTION_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    default:
      return state;
  }
}

export default promotionDetailReducer;
