
import { callApi, success } from "../../utils/apiUtils";
import { put, takeLatest } from "redux-saga/effects";
import { getPromotionFail, getPromotionSuccess, updatePromotionFail, updatePromotionSuccess, getPromotionSubjectsFail, getPromotionSubjectsSuccess } from "./actions";
import ActionTypes from "./constants";
import { TIME_FORMAT } from "../../utils/constants";
import { push } from "connected-react-router";
import { RoutePaths } from "../App/routes";
import { apiError } from "../App/actions";

export function* getPromotion({payload: id}) {
  try {
    const { code, data, message } = yield callApi(`/promotions/${id}`, 'GET');
    if (success(code)) {
      yield put(getPromotionSuccess(data));
    } else {
      yield put(getPromotionFail(message));
    }
  } catch (error) {
    yield put(getPromotionFail(error.message));
  }
}

export function* getPromotionSubjects() {
  try {
    const { code, data, message } = yield callApi(`/promotions/promotions-subjects`, 'GET');
    if (success(code)) {
      data.sort((a, b) => (a.id > b.id ? 1 : -1));
      yield put(getPromotionSubjectsSuccess(data));
    } else {
      yield put(getPromotionSubjectsFail(message));
    }
  } catch (error) {
    yield put(getPromotionSubjectsFail(error.message));
  }
}

export function* updatePromotion({ payload: { id, promotion } }) {
  try {
    let values = promotion;
    values.startDate = values.startDate ? values.startDate!.toISOString() : values.startDate;
    values.endDate = values.endDate ? values.endDate!.toISOString() : values.endDate;
    values.daysOfWeek = values.daysOfWeek ? `[${values.daysOfWeek}]` : values.daysOfWeek;
    const { menuItemIds = [] } = values;
    values.menuItems = JSON.stringify(menuItemIds.map(menuItemId => ({ menuItemId })));
    delete values.menuItemIds; // fix api issue
    const { code, data, message } = yield callApi(`/promotions/${id}`, 'PUT', values);
    if (success(code)) {
      yield put(updatePromotionSuccess(data));
      yield put(push(RoutePaths.promotion));
    } else {
      yield put(updatePromotionFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(updatePromotionFail(error.message));
    yield put(apiError(error.message));
  }
}

// Individual exports for testing
export default function* promotionDetailSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PROMOTION, getPromotion);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PROMOTION_SUBJECTS, getPromotionSubjects);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_PROMOTION, updatePromotion);
}
