import React, { useState } from 'react';
import styled from 'styled-components';
import { useHistory } from 'react-router-dom';
import { Button, Space, Col, Typography, Card as AntdCard, Modal } from 'antd';
import { PUBLIC_API } from 'containers/App/urls';
import { RoutePaths } from 'containers/App/routes';
import IMG_RES_DEFAULT from '../../../images/restaurant-placeholder.svg';
import { EditIcon, RemoveIcon } from 'styles/icon-components';
import { ContainerImg } from 'styles/custom-styled-components';
import { ExclamationCircleOutlined } from '@ant-design/icons';
import moment from 'moment';
import messages from '../messages';
import { injectIntl } from 'react-intl'
import NumberFormat from 'react-number-format';;
import Avatar from 'react-avatar';
import cacheUtils from 'utils/cacheUtils';
import { initials } from 'utils/string';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';

const HoveredCardWrapper = styled.div`
  position: absolute;
  top: 40%;
  left: 35%;
  text-align: center;
`;
function HoveredCard(props) {
  const { promotion, handleOnClickRemove, intl, type } = props;
  const history = useHistory();
  const handleOnClickEdit = () =>
    history.push(
      `${type ? RoutePaths.promotionDetail : RoutePaths.giftCardDetail}/${
        promotion.id
      }`,
    );
  const onClickRemove = () => {
    if (handleOnClickRemove) {
      handleOnClickRemove(promotion!.id);
    }
  };
  const confirm = () => {
    Modal.confirm({
      title: intl.formatMessage(messages.confirmDelete),
      icon: <ExclamationCircleOutlined />,
      content: intl.formatMessage(messages.confirmDeleteMessage, {
        promotion: promotion.name,
      }),
      okText: intl.formatMessage(messages.delete),
      cancelText: intl.formatMessage(messages.cancel),
      maskClosable: true,
      onOk: onClickRemove,
    });
  };
  return (
    <HoveredCardWrapper>
      <Space>
        <Button
          shape="circle"
          style={{ width: 60, height: 60 }}
          onClick={handleOnClickEdit}
        >
          <EditIcon />
        </Button>
        <Button
          shape="circle"
          style={{ width: 60, height: 60 }}
          onClick={confirm}
        >
          <RemoveIcon />
        </Button>
      </Space>
    </HoveredCardWrapper>
  );
}

function CardDetail(props) {
  const { promotion, type, intl } = props;
  const userInfo = cacheUtils.getUserInfo();
  const userInfoJson = JSON.parse(userInfo ? userInfo : '');
  const { merchant } = userInfoJson?.profile;
  const { Title, Text } = Typography;
  const {
    photo,
    name,
    startDate,
    endDate,
    discountRedeemTypeId,
    status,
    price,
    amount
  } = promotion;
  const currencyMemoi = useCurrencyHook();
  // const Container = ({ imgLink, children }: ContainerImgProps) => {
  //   return <ContainerImg imgLink={imgLink}>{children}</ContainerImg>
  // }
  return (
    <ContainerImg imgLink={photo} height={200}>
      <div className="edit-upload-image-shop">
        {merchant.photo ? (
          <img className="user__avatar" src={`${PUBLIC_API}/${merchant.photo}`} />
        ) : (
          <Avatar
            className="user__avatar"
            initials={initials}
            name={merchant.name}
            size="30"
          />
        )}
        <span className="user__name--name">
          {merchant.name}
        </span>
      </div>
      {price && <div className="edit-upload-image-amount"><NumberFormat value={parseInt(amount)} displayType={'text'} thousandSeparator={'.'} renderText={value => (`${value} ${currencyMemoi}`)} decimalSeparator={','}/></div>}
      {!!startDate && !!endDate && (
        <div className="edit-upload-image-time">
          {intl.formatMessage(messages.duration, {
           from: moment(startDate).format("DD/MM/YYYY"), to: moment(endDate).format("DD/MM/YYYY")
          })}
        </div>
      )}
       <div className="edit-upload-image-status">
      <Text className={status ? 'active' : 'inactive'}>
        {status
          ? intl.formatMessage(messages.active)
          : intl.formatMessage(messages.inactive)}
      </Text>
      </div>
    </ContainerImg>
  );
}

function Card(props) {
  const { promotion, handleOnClickRemove, intl, type } = props;
  const [isHovered, setHovered] = useState(false);

  return (
    <Col xl={8} lg={12} md={12} sm={12} xs={24}>
      <AntdCard
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
        className="touch-card"
      >
        <CardDetail promotion={promotion} intl={intl} type={type} />
        {isHovered && (
          <HoveredCard
            promotion={promotion}
            handleOnClickRemove={handleOnClickRemove}
            intl={intl}
            type={type}
          />
        )}
      </AntdCard>
    </Col>
  );
}

export default injectIntl(Card);
