import React, { useState } from 'react';
import styled from 'styled-components';
import { useHistory } from 'react-router-dom';
import { Button, Space, Col, Typography, Card as AntdCard, Modal } from 'antd';
import { PUBLIC_API } from 'containers/App/urls';
import { RoutePaths } from 'containers/App/routes';
import IMG_RES_DEFAULT from '../../../images/restaurant-placeholder.svg';
import { EditIcon, RemoveIcon } from 'styles/icon-components';
import { ExclamationCircleOutlined } from '@ant-design/icons';
import IMG_DEFAULT_GIFT from '../../../images/default-gift-bg.svg';
import moment from 'moment';
import messages from "../messages";
import { injectIntl } from "react-intl";

const HoveredCardWrapper = styled.div`
  position: absolute;
  top: 40%;
  left: 35%;
  text-align: center;
`;

function HoveredCard(props) {
  const { promotion, handleOnClickRemove, intl, type } = props;
  const history = useHistory();
  const handleOnClickEdit = () => history.push(`${type ? RoutePaths.promotionDetail : RoutePaths.giftCardDetail}/${promotion.id}`);
  const onClickRemove = () => {
    if (handleOnClickRemove) {
      handleOnClickRemove(promotion!.id);
    }
  }
  const confirm = () => {
    Modal.confirm({
      title: intl.formatMessage(messages.confirmDelete),
      icon: <ExclamationCircleOutlined />,
      content: intl.formatMessage(messages.confirmDeleteMessage, { promotion: promotion.name }),
      okText: intl.formatMessage(messages.delete),
      cancelText: intl.formatMessage(messages.cancel),
      maskClosable: true,
      onOk: onClickRemove
    });
  }
  return (
    <HoveredCardWrapper>
      <Space>
        <Button
          shape="circle"
          style={{ width: 60, height: 60 }}
          onClick={handleOnClickEdit}
        ><EditIcon /></Button>
        <Button shape="circle" style={{ width: 60, height: 60 }} onClick={confirm}><RemoveIcon /></Button>
      </Space>
    </HoveredCardWrapper >
  )
}

function CardDetail(props) {
  const { promotion, type, intl } = props;
  const { Title, Text } = Typography
  const {
    photo,
    name,
    startDate,
    endDate,
    discountRedeemTypeId,
    status
  } = promotion;
  return (
    <>
      <div className="promotion-card__img">
        <img className={!photo ? "image-default" : "image"} src={!photo ? type ? IMG_RES_DEFAULT : IMG_DEFAULT_GIFT : `${PUBLIC_API}/${photo}`} />
      </div>
      <div className="card-footer">
      <div className="promotion-card__row">
        <Title level={3}>{name}</Title>
      </div>
      <div className="promotion-card__date discount">
        {(!!startDate && !!endDate ) && <Text>{(( type === 1) || type === 0) ? intl.formatMessage(messages.duration, { from: moment(startDate).format("DD/MM/YYYY"), to: moment(endDate).format("DD/MM/YYYY")}): ''}</Text>}
        <Text className={status ? 'active': 'inactive'}>{status ? intl.formatMessage(messages.active) : intl.formatMessage(messages.inactive)}</Text>
      </div>
      </div>
    </>
  )
}

function Card(props) {
  const { promotion, handleOnClickRemove, intl, type } = props;
  const [ isHovered, setHovered ] = useState(false);

  return (
    <Col xl={8} lg={12} md={12} sm={12} xs={24}>
      <AntdCard
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
        className="touch-card"
      >
        <CardDetail promotion={promotion} intl={intl} type={type}/>
        {isHovered && <HoveredCard promotion={promotion} handleOnClickRemove={handleOnClickRemove} intl={intl} type={type}/>}
      </AntdCard >
    </Col>
  )
}


export default injectIntl(Card);
