import React from 'react';
import styled from 'styled-components';
import { Link, useHistory } from "react-router-dom";
import { Input, Button, Space, Form } from 'antd';
import { SearchOutlined } from '@ant-design/icons';
import { PlusCharacter } from 'styles/icon-components';
import { RoutePaths } from 'containers/App/routes';
import { injectIntl } from "react-intl";
import messages from "../messages";
import messagesGlobal from "translations/messages";
import { getPromotions } from "../actions";
import { useDispatch } from "react-redux";
import FloatLabel from 'components/FormatInput/FloatLabel';

const PromotionListHeaderWrapper = styled.div`
    .ant-form-item {
      margin-bottom: 0px !important;
    }
    .ant-select-selection-item {
      line-height: 38px !important;
    }
    .header {
      &__title {
       font-size: 18px;
       font-weight: normal;
       color: #333333;
       padding-bottom: 10px;
      }
      &__toolbar {
        display: flex;
        @media only screen and (max-width: 480px) {
          flex-wrap: wrap;
        }
        @media only screen
        and (min-device-width: 768px)
        and (max-device-width: 1024px)
        and (-webkit-min-device-pixel-ratio: 1) {
         flex-wrap: wrap;
        }
	    }
    }
    .tabs {
     display: flex;
	   flex-direction: row;
	   flex-wrap: nowrap;
     justify-content: flex-start;
     list-style: none;
     padding: 0;
     margin: 0;


     &__promotion {
       font-size: 16px;
       padding: 17px 10px;
       margin-right: 15px;
       border-bottom: 1px solid #ccc;
       cursor: pointer;
       color: inherit;
       &.active {
       color: #9cd339;;
       border-bottom: 2px solid #9cd339;
     }
     }

    }

    .filter {
     display: flex;
     margin-left: auto;
     align-items: center;
     @media only screen and (max-width: 480px) {
       display: block;
       margin: 15px 0 !important;
     }

     @media only screen
        and (min-device-width: 768px)
        and (max-device-width: 1024px)
        and (-webkit-min-device-pixel-ratio: 1) {
         margin: 15px;
         margin-left: 0 !important;
        }

     &__all {
     width: 220px;
     margin-right: 10px;
     > div {
      width: 100%;
     }
     @media only screen and (max-width: 480px) {
       margin: 0;
       width: 100% !important;
       }
     }

     &__search {
     @media only screen and (max-width: 480px) {
       margin-top: 15px;
       width: 100%;
       }
     }
     @media only screen
        and (min-device-width: 768px)
        and (max-device-width: 1024px)
        and (-webkit-min-device-pixel-ratio: 1) {
         width: 100%;
        }
    }
`;

function Header(props) {
  const { type, intl } = props;
  const dispatch = useDispatch();
  const history = useHistory();
  const [form] = Form.useForm();
  const handleOnClick = () => {
    type ? history.push(RoutePaths.promotionAddnew) : history.push(RoutePaths.giftCardAddnew);
  }
  const onClickSearch = (values) => {
    dispatch(getPromotions(type, values.searchText.trim()))
  }
  return (
    <PromotionListHeaderWrapper>
      <div className="header__toolbar">
        <div className="tabs">
          <Link to="/promotion" className={`tabs__promotion ${type === 1 ? 'active' : ''}`}>{intl.formatMessage(messagesGlobal.discount)}</Link>
          <Link to="/promotion/giftCard" className={`tabs__promotion ${type === 0 ? 'active' : ''}`}>{intl.formatMessage(messagesGlobal.giftCard)}</Link>
        </div>
        <div className="filter">
          <div className="filter__search">
            <Form form={form} onFinish={onClickSearch}>
              <Space>
                <Form.Item name="searchText">
                  <FloatLabel  size="large" width={300} label={intl.formatMessage(messages.search)} prefix={<SearchOutlined />} />
                </Form.Item>
                <Button size="large" type="primary" htmlType="submit">{intl.formatMessage(messages.search)}</Button>
                <Button size="large" type="primary" onClick={handleOnClick} shape="circle" style={{padding: 0}}><PlusCharacter /></Button>
              </Space>
            </Form>
          </div>
        </div>
      </div>
    </PromotionListHeaderWrapper>
  );
}

export default injectIntl(Header)
