import React, { useEffect } from 'react';
import styled from 'styled-components';
import { Row, Spin } from "antd";
import Card from './Card';
import GiftCard from './Card/giftCard';
import { useDispatch, useSelector } from "react-redux";
import { createStructuredSelector } from "reselect";
import makeSelectPromotionList from "./selectors";
import { deletePromotion, getPromotions } from "./actions";

const PromotionActivityTabWrapper = styled.div`
    padding: 20px 0px;
    @media screen { 
      .ant-card:hover {
        background-color: rgba(0, 0, 0, 0.20000000298023224);
      }
    } 
    @media handheld { 
      .ant-card:click {
        background-color: rgba(0, 0, 0, 0.20000000298023224);
      }
    }
    @media screen and (max-width:800px) { 
      .ant-card:click {
        background-color: rgba(0, 0, 0, 0.20000000298023224);
      }
    }
    .ant-card-body {
      padding: 0px;
    }
    .card-footer {
      padding: 20px;
    }
    .promotion-card__row {
      h3.ant-typography {
        font-size: 15px;
        font-weight: 600;
      }
    }
    .promotion-card__date.discount {
      display: flex;
      justify-content: space-between;
      span.ant-typography {
        line-height: 18px;
      }
      .active {
        color: #9cd339;
      }
      .inactive {
        color: red;
      }
    }
`;

const promotionListSelector = createStructuredSelector({
  promotionList: makeSelectPromotionList()
})

export default function Tab(props) {
  const dispatch = useDispatch();
  const { type } = props;
  const { promotionList } = useSelector(promotionListSelector);
  const { isFetching, promotions } = promotionList;

  useEffect(() => {
    dispatch(getPromotions(type, ''));
  },[]);

  const handleOnClickRemove = (id) => {
    dispatch(deletePromotion(id));
  }

  return (
    <Spin spinning={isFetching}>
      <PromotionActivityTabWrapper>
       <Row gutter={[20, 20]}>
         {
           promotions.map((promotion,index) => (
            type ? <Card promotion={promotion} handleOnClickRemove={handleOnClickRemove} key={index} type={type}/>
            : <GiftCard promotion={promotion} handleOnClickRemove={handleOnClickRemove} key={index} type={type}/>
           ))
         }
       </Row>
      </PromotionActivityTabWrapper>
    </Spin>
  );
}
