import { put, takeLatest } from 'redux-saga/effects';

import { callApi, success } from "../../utils/apiUtils";
import { deletePromotionFail, deletePromotionSuccess, getPromotionFail, getPromotionsSuccess } from "./actions";
import ActionTypes from "./constants";

export function* getPromotions({payload: { type, searchText}}) {
  try {
    const searchParams = new URLSearchParams();
    if (searchText) {
      searchParams.append('searchText', searchText);
    }
    let promotions;
    if (type) {
      promotions = yield callApi(`/promotions?${searchParams.toString()}`, 'GET');
    } else {
      promotions = yield callApi(`/gift-cards?${searchParams.toString()}`, 'GET');
    }
    const { code, data, message} = promotions;
    if (success(code)) {
      yield put(getPromotionsSuccess(data));
    } else {
      yield put(getPromotionFail(message));
    }
  } catch (error) {
    yield put(getPromotionFail(error.message));
  }
}

export function* deletePromotion({payload: id}) {
  try {
    const { code, data, message } = yield callApi(`/promotions/${id}`, 'DELETE');
    if (success(code)) {
      yield put(deletePromotionSuccess(id));
    } else {
      yield put(deletePromotionFail(message));
    }
  } catch (error) {
    yield put(deletePromotionFail(error.message));
  }
}

// Individual exports for testing
export default function* promotionListSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PROMOTIONS, getPromotions);
  // @ts-ignore
  yield takeLatest(ActionTypes.DELETE_PROMOTION, deletePromotion);
}
