import React, { useState, useRef, useEffect } from 'react';
import { RevenueBranchModel } from '../revenueModels';
import { Doughnut } from 'react-chartjs-2';
import { Card, Button, Modal, Typography } from 'antd';
import { sumBy } from 'lodash';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import 'chartjs-plugin-labels';
const { Title } = Typography;
export function RevenuePieChart(props) {
  const { pieChartRevenueList, dateRange } = props;
  let refContainer = useRef();
  const [legend, setLegend] = useState({
    legendShort: <> no legend </>,
    legendFull: <> no legend </>,
  });
  const [visible, setVisible] = useState(false);
  const valueAsPercentage = (value, total) => {
    return ((value / total) * 100).toFixed(1);
  };
  const createMarkup = () => {
    return legend.legendShort;
  };

  const createMarkupModal = () => {
    return legend.legendFull;
  };


  useEffect(() => {
    const leg = generateLegend();
    setLegend({ legendShort: leg.legendShort, legendFull: leg.legendFull });
  }, [dateRange]);

  const generateLegend = () => {
    if (!refContainer) return null;
    return (refContainer as any).chartInstance.generateLegend();
  };
  const setTextInputRef = element => {
    refContainer = element;
  };

  const handleClickMore = () => {
    setVisible(true);
  }
  const doughnut = (
    <Doughnut
      ref={element => setTextInputRef(element)}
      data={{
        labels: pieChartRevenueList.label,
        datasets: [
          {
            label: 'Population (millions)',
            backgroundColor: pieChartRevenueList.color,
            data: pieChartRevenueList.data,
            pointStyle: 'circle',
          },
        ],
      }}
      height={200}
      width={335}
      options={{
        responsive: true,
        maintainAspectRatio: true,
        legend: {
          display: false,
        },
        legendCallback: function (chart) {
          // Return the HTML string here.
          const dataset = chart.data.datasets[0];
          const total = sumBy(dataset.data, number =>
            parseFloat(number as any),
          );
          const branchListLabels = chart.data.datasets[0].data.map(
            (data, index) => (
              <div className="wrapper-legend">
                <div
                  className="bullet-doughnut"
                  style={{
                    backgroundColor: `${chart.data.datasets[0].backgroundColor[index]}`,
                  }}
                ></div>
                <div id={`legend-${index}-item`} className="branch-doughnut">
                  {chart.data.labels[index]}
                </div>
                <div className="percent-data">
                  {total === 0 ? 0 : valueAsPercentage(data, total)}%
                </div>
              </div>
            ),
          );
          const legendShort = (
            <>
              <div className={`doughnut-legend`}>
                {branchListLabels.slice(0, 4)}
              </div>
              <div>
              {branchListLabels.length > 4 && <Button type="link" onClick={handleClickMore}><FormattedMessage {...messages.seeMore} /></Button>}
              </div>
            </>
          );
          const legendFull = (
            <>
              <div className={`doughnut-legend`}>{branchListLabels}</div>
            </>
          );
          return { legendShort: legendShort, legendFull: legendFull };
        },
        plugins: {
          labels: {
            render: 'percentage',
            fontColor: ['white', 'white', 'white', 'white', 'white'],
            precision: 1,
          },
        },
        cutoutPercentage: 30,
      }}
    />
  );
  return (
    <Card>
      <div className="line-chart__title">
        <Title level={4} style={{paddingLeft: '0em'}}><FormattedMessage {...messages.titleRevenuePieChart} /></Title>
      </div>
      {doughnut}
      <div className="legend-doughnut">{createMarkup()}</div>
      <Modal className="branch-list-modal" visible={visible} width={800} closable={true} onCancel={() => setVisible(false)} keyboard={true} onOk={() => setVisible(false)}>
        <div className="line-chart__title">
          <Title level={4} style={{paddingLeft: '0em', textAlign: 'center'}}><FormattedMessage {...messages.titleRevenuePieChart} /></Title>
        </div>
        {doughnut}
      <div className="legend-doughnut">{createMarkupModal()}</div>
    </Modal>
  </Card>
  );
}
