import React, { useState, useEffect } from 'react';
import { RevenueChart } from './revenueChart';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import makeSelectReport from './selectors';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from './reducer';
import saga from './saga';
import { RevenueReview } from './revenueReview';
import { RevenueBranch } from './revenueBranch';
import { RevenueMethodItem } from './revenueMethodItem';
import RevenueSearch from './revenueSearch';
import { USER_INFO_KEY } from 'containers/App/constants';
import styled from 'styled-components';
import _ from 'lodash';
import { formatMomentMinDate, formatMomentMaxDate } from 'utils/common'
import { Spin } from 'antd';
import moment from 'moment-timezone';
import {
  getMerchantRevenue,
  getStoreRevenue,
  setTypeLineChart,
  setDateRange,
} from './actions';

const stateSelector = createStructuredSelector({
  report: makeSelectReport(),
});

const Chart = require('react-chartjs-2').Chart;
const ReportWrapper = styled.div`
background: #ececec;
  padding: 20px;
  font-family: Muli !important;
  font-size: 13px;
  font-weight: 400;
  line-height: 20px;
  text-align: left !important;
  .ant-card {
    color: #333333;
    line-height: 1.25em;
    border-radius: 0px;
  }
  .list-store-revenue {
    display: flex;
    flex-wrap: wrap;
    padding-left: 0;
    .store {
      text-align: left;
    }
    div.store-detail {
      margin-top: 30px;
      position: relative;
      display: flex;
    }
    .revenue-card{
        &__info {
          padding 5px;
          text-align: center;
        }
      }
    }
  }
  .list-branch-revenue {
    display: flex;
    flex-wrap: wrap;
    padding-left: 0;
    .store {
      text-align: left;
    }
    .revenue-card{
        &__info {
          padding: 10px;
          padding-top: 15px;
          text-align: center;
          white-space: break-spaces;
          &--title {
            line-height: 20px;
          }
        }
      }
    }
  }
`;

export function Report(props) {
  const userInfoString = localStorage.getItem(USER_INFO_KEY);
  const userInfo = JSON.parse(userInfoString!);

  useInjectReducer({ key: 'report', reducer: reducer });
  useInjectSaga({ key: 'report', saga: saga });

  const { report } = useSelector(stateSelector);
  const { merchantId } = userInfo.profile!;
  const [loadingType, setLoadingType] = useState('init');
  const {
    isFetching,
    isFetchingReview,
    donutRevenueResChart,
    reviewTab,
    LineRevenueResChart,
    branchList,
    message,
    typeChart,
    dateRange,
  } = report;
  const dispatch = useDispatch();
  const hanldeSearch = (from, to) => {
    if (!to) to = moment();
    if (!from) from = moment().startOf('month');
    to = formatMomentMaxDate(to);
    from = formatMomentMinDate(from);
    dispatch(setDateRange({ dateFrom: from, dateTo: to }));
    dispatch(
      getMerchantRevenue({ dateFrom: from, dateTo: to }, merchantId, typeChart),
    );
    dispatch(getStoreRevenue({ dateFrom: from, dateTo: to }, merchantId));
    setLoadingType('search');
  };

  const onChangeDisplayType = val => {
    dispatch(setTypeLineChart(val));
    setLoadingType('typeChart');
  };
  useEffect(() => {
    dispatch(getMerchantRevenue(dateRange, merchantId, typeChart));
  }, [typeChart, dateRange]);
  useEffect(() => {
    const dateTo = formatMomentMaxDate(moment());
    const dateFrom = formatMomentMinDate(moment().startOf('month'));
    const dateRage = { dateFrom: dateFrom, dateTo: dateTo };
    dispatch(setDateRange(dateRage));
    dispatch(getMerchantRevenue(dateRage, merchantId, typeChart));
    dispatch(getStoreRevenue(dateRage, merchantId));
  }, []);
  return (
    <ReportWrapper>
      {isFetchingReview && isFetching && (
        <div
          style={{
            flex: 1,
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
            justifyContent: 'center',
            height: '50px',
          }}
        >
          <Spin />
        </div>
      )}
          <div className="search-time-revenue">
            {(loadingType === 'typeChart' || (!isFetchingReview && !isFetching)) && (
              <RevenueSearch hanldeSearch={hanldeSearch} dateRange={dateRange} />
            )}
          </div>
          <div className="list-store-revenue">
            {(loadingType === 'typeChart' ||
              (!isFetchingReview && !isFetching)) && (
              <RevenueReview merchantId={merchantId} reviewTab={reviewTab} />
            )}
          </div>
          <div className="chart-revenue">
            {(loadingType === 'typeChart' ||
              (!isFetchingReview && !isFetching)) && (
              <RevenueChart
                merchantId={merchantId}
                donutRevenueResChart={donutRevenueResChart}
                lineRevenueResChart={LineRevenueResChart}
                onChangeDisplayType={onChangeDisplayType}
                typeLineChart={typeChart}
                dateRange={dateRange}
              />
            )}
          </div>
          <div className="list-branch-revenue">
            {!isFetchingReview && !isFetching && (
              <RevenueBranch merchantId={merchantId} branchList={branchList} />
            )}
          </div>
          <div className="method-item-revenue">
            {!isFetchingReview && !isFetching && (
              <RevenueMethodItem merchantId={merchantId} dateRange={dateRange} />
            )}
          </div>
    </ReportWrapper>
  );
}
