import React, { useState, useEffect } from 'react';
import styled from 'styled-components';

import { Row, Col } from 'antd';
import { RevenuePieChart } from './RevenueChart/index';
import { RevenueLineChart } from './RevenueChart/revenueLineChart';
import { COLOR_CHART, TIME_TYPE } from 'containers/App/constants';
import NODATA_CHART from '../../images/nodata.svg';
import NODATA_PIE_CHART from '../../images/pie-chart.svg';
import * as Moment from 'moment';
import { extendMoment } from 'moment-range';
import { DatasetModel } from './types';
const _ = require('lodash');
const moment = extendMoment(Moment);
import { createStructuredSelector } from 'reselect';
import makeSelectReport from './selectors';

const stateSelector = createStructuredSelector({
  report: makeSelectReport(),
});

const RevenueChartWrapper = styled.div`
  font-size: 1vw;
  .ant-col.ant-col-8 .ant-card-body {
    padding: 1.5em 1.25em;
  }
  .ant-card {
    line-height: 1.0625em;
    font-size: 13px;
    .ant-card-body {
      font-size: inherit;
    }
  }
  .line-chart__title {
    position: relative;
    h4 {
      color: #333333;
      font-size: 1.46em;
      font-weight: 600;
      padding-left: 2.5em;
      text-align: left;
    }
    .ant-tabs.ant-tabs-top {
      position: absolute;
      right: 0px;
      top: -1.5625em;
      font-size: 0.875em;
      .ant-tabs-nav,
      .ant-tabs-tab-active {
        font-size: 1em !important;
      }
      .ant-tabs-nav .ant-tabs-tab {
        font-size: 11px !important;
        padding: 1em 0;
      }
    }
  }
  .legend-doughnut {
    margin-top: 2.875em;
    div.doughnut-legend {
      padding: 0px;
      list-style: none;
    }
    div.doughnut-legend div.wrapper-legend {
      margin: 0.3em 0;
    }
    div.doughnut-legend div.wrapper-legend {
      display: inline-flex;
      flex-flow: wrap;
      width: 100%;
      div {
        text-align: end;
      }
      .bullet-doughnut {
        border-radius: 100%;
        width: 0.625em;
        height: 0.625em;
        float: left;
        margin-right: 1em;
        position: relative;
        top: 0.125em;
      }
      .branch-doughnut {
        display: -webkit-box;
        max-width: 50%;
        width: 50%;
        -webkit-line-clamp: 1;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
        text-align: left;
      }
      .percent-data {
        width: 35%;
      }
    }
    div {
      text-align: center;
      button.ant-btn-link {
        height: 2em;
        padding: 0.5em 0.9375em;
        border-radius: 1.25em;
        span {
          font-size: 0.87em;
        }
      }
    }
  }
  @media only screen and (min-width: 200px) {
    font-size: 3vw;
    .ant-col.ant-col-7,
    .ant-col.ant-col-17 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      margin-bottom: 15px;
    }
  }
  @media only screen and (min-width: 425px) {
    font-size: 2.5vw;
    .ant-col.ant-col-7,
    .ant-col.ant-col-17 {
      flex: none;
      max-width: none;
      width: 100%;
      margin-bottom: 15px;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 785px) {
    font-size: 1.3vw;
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 876px) {
    font-size: 1.2vw;
  }
  @media only screen and (min-width: 1325px) {
    font-size: 1vw;
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (min-width: 1680px) {
    .ant-col.ant-col-7 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-17 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
  }
  @media only screen and (max-width: 550px) {
    .line-chart__title {
      .ant-tabs.ant-tabs-top {
        position: absolute;
        right: 0px;
        top: -3em;
      }
    }
  }
`;

export function RevenueChart(props) {
  const {
    lineRevenueResChart,
    donutRevenueResChart,
    typeLineChart,
    dateRange,
  } = props;
  const [loading, setLoading] = useState(true);
  const [isOnly, setIsOnly] = useState(false);
  const [lineChartRevenueList, setLineChartRevenueList] = useState({
    labels: [] as string[],
    datasets: [] as DatasetModel[],
  });
  const [pieChartRevenueList, setPieChartRevenueList] = useState({
    label: [],
    data: [],
    color: [],
    indexResColor: [],
  });
  const getChartRevenueList = async () => {
    let indexColor;
    let pieChartFormat = {} as any;
    if (!_.isEmpty(donutRevenueResChart)) {
      const sortData = donutRevenueResChart.sort((a, b) => {
        return b.amount - a.amount;
      });
      pieChartFormat = sortData.reduce(
        (accumulator, currentValue, currentIndex) => {
          indexColor = currentIndex % COLOR_CHART.length;
          accumulator['label'].push(currentValue.name);
          accumulator['data'].push(currentValue.amount);
          accumulator['color'].push(COLOR_CHART[indexColor].borderColor);
          accumulator['indexResColor'].push({
            name: currentValue.name,
            indexColor: indexColor,
          });
          return accumulator;
        },
        { label: [], data: [], color: [], indexResColor: [] },
      );
      if (donutRevenueResChart.length > 1) {
        setPieChartRevenueList(pieChartFormat);
      }
      if (donutRevenueResChart.length === 1) {
        setIsOnly(true);
      }
    }
    let dateLabelList = [] as any;

    let lineChartFormat = lineRevenueResChart.restaurantData.reduce(
      (accumulator, currentValue, currentIndex) => {
        const datasetFormat = currentValue.revenues.reduce(
          (accumulatorDate, currentValueDate, currentIndexDate) => {
            if (currentIndex === 0) {
              dateLabelList.push(Object.keys(currentValueDate)[0]);
            }
            accumulatorDate.dataList.push(Object.values(currentValueDate)[0]);
            return accumulatorDate;
          },
          { dataList: [] },
        );
        let indexColor = _.isEmpty(donutRevenueResChart)
          ? currentIndex % COLOR_CHART.length
          : pieChartFormat.indexResColor.filter(
              idx => idx.name === currentValue.restaurant.name,
            );
        indexColor = indexColor[0] ? indexColor[0].indexColor : currentIndex;
        const dataset = {
          data: datasetFormat.dataList,
          label: currentValue.restaurant.id,
          borderColor: COLOR_CHART[indexColor].borderColor,
          backgroundColor: COLOR_CHART[indexColor].backgroundColor,
          borderWidth: 0,
          pointBackgroundColor: 'rgba(19, 247, 228,1)',
          pointBorderColor: 'rgba(19, 247, 228,1)',
          pointBorderWidth: 2,
          fill: 'origin',
        };
        accumulator.push(dataset);
        return accumulator;
      },
      [],
    );
    let dateCountList;
    const formatLabel = div => {
      const divNumber = Math.floor(dateLabelList.length / div);
      return dateLabelList.map((d, index, array) =>
        index % divNumber === 0 || index === array.length - 1 ? d : '',
      );
    };
    switch (typeLineChart) {
      case 'week':
      case 'month':
      case 'year':
        if (dateLabelList.length > 30) {
            dateCountList = formatLabel(5);
        } else {
          if (dateLabelList.length > 6) {
            dateCountList = formatLabel(5);
          } else {
            dateCountList = dateLabelList
          }
        }
        break;
      case 'day':
      default:
        if (
          !moment(dateRange.dateFrom).isSame(moment(dateRange.dateTo), 'day')
        ) {
          if (dateLabelList.length > 15) {
            dateCountList = formatLabel(5);
          } else {
            dateCountList = dateLabelList
          }
        } else {
          dateCountList = dateLabelList;
        }
        break;
    }
    const dateLabelListPlusDate = dateCountList;
    const sortResData = lineChartFormat.sort((resA, resB) => {
      return (
        resA.data.reduce((a, b) => a + b, 0) -
        resB.data.reduce((a, b) => a + b, 0)
      );
    });
    const dataLineChart = {
      labels: dateLabelListPlusDate,
      datasets: sortResData,
    };
    setLineChartRevenueList(dataLineChart);
    setLoading(false);
  };

  const onChangeDisplayType = val => {
    props.onChangeDisplayType(val);
  };
  useEffect(() => {
    getChartRevenueList();
  }, [lineRevenueResChart]);
  const spanLineByResCount = isOnly ? 24 : 17;
  return (
    <RevenueChartWrapper>
      {!loading && (
        <Row gutter={[6, 6]}>
          <>
            {!_.isEmpty(lineChartRevenueList.datasets) &&
            !_.isEmpty(lineChartRevenueList.labels) &&
            !lineChartRevenueList.datasets.every(data =>
              data.data.every(d => Number(d) === 0),
            ) ? (
              <Col span={spanLineByResCount}>
                <RevenueLineChart
                  lineChartRevenueList={lineChartRevenueList}
                  onChangeDisplayType={onChangeDisplayType}
                  typeLineChart={typeLineChart}
                />
              </Col>
            ) : (
              <Col span={spanLineByResCount}>
                <img src={NODATA_CHART} style={{ width: '100%' }} />
              </Col>
            )}
            {!_.isEmpty(pieChartRevenueList.data) &&
            !_.isEmpty(pieChartRevenueList.label) &&
            !pieChartRevenueList.data.every(data => data == 0) ? (
              !isOnly ? (
                <Col span={24 - spanLineByResCount}>
                  <RevenuePieChart pieChartRevenueList={pieChartRevenueList} />
                </Col>
              ) : (
                <></>
              )
            ) : (
              <Col span={24 - spanLineByResCount}>
                <div style={{ height: '100%', backgroundColor: 'white', textAlign: 'center', paddingBottom:'20px'}}>
                  <img src={NODATA_PIE_CHART} style={{ width: '65%' }} />
                </div>
              </Col>
            )}
          </>
        </Row>
      )}
    </RevenueChartWrapper>
  );
}
