import React, { useState, useEffect } from 'react';
const _ = require('lodash');
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import makeSelectReport from './selectors';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from './reducer';
import saga from './saga';

import styled from 'styled-components';
import { Row, Col, Spin } from 'antd';
import { RevenueItem, RevenueMethod } from './RevenueMethodItem/index';
import { getMethod, getItem } from './actions';

import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';


const stateSelector = createStructuredSelector({
  report: makeSelectReport(),
});

const RevenueMethodItemWrapper = styled.div`
font-size: 1vw; 
  .ant-card {
    font-size: inherit;
    .ant-card-body {
      font-size: 13px;
    }
  }
  .item-list__title {
    font-size: 13px;
    font-weight: 700;
    padding: 16px;
  }
  .legend-doughnut {
    margin: 5px;
    padding-top: 15px
  }
  .pie-method-chart__title {
    h4 {
      font-size: 16px;
      font-weight: 700;
      line-height: 19px;
      margin-bottom: 1.5em;
    }
  }
  @media only screen and (min-width:200px){
    font-size: 2.5vw;
    .ant-col.ant-col-8, .ant-col.ant-col-16 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-16 {
      margin-bottom: 15px;
    }
  }
  @media only screen and (min-width: 425px){
    .item-list__title {
      .ant-typography {
        font-size: 16x;
        font-weight: 700;
        line-height: 19px;
        padding: 16px;
      }
    }
    .ant-col.ant-col-8, .ant-col.ant-col-16 {
      flex: none;
      max-width: none;
      width: 100%;
      .ant-card.ant-card-bordered {
        height: 100%;
      }
    }
    .ant-col.ant-col-16 {
      margin-bottom: 15px;
    }
  }
  }
  @media only screen and (min-width: 785px){
    font-size: 1.3vw;
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        .ant-col.ant-col-9 {
          font-size: 1em;
          line-height: 1.0625em;
        }
        .revenue-chart-method {
          font-size: 1em;
          font-weight: 600;
          line-height: 1.25em;
        }
        height: 435px;
      }
    }
    .ant-col.ant-col-16 {
      margin-bottom: 0px;
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 435px;
      }
    }
  }
  @media only screen and (min-width: 876px) {
    font-size: 1.2vw;
  }
  @media only screen and (min-width: 1325px){
    font-size: 1vw;
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 435px;
      }
    }
    .ant-col.ant-col-16 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 435px;
      }
    }
  }
  @media only screen and (min-width: 1680px){
    .ant-col.ant-col-8 {
      flex: 0 0 33.33333333%;
      max-width: 33.33333333%;
      .ant-card.ant-card-bordered {
        height: 800px;
      }
    }
    .ant-col.ant-col-16 {
      flex: 0 0 66.66666667%;
      max-width: 66.66666667%;
      .ant-card.ant-card-bordered {
        height: 800px;
      }
    }
  }
`;

export function RevenueMethodItem(props) {
  const { merchantId, dateRange } = props;
  const [isEmptyChart, setEmptyChart] = useState(true);
  const [doughnutChartMethodList, setDoughnutChartMethodList] = useState(
    {} as any,
  );
  useInjectReducer({ key: 'report', reducer: reducer });
  useInjectSaga({ key: 'report', saga: saga });

  const { report } = useSelector(stateSelector);
  const { isFetchingItem, isFetchingMethod, item, method } = report;
  const dispatch = useDispatch();
  const setMethodItem = async () => {
    if (method) {
      const chartFormat = _.isEmpty(method)
        ? []
        : method.reduce(
          (accumulator, currentValue, currentIndex) => {
            const orderTyNm =
              currentValue.orderType == 'service' ? (
                <FormattedMessage {...messages.service} />
              ) : (
                <FormattedMessage {...messages.product} />
              );
            accumulator['label'].push(orderTyNm);
            accumulator['data'].push(currentValue.amount);
            return accumulator;
          },
            { label: [] as string[], data: [] as number[] } as any,
          );
      if (
        !_.isEmpty(chartFormat.data) &&
        !chartFormat.data.every(d => parseFloat(d) === 0)
      ) {
        setEmptyChart(false);
      } else {
        setEmptyChart(true);
      }
      setDoughnutChartMethodList(chartFormat);
    }
  };

  useEffect(() => {
    dispatch(getItem(dateRange, merchantId));
    dispatch(getMethod(dateRange, merchantId));
  }, [dateRange]);

  useEffect(() => {
    setMethodItem();
  }, [method, item]);

  return (
    <RevenueMethodItemWrapper>
      {!isFetchingItem && !isFetchingMethod && (
        <Row gutter={6}>
          <Col span={16}>
            <RevenueItem itemList={item} />
          </Col>
          <Col span={8}>
            {<RevenueMethod doughnutChartMethodList={doughnutChartMethodList} isEmptyChart={isEmptyChart}/>}
          </Col>
        </Row>
      )}
    </RevenueMethodItemWrapper>
  );
}
