import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import {
  Row,
  Col,
  DatePicker,
  Typography,
  Space,
  Button,
  notification,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import moment from 'moment';

const RevenueSearchWrapper = styled.div`
  margin-bottom: 20px;
  > .ant-row {
    justify-content: flex-end;
  }
  .ant-picker {
    padding: 8px 11px 8px !important;
    align-items: center !important;
    .ant-picker-suffix {
      position: relative;
      top: 0;
      left: 0;
    }
  }
  @media only screen and (min-width: 0px) {
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        display: none;
      }
      .ant-space-item:nth-child(2) {
        width: 90%;
        margin-right: 5px;
        .ant-picker {
          width: 100%;
        }
      }
    }
  }
  @media only screen and (min-width: 425px) {
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        display: inline-block;
        width: 15%;
        .ant-typography {
          line-height: 17px;
        }
      }
      .ant-space-item:nth-child(2) {
        width: 80%;
        margin-right: 5px;
        .ant-picker {
          width: 100%;
        }
      }
    }
    .btn-search-col {
      text-align: end;
      button {
        width: 100%;
      }
    }
  }
  @media only screen and (min-width: 768px) {
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        width: 20
      }
      .ant-space-item:nth-child(2) {
        width: 70%;
        .ant-picker {
          width: 100%;
        }
      }
    }
    .btn-search-col {
      padding-left: 0px !important;
      button {
        width: 130px;
      }
    }
  }
`;

const { Text } = Typography;
const style = { borderRadius: '20px' };
function RevenueSearch(props) {
  const { hanldeSearch, dateRange, intl } = props;
  const [from, setFrom] = useState() as any;
  const [to, setTo] = useState() as any;
  const onChangeFrom = (date, dateString) => {
    setFrom({date, dateString});
  };
  const onChangeTo = (date, dateString) => {
    setTo({date, dateString});
  };
  const onSearch = () => {
    const fromSearch = from ? from.date : moment().startOf('month');
    const toSearch = to ? to.date : moment();
    let isValid = true;
    if (moment(fromSearch).isAfter(toSearch)) {
      notification.error({ message: intl.formatMessage(messages.requireFromDate)});
      isValid = false;
    }
    if (moment(fromSearch).isAfter(moment())) {
      notification.error({ message: intl.formatMessage(messages.requireToDate)});
      isValid = false;
    }
    if (moment(fromSearch).isBefore(moment('2017-01-01'))) {
      notification.error({ message: intl.formatMessage(messages.requireFromDateMax)});
      isValid = false;
    }
    if (isValid) {
      hanldeSearch(from.date, to.date);
    }
  };
  useEffect(() => {
    setFrom({dateString: dateRange.dateFrom, date: moment(dateRange.dateFrom)});
    setTo({dateString: dateRange.dateTo, date: moment(dateRange.dateTo)});
  }, [dateRange]);
  useEffect(() => {
    setFrom(dateRange.dateFrom);
    setTo(dateRange.dateTo);
  }, []);
  return (
    <RevenueSearchWrapper>
      <Row>
        <Col xl={2} lg={2} md={2} sm={0} xs={0}></Col>
        <Col xl={8} lg={8} md={9} sm={8} xs={9}>
          <Space align="baseline" className="space-search-item">
            <Text><FormattedMessage {...messages.from}/></Text>
            <DatePicker
              placeholder=""
              onChange={onChangeFrom}
              style={style}
              defaultValue={moment(dateRange.dateFrom)}
              format="DD/MM/YYYY"
            />
          </Space>
        </Col>
        <Col xl={8} lg={8} md={9} sm={9} xs={9}>
          <Space align="baseline" size={20} className="space-search-item">
            <Text style={{ width: '100px' }}><FormattedMessage {...messages.to}/></Text>
            <DatePicker
              placeholder=""
              onChange={onChangeTo}
              style={style}
              defaultValue={moment(dateRange.dateTo)}
              format="DD/MM/YYYY"
            />
          </Space>
        </Col>
        <Col className="btn-search-col" xl={3} lg={4} md={4} sm={6} xs={6}>
          <Button type="primary" shape="round" size="large" onClick={onSearch}>
          <FormattedMessage {...messages.searchReport}/>
          </Button>
        </Col>
      </Row>
    </RevenueSearchWrapper>
  );
}
export default injectIntl(RevenueSearch);