import React, { useState, useEffect } from 'react';
import { useHistory } from 'react-router-dom';
import { useDispatch } from 'react-redux';
import { Modal } from 'antd';
import { CHANGE_PASSWORD } from 'containers/App/urls';
import { USER_INFO_KEY, TOKEN_KEY } from 'containers/App/constants';
import { loginSuccessAction } from 'containers/Auth/authActions';
import { fetchAPI } from 'utils/fetchAPI';
import { RoutePaths } from 'containers/App/routes';
import { injectIntl } from "react-intl";
import messages from "translations/messages";

function ResetPassword({ intl }) {
  const [ visible, setVisible ] = useState(0);
  const history = useHistory();
  const dispatch = useDispatch();

  const backtoHome = () => {
    setTimeout(() => {
      localStorage.removeItem(TOKEN_KEY);
      localStorage.removeItem(USER_INFO_KEY);
      dispatch(loginSuccessAction(null));
      history.push(RoutePaths.login);
      history.go(0); // reload page
    }, 500);
  };

  useEffect(() => {
    const urlParams = new URLSearchParams(window.location.search);
    const token = urlParams.get('token');
    const url = `${CHANGE_PASSWORD}?token=${token}`
    fetchAPI({
      method: 'GET',
      url
    }).then(response => {
      if (response) {
        setVisible(1);
        backtoHome();
      } else {
        setVisible(-1);
      }
    })
  }, []);

  return (
    <>
      <Modal title={intl.formatMessage(messages.updatePassSuccess)} visible={visible > 0} onOk={backtoHome} onCancel={backtoHome}>
        {intl.formatMessage(messages.backToMain)}
      </Modal> 
        <Modal title={intl.formatMessage(messages.updatePassFail)} visible={visible < 0} onOk={backtoHome} onCancel={backtoHome}>
        {intl.formatMessage(messages.comebackLate)}
      </Modal>
    </>
  )
}
export default injectIntl(ResetPassword);