import React, { useState, useRef, useEffect } from 'react';
import {
  Modal,
  Button,
  Upload,
  Input,
  Form,
  Select,
  Menu,
  Spin,
  notification,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import message from 'translations/messages';

import styled from 'styled-components';
import GoogleMapReact from 'google-map-react';
import messagesGlobal from 'translations/messages';
import PlacesAutocomplete, {
  geocodeByAddress,
  getLatLng,
} from 'react-places-autocomplete';
import { fetchAPI, JsonToFormData, replaceUrl } from 'utils/fetchAPI';
import { RESTAURANT_BY_ID_URL, PUBLIC_API } from 'containers/App/urls';
import { RestaurantModel } from 'containers/Restaurant/Store/types';
import { PRIMARY_COLOR, MOBILE_BREAK_POINT } from 'styles/constants';
import IC_MARK from '../../../../images/ic-mark.svg';
import { USER_INFO_KEY } from 'containers/App/constants';
import { fileValidation } from 'utils/validation';
import { useDispatch, useSelector } from 'react-redux';
import { StoreIcon } from 'styles/icon-components';
import { getRestaurants } from '../../../App/actions';
import { extractPhoneNumber } from 'utils/common';
import { makeSelectPhoneCountries } from '../../../App/selectors';
import { usePhoneAddon } from '../../../../components/CustomHook/usePhoneAddon';
import { createStructuredSelector } from 'reselect';
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  phoneCountries: makeSelectPhoneCountries(),
});

const UpdateRestaurantInfoWrapper = styled.div`
  display: flex;
  span.ant-input-group-addon {
    border-bottom-left-radius: 20px;
    border-top-left-radius: 20px;
  }
  span.ant-input-group-addon + span.ant-input-affix-wrapper {
    border-bottom-left-radius: 0px !important;
    border-top-left-radius: 0px !important;
  }
  .update-restaurant {
    &__info {
      width: 40%;
      .ant-upload {
        width: 100% !important;
        margin-bottom: 20px;
      }
      &__image {
        width: 100%;
        cursor: pointer;
        border: 1px solid #e6e6e6;
        border-radius: 8px;
        width: 100%;
        height: 200px;
        display: flex;
        align-items: center;
        justify-items: center;
        &__blank {
          flex-grow: 1;
          text-align: center;
          color: #e6e6e6;
          svg {
            width: 40px;
            height: 30px;
            margin-bottom: 10px;
          }
        }
        img {
          border: dashed 1px ${PRIMARY_COLOR};
          border-radius: 8px;
          width: 100%;
          height: 200px;
        }
      }
    }
    &__map {
      width: 60%;
      margin-left: 20px;
      border-radius: 8px;
      overflow: hidden;
    }
  }
  .ant-form-item {
    margin-top: 20px;
    margin-bottom: 0px !important;
  }
  @media only screen and (max-width: ${MOBILE_BREAK_POINT}px) {
    display: flex;
    flex-wrap: wrap;
    .update-restaurant {
      &__info {
        flex-grow: 1;
      }
      &__map {
        flex-grow: 1;
      }
    }
  }
`;

const InputWrapper = styled.div``;

const AutoCompleteAddressWrapper = styled.div`
  height: 250;
  width: 100%;
  z-index: 1000;
  position: absolute;
  overflow: visible;
`;

interface Props {
  visible: boolean;
  onCancel(): any;
  getRestaurantDetail: any;
  restaurantDetails: RestaurantModel;
  intl?: any;
}

interface Coordinate {
  lat: number;
  lng: number;
}

export const UpdateRestauranInfoModal = injectIntl((props: Props) => {
  const {
    visible,
    onCancel,
    getRestaurantDetail,
    restaurantDetails,
    intl,
  } = props;
  const { phoneCountries } = useSelector(stateSelector);
  const prefixSelector = usePhoneAddon(phoneCountries);
  let { id, phoneNumber, phoneCountryCode } = restaurantDetails;
  const [code, number] = extractPhoneNumber(phoneNumber, phoneCountryCode);
  phoneNumber = number;
  phoneCountryCode = code;
  const [address, setAddress] = useState<string>('');
  const [defaultCoordinate, setDefaultCoordinate] = useState<Coordinate>({
    lat: 16.0755022,
    lng: 108.22002117,
  });
  const [loading, setLoading] = useState(false);
  const defaultPhoto = restaurantDetails.photo
    ? `${PUBLIC_API}/${restaurantDetails.photo}`
    : '';
  const [imageUrl, setImageUrl] = useState<any>(defaultPhoto);
  const [imageFile, setImageFile] = useState();
  const inputRef = useRef<{ files: any; click: any }>();
  const [coordinate, setCoordinate] = useState<Coordinate>({
    lat: 16.0755022,
    lng: 108.22002117,
  });
  let bodyFormData = new FormData();
  const [form] = Form.useForm();
  const dispatch = useDispatch();
  const handleChange = addr => {
    setAddress(addr);
  };

  const handleSelect = addr => {
    form.setFieldsValue({ ...form.getFieldsValue(), fullAddress: addr });
    geocodeByAddress(addr)
      .then(results => getLatLng(results[0]))
      .then(latLng => setCoordinate(latLng))
      .catch(error => console.error('Error', error));
  };
  const onFinish = async values => {
    try {
      setLoading(true);
      const userInfoString = localStorage.getItem(USER_INFO_KEY);
      const userInfo = JSON.parse(userInfoString!);
      const { merchantId } = userInfo.profile!;
      const { phoneCountryCode, phoneNumber } = values;
      const validPhoneNumber =
        phoneNumber[0] === '0' ? phoneNumber.replace('0', '') : phoneNumber;
      const modifiedValues = {
        ...values,
        phoneNumber: `${phoneCountryCode}${validPhoneNumber}`,
        merchantId: merchantId,
        detail: 'Some testing restaurant',
        restaurantTypeId: 1,
        pickUpEffectiveTime: 1,
      };
      bodyFormData = JsonToFormData(modifiedValues);
      if (imageFile) {
        bodyFormData.append('aaaac', imageFile!);
      }
      const response = await fetchAPI({
        method: 'PUT',
        url: replaceUrl(RESTAURANT_BY_ID_URL, { id }),
        formData: true,
        data: bodyFormData,
      });
      dispatch(getRestaurants(merchantId));
      if (response) {
        getRestaurantDetail();
        onCancel();
      }
    } finally {
      setLoading(false);
    }
  };

  const handleOnCancel = () => {
    onCancel();
    setCoordinate(defaultCoordinate);
    form.setFieldsValue({
      ...form.getFieldsValue(),
      fullAddress: restaurantDetails.fullAddress,
    });
  };
  const handleChangeUploadImage = info => {
    const file = inputRef?.current?.files[0];
    if (!fileValidation(file.name))
      return notification.error({
        message: intl.formatMessage(messages.invalidFile),
      });
    const reader = new FileReader();
    const url = reader.readAsDataURL(file);
    reader.onloadend = function (e) {
      setImageUrl(reader.result!);
    };
    setImageFile(file);
  };

  useEffect(() => {
    geocodeByAddress(restaurantDetails.fullAddress)
      .then(results => getLatLng(results[0]))
      .then(coordinate => {
        setCoordinate(coordinate);
        setDefaultCoordinate(coordinate);
      })
      .catch(error => console.error('Error', error));
  }, []);

  useEffect(() => {
    const result = /\(\+(\d{1,2})\) (\d+)/.exec(phoneNumber || '');
    if (result !== null) {
      const [groups, phoneCountryCode, phoneNumber] = result;
      form.setFieldsValue({
        ...restaurantDetails,
        phoneNumber: phoneNumber,
        phoneCountryCode,
      });
    }
  }, [visible]);

  return (
    <Form
      form={form}
      name="updateRestaurantInfo"
      onFinish={onFinish}
      initialValues={restaurantDetails as any}
    >
      <Modal
        visible={visible}
        width={800}
        onCancel={handleOnCancel}
        centered
        footer={[
          <Button
            type="primary"
            htmlType="submit"
            loading={loading}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}
          >
            <FormattedMessage {...messages.save} />
          </Button>,
        ]}
      >
        <h3 style={{ textAlign: 'center', marginBottom: 20, fontSize: 15 }}>
          <FormattedMessage {...messages.editStore} />
        </h3>
        <UpdateRestaurantInfoWrapper>
          <div className="update-restaurant__info">
            <div className="update-restaurant__info__image">
              {imageUrl ? (
                <img
                  src={imageUrl}
                  onClick={() => inputRef.current!.click()}
                  style={{ objectFit: 'cover' }}
                />
              ) : (
                <div
                  className="update-restaurant__info__image__blank"
                  onClick={() => inputRef.current!.click()}
                >
                  <StoreIcon />
                  <div>
                    <FormattedMessage {...messages.restaurantImage} />
                  </div>
                  <span className="img-hint">
                    <FormattedMessage
                      {...messagesGlobal.encourageCondition}
                      values={{ height: 280, width: 200 }}
                    />
                  </span>
                </div>
              )}
            </div>
            <input
              type="file"
              ref={inputRef as any}
              accept="image/*"
              onChange={handleChangeUploadImage}
              style={{ visibility: 'hidden', height: 0, position: 'fixed' }}
            />
            <FormattedMessage {...messages.storeName}>
              {storeName => (
                <InputWrapper>
                  <Form.Item
                    name="name"
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messages.requiredResName} />
                        ),
                      },
                    ]}
                  >
                    <FloatLabel allowClear label={`${storeName}*`} />
                  </Form.Item>
                </InputWrapper>
              )}
            </FormattedMessage>
            <FormattedMessage {...messages.address}>
              {placeHolder => (
                <InputWrapper>
                  <Form.Item
                    name="fullAddress"
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messages.requiredAddr} />
                        ),
                      },
                    ]}
                  >
                    <PlacesAutocomplete
                      value={address}
                      onChange={handleChange}
                      onSelect={handleSelect}
                    >
                      {({
                        getInputProps,
                        suggestions,
                        getSuggestionItemProps,
                        loading,
                      }) => (
                        <div>
                          <FloatLabel
                            allowClear
                            {...getInputProps({
                              label: `${placeHolder}*`,
                              className: 'location-search-input',
                            })}
                            value={form.getFieldValue('fullAddress')}
                            maxLength={100}
                          />
                          <AutoCompleteAddressWrapper>
                            {loading ? (
                              <div
                                style={{
                                  textAlign: 'center',
                                  top: '20px',
                                  position: 'relative',
                                }}
                              >
                                {' '}
                                <Spin />{' '}
                              </div>
                            ) : (
                              <Menu>
                                {suggestions.map(suggestion => {
                                  return (
                                    <Menu.Item
                                      {...getSuggestionItemProps(suggestion)}
                                    >
                                      <span>{suggestion.description}</span>
                                    </Menu.Item>
                                  );
                                })}
                              </Menu>
                            )}
                          </AutoCompleteAddressWrapper>
                        </div>
                      )}
                    </PlacesAutocomplete>
                  </Form.Item>
                </InputWrapper>
              )}
            </FormattedMessage>
            <FormattedMessage {...messages.phoneNumber}>
              {phoneNumber => (
                <InputWrapper>
                  <Form.Item
                    name="phoneNumber"
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage {...messages.requiredPhone} />
                        ),
                      },
                      {
                        message: (
                          <FormattedMessage {...messages.invalidPhone} />
                        ),
                        pattern: /^[\d]+$/,
                      },
                      () => ({
                        validator(rule, value) {
                          if (value.length > 10) {
                            return Promise.reject(
                              intl.formatMessage(messages.invalidPhone),
                            );
                          } else {
                            return Promise.resolve();
                          }
                        },
                      }),
                    ]}
                  >
                    <FloatLabel
                      addonBefore={prefixSelector}
                      allowClear
                      label={`${phoneNumber}*`}
                    />
                  </Form.Item>
                </InputWrapper>
              )}
            </FormattedMessage>
            <FormattedMessage {...messages.email}>
              {email => (
                <InputWrapper>
                  <Form.Item
                    name="email"
                    rules={[
                      {
                        message: (
                          <FormattedMessage {...messages.invalidEmail} />
                        ),
                        type: 'email',
                      },
                    ]}
                  >
                    <FloatLabel allowClear label={`${email}`} />
                  </Form.Item>
                </InputWrapper>
              )}
            </FormattedMessage>
          </div>
          <div className="update-restaurant__map">
            <GoogleMapReact
              bootstrapURLKeys={{
                key: 'AIzaSyAbbMe1qb24OT8fKgk8RGObXpAdS5w0FTE',
              }}
              defaultCenter={coordinate}
              defaultZoom={15}
              center={coordinate}
            >
              <img
                data-lat={coordinate.lat}
                data-lng={coordinate.lng}
                data-text="My Marker"
                style={{ width: '20px', height: '20px' }}
                src={IC_MARK}
              />
            </GoogleMapReact>
          </div>
        </UpdateRestaurantInfoWrapper>
      </Modal>
    </Form>
  );
});
