import React, { useState } from 'react';
import { Modal, Button, Form, Input, notification } from 'antd';
import { InputWrapper } from 'styles/custom-styled-components';
import { GroupModel } from 'containers/Restaurant/Store/types';
import { useParams } from 'react-router-dom';
import { fetchAPI } from 'utils/fetchAPI';
import { SECTION } from 'containers/App/urls';
import { validateRequiredSpace } from '../../../../../../../utils/validation';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';

interface Props {
  visible: boolean;
  onCancel: () => void;
  getGroups: any;
  initialGroup?: GroupModel;
  currentFloorId?: number;
}

export const GroupModal = (props: Props) => {
  const { visible, onCancel, getGroups, initialGroup, currentFloorId } = props;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  // @ts-ignore
  const { id } = useParams();
  const onFinish = async values => {
    try {
      for (var key in values) {
        if (typeof values[key] === 'string') {
          values[key] = values[key].trim();
        }
      }
      setLoading(true);
      const modifiedValues = { ...values, floorId: currentFloorId };
      const response = await fetchAPI({
        method: 'POST',
        data: modifiedValues,
        url: SECTION,
      });
      if (response) {
        getGroups();
        onCancel();
        form.resetFields();
      }
    } finally {
      setLoading(false);
    }
  };
  const handleOnCancel = () => {
    onCancel();
    form.resetFields();
  };
  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      initialValues={initialGroup}
    >
      <Modal
        visible={visible}
        width={400}
        centered
        onCancel={handleOnCancel}
        footer={[
          <Button
            type="primary"
            htmlType="submit"
            className="w-100"
            loading={loading}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}
          >
            <FormattedMessage {...messages.save} />
          </Button>,
        ]}
      >
        <h2 className="text-center">
          <FormattedMessage {...messages.createGroup} />
        </h2>
        <FormattedMessage {...messages.groupName}>
          {groupName => (
            <InputWrapper>
              <Form.Item name="name" rules={[validateRequiredSpace]}>
                <FloatLabel allowClear label={`${groupName}*`} />
              </Form.Item>
            </InputWrapper>
          )}
        </FormattedMessage>
      </Modal>
    </Form>
  );
};
