import React from 'react';
import { Modal, Button, Form, Input, notification } from 'antd';
import { InputWrapper } from 'styles/custom-styled-components';
import { fetchAPI } from 'utils/fetchAPI';
import { TABLE } from 'containers/App/urls';
import { DragItemModel } from '../../../../../Store/types';
import { validateRequiredSpace } from 'utils/validation';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel'

interface Props {
  visible: boolean;
  onCancel: () => void;
  getDragItems: () => void;
  initialDragItem?: DragItemModel;
  currentFloorId?: number;
}

export const DragItemModal = (props: Props) => {
  const { visible, onCancel, getDragItems, initialDragItem, currentFloorId } = props;
  const [form] = Form.useForm();
  const onFinish = async (values) => {
    for (var key in values) {
      if (typeof values[key] === 'string') {
        values[key] = values[key].trim();
      }
    }
    const modifiedValues = { ...initialDragItem, ...values, floorId: currentFloorId! };
    const response = await fetchAPI({
      method: 'POST',
      data: modifiedValues,
      url: TABLE
    });
    if (response) {
      getDragItems();
      onCancel();
    }
  }
  return (
    <Form
      form={form}
      name="horizontal_login"
      initialValues={initialDragItem}
    >
      <Modal
        visible={visible}
        width={400}
        centered
        onCancel={onCancel}
        footer={
          [<Button
            type="primary"
            htmlType="submit"
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}><FormattedMessage {...messages.save}/></Button>]
        }
      >
        <h2><FormattedMessage {...messages.createDragItem}/></h2>
        <InputWrapper >
          <Form.Item
            name="name"
            rules={[validateRequiredSpace]}
          >
            <FloatLabel allowClear label={'Tên giường*'} />
          </Form.Item>
        </InputWrapper>
      </Modal>
    </Form>
  )
}
