import React, { useState, useCallback, useEffect } from 'react';
import styled from 'styled-components';
import './style.scss'
import { FloorModel } from 'containers/Restaurant/Store/types';
import { TABLES, UPDATE_RESTAURANT_LAYOUT_BY_ID } from 'containers/App/urls';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import { getSearchParamValueByParams } from 'utils/searchParams';
import { useHistory } from 'react-router-dom';
import { makeSelectDragItems, getDragItemsSuccess, makeSelectArea, updateDragItem } from "containers/Restaurant/Store";
import { createStructuredSelector } from 'reselect';
import { useSelector, useDispatch } from 'react-redux';
import { WrapperDragItem } from './wrapperDrag';
import { Button, notification } from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import _ from 'lodash';
import { TABLET_BREAK_POINT, MOBILE_BREAK_POINT } from 'styles/constants';
const Wrapper = styled.div`
  .btn-wrapper {
    display: flex;
    justify-content: flex-end;
    padding: 20px 0;
  }
  .btn-save {
    width: 110px;
    height: 44px;
    border-radius: 22px;
    background-color: #9cd339;
  }
`

const ContainerWrapper = styled.div`
  position: relative;
  top: 0px;
  left: 0px;
  height: 600px;
  overflow: hidden;
  border: solid 1px #F0F0F0;
  @media only screen and (max-width: ${TABLET_BREAK_POINT}px) {
    overflow: unset;
    overflow-x: scoll;
    overflow-y: hidden;
  }
  @media only screen and (max-width: ${MOBILE_BREAK_POINT}px) {
    overflow: unset;
    overflow-x: scoll;
    overflow-y: hidden;
  }
`;
const stateSelector = createStructuredSelector({
  dragItems: makeSelectDragItems(),
  area: makeSelectArea()
});

export const Container = injectIntl((props: ({ currentFloor?: FloorModel, intl?: any })) => {
  if (!props.currentFloor) {
    return <div></div>
  }
  const { dragItems, area } = useSelector(stateSelector);
  const dispatch = useDispatch();
  const { currentFloor, intl } = props;
  const { width, height, id: floorId } = currentFloor!;
  const [loading, setLoading] = useState(false);
  const [selectedGroupId, setSelectedGroupId] = useState<number>(0);
  const [selectedAreaId, setSelectedAreaId] = useState<number>(0);
  const history = useHistory();
  const tableProps = ['id', 'name', 'numberOfSeat', 'rotationDegree', 'width', 'height', 'positionX', 'positionY'];

  const getDragItems = async () => {
    const response = await fetchAPI({
      method: 'GET',
      url: `${TABLES}?floorId=${floorId}`,
    });
    if (response) {
      dispatch(getDragItemsSuccess(response));
    }
  }

  const setTableItemAction = e => {
    dispatch(updateDragItem(e));
  }

  useEffect(() => {
    history.listen((location) => {
      const selectedGroupId = +getSearchParamValueByParams(location.search, 'selectedGroupId');
      const selectedAreaId = +getSearchParamValueByParams(location.search, 'selectedAreaId');
      setSelectedGroupId(selectedGroupId);
      setSelectedAreaId(selectedAreaId);
    })
    getDragItems();
  }, [props.currentFloor]);

  const save = async () => {
    setLoading(true);
    const tables = _.map(dragItems, item => _.pick(item, tableProps));
    const response = await fetchAPI({
      method: 'PUT',
      url: replaceUrl(UPDATE_RESTAURANT_LAYOUT_BY_ID, { floorId }),
      data: { tables },
    });
    if (response) {
      getDragItems();
      notification.success({ message: intl.formatMessage(messages.updateSuccessMess) });
    }
    setLoading(false);
  }
  return (
    <Wrapper>
      <ContainerWrapper>
        <WrapperDragItem area={area} setTableItemAction={setTableItemAction} selectedAreaId={selectedAreaId} getDragItems={getDragItems} dragItems={dragItems || []} selectedGroupId={selectedGroupId} />
      </ContainerWrapper>
      <div className="btn-wrapper">
        <Button type="primary" className="btn-save" loading={loading} onClick={save}><FormattedMessage {...messages.save}/></Button>
      </div>
    </Wrapper>
  );
})
