import React from "react";
import ReactDOM from "react-dom";
import Moveable from "react-moveable";
import { ref } from "framework-utils";
import { Frame } from "scenejs";
import "./style.scss";
import styled from "styled-components";
import { fetchAPI } from "utils/fetchAPI";
import { TABLE_DETAIL } from "containers/App/urls";
import { ImageItem, DragItemName } from "./Drag-items";
import {
  DEFAULT_BED_SIZE
} from "../constants";
import { roundDeg } from "utils/number";

const Wrapper = styled.div`

.moveable-control-box {
  visibility: ${props => props.visibility}!important;
  z-index: 1000;
}
`;
const Label = styled.div`
  ${props => !props.isSelected ? 'color: black' : ''};
`;

function getTopLeftAfterRotate(xa, ya, w, h, deg) {
  const xo = xa + w / 2;
  const yo = ya + h / 2;
  let newDeg = (deg / 90) % 2 !== 0 ? 90 : 0;
  if(newDeg){
    const newWidth = h;
    const newHeigth = w
    const x = newDeg === 90 ? xo - newWidth / 2 : xo + newWidth / 2;
    const y = yo - newHeigth / 2;
    return [x, y, newDeg]
  }
  return [xa, ya, newDeg]
}

function getTopLeftBeforeRotate(xa, ya, w, h, deg) {
  const xo = xa + h / 2;
  const yo = ya + w / 2;
  if(deg){
    const x = xo - w / 2;
    const y = yo - h / 2;
    return [x, y]
  }
  return [xa, ya]
}

const calaculateWidthHeight = (bx, by, t) => {
  const cos = x => Math.cos(x);
  const sin = x => Math.sin(x);
  const sqr = x => x * x;
  const round = x => Math.round(x);
  const abs = x => Math.abs(x);

  const realWidth = (1 / (sqr(cos(t)) - sqr(sin(t)))) * (bx * cos(t) - by * sin(t));
  const realHeight = (1 / (sqr(cos(t)) - sqr(sin(t)))) * (- bx * sin(t) + by * cos(t));
  return { realWidth: round(abs(realWidth)), realHeight: round(abs(realHeight)) };
}

export class MovableItem extends React.Component {
  state = {
    target: null,
    container: null,
    scalable: true,
    resizable: false,
    warpable: false,
    visibility: 'hidden',
    rotationDegree: this.props.item.rotationDegree,
    positionX: this.props.item.positionX,
    positionY: this.props.item.positionY,
    item: this.props.item,
    width: this.props.item.width,
    height: this.props.item.height,
  };

  getDefaulSize = () => {
    return DEFAULT_BED_SIZE;
  }

  defaultWidth = this.getDefaulSize().width;
  defaultHeight = this.getDefaulSize().height;

  frame = new Frame({
    left: `${this.props.item.positionX}`,
    top: `${this.props.item.positionY}`,
    width: `${this.props.item.width}`,
    height: `${this.props.item.height}`,
    transform: {
      rotate: `${this.props.item.rotationDegree}deg`,
      scaleX: this.props.item.width / this.defaultWidth,
      scaleY: this.props.item.height / this.defaultHeight,
    },
  });

  containerWrapper = document.querySelector('quoc-container');

  componentDidMount() {
    const { item } = this.props;
    const { positionX, positionY, width, height, rotationDegree } = item;
    const [x, y] = getTopLeftBeforeRotate(positionX, positionY, width, height, rotationDegree);
    this.setState({
      container: document.querySelector('#con'),
      positionX: x,
      positionY: y
    });
    this.setState({
      target: document.querySelector(`.moveable-${item.id}`)
    });
    window.addEventListener("resize", this.onWindowReisze);
  }

  componentWillUnmount() {
    window.removeEventListener("resize", this.onWindowReisze);
  }

  formatRotationDegree = (d) => {
    if (d >= 0) {
      if (d > 360) {
        return this.formatRotationDegree(d % 360);
      }
      const is2ndOr4thQuater = (d >= 90 & d <= 180) | (d >= 270 & d <= 360);
      if (is2ndOr4thQuater) {
        const dMod180 = d % 180;
        return Math.abs(180 - dMod180);
      } else {
        return Math.abs(d);
      }
    }
    return this.formatRotationDegree(360 + d);
  }

  updateItemPosition = async (clientX, clientY) => {
    const { item } = this.state;
    const response = await fetchAPI({
      method: 'PUT',
      url: replaceUrl(TABLE_DETAIL, { id }),
      data: { ...item, positionX: Math.round(clientX), positionY: Math.round(clientY) },
    });
    if (response) {
      this.setState({ item: response })
    }
  }

  updateItemRotation = async (rotationDegree, left, top) => {
    const { item } = this.state;
    const response = await fetchAPI({
      method: 'PUT',
      url: replaceUrl(TABLE_DETAIL, { id }),
      data: { ...item, rotationDegree, positionX: left, positionY: top },
    });
    if (response) {
      this.setState({ item: response })
    }
  }
  setTransform(target, keptStyle) {
    target.style.cssText = `transform-origin: center center; ${keptStyle}`
  }
  setLabel(clientX, clientY, text) {
    this.label.style.cssText = `
      display: block;
      transform: translate(${clientX}px, ${clientY - 10}px) translate(-100%, -100%) translateZ(-100px);`;
    this.label.innerHTML = text;
  }

  onPinch = ({ clientX, clientY }) => {
    setTimeout(() => {
      this.setLabel(
        clientX,
        clientY,
        `X: ${this.frame.get("left")}<br/>
         Y: ${this.frame.get("top")}<br/>
         W: ${this.frame.get("width")}<br/>
         H: ${this.frame.get("height")}<br/>
         S: ${this.frame.get("transform", "scaleX").toFixed(2)},
         ${this.frame.get("transform", "scaleY").toFixed(2)}<br/>
         R: ${parseInt(this.frame.get("transform", "rotate")).toFixed(1)}deg`
      );
    });
  };

  onDrag = ({ target, currentTarget, clientX, clientY, top, left, isPinch }) => {
    this.frame.set("left", `${left}px`);
    this.frame.set("top", `${top}px`);
    const { item, rotationDegree, width, height } = this.state;
    const keptStyle = `width: ${width}px; height: ${height}px; left: ${left}px; top: ${top}px; position:absolute;transform:rotate(${rotationDegree}deg);`;
    this.setTransform(target, keptStyle);
    if (!isPinch) {
      this.setLabel(clientX, clientY, `X: ${Math.round(currentTarget.state.left)}px<br/>Y: ${Math.round(currentTarget.state.top)}px`);
    }
    const x = left;
    const y = top;
    this.setState({ positionX:  Math.round(x), positionY: Math.round(y)})
  };

  onDragEnd = (props) => {
    const { target : { offsetLeft, offsetTop }, currentTarget: {state: { top, left } }} = props;
    const { rotationDegree, width, height } = this.state;
    const { item } = this.props;
    const dragEndValue = {...item, rotationDegree: rotationDegree, positionX: Math.round(left), positionY: Math.round(top), width: width, height: height};
    this.props.setTableItemAction(dragEndValue);
    this.label.style.display = "none";
  }
  onScale = ({ target, delta, clientX, clientY, isPinch, currentTarget }) => {
    const scaleX = this.frame.get("transform", "scaleX") * delta[0];
    const scaleY = this.frame.get("transform", "scaleY") * delta[1];
    this.frame.set("transform", "scaleX", scaleX);
    this.frame.set("transform", "scaleY", scaleY);
    const { item } = this.state;
    const { positionX, positionY } = item;
    const { rotationDegree } = this.state
    const { height, width } = currentTarget.state.targetClientRect;
    const roundedWidth = Math.round(width);
    const roundedHeight = Math.round(height);
    this.setState({width: roundedWidth, height: roundedHeight})
    const keptStyle =`width:${roundedWidth}px; height:${roundedHeight}px;left:${positionX}px;top:${positionY}px;position:absolute;transform:rotate(${rotationDegree}deg) ;`;
    this.setTransform(target, keptStyle);
    if (!isPinch) {
      this.setLabel(
        clientX,
        clientY,
        `S: ${scaleX.toFixed(2)}, ${scaleY.toFixed(2)}`
      );
    }
  };

  updateItemScale = async (width, height, left, top) => {
    const { item } = this.state;
    const response = await fetchAPI({
      method: 'PUT',
      url: replaceUrl(TABLE_DETAIL, { id }),
      data: { ...item, width, height, positionX: left, positionY: top },
    });
    if (response) {
      this.setState({ item: response })
    }
  }

  onScaleEnd = (onScaleEndProps) => {
    const { item } = this.props;
    const { rotationDegree } = this.state.item;
    const { currentTarget, target } = onScaleEndProps;
    const { height, width } = currentTarget.state.targetClientRect;
    const positiveRotationDegree = this.formatRotationDegree(rotationDegree);
    const radianDegree = Math.PI * positiveRotationDegree / 180;
    const roundedWidth = Math.round(width);
    const roundedHeight = Math.round(height);
    const { realWidth, realHeight } = calaculateWidthHeight(roundedWidth, roundedHeight, radianDegree);
    const roundedLeft = Math.round(target.offsetLeft);
    const roundedTop = Math.round(target.offsetTop);
    const scaleValue = {...item, width: realWidth, height: realHeight, positionX: roundedLeft, positionY: roundedTop };
    this.props.setTableItemAction(scaleValue)
  }

  onRotate = ({ target, clientX, clientY, beforeDelta, isPinch }) => {
    const { width, height, positionX, positionY } = this.state;
    const deg = parseInt(parseInt(this.frame.get("transform", "rotate")) + beforeDelta);
    const keptStyle = `width:${width}px; height:${height}px;left:${positionX}px;top:${positionY}px;position:absolute;transform:rotate(${deg}deg)`;
    this.frame.set("transform", "rotate", `${deg}deg`);
    this.setState({ rotationDegree: deg })
    this.setTransform(target, keptStyle);
    this.setLabel(clientX, clientY, `R: ${deg}<br />X: ${positionX}px<br/>Y: ${positionY}px`);
    if (!isPinch) {
    }
  };

  onRotateEnd = (onRotateEndProps) => {
    const { item } = this.props;
    const { target } = onRotateEndProps;
    const { offsetLeft, offsetTop } = target;
    const deg = roundDeg(parseInt(this.frame.get("transform", "rotate")));
    const [left, top, newDeg] = getTopLeftAfterRotate(offsetLeft, offsetTop, item.width, item.height, deg);
    const rotateEndValue = { ...item, rotationDegree: newDeg, positionX: Math.round(left), positionY: Math.round(top)}

    this.setState({ rotationDegree: deg })
    this.props.setTableItemAction(rotateEndValue)
    this.label.style.display = "none";
  };

  onResize = ({ target, clientX, clientY, width, height, isPinch }) => {
    const { rotationDegree, positionX, positionY, item } = this.state
    this.frame.set("width", `${width}px`);
    this.frame.set("height", `${height}px`);
    this.setState({width: width, height: height})
    const keptStyle = `width: ${width}px; height: ${height}px;left:${positionX}px;top:${positionY}px;position:absolute;transform:rotate(${rotationDegree}deg) ;`;
    this.setTransform(target, keptStyle);
    if (!isPinch) {
      this.setLabel(clientX, clientY, `W: ${width}px<br/>H: ${height}px`);
    }
  };

  onResizeEnd = (props) => {
    const { currentTarget: { state: { width, height } } } = props;
    const { item } = this.props;
    const resizeValue = { ...item, width: width, height: height };
    this.setState({width: width, height: height});
    this.props.setTableItemAction(resizeValue);
    this.label.style.display = "none";
  }

  onWarp = ({ target, clientX, clientY, delta, multiply }) => {
    this.frame.set(
      "transform",
      "matrix3d",
      multiply(this.frame.get("transform", "matrix3d"), delta)
    );
    this.setTransform(target);
    this.setLabel(clientX, clientY, `X: ${clientX}px<br/>Y: ${clientY}px`);
  };

  onEnd = () => {
    this.label.style.display = "none";
  };

  render() {
    const { item, isSelected } = this.props;
    const { id, type } = item;
    const { target, visibility } = this.state;

    const moveableStyle = {
      left: `${this.state.positionX}px`,
      top: `${this.state.positionY}px`,
      width: `${this.state.width}px`,
      height: `${this.state.height}px`,
      position: `absolute`,
      transform: `rotate(${this.state.rotationDegree}deg)`,
      transformOrigin: "center center"
    };

    const isKeepRatio = type === 1;
    return (
      <Wrapper
        className=""
        visibility={visibility}
        id={id}
        onDoubleClick={() => this.setState({ visibility: visibility === 'visible' ? 'hidden' : 'visible' })}
        style={{zIndex: '9999', position: 'relative'}}
      >
        <Moveable
          ref={ref(this, `moveable-${id}`)}
          target={target}
          pinchThreshold={20}
          container={this.state.container}
          draggable={true}
          resizable={true}
          warpable={true}
          rotatable={true}
          pinchable={true}
          origin={true}
          onDrag={this.onDrag}
          onResize={this.onResize}
          onScale={this.onScale}
          onWarp={this.onWarp}
          onRotate={this.onRotate}
          onPinch={this.onPinch}
          onDragEnd={this.onDragEnd}
          onScaleEnd={this.onScaleEnd}
          onResizeEnd={this.onResizeEnd}
          onWarpEnd={this.onEnd}
          onRotateEnd={this.onRotateEnd}
          onPinchEnd={this.onEnd}
          keepRatio={isKeepRatio}
        />
        <div
          className={`moveable-${id}`}
          style={moveableStyle}
        >
          <DragItemName isSelected>{name}</DragItemName>
          <ImageItem
            rotationDegree={this.state.rotationDegree}
            width={this.state.width}
            height={this.state.height}
            isSelected={isSelected}
            item={item}
            key={item.id} />
        </div>
        <Label isSelected className="label" ref={ref(this, "label")} />
      </Wrapper>
    );
  }
}

