import React from 'react';
import { DEFAULT_FLOOR_HEIGHT, TINY_SQUARE_SIZE, DEFAULT_FLOOR_WIDTH, DEFAUTL_FLOOR_HEIGHT_BY_PX, DEFAUTL_FLOOR_WIDTH_BY_PX, TINY_SQUARE_SIZE_BY_PX, SM_PER_PIXEL } from '../constants';
import styled from 'styled-components';
import { FloorModel } from 'containers/Restaurant/Store/types';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';

export const GridWrapper = styled.div<{ width: number, height: number }>`
  display: flex;
  flex-wrap: wrap;
  height: ${props => props.height}px;
  width: ${props => props.width}px;
  border-top: solid 1px darkgray;
  border-left: solid 1px darkgray;
`;

export const TinySquareWrapper = styled.div<{ flexBasis: string }>`
  height: ${TINY_SQUARE_SIZE_BY_PX}px;
  width: ${TINY_SQUARE_SIZE_BY_PX}px;
  border-right: solid 1px darkgray;
  border-bottom: solid 1px darkgray;
  flex-basis: ${props => props.flexBasis};
`;

export const Grid = (props: { currentFloor?: FloorModel }) => {
  const { currentFloor } = props;
  if (!currentFloor) {
    return <FormattedMessage {...messages.emptyCurrFloor}/>;
  }
  const { height, width } = props.currentFloor!;
  const squares: Array<JSX.Element> = [];
  const flexBasis = (TINY_SQUARE_SIZE / width!) * 100;
  for (let i = 0; i < (height! / TINY_SQUARE_SIZE) * (width! / TINY_SQUARE_SIZE); i++) {
    squares.push(<TinySquareWrapper flexBasis={`${flexBasis}%`} />);
  }
  if (!width || !height) {
    return <div><FormattedMessage {...messages.noWiHe}/></div>;
  }
  return (
    <GridWrapper width={width * SM_PER_PIXEL} height={height * SM_PER_PIXEL}>{squares}</GridWrapper>
  )
}
