import React, { useState } from 'react';
import styled from 'styled-components';
import { Tooltip, Empty } from 'antd';
import { PUBLIC_API, MENUS_MENU_ITEM_RESTAURANT_BY_TWO_ID } from 'containers/App/urls';
import {MenuItemIcon} from 'styles/icon-components';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import { useParams } from 'react-router-dom';
import { useDispatch } from "react-redux";
import { getMenu } from "../../../Store";
import { MenuModel, MenuItemModel } from 'containers/Menu/MenuList/menuListMenuModels';
import { DeletePopOver } from '../../Delete-popover';

const RestaurantCoursesWrapper = styled.div`
`;

const RestaurantCourseWrapper = styled.div`
  .restaurant-course {
    &__title {
      font-size: 19px;
      font-weight: 600;
      text-transform: uppercase;
    }
    &__dishes {
      display: flex;
      flex-wrap: wrap;
      padding-bottom: 25px;
    }
  }
  hr {
      border: none;
      border-top: solid 1px #F0F0F0;
      margin-top: 13px;
    }
`;

const DishWrapper = styled.div`
  flex: 0 0 50%;
  display: flex;
  margin-top: 15px;
  padding-right: 10px;
  justify-content: space-between;
  .menuItemIc {
    width: 25%;
    height: 100px;
    display: flex;
    align-items: center;
    justify-content: center;
  }
  .dish {
    &__image {
      width: 25%;
      height: 100px;
      object-fit: cover;
    }
    &__text {
      width: 65%;
      padding-left: 20px;
      &-main {
        font-size: 15px;
        font-weight: 600;
        color: #333;
      }
      &-minor {
        padding-top: 10px;
        color: #9C9696;
        line-height: 1.5;
        display: -webkit-box;
        max-width: 200px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
      }
    }
    &__tooltip-handler {
      flex-grow: 1;
      float: right;
    }
  }
  @media only screen and (max-width: 768px){
    flex: 0 0 100%;
    .dish {
      &__image {
        width: 25%;
        height: 100%;
      }
      &__text {
        width: 73%;
        padding-left: 20px;
        &-main {
          font-size: 13px;
          font-weight: 700;
          color: #333;
        }
        &-minor {
          padding-top: 10px;
          color: #9C9696;
          display: -webkit-box;
          max-width: 200px;
          -webkit-line-clamp: 2;
          -webkit-box-orient: vertical;
          overflow: hidden;
          text-overflow: ellipsis;
        }
      }
      &__tooltip-handler {
        flex-grow: 1;
        float: right;
      }
    }
  }
`;

function RestaurantCourse(props: { course: MenuModel, getCourses: () => Promise<void> }) {
  const { course, getCourses } = props;
  const { categoryName, menuItems } = course;
  return (
    <RestaurantCourseWrapper>
      <div className="restaurant-course__title">
        {categoryName}
      </div>
      <hr />
      <div className="restaurant-course__dishes">
        {
          menuItems && menuItems.length && menuItems.map(dish => <Dish dish={dish} getCourses={getCourses} />)
        }
      </div>
    </RestaurantCourseWrapper>
  )
}

function Dish(props: { dish: MenuItemModel, getCourses: () => Promise<void> }) {
  const { dish, getCourses } = props;
  // @ts-ignore
  const { id: restaurantId } = useParams();
  const [error, setError] = useState(false);
  const dispatch = useDispatch();
  const { name, description, id, photo } = dish;
  const deleteMenuItem = async () => {
    const response = await fetchAPI({
      method: 'DELETE',
      url: replaceUrl(MENUS_MENU_ITEM_RESTAURANT_BY_TWO_ID, { id: restaurantId, secondId: id}),
    });
    if (response) {
      dispatch(getMenu(restaurantId));
    }
  }
  const onError = (e) => {
    setError(true);
  };
  return (
    <DishWrapper>
      {photo ? <img src={`${PUBLIC_API}/${photo}`} className="dish__image" onError={(event)=>(event.target as any).setAttribute("src","https://images.pexels.com/photos/1640777/pexels-photo-1640777.jpeg?cs=srgb&dl=pexels-ella-olsson-1640777.jpg&fm=jpg")}/>
        : <div className="menuItemIc"><MenuItemIcon/></div>}
      <div className="dish__text">
        <div className="dish__text-main">{name}</div>
        <div className="dish__text-minor">{description}</div>
      </div>
      <span>
        <DeletePopOver onDelete={deleteMenuItem} />
      </span>
    </DishWrapper>
  );
}

export function RestaurantCourses(props) {
  const { coursesList, getCourses } = props;
  const coursesListDisplay = coursesList.length ? coursesList.filter(course => course.menuItems && course.menuItems.length > 0) : [];
  return (
    <RestaurantCoursesWrapper>
      {
        coursesListDisplay.length ? coursesListDisplay.map(course =>
          <RestaurantCourse
            course={course}
            getCourses={getCourses}
          />)
          : <Empty />
      }
    </RestaurantCoursesWrapper>
  )
}
