import React, { useState } from 'react';
import styled from 'styled-components';
import { Select, Input, Button, Space } from 'antd';
import { SearchOutlined } from '@ant-design/icons';
import { useHistory } from 'react-router-dom';
import { getSearchParamValueByParams } from 'utils/searchParams';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import { TABLET_BREAK_POINT, MOBILE_BREAK_POINT } from 'styles/constants';
import { PlusOutlined } from '@ant-design/icons';
import { createStructuredSelector } from "reselect";
import { searchMenu } from "../../../Store";
import { useDispatch } from "react-redux";
import FloatLabel from 'components/FormatInput/FloatLabel';

const RestaurantFiltersWrapper = styled.div`
  display: flex;
  margin: -10px 0 10px 0;
  margin-left: 20%;
  justify-content: flex-end;
  .ant-input-affix-wrapper-lg {
    padding: 9px;
  }
  .wrapper {
    margin-left: 10px;
    display: inline-flex;
    align-items: flex-end;
  }
  .restaurant-course {
    &__filter-group {
        margin-right: 10px;
        flex-grow: 1;
        min-width: 160px;
      }
      &__search {
        margin-right: 10px;
        min-width: 260px;
      }
      &__search-button {
        margin-top: 10px;
        margin-right: 10px;
        width: 100px;
        button {
          width: 100%;
        }
    }
    &__add-button {
        margin-top: 10px;
        &--tablet {
          display: flex;
          align-items: center;
          justify-content: center;
        }
        &--mobile {
          display: none;
        }
      }
  }
  @media only screen and (max-width: ${TABLET_BREAK_POINT}px) {
    margin: -15px 0 10px 0;
    .restaurant-course {
      &__filter-group {
        margin-top: 10px;
        margin-right: 10px;
        flex-grow: 1;
        min-width: 130px;
      }
      &__search {
        margin-top: 10px;
        margin-right: 10px;
        min-width: unset;
      }
      &__search-button {
        margin-top: 10px;
        margin-right: 10px;
        width: 100px;
        button {
          width: 100%;
        }
    }
    &__add-button {
        margin-top: 10px;
        &--tablet {
          display: flex;
          align-items: center;
          justify-content: center;
        }
        &--mobile {
          display: none;
        }
      }
  }
  }
  @media only screen and (max-width: ${MOBILE_BREAK_POINT}px) {
    display: flex;  
    margin: 0px 0 10px 0;
    flex-wrap: wrap;
    margin-left: 0;
    .wrapper {
      width: 100%;
     }
    .mg-10 {
      margin-top: 10px;
    }
    .restaurant-course {
      &__filter-group {
        margin: 0;
        margin-top: 10px;
        flex-grow: 1;
      }
      &__search {
        margin-top: 10px;
        margin-left: 10px;
        flex-grow: 1;
      }
      &__search-button {
        margin: 0;
        margin-top: 10px;
        width: 100%;
        button {
          width: 100%;
        }
      }
      &__add-button {
        margin: 0;
        margin-top: 10px;
        margin-left: 10px;
        &--tablet {
          display: flex;
          align-items: center;
          justify-content: center;
        }
        &--mobile {
          display: none;
        }
      }
    }
  }
`;
export function RestaurantCourseFilters(props) {
  const { categories, type } = props;
  const [searchText, setSearchText] = useState('');
  const history = useHistory();
  const dispatch = useDispatch();
  const [hideCate, setHideCate] = useState(categories.length==0? false: true);
  const handleSearch = () => {
    dispatch(searchMenu({searchText: searchText ? searchText : ''}));
  }

  const handleFilter = (value) => {
    // setCategoryId(value);
    dispatch(searchMenu({categoryId: value}));
  }

  const handleAddMenu = () => {
    history.push(`${history.location.pathname}/product?type=${type}`);
  };

  return (
    <RestaurantFiltersWrapper>
      <div className="wrapper">
      {hideCate &&
        <div className="restaurant-course__filter-group">
          <FloatLabel
            defaultValue={0}
            size="large"
            label={<FormattedMessage {...messages.selectGroup} />}
            className="w-100"
            onChange={handleFilter}
            items={[...categories, { id: 0, name: <FormattedMessage {...messages.allSelectCategories} />}]}
            typeInput="selectMutil"
          />
        </div>
        }
        <FormattedMessage {...messages.search}>
          {
            search =>
              <FloatLabel
               value={searchText}
               size="large"
               width={300}
               label={search}
               prefix={<SearchOutlined/>}
               className="restaurant-course__search"
               onChange={(e) => setSearchText(e.target.value)}
              />
          }
        </FormattedMessage>
      </div>
      <div className="wrapper mg-10">
        <div className="restaurant-course__search-button">
          <Button
            size="large"
            type="primary"
            onClick={handleSearch}>
            <FormattedMessage {...messages.search} />
          </Button>
        </div>
        <div className="restaurant-course__add-button">
          <Button
            size="large"
            type="primary"
            shape="circle"
            onClick={handleAddMenu}
            className="restaurant-course__add-button--tablet">
            <PlusOutlined />
          </Button>
        </div>
      </div>
    </RestaurantFiltersWrapper>
  );
}
