import React, { useState } from 'react';
import styled from 'styles/styled-components';
import { PRIMARY_COLOR } from 'styles/constants';
import { CreateRestaurantModal } from './Restaurant-blank-card';
import { StoreIcon } from 'styles/icon-components';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';

const RestaurantCardWrapper = styled.div`
  background: #fff;
  border-radius: 8px;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  width: 100%;
  height: 230px;
  padding: 20px;
  display: flex;
  justify-content: center;
  align-items: center;
  .restaurant-blank-card {
    text-align: center;
    color: ${PRIMARY_COLOR};
    font-size: 13px;
    font-weight: lighter;
    svg {
      margin-bottom: 10px;
      width: 40px;
      height: 30px;
    }
  }
  &:hover {
    box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
    cursor: pointer;
  }
`;

interface Props {
  getRestaurants: () => Promise<void>;
}

export function RestaurantBlankCard(props: Props) {
  const { getRestaurants } = props;
  const [openCreateRestaurantModal, setOpenCreateRestaurantModal] = useState(false);
  return (
    <>
      <RestaurantCardWrapper onClick={() => setOpenCreateRestaurantModal(true)}>
        <div className="restaurant-blank-card">
          <div><StoreIcon /></div>
          <FormattedMessage {...messages.addNewRestaurant} />
        </div>
      </RestaurantCardWrapper>
      <CreateRestaurantModal
        visible={openCreateRestaurantModal}
        onCancel={() => setOpenCreateRestaurantModal(false)}
        getRestaurants={getRestaurants}
      />
    </>
  );
}
