import React, { useState } from 'react';
import styled from 'styles/styled-components';
import { BLACK_COLOR, MOBILE_BREAK_POINT } from 'styles/constants';
import { Input, Button, Space } from 'antd';
import { SearchOutlined } from '@ant-design/icons';
import { useHistory } from 'react-router-dom';
import { getSearchParamValueByParams } from 'utils/searchParams';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';

const RestaurantListHeaderWrapper = styled.div`
  display: flex;
  padding: 10px;
  color: ${BLACK_COLOR};
  font-size: 19px;
  font-weight: 600;
  line-height: 28px;
  text-align: left;
  .restaurant-list-header {
    display: flex;
    margin-left: auto;
  }
  .ant-input {
    border-radius: 0;
  }
  .ant-input-affix-wrapper-lg {
    padding: 10px;
  }
  @media only screen and (max-width: ${MOBILE_BREAK_POINT}px) {
    display: initial;
    .page-heading {
      padding-bottom: 10px;
    }
  }
`;

interface Props {
  getRestaurants: (searchText: string) => void;
}

export function RestaurantListHeader(props: Props) {
  const { getRestaurants } = props;
  const history = useHistory();
  const defaultSearchText = getSearchParamValueByParams(history.location.search, 'searchText');
  const [searchText, setSearchText] = useState<string>(defaultSearchText || '');
  const handleSearch = () => {
    const urlSearchParam = new URLSearchParams(history.location.search);
    if (!!searchText) {
      urlSearchParam.set('searchText', searchText.trim());
    } else {
      urlSearchParam.delete('searchText');
    }
    history.push({ search: urlSearchParam.toString() });
    getRestaurants(searchText.trim());
  }
  return (
    <RestaurantListHeaderWrapper>
      <div className="page-heading"><FormattedMessage  {...messages.restaurant} /></div>
      <div className="restaurant-list-header">
        <Space>
          <FormattedMessage  {...messages.search}>
            {message =>
              <FloatLabel allowClear 
                size="large"
                width={300}
                label={`${message}...`}
                prefix={<SearchOutlined />}
                value={searchText}
                onChange={e => setSearchText(e.target.value)}
                onPressEnter={handleSearch}
              />
            }
          </FormattedMessage>
          <Button
            size="large"
            type="primary"
            onClick={handleSearch}
          ><FormattedMessage {...messages.search} /></Button>
        </Space>
      </div>
    </RestaurantListHeaderWrapper>
  )
}