/*
 *
 * LanguageProvider reducer
 *
 */
import { DragItemModel } from './types';
import { ActionTypes } from './constants';
import { getSearchParamValueByParams } from 'utils/searchParams';
import _ from "lodash";

export interface UserInfoModel {
  readonly token: string | null;
}

const defaultCurrentFloorId = getSearchParamValueByParams(window.location.search, 'currentFloorId');

export interface RestaurantReducerModel {
  readonly isFetching: boolean;
  readonly message: string;
  readonly dragItems: DragItemModel[];
  readonly currentFloorId: number;
  readonly refresh: boolean;
  readonly itemTable: object;
  readonly area: object;
  readonly service: any[] | null;
  readonly menu: any[] | null;
  readonly combo: any[] | null;
  readonly params: { categoryId: number, searchText: string }
}

export const initialState: RestaurantReducerModel = {
  isFetching: false,
  message: '',
  dragItems: [],
  currentFloorId: +defaultCurrentFloorId,
  refresh: false,
  itemTable: {},
  area: {width: 100, height: 50},
  menu: null,
  combo: null,
  service: null,
  params: { categoryId: -1, searchText: '' }
};

const isCombo = (menuItem: any) => menuItem.products[0].type === 1 && (menuItem.products.length > 1);
const isMenu = (menuItem: any) => menuItem.products[0].type === 1 && (menuItem.products.length < 2);
const isService = (menuItem: any) => menuItem.products[0].type === 2;
function reducer(
  state: RestaurantReducerModel = initialState,
  action,
): RestaurantReducerModel {
  switch (action.type) {
    case ActionTypes.CREATE_DRAG_ITEM_SUCCESS:
      const newDragItems = [...state.dragItems, action.payload];
      return {...state, dragItems: newDragItems };
    case ActionTypes.UPDATE_DRAG_ITEM: {
      const index = _.findIndex(state.dragItems, { id: action.payload.id });
      const newDragItems = [...state.dragItems];
      if (index > -1) {
        newDragItems.splice(index, 1, action.payload);
      }
      return {...state, dragItems: newDragItems};
    }
    case ActionTypes.DELETE_DRAG_ITEM: {
      const index = _.findIndex(state.dragItems, { id: action.payload });
      const newDragItems = [...state.dragItems];
      if (index > -1) {
        newDragItems.splice(index, 1);
      }
      return {...state, dragItems: newDragItems};
    }
    case ActionTypes.GET_DRAG_ITEMS_BY_FLOOR_SUCCESS:
      return { ...state, dragItems: action.payload };
    case ActionTypes.SET_CURRENT_FLOOR_ID:
      return { ...state, currentFloorId: action.payload }
    case ActionTypes.MAKE_REFRESH:
      return { ...state, refresh: !state.refresh }
    case ActionTypes.SET_AREA_FLOOR:
      return { ...state, area: action.payload }
    case ActionTypes.GET_MENU:
      return { ...state, isFetching: true};
    case ActionTypes.GET_MENU_SUCCESS:
      let menu = action.payload.map(category => { return {...category, menuItems: _.filter(category.menuItems, isMenu)}});
      menu = menu.filter(category => category.categoryId);
      let service = action.payload.map(category => { return {...category, menuItems: _.filter(category.menuItems, isService)}});
      service = service.filter(category => category.categoryId);
      const combo = [{
        categoryId: -1,
        categoryName: '',
        menuItems: action.payload.reduce((accumulate, category) => accumulate.concat(_.filter(category.menuItems, isCombo)), [])
      }];
      return { ...state, isFetching: false, menu, combo, service}
    case ActionTypes.GET_MENU_FAIL:
      return { ...state, isFetching: false, message: action.payload};
    case ActionTypes.SEARCH_MENU:
      return { ...state, params: {...state.params, ...action.payload} };
    default:
      return state;
  }
}
export default reducer;
