import { createSelector } from 'reselect';
import { initialState } from './reducer';
import { ApplicationRootState } from 'types';

const selectRestaurantReducer = (state: ApplicationRootState) =>
  state.restaurant || initialState;

export const makeSelectDragItems = () =>
  createSelector(selectRestaurantReducer, restaurantReducer => restaurantReducer.dragItems);

export const makeSelectCurrentFloorId = () =>
  createSelector(selectRestaurantReducer, restaurantReducer => restaurantReducer.currentFloorId);

export const makeSelectRefresh = () =>
  createSelector(selectRestaurantReducer, restaurantReducer => restaurantReducer.refresh);

export const makeSelectItemTable = () =>
  createSelector(selectRestaurantReducer, restaurantReducer => restaurantReducer.itemTable);

export const makeSelectArea = () =>
  createSelector(selectRestaurantReducer, restaurantReducer => restaurantReducer.area);

export const makeIsFetching = () => createSelector(selectRestaurantReducer, restaurant => restaurant.isFetching);

export const makeMenu = () => createSelector(selectRestaurantReducer, restaurant => {
  const { params: { categoryId, searchText = '' } } = restaurant;
  return restaurant.menu ? restaurant.menu
    .map(category => {
      if (category.menuItems?.length) {
        const newMenuItems = category.menuItems.filter(item => item.name?.toLocaleLowerCase().includes(searchText.toLocaleLowerCase()))
        return { ...category, menuItems: newMenuItems };
      }
      return category;
    })
    .filter(cat => categoryId === -1 || cat.categoryId === categoryId || categoryId === 0) : restaurant.menu;
});

export const makeService = () => createSelector(selectRestaurantReducer, restaurant => {
  const { params: { categoryId, searchText = '' } } = restaurant;
  return restaurant.service ? restaurant.service
    .map(category => {
      if (category.menuItems?.length) {
        const newMenuItems = category.menuItems.filter(item => item.name?.toLocaleLowerCase().includes(searchText.toLocaleLowerCase()))
        return { ...category, menuItems: newMenuItems };
      }
      return category;
    })
    .filter(cat => categoryId === -1 || cat.categoryId === categoryId || categoryId === 0) : restaurant.service;
});

export const makeCategories = () => createSelector(selectRestaurantReducer,
    restaurant => restaurant.menu ? restaurant.menu.map(item => ({id: item.categoryId, name: item.categoryName})): []);

export const makeCombo = () => createSelector(selectRestaurantReducer, restaurant => {
  const { params: { searchText = '' } } = restaurant;
  return restaurant.combo ? restaurant.combo
    .map(category => {
      if (category.menuItems?.length) {
        const newMenuItems = category.menuItems.filter(item => item.name?.toLocaleLowerCase().includes(searchText.toLocaleLowerCase()))
        return { ...category, menuItems: newMenuItems };
      }
      return category;
    }) :  restaurant.combo;
});

