
export type TableType = 'square' | 'rounded' | 'long';
export type AreaType = 'kitchen' | 'bar' | 'pickup';
export type DragType = TableType | AreaType;
export interface RestaurantModel {
  readonly address: string;
  readonly address2: string;
  readonly address3: string;
  readonly city?: string;
  readonly clientId?: string;
  readonly convenienceFee?: string;
  readonly convenienceFeeApplyLevelId?: string;
  readonly convenienceFeeTypeId?: string;
  readonly countryName?: string;
  readonly createdBy?: string;
  readonly createdDateTime?: string;
  readonly dataSync?: string;
  readonly detail?: string;
  readonly email?: string;
  readonly facebook?: string;
  readonly featuredMenuItems?: string;
  readonly featuredPhotos?: string;
  readonly floors?: string;
  readonly fullAddress?: string;
  readonly id?: string;
  readonly instagram?: string;
  readonly issueTimeAfterPlacingOrder?: string;
  readonly largePickUpCookTime?: string;
  readonly latitude?: string;
  readonly longitude?: string;
  readonly managers?: string;
  readonly maxGrouping?: string;
  readonly minimumCharge?: string;
  readonly minimumServiceFee?: string;
  readonly name?: string;
  readonly noSlottingTime?: string;
  readonly occupiedSeatIdleTime?: string;
  readonly percentageServiceFee?: string;
  readonly phoneNumber?: string;
  readonly phoneCountryCode?: string;
  readonly photo?: string;
  readonly pickUpEffectiveTime?: string;
  readonly restaurantLocations?: string;
  readonly restaurantSubscription?: string;
  readonly serviceFeeAppliedThreshold?: string;
  readonly squareInfo?: string;
  readonly state?: string;
  readonly tax?: string;
  readonly tips?: string;
  readonly useTicket?: string;
  readonly vacations?: string;
  readonly website?: string;
  readonly wifiName?: string;
  readonly wifiPassword?: string;
  readonly workings?: string;
  readonly yelp?: string;
  readonly zipcode?: string;
  readonly isPublic?: boolean;
}

export interface CourseModel {
  readonly id?: number;
  readonly name: string;
  readonly description: string;
  readonly dishes?: Array<DishModel>;
}

export interface DishModel {
  readonly id?: number;
  readonly name: string;
  readonly description: string;
}

export interface FloorModel {
  id?: number;
  name?: string;
  height?: number;
  width?: number;
  intl?: any;
}

export interface DragItemModel {
  [x: string]: any;
  id?: number;
  name?: string;
  height?: number;
  width?: number;
  type: number; // 1 is a table, 2 is a Preparation area, 3 Cashier area, 4 Pickup location
  shapeId?: number; // 1: tròn, 2: chữ nhật, 3: vuông, 4: oval (edited) 
  isSelected?: boolean;
  numberOfSeat?: number;
  group?: String;
  positionX?: number;
  positionY?: number;
  frontendShape?: DragType;
  sectionId?: string | number;
}

export interface GroupModel {
  id?: number;
  name?: string;
}

export interface StaffModel {
  avatar: string;
  avatarHexagon: string;
  countryCode: string;
  createdTime: string;
  dateOfBirth: string;
  email: string;
  firstName: string;
  gender: string;
  id: number;
  language: string;
  lastName: string;
  merchantId: string;
  phone: string;
  phoneCountryCode: string;
  restaurantIds: string;
  restaurantNames: string;
  roleIds: Array<number>;
  roleNames: Array<string>;
  status: string;
  total: string;
  totalOrders: string;
  type: string;
  username: string;
}

export interface TableSizeModel {
  width: number;
  height: number;
}