import React, { useState, useEffect } from 'react';
import { useParams } from 'react-router';
import { Link, useHistory } from 'react-router-dom';
import styled from 'styled-components';
import {
  Form,
  Input,
  Button,
  Select,
  Checkbox,
  Upload,
  notification
} from 'antd';
import IMG_RES_DEFAULT from '../../../images/restaurant-placeholder.svg';
import { LoadingOutlined } from '@ant-design/icons';
import { formatCurrency } from 'utils/common';
import moment from 'moment';
import _ from 'lodash';
import { PRODUCTS_SIZES, PRODUCTS_SIZES_BY_ID_URL } from 'containers/App/urls';
import { RoutePaths } from 'containers/App/routes';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import {
  MENUS_MENU_CATEGORIES_URL,
  MENUS_MENU_ITEM_UPLOAD_PHOTO_URL,
  MENUS_MENU_ITEM_PRODUCT_URL,
  MENUS_MENU_ITEM_URL,
  PUBLIC_API,
  PRODUCTS_UNITS_URL
} from 'containers/App/urls';
import { EditUploadImageIcon } from 'styles/icon-components';
import {
  CategoryModel as ServiceDetailsCategoryModel,
  ServiceEditPayload,
  ProductUnits
} from 'containers/Service/ServiceEdit/serviceDetailModels';
import {
  ServiceItemModel,
  CategoryModel,
  SizeModel,
} from '../ServiceList/serviceListModels';
import { ParamModel } from './serviceDetailModels';
import { digits } from 'utils/number';
import { PROD_UNIT_TYPE } from 'utils/constants';
import { validatePrice, validateMaxTime, fileValidation } from 'utils/validation';
import { PlusCharacter, RemoveCharacter } from 'styles/icon-components';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import cacheUtils from 'utils/cacheUtils';
import { useSelector } from 'react-redux';
import { createSelector } from 'reselect';
import { makeSelectLocale } from '../../LanguageProvider/selectors';
import { FormatInput } from 'components/FormatInput';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createSelector(makeSelectLocale(), locale => ({
  locale,
}));


const { TextArea } = Input;
const MenuEditWrapper = styled.div`
  margin-left: 2px;
  height: 100%;
  .product-units-select {
    .ant-select {
      width: 100% !important;
      .ant-select-selector {
        padding: 5px 10px !important;
        border-radius: 22px !important;
        border-top-left-radius: 0 !important;
        border-bottom-left-radius: 0 !important;
        background-color: white;
      }
      // .ant-select-arrow {
      //   display: none;
      // }
    }
    .ant-select-selection-item {
      line-height: 30px !important;
    }
  }
  .ant-picker {
    width: 100%;
    padding: 11px 19px;
    border-radius: 22px;
  }
  .ant-input-number {
    width: 100%;
    border-radius: 20px 0px 0px 20px !important;
    border-right: none;
    font-size: 14px;
    font-weight: 600;
    color: #dc5454;
  }
  .ant-input {
    padding: 11px 19px;
    border-radius: 22px;
  }

  .ant-input-number-input {
    padding: 0 19px;
    height: 44px;
  }
  .ant-input-group-addon:last-child {
    padding-top: 8px;
    vertical-align: middle;
    display: inline-table;
    line-height: 24px;
    height: 44px;
    width: 20%;
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    background-color: white;
  }
  .ant-upload.ant-upload-select-picture-card {
    width: 230px;
    height: 230px;
    border: 0;
    background: none;
    .ant-upload {
      padding: 0;
    }
    img {
      border-radius: 8px;
    }
  }
  .ant-form-item-control {
    max-width: 100% !important;
  }
  .flex_addon {
    display: inline-flex;
    .ant-form-item {
      width: 80%;
    }
    .ant-form-item.product-units-select {
      width: 50%;
    }
  }
  .ant-row {
    width: 100%;
  }
  .ant-form-item {
    margin-bottom: 0 !important;
  }
  .ml-15 {
    margin-left: 15px;
  }
  .mr-15 {
    margin-right: 15px;
  }
  .pr-15 {
    padding-right: 15px;
    @media screen and (max-width: 445px) {
      padding-right: 0px;
    }
    @media screen and (max-width: 1200px) {
      padding-right: 10px;
    }
    @media screen and (max-width: 968px) {
      padding-right: 5px;
    }
  }
  .menu-edit {
    font-family: Muli, sans-serif;
    height: 100%;
    @media screen and (min-width: 768px) {
      display: flex;
    }
    &__info {
      background: #fff;
      box-shadow: 0 2px 3px 0 rgba(0, 0, 0, 0.15);
      padding: 20px;
      @media screen and (min-width: 768px) {
        flex: 1;
      }
    }
    .info {
      &__title {
        color: #333333;
        font-size: 13px;
        font-weight: 700;
        padding-bottom: 20px;
      }
      &__form {
        display: flex;
        flex-direction: row;
        justify-content: flex-start;
        @media screen and (max-width: 968px) {
          flex-direction: column-reverse;
        }
      }
      &__button {
        margin-top: 10px;
        button {
          width: 110px;
        }
        display: none;
        @media screen and (min-width: 768px) {
          display: block;
        }
        &--mobile {
          margin: 10px 0 10px 10px;
          button {
            width: 110px;
          }
          display: block;
          @media screen and (min-width: 768px) {
            display: none;
          }
        }
      }
    }
    .form-field {
      &__row {
        display: flex;
        flex-direction: row;
        flex-wrap: wrap;
        justify-content: left;
        .flex_addon:hover {
          .ant-input-group-addon {
            border-color: #b8e061;
          }
          .ant-form-item-has-error + .ant-input-group-addon {
            border-color: red;
          }
        }
        .ant-form-item-has-error + .ant-input-group-addon {
          border-color: red;
        }
        .ant-input-number-focused + .ant-input-group-addon {
          outline: 0;
          border-color: #b8e061;
          box-shadow: 0 0 0 2px rgba(156, 211, 57, 0.2);
        }
        textarea {
          margin: 5px 0 15px 0;
          min-height: 150px !important;
          border-radius: 8px;
        }
      }
      &__group {
        width: 50%;
        @media screen and (max-width: 968px) {
          width: 100%;
        }
      }
      &__plus {
        @media screen and (max-width: 445px) {
          flex: 0 0 5%;
        }
      }
      &__col {
        flex: 0 0 50%;
        margin-bottom: 15px;
      }
      &__col3 {
        flex: 0 0 33%;
        margin-bottom: 15px;
        @media screen and (max-width: 1404px) {
          flex: 0 0 31%;
        }
        @media screen and (max-width: 1107px) and (min-width: 968px) {
          flex: 0 0 29%;
        }
        @media screen and (max-width: 968px) {
          flex: 0 0 38%;
        }
        @media screen and (max-width: 591px) {
          flex: 0 0 30%;
        }
      }
      &__col5 {
        flex: 0 0 29%;
        margin-bottom: 15px;
        input::placeholder {
          font-size: 14px;
        }
        @media screen and (max-width: 1404px) {
          flex: 0 0 27%;
        }
        @media screen and (max-width: 968px) {
          flex: 0 0 27%;
        }
      }
      &__col7 {
        flex: 0 0 41%;
        margin-bottom: 15px;
        @media screen and (max-width: 1404px) {
          flex: 0 0 40%;
        }
        @media screen and (max-width: 968px) {
          flex: 0 0 43%;
        }
      }
      &__col4 {
        flex: 0 0 5%;
        margin-bottom: 15px;
        padding-right: 0px;
      }
      &__col2 {
        flex: 0 0 62%;
        margin-bottom: 15px;
        @media screen and (max-width: 1404px) {
          flex: 0 0 58%;
        }
        @media screen and (max-width: 968px) {
          flex: 0 0 62%;
        }
      }
      &__col1 {
        flex: 0 0 33.33333%;
        margin-bottom: 15px;
      }
      &__number {
        .ant-row.ant-form-item {
          flex: 0 0 98%;
          @media screen and (max-width: 1404px) {
            flex: 0 0 93%;
          }
          @media screen and (max-width: 968px) {
            flex: 0 0 98%;
          }
        }
      }
      &__name {
        input {
          border-radius: 22px;
          padding: 11px 19px;
        }
        @media screen and (max-width: 445px) {
          flex: 0 0 100%;
        }
      }
      &__category {
        min-width: 100px;
        padding-right: 5px;
        @media screen and (max-width: 445px) {
          flex: 0 0 100%;
        }
        .ant-select-arrow {
          min-width: auto;
        }
      }
      &__price {
        input {
          border-top-right-radius: 0 !important;
          border-bottom-right-radius: 0 !important;
          border-right: none;
        }
        @media screen and (max-width: 445px) {
          flex: 0 0 50%;
        }
      }
      &__discountPrice {
        input {
          border-top-right-radius: 0 !important;
          border-bottom-right-radius: 0 !important;
          border-right: none;
        }
        @media screen and (max-width: 445px) {
          flex: 0 0 80%;
        }
      }
      &__time {
        input {
          border-top-right-radius: 0 !important;
          border-bottom-right-radius: 0 !important;
          border-right: none;
        }
        @media screen and (max-width: 445px) {
          flex: 0 0 50%;
        }
      }
      &__photo {
        width: 230px;
        min-width: 230px;
        height: 230px;
        min-height: 230px;
        border-radius: 8px;
        border: solid 1px #e6e6e6;
        background: #fff;
        position: relative;
        cursor: pointer;
        margin: 0px;
        margin-bottom: 15px;
        .edit-upload-image-icon {
          position: absolute;
          top: 15px;
          right: 10px;
          display: none;
        }
        :hover {
          opacity: 0.2;
          .edit-upload-image-icon {
            display: block;
          }
        }
        @media screen and (max-width: 1600px) and (min-width: 1404px) {
          margin: 0px 0px 0px 20px;
        }
        @media screen and (max-width: 968px) {
          margin: 0px auto 40px;
        }
      }
    }

    &__extra {
      @media screen and (min-width: 768px) {
        height: 50%;
        display: flex;
        flex-wrap: wrap;
        flex: 0 0 50%;
      }
    }
    .extra {
      &__component {
        box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
        background: #fff;
        padding: 20px;
        margin-top: 10px;
        @media screen and (min-width: 768px) {
          flex: 0 0 calc(50% - 10px);
          margin-left: 10px;
          max-width: calc(50% - 10px);
          :nth-child(1),
          :nth-child(2) {
            margin-top: 0;
          }
        }
      }
    }
  }
  .checkbox-area {
    display: flex;
    width: 50%;
    @media screen and (max-width: 968px) {
      width: 100%;
    }
  }
  // Fix text area label
  textarea.ant-input {
    border-radius: 8px !important;
  }
  textarea.ant-input + label.label-textArea {
    top: 24px !important;
  }
  textarea.ant-input + label.label-float-textArea {
    top: 11px !important;
  }
`;

function ServiceEdit({ intl }) {
  const params = useParams<ParamModel>();

  const { locale } = useSelector(stateSelector);
  const [loading, setLoading] = useState(false);
  const [loadingSave, setLoadingSave] = useState(false);
  const [initialValues, setInitialValues] = useState<ServiceEditPayload>();
  const [menuDetails, setMenuDetails] = useState<ServiceItemModel>();
  const [sizesList, setSizesList] = useState<SizeModel[]>();
  const [menuCategories, setMenuCategories] = useState<
    ServiceDetailsCategoryModel[]
  >();
  const [productUnits, setProductUnits] = useState<
  ProductUnits[]
>([]);
  const [imageUrl, setImageUrl] = useState<any>('');

  const userInfo = cacheUtils.getUserInfo();
  const currency = () => {
    if (userInfo) {
    const userInfoJson = JSON.parse(userInfo);
    if (userInfoJson.profile?.merchant?.setting) {
      return userInfoJson.profile?.merchant?.setting.currency;
    }
    return 'VND';
  } else {
    return 'VND';
  }}
  const history = useHistory();

  const [form] = Form.useForm();
  const uploadButton = (
    <div>
            {loading ? <LoadingOutlined /> : <img src={IMG_RES_DEFAULT}/>}
      <div className="ant-upload-text" style={{ marginTop: '10px' }}>
        <FormattedMessage {...messages.image}/>
      </div>
      <span className="img-hint"><FormattedMessage
          {...messages.encourageCondition}
          values={{ height: 345,
            width: 180, }}
        /></span>
    </div>
  );

  const beforeUpload = file => {
    if (!fileValidation(file.name)) {
      notification.error({ message: intl.formatMessage(messages.invalidFile)});
       return false;
    }
    const reader = new FileReader();
    reader.onloadend = e => {
      setImageUrl(reader.result!);
    };
    reader.readAsDataURL(file);
    return false;
  };

  const executeSizes = async (oldSizes, newSizes) => {
    const sizesAddNew = newSizes.filter(size => !size.id);
    const sizesOld = newSizes.filter(size => size.id);

    const sizesNotUsed = oldSizes.filter(
      size => sizesOld.findIndex(sizeOld => sizeOld.id === size.id) === -1,
    );
    const sizesUsing = sizesOld.filter(
      size => oldSizes.findIndex(sizeOld => sizeOld.id === size.id) !== -1,
    );
    const sizesAddPromise = sizesAddNew.map(size =>
      fetchAPI({
        method: 'POST',
        url: PRODUCTS_SIZES,
        data: size,
      }),
    );
    const sizesUpdatePromise = sizesUsing.map(size =>
      fetchAPI({
        method: 'PUT',
        url: replaceUrl(`${PRODUCTS_SIZES_BY_ID_URL}`, { id: size.id }),
        data: size,
      }),
    );
    const sizesRemovePromise = sizesNotUsed.map(size =>
      fetchAPI({
        method: 'DELETE',
        url: replaceUrl(`${PRODUCTS_SIZES_BY_ID_URL}`, { id: size.id }),
      }),
    );
    const allPromise = [] as any;
    if (sizesAddPromise.length > 0) allPromise.push(...sizesAddPromise);
    if (sizesUpdatePromise.length > 0) allPromise.push(...sizesUpdatePromise);
    if (sizesRemovePromise.length > 0) allPromise.push(...sizesRemovePromise);
    const resultPromise = await Promise.all(allPromise);
    return (resultPromise as any)
      .slice(0, sizesAddPromise.length + sizesUpdatePromise.length)
      .map(size => size.id);
  };

  const handleSave = async values => {
    setLoadingSave(true);
    try {
    values = formatCurrency(values);
    const newSizes = values.sizes
      .filter(size => size && size.price)
      .map(size => {
        const name = size.name === "" ? null : size.name;
        return { ...size, name: name };
      });
    const oldSizes = sizesList
      ?.filter(size => size && size.price)
      .map(size => {
        const name = size.name === "" ? null : size.name;
        return { ...size, name: name };
      });
    const sizeIds = await executeSizes(oldSizes ? oldSizes : [], newSizes);
    let photo = menuDetails && menuDetails.photo ? menuDetails.photo : '';
    const { files } = values;
    const imageFile = files?.file;
    if (imageFile) {
      const formData = new FormData();
      formData.append('photo', imageFile!);
      photo = await fetchAPI({
        method: 'POST',
        url: MENUS_MENU_ITEM_UPLOAD_PHOTO_URL,
        formData: true,
        data: formData,
      });
    }

    const payload: ServiceEditPayload = {
      name: values.name,
      type: 2,
      description: values.description,
      price: values.sizes[0].price,
      discount: values.sizes[0].discountPrice,
      categoryId: values.categoryId,
      photo,
      applyAllRestaurants: values.applyAllRestaurants,
      purchaseOnline: values.purchaseOnline,
      calories: null,
      cookTime: values.cookTime
        ? values.cookTime.hours() * 60 + values.cookTime.minutes()
        : 0,
      sizes: sizeIds,
      ingredients: [],
      cookingRequestGroups: [],
      addOns: [],
      sku: values.sku,
    };

    let response = null;
    if (params && params.id) {
      response = await fetchAPI({
        method: 'PUT',
        url: MENUS_MENU_ITEM_PRODUCT_URL,
        data: { ...payload, menuItem: params.id },
      });
    } else {
      response = await fetchAPI({
        method: 'POST',
        url: MENUS_MENU_ITEM_PRODUCT_URL,
        data: payload,
      });
    }

    if (response) {
      history.push(RoutePaths.service);
    }
  } catch(e) {

  } finally {

  }
  };

  const getMenuDetails = async id => {
    const response = await fetchAPI({
      method: 'GET',
      url: `${MENUS_MENU_ITEM_URL}/${id}`,
    });

    if (response) {
      setMenuDetails(response);
      const product =
        response.products && response.products.length > 0
          ? response.products[0]
          : null;
      const { addons } = response;
      const cooktime =
        product && product.cooktime
          ? `${Math.floor(product.cooktime / 60)}:${product.cooktime % 60}`
          : '00:00';

      const sizesProducts =
        product.sizes.length > 0
          ? product.sizes.map(size => {
              // const unit = size.name ? size.name.split(" ")[1]: '';
              const name = size.name ? size.name.replace(/[^0-9\.]+/g, '') : '';
              return { ...size, name: name, unit: size.productUnitId ? Number( size.productUnitId) : null};
            })
          : [
              {
                name: '',
                price: null,
                discountPrice: null,
              },
            ];
      setSizesList(sizesProducts);
      const initData: ServiceEditPayload = {
        name: response.name,
        description: response.description,
        price: response.price,
        discount: response.discount,
        categoryId: response.category ? response.category.categoryId : null,
        photo: response.photo,
        applyAllRestaurants: response.applyAllRestaurants,
        purchaseOnline: response.purchaseOnline,
        calories: product.calories,
        cookTime: moment(cooktime ? cooktime : '00:00', 'HH:mm'),
        sizes: sizesProducts,
        ingredients: [],
        cookingRequestGroups: [],
        addOns: [],
        sku: product.sku
      };
      setInitialValues(initData);
      if (response.photo) {
        setImageUrl(`${PUBLIC_API}/${response.photo}`);
      }
      setLoading(false);
    }
  };

  const handleAddSizes = async add => {
    const sizes = form.getFieldValue('sizes');
    if (
      sizes.findIndex(
        size =>
          !size ||
          (size &&
            !size.id &&
            (!size.name || size.name === '') &&
            !size.price &&
            !size.discountPrice),
      ) === -1
    ) {
      add();
    }
  };
  const getMenuCategories = async () => {
    const response = await fetchAPI({
      method: 'GET',
      url: MENUS_MENU_CATEGORIES_URL,
    });
    if (response) {
      setMenuCategories(response);
    }
  };

  const getProductUnits = async () => {
    const response = await fetchAPI({
      method: 'GET',
      url: `${PRODUCTS_UNITS_URL}?type=${PROD_UNIT_TYPE.SERVICE_UNIT}`,
    });
    if (response) {
      setProductUnits(response);
    }
  };

  useEffect(() => {
    getMenuCategories();
    getProductUnits();
    if (params && params.id) {
      getMenuDetails(params.id);
    } else {
      const category: CategoryModel = {};
      setMenuDetails({
        id: 0,
        category: category,
        name: '',
        kitchenAliasName: '',
        description: '',
        price: 0,
        discount: 0,
        discountPercentage: 0,
        isPublic: 0,
        areaId: 0,
        photo: '',
        photos: null,
        stockout: false,
        stockOut: false,
        products: null,
        addons: null,
        sku: '',
        groupAddons: null,
        minimumCookTime: '',
        maximumCookTime: '',
        minimumCalories: '',
        maximumCalories: '',
        allergyItems: null,
        hasOption: false,
        isEffective: false,
        isFeaturedItem: false,
      });

      const initData: ServiceEditPayload = {
        name: '',
        description: '',
        price: null,
        discount: null,
        categoryId: undefined, // menuCategories && menuCategories[0] && menuCategories[0].id ? menuCategories[0].id : null,
        photo: '',
        applyAllRestaurants: true,
        purchaseOnline: true,
        calories: null,
        cookTime: null, // moment('00:00:00', 'HH:mm:ss'),
        ingredients: [],
        cookingRequestGroups: [],
        addOns: [],
        sizes: [
          {
            name: '',
            unit: 4,
            price: null,
            discountPrice: null,
          },
        ],
        sku: '',
      };
      setInitialValues(initData);
    }
  }, []);

  if (menuDetails && initialValues) {
    const sizeDiv = (field, index, action, fields) => {
      return (
        <div className="form-field__row">
          <div className="form-field__col5 pr-15 form-field__time flex_addon">
            <Form.Item
              name={field ? [field.name, 'name'] : ['sizes', '0', 'name']}
              rules={[
                {
                  pattern: new RegExp('^[0-9]*$'),
                  message: <FormattedMessage {...messages.requiredInputNumber}/> ,
                },
                ({ getFieldValue }) => ({
                  validator(rule, value) {
                    const name = getFieldValue('name').length;
                    if (name > 250){
                      return Promise.reject(
                        intl.formatMessage(
                          messages.requiredNameLength,
                        ),
                      );
                    }
                    return Promise.resolve();
                  }
                }),
                validateMaxTime(480)
              ]}
            ><FormatInput
            placeholder={intl.formatMessage(messages.time)}
          />
            </Form.Item>
            <Form.Item
             className="product-units-select"
             name={field ? [field.name, 'unit'] : ['sizes', '0', 'unit']}
            initialValue={(productUnits && productUnits.length > 0) ? productUnits[0].id : ''}
             >
           <Select showArrow={true}>
              {
                productUnits && productUnits.map((value,index) => (
                  <Select.Option value={ value.id } key={value.id} >
                    { value.name }
                  </Select.Option>
                ))
              }
            </Select>
            </Form.Item>
          </div>
          <div className="form-field__col5 pr-15 form-field__price flex_addon">
            <Form.Item
              name={field ? [field.name, 'price'] : ['sizes', '0', 'price']}
              dependencies={[['sizes', index, 'discountPrice']]}
              rules={[
                { required: true, message: <FormattedMessage {...messages.requiredInput}/> },
                validatePrice,
                ({ getFieldValue }) => ({
                  validator(rule, value) {
                    const discount = getFieldValue([
                      'sizes',
                      index,
                      'discountPrice',
                    ]);
                    if ( value && discount && (parseInt(value.toString().replace(/,/g, '')) < parseInt(discount.toString().replace(/,/g, '')))) {
                      
                      return Promise.reject(
                        intl.formatMessage(
                          messages.requiredValidPrice,
                        ),
                      );
                    }
                    return Promise.resolve();
                  },
                }),
              ]}
            ><FormatInput
            style={{
              verticalAlign: 'middle',
              width: '100%',
              color: '#DC3B7F',
            }}
            placeholder={`${intl.formatMessage(messages.price)}*`}
            formatter={digits}
            />
            </Form.Item>
            <div
              className="ant-input-group-addon"
            >
              {currency()}
            </div>
          </div>
          <div className="form-field__col3 pr-15 form-field__discountPrice flex_addon">
            <Form.Item
              name={
                field
                  ? [field.name, 'discountPrice']
                  : ['sizes', '0', 'discountPrice']
              }
              rules={[validatePrice]}
            >
               <FormatInput
                   style={{
                     verticalAlign: 'middle',
                     width: '100%',
                     color: '#DC3B7F',
                   }}
                   min={0}
                   placeholder={intl.formatMessage(messages.discountPrice)}
                   formatter={digits}
                 />
            </Form.Item>
            <div
              className="ant-input-group-addon"
            >
              {currency()}
            </div>
          </div>
          <div className="form-field__col4 pr-15 form-field__plus">
            {fields.length - 1 !== index ? (
              <Button
                size="large"
                type="primary"
                shape="circle"
                style={{
                  padding: 0,
                  background: 'none',
                  borderColor: 'white',
                  width: '40px',
                }}
                onClick={() => {
                  action.remove(field.name);
                }}
              >
                {' '}
                <RemoveCharacter />{' '}
              </Button>
            ) : (
              <Button
                size="large"
                type="primary"
                shape="circle"
                style={{ padding: 0 }}
                onClick={() => {
                  handleAddSizes(action.add);
                }}
              >
                {' '}
                <PlusCharacter />{' '}
              </Button>
            )}
          </div>
        </div>
      );
    };
    return (
      <MenuEditWrapper>
        <div className="menu-edit">
          <div className="menu-edit__info">
            <Form form={form} initialValues={initialValues}>
              <div className="info__title"><FormattedMessage {...messages.serInfoMess}/></div>
              <div className="info__form">
                <div className="form-field__group">
                  <div className="form-field__row">
                    <div className="form-field__col5 pr-15  form-field__name">
                      <Form.Item name="sku">
                        <FloatLabel label={intl.formatMessage(messages.serviceCode)} />
                      </Form.Item>
                    </div>
                    <div className="form-field__col7 pr-15  form-field__name">
                      <Form.Item
                        name="name"
                        rules={[
                          { required: true, message: <FormattedMessage {...messages.requiredInput}/> },
                        ]}
                      >
                        <FloatLabel label={`${intl.formatMessage(messages.serviceNamePh)}*`} />                
                      </Form.Item>
                    </div>
                    <div className="form-field__col5  form-field__category">
                      <Form.Item
                        className="category-select"
                        name="categoryId"
                        rules={[
                          { required: true, message: <FormattedMessage {...messages.requiredChoose}/> },
                        ]}
                      >
                        <FloatLabel size="large" label={intl.formatMessage(messages.categoryPh)} items={menuCategories ? menuCategories : []} typeInput="selectMutil"/>
                      </Form.Item>
                    </div>
                  </div>
                  <Form.List name="sizes">
                    {(fields, { add, remove }) => (
                      <div>
                        {fields.map((field, index) =>
                          sizeDiv(field, index, { add, remove }, fields),
                        )}
                      </div>
                    )}
                  </Form.List>
                  <div className="form-field__row form-field__number">
                    <Form.Item name="description">
                      <FloatLabel rows={4} label={intl.formatMessage(messages.description)} typeInput="TextArea"/>
                    </Form.Item>
                  </div>
                </div>
                <div className="form-field__photo">
                  <Form.Item name="files">
                    <Upload
                      name="avatar"
                      listType="picture-card"
                      className="avatar-uploader"
                      showUploadList={false}
                      action="https://www.mocky.io/v2/5cc8019d300000980a055e76"
                      beforeUpload={beforeUpload}
                      accept="image/*"
                    >
                      {imageUrl ? (
                        <img
                          src={imageUrl}
                          alt="avatar"
                          style={{ width: '100%', objectFit: 'cover' }}
                        />
                      ) : (
                        uploadButton
                      )}
                      {imageUrl && (
                        <div className="edit-upload-image-icon">
                          <EditUploadImageIcon />
                        </div>
                      )}
                    </Upload>
                  </Form.Item>
                </div>
              </div>
              <div className="checkbox-area">
                <Form.Item noStyle>
                  <Form.Item name="applyAllRestaurants" valuePropName="checked">
                    <Checkbox><FormattedMessage {...messages.applyAll}/></Checkbox>
                  </Form.Item>
                  <Form.Item name="purchaseOnline" valuePropName="checked">
                    <Checkbox><FormattedMessage {...messages.purchaseOnline}/></Checkbox>
                  </Form.Item>
                </Form.Item>
              </div>
              <div className="info__button">
                <Button
                  type="primary"
                  htmlType="submit"
                  loading={loadingSave}
                  onClick={() => {
                    form
                      .validateFields()
                      .then(values => {
                        handleSave(values);
                      })
                      .catch(info => {
                        console.log('Validate Failed:', info);
                      });
                  }}
                >
                   <FormattedMessage {...messages.save}/>
                </Button>
              </div>
            </Form>
          </div>
          <div className="info__button--mobile">
            <Button
              type="primary"
              htmlType="submit"
              loading={loadingSave}
              onClick={() => {
                form
                  .validateFields()
                  .then(values => {
                    handleSave(values);
                  })
                  .catch(info => {
                  });
              }}
            >
              <FormattedMessage {...messages.save}/>
            </Button>
          </div>
        </div>
      </MenuEditWrapper>
    );
  }
  return null;
}
export default injectIntl(ServiceEdit);