import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import _ from 'lodash';

import ServiceListHeader from "./serviceListHeader";
import ServiceListTab from "./serviceListTab";

import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { makeSelectCategoryId } from '../Store/selectors';
import reducer from '../Store/reducer';
import saga from '../Store/saga';
import { setCategory } from '../Store/actions';
import { validNumber } from "utils/common";
import IMG_RES_DEFAULT from '../../images/restaurant-placeholder.svg';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import {fetchAPI} from 'utils/fetchAPI';
import {MENUS_MENU_ITEMS_MERCHANT_URL} from 'containers/App/urls';
import {ServiceModel} from "./serviceListModels";
import MenuItem from 'antd/lib/menu/MenuItem';

const stateSelector = createStructuredSelector({
  params: makeSelectCategoryId(),
});

const ServiceListWrapper = styled.div`
    font-family: Muli, sans-serif;
   .menu-list {
     padding: 20px;
   }
`;

function getCombo(data) {
  return data.reduce(
    (accumulate, category) => accumulate.concat(
      _.remove(
        category.menuItems,
        ((menuItem : any) => menuItem.products.length > 1)
      )
    ),
    []
  )
}

export function ServiceList(props) {
  useInjectReducer({ key: 'menu', reducer: reducer });
  useInjectSaga({ key: 'menu', saga: saga });

  const { params } = useSelector(stateSelector);
  const dispatch = useDispatch();

  const [loading, setLoading] = useState(true);
  const [categoryId, setCategoryId] = useState<number | 0>();
  const [menuListOrigin, setMenuListOrigin] = useState<ServiceModel[]>([]);
  const [menuList, setMenuList] = useState<ServiceModel[]>([]);
  const [comboList, setComboList] = useState<MenuItem[]>([]);
  const handleCategoryChange = (categoryId) => {
    dispatch(setCategory(categoryId));
    if (!categoryId) {
      setMenuList(menuListOrigin);
    } else {
      setMenuList(menuListOrigin.filter(menu => menu.categoryId === categoryId));
    }
  };

  const handleSearch = async (obj) => {
    if (obj.keyword) {
      setLoading(true);
      const urlReplace = `${MENUS_MENU_ITEMS_MERCHANT_URL}?type=2&searchText=${obj.keyword.trim()}`
      const response = await fetchAPI({
        method: 'GET',
        url: urlReplace
      });

      if (response) {
        const categoryId = getCategoryFromUrl();
        setCategoryId(categoryId);
        setMenuList(
          params.categoryId
            ? response.filter(item => item.categoryId === params.categoryId)
            : response,
        );
        setComboList(getCombo(response));
        setLoading(false);
      }
    } else {
      getMenus();
    }
  };
  const getCategoryFromUrl = () => {
    const urlParams = new URLSearchParams(window.location.search);
    const categoryIdParams = urlParams.get('categoryId');
    return categoryIdParams && validNumber(categoryIdParams) ? Number(categoryIdParams) : 0;
  }
  const getMenus = async () => {
    const response = await fetchAPI({
      method: 'GET',
      url: `${MENUS_MENU_ITEMS_MERCHANT_URL}?type=2`
    });

    if (response) {
      const categoryId = getCategoryFromUrl();
      setCategoryId(categoryId);
      setMenuList(
        categoryId
          ? response.filter(item => item.categoryId === categoryId)
          : response,
      );
      setMenuListOrigin(response);
      setComboList(getCombo(response));
      setLoading(false);
    }
  };

  useEffect(() => {
    getMenus();
  }, []);

  return (
    <ServiceListWrapper>
      <div className="menu-list">
        <ServiceListHeader handleSearch={handleSearch} handleCategoryChange={handleCategoryChange} categoryId={categoryId}/>
        <ServiceListTab 
            loading={loading}
            menuList={menuList}
            getMenus={getMenus}
          />
      </div>
    </ServiceListWrapper>
  )
}
