import React from 'react';
import styled from 'styled-components';
import {Popover, Typography,notification} from 'antd';
import {Link} from "react-router-dom";

import {ThreeDotsIcon, EditIcon, RemoveIcon} from '../../../styles/icon-components';
import {fetchAPI} from 'utils/fetchAPI';
import {MENUS_MENU_ITEM_URL} from 'containers/App/urls';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';

const ServiceListActionWrapper = styled.div`
    .menu-list-action {
    padding: 10px 15px;
    
    &__edit {
     border-bottom: 1px solid #4c4c4c;
     padding-bottom: 15px;
     cursor: pointer;
     > span {
      padding: 0;
     }
     svg {
     margin-right: 10px;
      g {
       fill: #fff;
      }
     }
    }
    
    &__delete {
     padding-top: 15px;
     cursor: pointer;
     > span {
      padding: 0;
     }
     svg {
     margin-right: 10px;
      g {
       fill: #fff;
      }
     }
    }
    
    }
    
    a {
     text-decoration: none;
     color: inherit;
    }
    
`;


const actionContent = (props) => {
  const {type, serviceItem, getServices} = props;
  const {id, name} = serviceItem;

  const handleDelete = async () => {
    const response = await fetchAPI({
      method: 'DELETE',
      url: `${MENUS_MENU_ITEM_URL}/${id}`,
    });
    if (response) {
      getServices();
      notification.success({ message: <FormattedMessage {...messages.successDeleted}/> });

    }
  };

  return (<ServiceListActionWrapper>
    <div className="menu-list-action">
      <div className="menu-list-action__edit">
        <Link to={`/service/edit/${id}`}>
          <EditIcon/><FormattedMessage {...messages.edit}/>
        </Link>
      </div>
      <div className="menu-list-action__delete" onClick={handleDelete}>
        <RemoveIcon/><FormattedMessage {...messages.deleteBtn}/>
      </div>
    </div>
  </ServiceListActionWrapper>);
};

export function ServiceListAction(props) {
  return (
    <Popover placement="top"  content={actionContent(props)} trigger="click">
      <div style={{ width: '100%', height: '100%'}}>
        <div style={{ position: "absolute", right: '50px'}}>
          <ThreeDotsIcon/>
        </div>
      </div>
    </Popover>
  );
}
