import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import _ from 'lodash';
import { Spin, Checkbox, Button, Form } from 'antd';

import { MenuItemIcon } from 'styles/icon-components';
import { ServiceListAction } from './serviceListAction';
import { PUBLIC_API } from '../../App/urls';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';

const ServiceListMenuTabWrapper = styled.div`
  .menu-select {
    display: flex;
    align-items: center;
    min-height: 40px;
    &__all {
      font-size: 13px;
      color: #333333;
      .ant-checkbox + span {
        padding-left: 15px;
      }
    }
    &__btn {
      width: 250px;
      height: 40px;
      border-radius: 22px;
      background-color: #dc5454;
      font-size: 13px;
      color: #ffffff;
    }
  }
  .menu-tab {
    width: calc(100% + 50px);
    @media only screen and (max-width: 736px) {
      width: calc(100% + 15px);
    }
    @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
      width: calc(100% + 15px);
    }
    &__section {
      display: block;
    }
    .section {
      &__check {
        padding-right: 15px;
      }

      &__title {
        font-size: 18px;
        font-weight: 600;
        color: #333333;
        border-bottom: 2px solid #f1f1f1;
        padding-bottom: 10px;
        margin: 20px 0;
        text-transform: uppercase;
      }

      &__content {
        font-size: 15px;
        display: flex;
        flex-wrap: wrap;
      }
    }

    .item {
      display: flex;
      flex-direction: row;
      justify-content: flex-start;
      align-items: flex-start;
      width: 33%;
      min-height: 90px;
      padding-right: 49px;
      padding-bottom: 20px;
      position: relative;
      @media only screen and (max-width: 736px) {
        width: 100%;
        padding-right: 15px;
      }
      @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
        width: 50%;
      }

      &__image {
        display: flex;
        flex-direction: row;
        justify-content: center;
        align-items: center;
        min-height: 62px;
        min-width: 70px;
        margin-right: 20px;
        background-color: #ececec;

        img {
          width: 70px;
          height: 62px;
        }
      }

      &__check {
        align-self: center;
        padding-right: 15px;
      }

      &__title {
        font-size: 15px;
        margin-right:15px;
        font-weight: bold;
        font-stretch: normal;
        color: #333333;
        padding-bottom: 10px;
      }

      &__description {
        font-size: 13px;
        color: #9c9696;
        line-height: 1.5;
        display: -webkit-box;
        max-width: 200px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
      }

      &__actions {
        position: absolute;
        width: 100%;
        height: 100%;
        cursor: pointer;
        @media only screen and (max-width: 736px) {
          right: 0px;
        }
        @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) and (-webkit-min-device-pixel-ratio: 1) {
          right: 5px;
        }
      }
    }
  }
`;

function ServiceListTab(props) {
  const {
    loading,
    menuList,
    products = [],
    getMenus,
    editable,
    handleSubmit,
    intl,
  } = props;

  const [form] = Form.useForm();
  const [visible, setVisible] = useState<boolean>(false);
  const [checkboxList, setCheckboxList] = useState({});

  const handleCheckAll = e => {
    const { checked } = e.target;
    let values = {};
    _.forOwn(checkboxList, (value, key) => {
      _.forOwn(value, (value, key) => {
        values = { ...values, [key.toString()]: checked };
      });
    });
    form.setFieldsValue(values);
    setVisible(checked);
  };

  const handleCheckboxGroupChange = e => {
    const { name, checked } = e.target;
    let values = {};
    if (checkboxList[name]) {
      _.forOwn(checkboxList[name], (value, key) => {
        values = { ...values, [key.toString()]: checked };
      });
    }
    form.setFieldsValue(values);
    setVisible(_.some(_.values(form.getFieldsValue()), value => value));
  };

  const onClickSubmit = values => {
    const productIds = _.keys(values)
      .filter(key => values[key])
      .map(key => +key);
    handleSubmit(productIds);
  };

  const onValuesChange = values => {
    setVisible(_.some(form.getFieldsValue(), value => value));
  };

  useEffect(() => {
    const foo = menuList.reduce((acc, cur) => {
      const obj = cur.menuItems.reduce(
        (acc, cur) => ({ ...acc, [_.get(cur, 'products[0]')]: false }),
        {},
      );
      return { ...acc, [cur.categoryId]: obj };
    }, {});
    setCheckboxList(foo);
  }, [menuList]);

  useEffect(() => {
    const initialValues = products
      .map(p => p.id)
      .reduce((acc, cur) => ({ ...acc, [cur]: true }), {});
    if (!_.isEmpty(initialValues)) {
      setVisible(true);
    }
    form.setFieldsValue(initialValues);
  }, [products]);

  return (
    <ServiceListMenuTabWrapper>
      <Form
        form={form}
        onFinish={onClickSubmit}
        onValuesChange={onValuesChange}
      >
        {editable && (
          <div className="menu-select">
            <Checkbox
              name="all"
              className="menu-select__all"
              onChange={handleCheckAll}
            >
              {intl.formatMessage(messages.checkboxProductResTitle)}
            </Checkbox>
            {visible && (
              <Button className="menu-select__btn" htmlType="submit">
                + {intl.formatMessage(messages.addProductIntoCombo)}
              </Button>
            )}
          </div>
        )}
        <div className="menu-tab">
          {loading && (
            <div
              style={{ textAlign: 'center', top: '20px', position: 'relative' }}
            >
              <Spin />
            </div>
          )}
          {menuList &&
            menuList.map(menu => {
              const { menuItems } = menu;
              return (
                menuItems &&
                menuItems.length > 0 &&
                menuItems.every(menuItem => menuItem.products.length < 2) && (
                  <div
                    className="menu-tab__section"
                    key={'section_' + menu.categoryId}
                  >
                    <div className="section__title">
                      {editable && (
                        <span className="section__check">
                          <Checkbox
                            name={menu.categoryId}
                            onChange={handleCheckboxGroupChange}
                          />
                        </span>
                      )}
                      <span>{menu.categoryName}</span>
                    </div>
                    <div className="section__content">
                      {menuItems.map(menuItem => {
                        const {
                          id,
                          photo,
                          name,
                          description,
                          products,
                        } = menuItem;
                        if (products.length > 1) {
                          return null;
                        }
                        const productId = _.get(menuItem, 'products[0]', '');
                        return (
                          <div className="item" key={'menuItem_' + id}>
                            {editable && (
                              <div className="item__check">
                                <Form.Item
                                  name={productId}
                                  valuePropName="checked"
                                >
                                  <Checkbox />
                                </Form.Item>
                              </div>
                            )}
                            <div className="item__image">
                              {photo ? (
                                <img
                                  src={photo ? `${PUBLIC_API}/${photo}` : ''}
                                  style={{ objectFit: 'cover' }}
                                />
                              ) : (
                                <MenuItemIcon />
                              )}
                            </div>
                            <div className="item__content">
                              <div className="item__title">{name}</div>
                              <div className="item__description">
                                {description}
                              </div>
                            </div>
                            <div className="item__actions">
                              <ServiceListAction
                                type="menu"
                                serviceItem={menuItem}
                                getServices={getMenus}
                              />
                            </div>
                          </div>
                        );
                      })}
                    </div>
                  </div>
                )
              );
            })}
        </div>
      </Form>
    </ServiceListMenuTabWrapper>
  );
}
export default injectIntl(ServiceListTab);