import React, { useState } from 'react';
import styled from 'styled-components';
import { Space, Divider, Col, Modal, Typography, notification } from 'antd';
import { EditFilled, DeleteFilled } from '@ant-design/icons';
import CreateEditCommissionCategory from './createEditCommissionCategory';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { makeSelectCommissionSetting } from '../Store/selectors';
import { removeCommission } from '../Store/actions';
import _ from 'lodash';
const stateSelector = createStructuredSelector({
  commissionSetting: makeSelectCommissionSetting(),
});

const CardCommission = styled.div`
  margin: 0px 5px;
  border-radius: 16px;
  border: 1px solid #dddddd;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  width: 100%;
  height: 32px;
  display: flex;
  padding: 0px 5px;
  align-items: center;
  justify-content: center;
  color: white;
  background-color: #4A4A4A;
  :hover {
    width: 100%;
  }
`;

const HovereddCard = styled.div`
  // .anticon:hover {
  //   cursor: pointer;
  //   color: #dc5454;
  // }
`;
const { Title } = Typography;

interface Props {
  commission: any;
  onOpenCreateCommissionModal?: any;
  getCommissionList?: any;
  commissionIdx?: any;
  intl?: any;
}

const HoveredExpand = injectIntl((props: Props) => {
  const { commission, onOpenCreateCommissionModal, commissionIdx, intl } = props;
  const dispatch = useDispatch();
  const { commissionSetting } = useSelector(stateSelector);
  const handleOnClickDelete = async () => {
    Modal.confirm({
      title: (
        <Title level={4}>
          {intl.formatMessage(messages.titleConfirmDeleted, { item: `${commission.name}` })}
        </Title>
      ),
      content: (
        intl.formatMessage(messages.contentConfirmDeleted, { item: `${commission.name}` })
      ),
      okText: (
        intl.formatMessage(messages.deleteBtn)
      ),
      cancelText: (
        intl.formatMessage(messages.cancelBtn)
      ),
      keyboard: true,
      onOk: () => {
        _.remove(
          commissionSetting?.list ? commissionSetting?.list : [],
          (com, index) => index === commissionIdx,
        );
        const newCommission = {...commissionSetting, list: commissionSetting?.list};
        dispatch(removeCommission(newCommission));
      },
    });
  };
  return (
    <HovereddCard>
      <Space size={-5}>
        <EditFilled onClick={() => onOpenCreateCommissionModal()} />
        <Divider type="vertical" />
        <DeleteFilled onClick={() => handleOnClickDelete()} />
      </Space>
    </HovereddCard>
  );
})

export function CommissionCard(props: Props) {
  const { commission, getCommissionList, commissionIdx } = props;
  const [isHovered, setHovered] = useState(false);
  const [openEditCommissionModal, setOpenEditCommissionModal] = useState(false);

  return (
    <Col>
      <CardCommission
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
      >
        <Space>
          <div>{`${commission.name} - ${commission.percent}%`}</div>
          {isHovered && (
            <HoveredExpand
              commission={commission}
              onOpenCreateCommissionModal={() => setOpenEditCommissionModal(true)}
              getCommissionList={getCommissionList}
              commissionIdx={commissionIdx}
          />
          )}
        </Space>
      </CardCommission>
      {openEditCommissionModal && (
        <CreateEditCommissionCategory
          visible={openEditCommissionModal}
          onCancel={() => setOpenEditCommissionModal(false)}
          getCommissionList={getCommissionList}
          isCreate={false}
          commission={commission}
          commissionIdx={commissionIdx}
        />
      )}
    </Col>
  );
}