import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { fetchAPI } from 'utils/fetchAPI';
import { PlusOutlined } from '@ant-design/icons';
import {
  Typography,
  Row,
  Col,
  Button,
  Checkbox,
  Space,
  Form,
  Input,
} from 'antd';
import { CommissionCard } from './cardCommission';
import CreateEditCommissionCategory from './createEditCommissionCategory';
import { injectIntl } from 'react-intl';
import messages from '../I18t/messages';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { setMerchantSetting, setCommissionOpt } from '../Store/actions';
import {
  makeSelectSetting,
  makeSelectFletch,
  makeSelectCommissionSetting,
  makeSelectMerchantSetting,
} from '../Store/selectors';
import messagesGlobal from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createStructuredSelector({
  merchantSetting: makeSelectMerchantSetting(),
  setting: makeSelectSetting(),
  isFletching: makeSelectFletch(),
  commission: makeSelectCommissionSetting(),
});

const CommissionSettingWrapper = styled.div`
  margin-bottom: 20px;
  height: 100%;
  padding: 20px;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 3px 0;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
  }
  .no-commission {
    color: white;
    background-color: #dd3880;
  }
  .commission {
    color: white;
    background-color: #00aaf6;
  }
  div.ant-typography,
  .ant-typography p {
    margin-bottom: 0;
  }
  @media only screen and (min-width: 576px) {
    margin-right: 20px;
  }
`;
const MenuSettingWrapper = styled.div`
  width: 100%;
  padding: 18px;
  height: 100%;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 3px 0;
  }
  .ant-form-item {
    margin-bottom: 0px !important;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
  .ant-input {
    padding: 0px 0px 0px 11px !important;
  }
  .label-input {
    margin-top: 0.75em;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
  }
  .no-payroll {
    color: white;
    background-color: #dd3880;
  }
  .payroll {
    color: white;
    background-color: #00aaf6;
  }
  .form-item-timeUsing {
    margin-bottom: 26px;
  }
  .currency-system {
    width: 100%;
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        width: 75%;
      }
      .ant-space-item:nth-child(2) {
        width: calc(70% + 8px);
      }
      @media only screen and (max-width: 402px) {
        display: inline;
        .ant-space-item:nth-child(1) {
          width: 100%;
          margin-bottom: 15px;
        }
        .ant-space-item:nth-child(2) {
          width: 100%;
        }
      }
    }
  }
`;
const { Title, Paragraph } = Typography;
function CommissionSetting({ intl }) {
  const { commission, setting, isFletching, merchantSetting } = useSelector(
    stateSelector,
  );
  const [openCreateCommissionModal, setOpenCreateCommissionModal] = useState(
    false,
  );
  const [form] = Form.useForm();
  const dispatch = useDispatch();
  const opt: string[] = [];
  commission?.options?.map(option => {
    opt.push(option.type);
  });
  const [optionValues, setOptionValues] = useState(opt);
  const onFinish = values => {
    let opts: { type: string }[] = [];
    optionValues.map(type => {
      const object = { type: type };
      opts.push(object);
    });
    dispatch(
      setMerchantSetting({
        setting: { tip: values.tip },
        commissions: {
          list: commission?.list,
          options: opts ? opts : [],
        },
      }),
    );
  };

  const hanldeChangeOpt = async values => {
    setOptionValues(values);
    dispatch(setCommissionOpt(values));
  };
  useEffect(() => {
    if (setting) {
      form.setFieldsValue({ tip: setting?.tip ? setting?.tip : null });
    }
  }, [setting]);
  return (
    <Form form={form} onFinish={onFinish}>
      <Row gutter={[0, 20]}>
        <Col xl={10} lg={10} md={10} sm={14} xs={24}>
          <CommissionSettingWrapper>
            <div className="setting-menu">
              <Title level={4} className="setting-menu-title">
                {intl.formatMessage(messagesGlobal.commission)}
              </Title>
              <Button
                type="primary"
                shape="circle"
                icon={<PlusOutlined />}
                size="large"
                onClick={() => setOpenCreateCommissionModal(true)}
              />
            </div>
            {/* <Row> */}
            <Row gutter={[0, 20]}>
              <Col className="label-input" xl={6} lg={6} md={6} sm={24} xs={24}>
                <Paragraph className="tax-label">
                  {intl.formatMessage(messagesGlobal.applyFor)}
                </Paragraph>
              </Col>
              <Col xl={18} lg={18} md={18} sm={24} xs={24}>
                {/* <Form.Item name="type"> */}
                <Checkbox.Group value={optionValues} onChange={hanldeChangeOpt}>
                  <Space size={30}>
                    <Checkbox value={2}>
                      {intl.formatMessage(messagesGlobal.service)}
                    </Checkbox>
                    <Checkbox value={1}>
                      {intl.formatMessage(messagesGlobal.product)}
                    </Checkbox>
                  </Space>
                </Checkbox.Group>
                {/* </Form.Item> */}
              </Col>
            </Row>
            <Row gutter={[10, 10]}>
              {(commission?.list ? commission?.list : []).map(
                (commission, index) => (
                  <CommissionCard
                    commission={commission}
                    key={index}
                    commissionIdx={index}
                  />
                ),
              )}
            </Row>
            {openCreateCommissionModal && (
              <CreateEditCommissionCategory
                visible={openCreateCommissionModal}
                onCancel={() => setOpenCreateCommissionModal(false)}
                isCreate={true}
              />
            )}
          </CommissionSettingWrapper>
        </Col>
        <Col xl={6} lg={6} md={8} sm={10} xs={24}>
          <MenuSettingWrapper>
            <Title level={4} className="setting-config">
              {intl.formatMessage(messagesGlobal.tip)}
            </Title>
            <Row className="currency-system">
              <Space align="center">
                <Paragraph className="">
                  {intl.formatMessage(messagesGlobal.titleTimeUsing)}
                </Paragraph>
                <Form.Item
                  name="tip"
                  rules={[
                    {
                      pattern: new RegExp('^[0-9]*$'),
                      message: intl.formatMessage(
                        messagesGlobal.requiredInputNumber,
                      ),
                    },
                  ]}
                  className="form-item-timeUsing"
                >
                  <FloatLabel addonAfter={'%'} />
                </Form.Item>
              </Space>
            </Row>
          </MenuSettingWrapper>
        </Col>
      </Row>
      <Button
        type="primary"
        shape="round"
        size="large"
        htmlType="submit"
        className="btn-save"
      >
        {intl.formatMessage(messagesGlobal.save)}
      </Button>
    </Form>
  );
}
export default injectIntl(CommissionSetting);
