import React, { useState, useRef } from 'react';
import {
  Modal,
  Button,
  Input,
  Form,
  Typography,
  Space,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import messagesLocal from '../I18t/messages';
import styled from 'styled-components';
import { validatePercent } from '../../../utils/validation';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { makeSelectCommissionSetting } from '../Store/selectors';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createStructuredSelector({
  commissionSetting: makeSelectCommissionSetting(),
});
import { addCommission, updateCommission } from '../Store/actions';

const CreateCommissionCategoryWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 15px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
  .ant-input-group-wrapper {
    .ant-input-group {
      input {
        border-right: none;
      }
      .ant-input-group-addon:last-child {
        border-radius: 22px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
        width: 53px;
        background: white;
        border-left: none;
      }
    }
  }
`;
const { Title, Text } = Typography;
interface Props {
  visible: boolean;
  onCancel(): any;
  isCreate: boolean;
  commission?: any;
  intl: any;
  commissionIdx?: any;
}

function CreateCommissionCategory(props: Props) {
  const { visible, onCancel, isCreate, commission, intl, commissionIdx } = props;
  const { commissionSetting } = useSelector(stateSelector);
  const dispatch = useDispatch();
  const [form] = Form.useForm();
  const [loading, setLoading] = useState<boolean>(false);
  const onFinish = async values => {
    if (isCreate) {
      // const newList = commissionSetting?.list ? commissionSetting?.list : ([] as any);
      // newList.push(values);
      // const newCommission = {...commissionSetting, list: newList};
      console.log("commissionSetting ", commissionSetting);
      dispatch(addCommission(values));
    } else {
      // const newList = commissionSetting?.list ? commissionSetting?.list.map((com, index) => index === commissionIdx ? {...com, ...values} : com) : ([] as any).push(values);
      // const newCommission = {...commissionSetting, list: newList};
      dispatch(updateCommission({... !!commission.id && { id: commission.id }, ...values}, commissionIdx));
    }
    onCancel();
  };

  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      layout="horizontal"
      size="middle"
      initialValues={commission ? commission : {}}
    >
      <Modal
        visible={visible}
        onCancel={onCancel}
        width={330}
        centered
        footer={null}
      >
        <CreateCommissionCategoryWrapper>
          <Space direction="vertical" style={{ width: '100%' }}>
            <Title level={4} className="modal-edit__menu--title">
              {isCreate ? (
                <FormattedMessage {...messages.addCommissionCategory} />
              ) : (
                <FormattedMessage {...messages.editCommissionCategory} />
              )}
            </Title>
            <Form.Item
              colon={false}
              name="name"
              rules={[
                { required: true, message: <FormattedMessage {...messages.requiredInput} />},
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messages.commissionName)}`} />
            </Form.Item>
            <Form.Item
              colon={false}
              name="percent"
              rules={[
                {
                  pattern: new RegExp("^\\d+(\\.\\d{1,2})?$"),
                  message: intl.formatMessage(messages.requiredInputNumber) 
                },
                validatePercent]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messagesLocal.percent)}`} addonAfter="%"/>
            </Form.Item>
            <Form.Item>
            <Button
            type="primary"
            htmlType="submit"
            style={{width: '100%'}}
            loading={loading}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}><FormattedMessage {...messages.save} /></Button>
            </Form.Item>
          </Space>
        </CreateCommissionCategoryWrapper>
      </Modal>
    </Form>
  );
}
export default injectIntl(CreateCommissionCategory);