import React, { useEffect, useState, useCallback } from 'react';
import styled from 'styled-components';
import { useDispatch } from 'react-redux';
import { injectIntl } from 'react-intl';
import messages from '../I18t/messages';
import messagesGlobal from 'translations/messages';
import { digits } from 'utils/number';
import { FormatInput } from 'components/FormatInput';
import {
  makeSelectMerchantSetting,
  makeSelectSetting,
} from '../Store/selectors';
import { useCurrencyHook } from '../../../components/CustomHook/useCurrencyHook';
import { useSelector } from 'react-redux';
import { setMerchantSetting } from '../Store/actions';
import { createStructuredSelector } from 'reselect';
import FloatLabel from 'components/FormatInput/FloatLabel';
const stateSelector = createStructuredSelector({
  merchantSetting: makeSelectMerchantSetting(),
  setting: makeSelectSetting(),
});
import { Typography, Input, Button, Form, Row, Col ,Space} from 'antd';
import _ from 'lodash';
const ConfigSettingWrapper = styled.div`
  height: 100%;
  width: 100%;
  margin-left: 1px;
  font-family: Muli;
  input.ant-input,
  .ant-select-selector,
  div.ant-picker {
    min-height: 44px !important;
    align-items: center;
  }
  textarea.ant-input {
    padding: 18px;
    border-radius: 0px;
  }
  span.ant-picker-suffix {
    align-self: initial;
  }
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
  div.ant-picker {
    border-radius: 22px;
  }
  button {
    width: 110px;
    height: 44px;
    border-radius: 22px;
  }
  .path-icon {
    display: none;
  }
  .group {
    padding: 20px;
    margin-bottom: 20px;
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
    background-color: #ffffff;
    .label-input {
      margin-top: 1em;
    }
  }
  .ant-input {
    padding: 0px 0px 0px 11px !important; 
  }
  @media only screen and (min-width: 1380px) {
    .section {
      display: flex;
      align-items: center;
      justify-content: space-between;
      padding: 8px 0 8px 0;
      .ant-typography {
        margin-bottom: 0;
      }
      .ant-form-item {
        margin-bottom: 0 !important;
      }
      &__item {
        white-space: nowrap;
      }
      &__item--small {
        margin-right: 10px;
        width: 130px;
      }
    }
    .section--no-padding {
      display: flex;
      align-items: center;
      justify-content: space-between;
      padding: 8px 0;
      .ant-typography {
        margin-bottom: 0;
      }
      .ant-form-item {
        margin-bottom: 0 !important;
      }
      .km {
        width: 105px;
      }
      .currency {
        width: 160px;
      }
      .path-icon {
        display: block;
      }

      .fee-from {
        &__title {
          flex-basis: 40px;
        }
      }
    }
  }
  @media only screen and (min-width: 992px) {
    width: 40%;
  }
  @media only screen and (min-width: 786px) {
    width: 70%;
  }
  @media only screen and (min-width: 1200px) {
    width: 30%;
  }
  .currency-system {
    width: 100%;
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        width: 75%;
      }
      .ant-space-item:nth-child(2) {
        width: calc(70% + 8px);
      }
      @media only screen and (max-width: 402px) {
        display: inline;
        .ant-space-item:nth-child(1) {
          width: 100%;
          margin-bottom: 15px;
        }
        .ant-space-item:nth-child(2) {
          width: 100%;
        }
      }
    }
  }
`;

const { Title, Paragraph } = Typography;

const messageSuccess = [
  'Chỉnh sửa cài đặt thành công',
  'Settings have been updated',
];
const messageFail = ['Chỉnh sửa cài đặt thất bại', 'Edit setting was failed'];

interface Props {
  intl: any;
  messages: any;
}

function CustomerServiceSetting(props: Props) {
  const { intl } = props;
  const [loading, setLoading] = useState<boolean>(false);
  const dispatch = useDispatch(); // eslint-disable-line @typescript-eslint/no-unused-vars
  const { setting } = useSelector(stateSelector);
  const [form] = Form.useForm();

  const currencyMemoi = useCurrencyHook();

  const onFinish = values => {
    dispatch(setMerchantSetting({ setting: { ...values } }));
  };
  useEffect(() => {
    if (setting) {
      form.setFieldsValue(setting);
    }
  }, [setting]);
  return (
    <ConfigSettingWrapper>
      <Form form={form} style={{ height: '100%' }} onFinish={onFinish}>
        <div className="group">
          <Title level={4} className="setting-config">
            {intl.formatMessage(messages.exchangePoint)}
          </Title>
          <Row className="currency-system">
            <Space align="center">
              <Paragraph className="">
                {intl.formatMessage(messages.amount)}
              </Paragraph>
              <Form.Item
                className="section__item ex-money"
                name="moneyExchanged"
                rules={[
                  {
                    pattern: new RegExp('^[0-9,]*$'),
                    message: intl.formatMessage(
                      messagesGlobal.requiredInputNumber,
                    ),
                  },
                ]}
              >
                <FormatInput
                  formatter={digits}
                  addonAfter={currencyMemoi}
                />
              </Form.Item>
              {/* </Col> */}
            </Space>
          </Row>
          <Row className="currency-system">
            <Space align="center">
              <Paragraph className="">
                {intl.formatMessage(messages.point)}
              </Paragraph>
              <Form.Item
                name="pointExchanged"
                rules={[
                  {
                    pattern: new RegExp('^[0-9]*$'),
                    message: intl.formatMessage(
                      messagesGlobal.requiredInputNumber,
                    ),
                  },
                ]}
              >
                <FloatLabel 
                 />
              </Form.Item>
            </Space>
          </Row>
        </div>
        <Button
          type="primary"
          shape="round"
          size="large"
          loading={loading}
          htmlType="submit"
          className="btn-save"
        >
          {intl.formatMessage(messagesGlobal.save)}
        </Button>
      </Form>
    </ConfigSettingWrapper>
  );
}
export default injectIntl(CustomerServiceSetting);
