import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { IngredientModel } from '../../Store/types';
import { Space, Divider, Col, Modal, Typography } from 'antd';
import { EditFilled, DeleteFilled } from '@ant-design/icons';
import { PRODUCTS_INGREDIENTS_BY_ID_URL, PRODUCTS_MEASURE_UNIT_URL } from 'containers/App/urls';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import CreateEditIngredient from '../Modal/createEditIngredient';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';
import { removeIngredient } from '../../Store/actions';
import { useDispatch } from 'react-redux';

const CardIngredient = styled.div`
  margin: 0px 5px;
  border-radius: 16px;
  border: 1px solid #dddddd;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  width: 100%;
  height: 32px;
  display: flex;
  padding: 0px 5px;
  align-items: center;
  justify-content: center;
  color: white;
  background-color: #4A4A4A;
  :hover {
    width: 100%;
  }
`;

const HovereddCard = styled.div`
`;
const { Title } = Typography;

interface Props {
  ingredient: IngredientModel;
  onOpenCreateMenuModal?: any;
  getIngredients?: any;
  measureUnits?: any;
  intl?: any;
  index?: any;
}

const HoveredExpand = injectIntl((props: Props) => {
  const { ingredient, onOpenCreateMenuModal, getIngredients, intl, index } = props;
  const dispatch = useDispatch();
  const handleOnClickDelete = async () => {
    Modal.confirm({
      title: (
        <Title level={4}>
          {intl.formatMessage(messages.titleConfirmDeleted, { item: `${ingredient.name}` })}
        </Title>
      ),
      content: (
        intl.formatMessage(messages.contentConfirmDeleted, { item: `${ingredient.name}` })
      ),
      okText: (
        intl.formatMessage(messages.deleteBtn)
      ),
      cancelText: (
        intl.formatMessage(messages.cancelBtn)
      ),
      keyboard: true,
      onOk: async () => {
        dispatch(removeIngredient(index));
      },
    });
  };
  return (
    <HovereddCard>
      <Space size={-5}>
        <EditFilled onClick={() => onOpenCreateMenuModal()} />
        <Divider type="vertical" />
        <DeleteFilled onClick={() => handleOnClickDelete()} />
      </Space>
    </HovereddCard>
  );
})

export function IngredientCard(props: Props) {
  const { ingredient , getIngredients, measureUnits, index } = props;
  const [isHovered, setHovered] = useState(false);
  const [openEditMenuModal, setOpenEditMenuModal] = useState(false);
  return (
    <Col>
      <CardIngredient
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
      >
        <Space>
          <div>{`${ingredient.name}`}</div>
          {isHovered && (
            <HoveredExpand
              ingredient={ingredient}
              onOpenCreateMenuModal={() => setOpenEditMenuModal(true)}
              getIngredients={getIngredients}
              index={index}
            />
          )}
        </Space>
      </CardIngredient>
      {openEditMenuModal && (
        <CreateEditIngredient
          visible={openEditMenuModal}
          onCancel={() => setOpenEditMenuModal(false)}
          getIngredients={getIngredients}
          isCreate={false}
          ingredient={ingredient}
          measureUnits={measureUnits}
          index={index}
        />
      )}
    </Col>
  );
}
