import React, { useState } from 'react';
import styled from 'styled-components';
import { PreparationGroupModel, PreparationItemModel } from '../../Store/types';
import {
  Space,
  Divider,
  Col,
  Modal,
  Typography,
} from 'antd';
import { EditFilled, DeleteFilled } from '@ant-design/icons';
import { fetchAPI, replaceUrl} from 'utils/fetchAPI';
import { PRODUCTS_COOKING_REQUEST_GROUP_BY_ID_URL } from 'containers/App/urls';
import CreateEditPreparation from '../Modal/createEditPreparation';
import { FormattedMessage, injectIntl } from 'react-intl';
import { removeCookingRequestGroup } from '../../Store/actions';
import { useDispatch } from 'react-redux';

const PreparationCardWrapper = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 10px 0;
  overflow: auto;
  @media screen and (min-width: 1200px) {
    .setting-preparation-col {
      top: 10px;
      .setting-preparation-title {
      }
    }
  }
  .setting-preparation-title {
    flex-basis: 10%;
    min-width: 20%;
  }
  .cooking-request {
    flex: 1;
    display: flex;
    flex-wrap: wrap;
    align-items: space-between;
    justify-content: flex-start;
  }
`;

const PreparationElementWrapper = styled.div`
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 8px 20px;
  margin: 0px 5px 8px;
  border-radius: 16px;
  border: 1px solid #dddddd;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  height: 32px;
  span {
    max-width: 100px;
    display: inline-block;
    overflow: hidden;
    white-space: nowrap;
  }
`;

const HovereddCard = styled.div`
  text-align: end;
  flex-basis: 80px;
  .anticon:hover {
    cursor: pointer;
    color: #dc5454;
  }
`;

const { Text } = Typography;

interface Props {
  preparation: PreparationGroupModel;
  onOpenCreatePreparationModal?: any;
  preparationItem?: PreparationItemModel;
  getPreparationList?: any;
  lastIndex?: number;
  index?: number;
  messages?: any;
  intl?: any;
}

function PreparationElement(props) {
  const { preparationItem } = props;
  return (
    <PreparationElementWrapper>
      <span>{preparationItem.name}</span>
    </PreparationElementWrapper>
  );
}
const HoveredExpand = injectIntl((props: Props) => {
  const {
    preparation,
    onOpenCreatePreparationModal,
    getPreparationList,
    messages,
    index,
    intl
  } = props;
  const dispatch = useDispatch();
  const handleOnClickDelete = async () => {
    Modal.confirm({
      title: intl.formatMessage(messages.titleConfirmDeleted, { item: `${preparation.name}` }),
      content: intl.formatMessage(messages.contentConfirmDeleted, { item: `${preparation.name}` }),
      okText: intl.formatMessage(messages.deleteBtn),
      cancelText: intl.formatMessage(messages.cancelBtn),
      keyboard: true,
      onOk: async () => {
        dispatch(removeCookingRequestGroup(index));
      },
    });
  };
  return (
    <HovereddCard>
      <Space size={-5}>
        <EditFilled onClick={() => onOpenCreatePreparationModal()} />
        <Divider type="vertical" />
        <DeleteFilled onClick={() => handleOnClickDelete()} />
      </Space>
    </HovereddCard>
  );
})

export function CardPreparation(props: Props) {
  const { preparation, getPreparationList, lastIndex, index, messages } = props;
  const { cookingRequests } = preparation;
  const [openEditPreparationModal, setOpenEditPreparationModal] = useState(
    false,
  );

  return (
    <Col style={{width: '100%'}}>
      <PreparationCardWrapper>
        <Text className="setting-preparation-title">
          {preparation.name}
        </Text>
        <div className="cooking-request">
          {cookingRequests.map((preparationItem, index) => (
            <PreparationElement preparationItem={preparationItem} key={index} />
          ))}
        </div>
        <HoveredExpand
          preparation={preparation}
          onOpenCreatePreparationModal={() =>
            setOpenEditPreparationModal(true)
          }
          getPreparationList={getPreparationList}
          messages={messages}
          index={index}
        />
      </PreparationCardWrapper>
      {index !== ((lastIndex ? lastIndex : 1) - 1) && <Divider />}
      {openEditPreparationModal && (
        <CreateEditPreparation
          visible={openEditPreparationModal}
          onCancel={() => setOpenEditPreparationModal(false)}
          getPreparationList={getPreparationList}
          isCreate={false}
          preparation={preparation}
          messages={messages}
        />
      )}
    </Col>
  );
}
