import React, { useState, useRef } from 'react';
import {
  Modal,
  Button,
  Input,
  Form,
  Typography,
  Space,
  Select
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import styled from 'styled-components';
import { fetchAPI, replaceUrl } from 'utils/fetchAPI';
import { PRODUCTS_INGREDIENTS_URL, PRODUCTS_INGREDIENTS_BY_ID_URL } from 'containers/App/urls';
import { IngredientModel } from '../../Store/types';
import { addIngredient, updateIngredient } from '../../Store/actions';
import { useDispatch } from 'react-redux';
import FloatLabel from 'components/FormatInput/FloatLabel';

const CreateEditIngredientWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 16px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
  .ant-input-group-wrapper {
    .ant-input-group {
      input {
        border-right: none;
      }
      .ant-input-group-addon:last-child {
        border-radius: 22px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
        width: 53px;
        background: white;
        border-left: none;
      }
    }
  }
`;
const { Title, Text } = Typography;
interface Props {
  visible: boolean;
  onCancel(): any;
  getIngredients: any;
  isCreate: boolean;
  ingredient: IngredientModel;
  measureUnits: any;
  intl: any;
  index?: any;
}

function CreateEditIngredient(props: Props) {
  const { visible, onCancel, getIngredients, isCreate, ingredient, intl, measureUnits, index } = props;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState<boolean>(false);
  const dispatch = useDispatch();
  const onFinish = async values => {
    if (ingredient) {
      dispatch(updateIngredient({id: ingredient.id, ...values}, index))
    } else {
      dispatch(addIngredient(values))
    }
    onCancel();
  };

  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      layout="horizontal"
      size="middle"
      initialValues={ingredient ? ingredient : {}}
    >
      <Modal
        visible={visible}
        onCancel={onCancel}
        width={330}
        centered
        footer={null}
      >
        <CreateEditIngredientWrapper>
          <Space direction="vertical" style={{ width: '100%' }}>
            <Title level={4} className="modal-edit__menu--title">
              {isCreate ? (
                <FormattedMessage {...messages.addIngredient} />
              ) : (
                <FormattedMessage {...messages.editIngredient} />
              )}
            </Title>
            <Form.Item
              colon={false}
              name="name"
              rules={[
                { required: true, message: <FormattedMessage {...messages.requiredInput} />},
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messages.ingredientName)}`} />
            </Form.Item>
            <Form.Item
                name="measureUnitId"
                rules={[
                  {
                    required: true,
                    message: `${intl.formatMessage(
                      messages.requiredInput,
                    )} ${intl
                      .formatMessage(messages.unit)
                      .toLowerCase()}`,
                  },
                ]}
              >
                <FloatLabel
                  size="large"
                  label={intl.formatMessage(messages.unit)}
                  showArrow
                  typeInput="selectMutil"
                  items={measureUnits}
                />
              </Form.Item>
            <Form.Item>
            <Button
            type="primary"
            htmlType="submit"
            style={{width: '100%'}}
            loading={loading}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}><FormattedMessage {...messages.save} /></Button>
            </Form.Item>
          </Space>
        </CreateEditIngredientWrapper>
      </Modal>
    </Form>
  );
}
export default injectIntl(CreateEditIngredient);