import React from 'react';
import {
  Modal,
  Button,
  Input,
  Form,
  Typography,
  Space,
} from 'antd';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import messageLocal from '../../I18t/messages';
import styled from 'styled-components';
import { MenuModel } from '../../Store/types';
import { injectIntl } from "react-intl";
import { addCategory, updateCategory } from '../../Store/actions';
import { useDispatch } from 'react-redux';
import FloatLabel from 'components/FormatInput/FloatLabel';


const CreateMenuCategoryWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 15px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
`;
const { Title, Text } = Typography;
interface Props {
  visible: boolean;
  onCancel(): any;
  getMenuList: any;
  isCreate: boolean;
  menu?: MenuModel;
  intl: any;
  index?: any;
}

function CreateEditMenuCategory(props: Props) {
  const { visible, onCancel, isCreate, menu, intl, index } = props;
  const [form] = Form.useForm();
  const dispatch = useDispatch();
  const onFinish = async values => {
    if (menu) {
      dispatch(updateCategory({id: menu.id, ...values}, index))
    } else {
      dispatch(addCategory(values))
    }
    onCancel();
  };

  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      layout="horizontal"
      size="middle"
      initialValues={menu ? menu : {}}
    >
      <Modal
        visible={visible}
        onCancel={onCancel}
        width={330}
        centered
        footer={null}
      >
        <CreateMenuCategoryWrapper>
          <Space direction="vertical" style={{ width: '100%' }}>
            <Title level={4} className="modal-edit__menu--title">
              {isCreate ? (
                <FormattedMessage {...messages.addMenuCategory} />
              ) : (
                <FormattedMessage {...messages.editMenuCategory} />
              )}
            </Title>
            <Form.Item
              colon={false}
              name="name"
              rules={[
                { required: true, message:  intl.formatMessage(messageLocal.requiredCategoryName) },
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={intl.formatMessage(messageLocal.name)} />
            </Form.Item>
            <Form.Item>
            <Button
            type="primary"
            htmlType="submit"
            style={{width: '100%'}}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}>{intl.formatMessage(messages.save)}</Button>
            </Form.Item>
          </Space>
        </CreateMenuCategoryWrapper>
      </Modal>
    </Form>
  );
}
export default injectIntl(CreateEditMenuCategory);