import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { Typography, Form, Row, Col, AutoComplete, Input } from 'antd';
import { injectIntl } from 'react-intl';
import messages from '../../I18t/messages';
import messagesGlobal from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';
const MenuSettingWrapper = styled.div`
  width: 100%;
  margin-bottom: 20px;
  padding: 20px;
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 3px 0;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
  .label-input {
    margin-top: 0.75em;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
    color: rgba(0, 0, 0, 0.85);
    font-weight: 600;
    font-size: 20px;
    line-height: 1.4;
  }
  .no-payroll {
    color: white;
    background-color: #dd3880;
  }
  .payroll {
    color: white;
    background-color: #00aaf6;
  }
`;

const { Title, Paragraph } = Typography;
function GeneralSetting({ setting, intl }) {

  return (
    <MenuSettingWrapper>
        <Title level={4} className="setting-config">
          {intl.formatMessage(messagesGlobal.general)}
        </Title>
        <Row gutter={24}>
          <Col style={{width: '100% '}}>
            <Row>
              <Col
                className="label-input"
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
              >
                <Paragraph className="tax-label">
                  {intl.formatMessage(messages.timeAverageService)}
                </Paragraph>
              </Col>
              <Col xl={12} lg={12} md={12} sm={12} xs={12}>
                <Form.Item
                  name="serveDuration"
                  className="section__item--small"
                  rules={[
                    {
                      pattern: new RegExp('^[0-9]*$'),
                      message: intl.formatMessage(messages.requiredNumber),
                    },
                  ]}
                >
                  <FloatLabel
                    addonAfter={intl.formatMessage(messages.minute)}
                    label="20"
                  />
                </Form.Item>
              </Col>
            </Row>
            <Row>
              <Col
                className="label-input"
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
              >
                <Paragraph className="tax-label">
                  {intl.formatMessage(messages.warning)}
                </Paragraph>
              </Col>
              <Col xl={12} lg={12} md={12} sm={12} xs={12}>
                <Form.Item
                  className="section__item--small"
                  name="warningPercent"
                  rules={[
                    {
                      pattern: new RegExp('^[0-9]*$'),
                      message: intl.formatMessage(messages.requiredNumber),
                    },
                  ]}
                >
                  <FloatLabel addonAfter="%" label="0" />
                </Form.Item>
              </Col>
            </Row>
          </Col>
        </Row>
    </MenuSettingWrapper>
  );
}
export default injectIntl(GeneralSetting);
