import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { fetchAPI } from 'utils/fetchAPI';
import { PRODUCTS_INGREDIENTS_URL, PRODUCTS_MEASURE_UNIT_URL } from 'containers/App/urls';
import { PlusOutlined } from '@ant-design/icons';
import { Typography, Row, Button } from 'antd';
import { IngredientCard } from '../Detail/cardIngredient';
import CreateEditIngredient from '../Modal/createEditIngredient';
import { injectIntl } from "react-intl";
import { useDispatch } from 'react-redux';
import { getIngredientConfig } from '../../Store/actions';
import messagesGlobal from "translations/messages";
const TaxSettingWrapper = styled.div`
  margin-bottom: 20px;
  width: 100%;
  padding: 12px;
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 3px 0;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1
  }
`;
const { Title } = Typography;
function IngredientSetting({ ingredients, measureUnits, intl }) {
  const [openCreateMenuModal, setOpenCreateMenuModal] = useState(false);
  const dispatch = useDispatch();
  const getIngredients = async () => {
    dispatch(getIngredientConfig());
  };
  return (
    <TaxSettingWrapper>
      <div className="setting-menu">
        <Title level={4} className="setting-menu-title">
         {intl.formatMessage(messagesGlobal.ingredients)}
        </Title>
        <Button
          type="primary"
          shape="circle"
          icon={<PlusOutlined />}
          size="large"
          onClick={() => setOpenCreateMenuModal(true)}
        />
      </div>
      <Row gutter={[10, 10]}>
        {ingredients.map((ingredient, index) => (
          <IngredientCard ingredient={ingredient} key={index} getIngredients={getIngredients} measureUnits={measureUnits} index={index}/>
        ))}
      </Row>
      {openCreateMenuModal && (
        <CreateEditIngredient
          visible={openCreateMenuModal}
          onCancel={() => setOpenCreateMenuModal(false)}
          getIngredients={getIngredients}
          isCreate={true}
          measureUnits={measureUnits}
        />
      )}
    </TaxSettingWrapper>
  );
}
export default injectIntl(IngredientSetting);