import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { PlusOutlined } from '@ant-design/icons';
import { injectIntl } from "react-intl";
import { Typography, Row, Button } from 'antd';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { MenuCard } from '../Detail/cardMenu';
import CreateEditMenuCategory from '../Modal/createEditMenuCategory';
import { getMenuConfig } from '../../Store/actions';
const MenuSettingWrapper = styled.div`
  margin-bottom: 20px;
  width: 100%;
  padding: 12px;
  background-color: rgb(255, 255, 255);
  .ant-card {
    border-radius: 0px;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
    h4 {
      flex: 1
    }
  }
`;
const { Title } = Typography;
function MenuSetting(props) {
  const {  messages ,intl, categories} = props;
  const [openCreateMenuModal, setOpenCreateMenuModal] = useState(false);
  const dispatch = useDispatch();
  const getMenuList = async () => {
    dispatch(getMenuConfig());
  };

  return (
    <MenuSettingWrapper>
        <div className="setting-menu">
          <Title level={4} className="setting-menu-title">
            {intl.formatMessage(messages.category)}
          </Title>
          <Button
            type="primary"
            shape="circle"
            icon={<PlusOutlined />}
            size="large"
            onClick={() => setOpenCreateMenuModal(true)}
          />
        </div>
        <Row gutter={[10, 10]}>
          {categories.map((menu, index) => (
            <MenuCard menu={menu} key={index} getMenuList={getMenuList} messageLocal={messages} index={index}/>
          ))}
        </Row>
      {openCreateMenuModal && (
        <CreateEditMenuCategory
          visible={openCreateMenuModal}
          onCancel={() => setOpenCreateMenuModal(false)}
          getMenuList={getMenuList}
          isCreate={true}
        />
      )}
    </MenuSettingWrapper>
  );
}
export default injectIntl(MenuSetting);