import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { PlusOutlined } from '@ant-design/icons';
import { Typography, Card, Row, Button } from 'antd';
import { CardPreparation} from '../Detail/cardPreparation';
import { injectIntl } from "react-intl";
import { useDispatch } from 'react-redux';
import { getIngredientConfig } from '../../Store/actions';
import messagesGlobal from "translations/messages";
import messagesLocal from "../../I18t/messages";
import CreateEditPreparation from '../Modal/createEditPreparation';
const PreparationSettingWrapper = styled.div`
  box-shadow: rgba(0, 0, 0, 0.1) 0px 1px 3px 0px;
  background-color: rgb(255, 255, 255);
  .ant-card {
    border-radius: 0px;
    .ant-card-body {
      padding: 12px;
    }
    .ant-divider.ant-divider-horizontal {
      margin: 3px 0;
    }
    button {
      span {
        display: inline-flex;
      }
    }
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
    h4 {
      flex: 1
    }
  }
`;
const { Title } = Typography;
function PreparationSetting(props) {
  const { messages, preparations, intl } = props;
  const [openCreatePreparationModal, setOpenCreatePreparationModal] = useState(false);
  const dispatch = useDispatch();
  const getPreparationList = async () => {
    dispatch(getIngredientConfig());
  };

  return (
    <PreparationSettingWrapper>
      <Card bordered={false} style={{ width: '100%', height: '100%' }}>
        <div className="setting-menu">
          <Title level={4} className="setting-menu-title">
            {intl.formatMessage(messagesLocal.methodOfPreparation)}
          </Title>
          <Button
            type="primary"
            shape="circle"
            icon={<PlusOutlined />}
            size="large"
            onClick={() => setOpenCreatePreparationModal(true)}
          />
        </div>
        <Row>
          {preparations.map((preparation, index) => (
            <CardPreparation preparation={preparation} key={index} getPreparationList={getPreparationList} lastIndex={preparations.length} index={index} messages={messagesGlobal}/>
          ))}
        </Row>
      </Card>
      {openCreatePreparationModal && (
        <CreateEditPreparation
          visible={openCreatePreparationModal}
          onCancel={() => setOpenCreatePreparationModal(false)}
          getPreparationList={getPreparationList}
          isCreate={true}
          messages={messages}
        />
      )}
    </PreparationSettingWrapper>
  );
}
export default injectIntl(PreparationSetting);