import React, { useEffect } from 'react';
import {
  Row,
  Col,
  Form,
  Button,
  Spin,
} from 'antd';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from '../Store/reducer';
import saga from '../Store/saga';
import { setMerchantSetting } from '../Store/actions';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import {
  makeSelectSetting,
  makeSelectFletch,
  makeSelectMeasureUnits,
  makeSelectCategories,
  makeSelectIngredients,
  makeSelectCookingRequestGroups,
  makeSelectMerchantSetting,
} from '../Store/selectors';
import MenuSetting from './SettingCard/menuSetting';
const stateSelector = createStructuredSelector({
  setting: makeSelectSetting(),
  isFletching: makeSelectFletch(),
  measureUnits: makeSelectMeasureUnits(),
  categories: makeSelectCategories(),
  ingredients: makeSelectIngredients(),
  cookingRequestGroups: makeSelectCookingRequestGroups(),
  merchantSetting: makeSelectMerchantSetting(),
});

function Menu(props) {
  const { intl } = props;
  useInjectReducer({ key: 'setting', reducer: reducer });
  useInjectSaga({ key: 'setting', saga: saga });
  const dispatch = useDispatch();
  const {
    setting,
    isFletching,
    measureUnits,
    categories,
    ingredients,
    cookingRequestGroups,
    merchantSetting,
  } = useSelector(stateSelector);
  const [form] = Form.useForm();

  useEffect(() => {
    if (setting) {
      form.setFieldsValue({
        serveDuration: setting.serveDuration,
        warningPercent: setting.warningPercent,
      });
    }
  }, [setting]);

  const onFinish = values => {
    dispatch(
      setMerchantSetting({
        ...values,
        ingredients,
        cookingRequestGroups,
        menuCategories: categories,
      }),
    );
  };
  return (
    <Spin spinning={isFletching}>
      <div
        style={{ paddingTop: 'unset' }}
        className="setting__group setting__group-third"
      >
        <Form form={form} onFinish={onFinish}>
          <div className="group" style={{marginBottom: 20}}>
            <Row gutter={12}>
              <Col xs={24} sm={11} md={11} lg={11} xl={11}>
                <Row>
                  <div className="first-box">
                    <MenuSetting messages={messages} categories={categories} />
                  </div>
                </Row>
              </Col>
            </Row>
          </div>
          <div className="row">
            <div className="col-11 col-md-11">
              <div className="setting__group-third__content setting__group-third__content-second">
                <Button
                  type="primary"
                  className="custormButton"
                  htmlType="submit"
                  size="large"
                >
                  {intl.formatMessage(messages.save)}
                </Button>
              </div>
            </div>
          </div>
        </Form>
      </div>
    </Spin>
  );
}
export default injectIntl(Menu);
