import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { PlusOutlined, CalendarOutlined } from '@ant-design/icons';
import messages from '../I18t/messages';
import { RemoveSettingCharacter } from 'styles/icon-components';
import messagesGlobal from 'translations/messages';
import { Typography, Select, Button, Form, Input, DatePicker } from 'antd';
import { DATE_FORMAT } from 'utils/constants';
import { injectIntl } from 'react-intl';
import FloatLabel from 'components/FormatInput/FloatLabel';

const PreparationSettingWrapper = styled.div`
  margin-bottom: 20px;
  padding: 20px;
  background-color: #ffffff;
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  .working {
    .ant-row.dayOfWeeks-select {
      width: 100%;
    }
    .ant-picker {
      width: 100%;
      height: 44px;
    }
    display: flex;
    justify-content: space-between;
    align-items: flex-start;
    padding-right: 10px;
    img {
      cursor: pointer;
      width: 18px;
      height: 21px;
    }
    .ant-form-item {
      margin-bottom: unset;
      margin-bottom: unset;
      .ant-form-item-control {
        margin-right: 10px;
      }
    }
    .ant-picker {
      border-radius: 22px;
    }
    .form-action {
      display: flex;
      margin-top: 9px;
    }
  }
  button {
    span {
      display: inline-flex;
    }
  }
  .setting-menu {
    > h4 {
      width: calc(99% - 34px);
    }
  }
  .working {
    > .ant-row.dayOfWeeks-select {
      width: 30%;
    }
    > .ant-row.dayOfWeeks-select:nth-child(3) {
      width: 40%;
    }
  }
`;
const { Title } = Typography;

function CloseTimeSetting(props) {
  const { intl, handleChangeStart, form } = props;
  return (
    <PreparationSettingWrapper>
      <Form form={form} name="form-2">
        <Form.List name="closeTimes">
          {(fields, { add, remove }) => (
            <div>
              <div className="setting-menu">
                <Title level={4} className="setting-menu-title">
                  {intl.formatMessage(messages.timeToClose)}
                </Title>
                <Button
                  type="primary"
                  shape="circle"
                  icon={<PlusOutlined />}
                  size="large"
                  onClick={() => add()}
                />
              </div>
              {fields.map(field => (
                <div className="working">
                  <Form.Item
                    name={
                      field
                        ? [field.name, 'fromDay']
                        : ['workingHours', '0', 'fromDay']
                    }
                    rules={[
                      {
                        required: true,
                        message: intl.formatMessage(
                          messagesGlobal.requiredInput,
                        ),
                      },
                      ({ getFieldValue }) => ({
                        validator(rule, value) {
                          const startDateValue = getFieldValue('closeTimes');
                          const startDates = startDateValue.filter(sd => {
                            if (sd !== undefined && sd.fromDay !== value)
                              return sd;
                          });
                          let isGreater = false;
                          startDates.map(sD => {
                            const date1 = new Date(sD.fromDay);
                            const date2 = new Date(value);
                            if (
                              date1.getFullYear() == date2.getFullYear() &&
                              date1.getMonth() == date2.getMonth() &&
                              date1.getDate() == date2.getDate()
                            ) {
                              isGreater = true;
                            }
                          });
                          if (!value || !startDateValue || !isGreater) {
                            return Promise.resolve();
                          }
                          return Promise.reject(
                            intl.formatMessage(
                              messages.closingDaysCantBeTheSame,
                            ),
                          );
                        },
                      }),
                    ]}
                    className="dayOfWeeks-select"
                  >
                    <FloatLabel
                      label={intl.formatMessage(messages.fromDate)}
                      className="fw"
                      format={DATE_FORMAT}
                      typeInput="datepicker"
                    />
                  </Form.Item>
                  <Form.Item
                    name={[field.name, 'toDay']}
                    className="dayOfWeeks-select"
                    rules={[
                      ({ getFieldValue }) => ({
                        validator(rule, value) {
                          const getValue = getFieldValue('closeTimes');
                          ;
                          const startDateValue =getValue[field.name].fromDay;
                          if (
                            !value ||
                            !startDateValue ||
                            startDateValue.isBefore(value)
                          ) {
                            return Promise.resolve();
                          }
                          return Promise.reject(
                            intl.formatMessage(messages.endDateAfterStartDate),
                          );
                        },
                      }),
                      ({ getFieldValue }) => ({
                        validator(rule, value) {
                          const endDateValue = getFieldValue('closeTimes');
                          const endDates = endDateValue.filter(ed => {
                            if (ed !== undefined && ed.toDay !== value)
                              return ed;
                          });
                          let isEqual = false;
                          endDates.map(ed => {
                            const date1 = new Date(ed.toDay);
                            const date2 = new Date(value);
                            if (
                              date1.getFullYear() == date2.getFullYear() &&
                              date1.getMonth() == date2.getMonth() &&
                              date1.getDate() == date2.getDate()
                            ) {
                              isEqual = true;
                            }
                          });
                          if (!value || !endDateValue || !isEqual) {
                            return Promise.resolve();
                          }
                          return Promise.reject(
                            intl.formatMessage(
                              messages.closingDaysCantBeTheSame,
                            ),
                          );
                        },
                      }),
                    ]}
                  >
                    <FloatLabel
                      label={intl.formatMessage(messages.toDate)}
                      className="fw"
                      format={DATE_FORMAT}
                      typeInput="datepicker"
                    />
                  </Form.Item>
                  <Form.Item
                    name={[field.name, 'description']}
                    className="dayOfWeeks-select"
                  >
                    <FloatLabel
                      label={intl.formatMessage(messages.description)}
                    />
                  </Form.Item>
                  <div className="form-action">
                    <span onClick={() => remove(field.name)}>
                      <RemoveSettingCharacter />
                    </span>
                  </div>
                </div>
              ))}
            </div>
          )}
        </Form.List>
      </Form>
    </PreparationSettingWrapper>
  );
}
export default injectIntl(CloseTimeSetting);
