import React, { useState, useEffect } from 'react';
import {
  Radio,
  Space,
  Row,
  Col,
  Typography,
  Form,
  AutoComplete,
  Button,
  notification,
  Spin,
} from 'antd';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';
import { setMerchantSetting } from '../Store/actions';
import { currencies, LANGUAGE_API, LANGUAGE } from 'utils/constants';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from '../Store/reducer';
import saga from '../Store/saga';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import moment from 'moment';
// import { getAdminConfig } from '../store/actions';
import {
  makeSelectOpenTimes,
  makeSelectCloseTimes,
  makeSelectWorkingTimes,
  makeSelectFletch,
} from '../Store/selectors';
import { changeLocale } from '../../LanguageProvider/actions';
import { FormatInput } from 'components/FormatInput';
import WorkingTimeSetting from './workingTimeSetting';
import CloseTimeSetting from './closeTimeSetting';
import OpenTimeSetting from './openTimeSetting';
const { Title } = Typography;
const stateSelector = createStructuredSelector({
  openTimes: makeSelectOpenTimes(),
  closeTimes: makeSelectCloseTimes(),
  workingTimes: makeSelectWorkingTimes(),
  isFetching: makeSelectFletch(),
});

function General(props) {
  const { intl } = props;
  useInjectReducer({ key: 'setting', reducer: reducer });
  useInjectSaga({ key: 'setting', saga: saga });
  const dispatch = useDispatch();
  const { openTimes, closeTimes, workingTimes, isFetching } = useSelector(
    stateSelector,
  );
  const [form] = Form.useForm();

  const handleChangeStart = e => {
    let workingHours = form.getFieldValue('openTimes');
    console.log("workingHours ", workingHours);
    workingHours = workingHours.map(w => {
      if ((w.fromDay > w.toDay) && w.toDay !== 0) {
        w.toDay = w.fromDay;
      }
      return w;
    });
    form.setFieldsValue({ openTimes: workingHours });
  };

  const onFinish = values => {
    dispatch(
      setMerchantSetting({
        merchantCloseTimes: values.closeTimes,
        merchantOpenTimes: values.openTimes,
        merchantWorkingTimes: values.workingTimes,
      }),
    );
  };

  const handleChangeWorkingStart = e => {
    let workingHours = form.getFieldValue('workingTimes');
    workingHours = workingHours.map(w => {
      if ((w.fromDay && !w.toDay) || w.fromDay > w.toDay) {
        w.toDay = w.fromDay;
      }
      return w;
    });
    form.setFieldsValue({ workingTimes: workingHours });
  };

  useEffect(() => {
    if (openTimes && openTimes?.length > 0) {
      const newTimeList = openTimes.map(working => {
        const openingTimeSpilit = working.openingTime.split(':');
        const closingTimeSpilit = working.closingTime.split(':');
        const breakingtimes = working.breaktimes
          ? working.breaktimes.map(breaktime => {
              const startTimeSpilit = breaktime.startTime.split(':');
              const endTimeSpilit = breaktime.endTime.split(':');
              return {
                ...breaktime,
                startTime: `${startTimeSpilit[0]}:${startTimeSpilit[1]}`,
                endTime: `${endTimeSpilit[0]}:${endTimeSpilit[1]}`,
              };
            })
          : [];
        return {
          ...working,
          openingTime: `${openingTimeSpilit[0]}:${openingTimeSpilit[1]}`,
          closingTime: `${closingTimeSpilit[0]}:${closingTimeSpilit[1]}`,
          breaktimes: breakingtimes,
        };
      });
      form.setFieldsValue({ openTimes: newTimeList });
    } else {
      form.setFieldsValue({ openTimes: [] });
    }
  }, [openTimes]);

  useEffect(() => {
    if (closeTimes && closeTimes?.length > 0) {
      const newTimes = closeTimes.map(time => {
        return {
          ...time,
          fromDay: time.fromDay ? moment(time.fromDay) : undefined,
          toDay: time.toDay ? moment(time.toDay) : undefined,
        };
      });
      form.setFieldsValue({ closeTimes: newTimes });
    } else {
      form.setFieldsValue({ closeTimes: [] });
    }
  }, [closeTimes]);

  useEffect(() => {
    if (workingTimes && workingTimes?.length > 0) {
      const newTimeList = workingTimes.map(working => {
        const newItems = working.items.map(item => {
          const openingTimeSpilit = item.startTime.split(':');
          const closingTimeSpilit = item.endTime.split(':');
          const breakingtimes = item.breaktimes
            ? item.breaktimes.map(breaktime => {
                const startTimeSpilit = breaktime.startTime.split(':');
                const endTimeSpilit = breaktime.endTime.split(':');
                return {
                  ...breaktime,
                  startTime: `${startTimeSpilit[0]}:${startTimeSpilit[1]}`,
                  endTime: `${endTimeSpilit[0]}:${endTimeSpilit[1]}`,
                };
              })
            : [];
          return {
            ...item,
            startTime: `${openingTimeSpilit[0]}:${openingTimeSpilit[1]}`,
            endTime: `${closingTimeSpilit[0]}:${closingTimeSpilit[1]}`,
            breaktimes: breakingtimes,
          };
        });
        return { ...working, items: newItems };
      });
      form.setFieldsValue({ workingTimes: newTimeList });
    } else {
      form.setFieldsValue({ workingTimes: [] });
    }
  }, [workingTimes]);

  return (
    <Spin spinning={isFetching}>
      <div
        style={{ paddingTop: 'unset' }}
        className="setting__group setting__group-third"
      >
        <Form form={form}>
          <div className="group">
            <Row gutter={12} className="row-operation">
              <Col lg={12} xl={12} md={12} sm={24} xs={24} className="col-time">
                <Row style={{marginBottom: "20px"}}>
                  <div className="first-box">
                    <OpenTimeSetting
                      handleChangeStart={handleChangeStart}
                      form={form}
                    />
                  </div>
                </Row>
                <Row>
                  <div className="first-box">
                    <CloseTimeSetting
                      handleChangeStart={handleChangeStart}
                      form={form}
                    />
                  </div>
                </Row>
              </Col>
              <Col lg={12} xl={12} md={12} sm={24} xs={24} className="col-time">
                <Row
                >
                  <div className="first-box">
                    <WorkingTimeSetting
                      workingTimes={workingTimes}
                      form={form}
                      handleChangeStart={handleChangeWorkingStart}
                    />
                  </div>
                </Row>
              </Col>
            </Row>
          </div>
          <div className="row">
            <div className="col-11 col-md-11">
              <div className="setting__group-third__content setting__group-third__content-second">
                <Button
                  type="primary"
                  className="custormButton"
                  htmlType="submit"
                  size="large"
                  onClick={() => {
                    form
                      .validateFields()
                      .then(values => {
                        onFinish(values);
                      })
                      .catch(info => {
                        console.log('Validate Failed:', info);
                      });
                  }}
                >
                  {intl.formatMessage(messages.save)}
                </Button>
              </div>
            </div>
          </div>
        </Form>
      </div>
    </Spin>
  );
}
export default injectIntl(General);
