import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { fetchAPI } from 'utils/fetchAPI';
import { WORKING_HOURS_SETTING } from 'containers/App/urls';
import { PlusOutlined, CalendarOutlined } from '@ant-design/icons';
import messages from '../I18t/messages';
import messagesGlobal from 'translations/messages';
import { Typography, Select, Button, Form, Divider, Tooltip } from 'antd';
import BREAKTIME_IC from 'images/breaktime-ic.svg';
import { RemoveSettingCharacter } from 'styles/icon-components';
import { validateTimeFormatNoSec } from 'utils/validation';
import { FormatTimeInput } from 'components/FormatInput';
import { timeDigits } from 'utils/number';
import { injectIntl } from 'react-intl';
import useDynamicRefs from 'use-dynamic-refs';
import FloatLabel from 'components/FormatInput/FloatLabel';

const PreparationSettingWrapper = styled.div`
  margin-bottom: 20px;
  padding: 20px;
  background-color: #ffffff;
  .setting-menu {
    display: flex;
    justify-content: space-between;
    .form-action.working-action {
      display: flex;
      width: 8%;
      align-items: center;
      > button {
        margin-left: calc(20% + 25px);
      }
    }
  }
  .working {
    .ant-row.dayOfWeeks-select {
      width: 25%;
    }
    .title-breaktime,
    .form-breaktime {
      width: 46%;
      display: flex;
      .ant-row {
        width: 50%;
      }
    }

    .title-breaktime {
      margin-top: 11px;
    }

    .form-action {
      display: flex;
      width: 8%;
      align-items: center;
    }
    display: flex;
    justify-content: space-between;
    align-items: flex-start;
    padding-right: 10px;
    img:nth-child(1) {
      cursor: pointer;
      width: 18px;
      height: 21px;
      margin-right: 8px;
    }
    img:nth-child(2) {
      cursor: pointer;
      width: 25.2px;
      height: 24px;
    }
    .ant-form-item {
      margin-bottom: unset !important;
      .ant-form-item-control {
        margin-right: 10px;
      }
    }
    .ant-picker {
      border-radius: 22px;
    }
    .form-action {
      align-self: center;
    }
  }
  .sub-list {
    margin-top: 10px;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  .setting-menu {
    > h4 {
      width: calc(92% - 13px);
    }
  }
`;
const { Title } = Typography;

function OpenTimeSetting(props) {
  const { intl, handleChangeStart, form } = props;
  const [getRef, setRef] = useDynamicRefs() as any;

  return (
    <PreparationSettingWrapper>
      <Form.List name="openTimes">
        {(fields, { add, remove }) => (
          <div>
            <div className="setting-menu">
              <Title level={4} className="setting-menu-title">
                {intl.formatMessage(messages.timeToOpen)}
              </Title>
              <div className="form-action working-action">
                <Button
                  type="primary"
                  shape="circle"
                  icon={<PlusOutlined />}
                  size="large"
                  onClick={() => add()}
                />
              </div>
            </div>
            {fields.map((field, index) => (
              <>
                <div className="working">
                  <div className="form-breaktime">
                    <Form.Item
                      name={[field.name, 'fromDay']}
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messagesGlobal.requiredInput,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        size="large"
                        label={intl.formatMessage(messages.fromDate)}
                        suffixIcon={<CalendarOutlined />}
                        onSelect={handleChangeStart}
                        items={[
                          {
                            id: 1,
                            name: intl.formatMessage(messages.monday),
                          },
                          {
                            id: 2,
                            name: intl.formatMessage(messages.tuesday),
                          },
                          {
                            id: 3,
                            name: intl.formatMessage(messages.wednesday),
                          },
                          {
                            id: 4,
                            name: intl.formatMessage(messages.thursday),
                          },
                          {
                            id: 5,
                            name: intl.formatMessage(messages.friday),
                          },
                          {
                            id: 6,
                            name: intl.formatMessage(messages.saturday),
                          },
                          {
                            id: 0,
                            name: intl.formatMessage(messages.sunday),
                          },
                        ]}
                        typeInput="selectMutil"
                      />
                    </Form.Item>
                    <Form.Item
                      name={[field.name, 'toDay']}
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messagesGlobal.requiredInput,
                          ),
                        },
                      ]}
                    >
                      <FloatLabel
                        size="large"
                        label={intl.formatMessage(messages.toDate)}
                        suffixIcon={<CalendarOutlined />}
                        onSelect={handleChangeStart}
                        items={[
                          {
                            id: 1,
                            name: intl.formatMessage(messages.monday),
                          },
                          {
                            id: 2,
                            name: intl.formatMessage(messages.tuesday),
                          },
                          {
                            id: 3,
                            name: intl.formatMessage(messages.wednesday),
                          },
                          {
                            id: 4,
                            name: intl.formatMessage(messages.thursday),
                          },
                          {
                            id: 5,
                            name: intl.formatMessage(messages.friday),
                          },
                          {
                            id: 6,
                            name: intl.formatMessage(messages.saturday),
                          },
                          {
                            id: 0,
                            name: intl.formatMessage(messages.sunday),
                          },
                        ]}
                        typeInput="selectMutil"
                      />
                    </Form.Item>
                  </div>
                  <div className="form-breaktime">
                    <Form.Item
                      name={[field.name, 'openingTime']}
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messagesGlobal.requiredChoose,
                          ),
                        },
                        validateTimeFormatNoSec(
                          form,
                          intl.formatMessage(messagesGlobal.requireFormatTime, {
                            format: 'HH:MM',
                          }),
                        ),
                      ]}
                    >
                      <FormatTimeInput
                        formatter={timeDigits}
                        placeholder={intl.formatMessage(messages.toTime)}
                        className="fw"
                        maxLength={5}
                        showSecond={false}
                      />
                    </Form.Item>
                    <Form.Item
                      name={[field.name, 'closingTime']}
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(
                            messagesGlobal.requiredInput,
                          ),
                        },
                        validateTimeFormatNoSec(
                          form,
                          intl.formatMessage(messagesGlobal.requireFormatTime, {
                            format: 'HH:MM',
                          }),
                        ),
                      ]}
                    >
                      <FormatTimeInput
                        formatter={timeDigits}
                        placeholder={intl.formatMessage(messages.toTime)}
                        className="fw"
                        maxLength={5}
                        showSecond={false}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-action">
                    <span
                      onClick={() => remove(field.name)}
                      className="remove-ic"
                    >
                      <RemoveSettingCharacter />
                    </span>
                    <Tooltip
                      placement="top"
                      title={intl.formatMessage(messagesGlobal.breaktimes)}
                      key={index}
                    >
                      <img
                        src={BREAKTIME_IC}
                        onClick={() =>
                          (getRef(index.toString()).current as any).click()
                        }
                      />
                    </Tooltip>
                  </div>
                </div>
                <Form.List name={[field.name, 'breaktimes']}>
                  {(subFields, { add, remove }) => (
                    <>
                      {subFields.map((field, subIndex) => (
                        <div className="working sub-list">
                          <div className="title-breaktime">
                            {subIndex === 0 && (
                              <span>
                                {intl.formatMessage(messagesGlobal.breaktimes)}
                              </span>
                            )}
                          </div>
                          <div className="form-breaktime">
                            <Form.Item
                              name={[field.name, 'startTime']}
                              rules={[
                                {
                                  required: true,
                                  message: intl.formatMessage(
                                    messagesGlobal.requiredInput,
                                  ),
                                },
                                validateTimeFormatNoSec(
                                  form,
                                  intl.formatMessage(
                                    messagesGlobal.requireFormatTime,
                                    {
                                      format: 'HH:MM',
                                    },
                                  ),
                                ),
                              ]}
                            >
                              <FormatTimeInput
                                formatter={timeDigits}
                                placeholder={intl.formatMessage(
                                  messages.fromTime,
                                )}
                                className="fw"
                                maxLength={5}
                                showSecond={false}
                              />
                            </Form.Item>
                            <Form.Item
                              name={[field.name, 'endTime']}
                              rules={[
                                {
                                  required: true,
                                  message: intl.formatMessage(
                                    messagesGlobal.requiredInput,
                                  ),
                                },
                                validateTimeFormatNoSec(
                                  form,
                                  intl.formatMessage(
                                    messagesGlobal.requireFormatTime,
                                    {
                                      format: 'HH:MM',
                                    },
                                  ),
                                ),
                              ]}
                            >
                              <FormatTimeInput
                                formatter={timeDigits}
                                placeholder={intl.formatMessage(
                                  messages.toTime,
                                )}
                                className="fw"
                                maxLength={5}
                                showSecond={false}
                              />
                            </Form.Item>
                          </div>
                          <div className="form-action">
                            <span
                              onClick={() => remove(field.name)}
                              className="remove-ic"
                            >
                              <RemoveSettingCharacter />
                            </span>
                          </div>
                        </div>
                      ))}
                      <Button
                        type="primary"
                        shape="circle"
                        onClick={() => add()}
                        style={{ display: 'none' }}
                        ref={setRef(index.toString()) as any}
                      />
                    </>
                  )}
                </Form.List>
                {fields.length > 1 && index !== fields.length - 1 && (
                  <Divider />
                )}
              </>
            ))}
          </div>
        )}
      </Form.List>
    </PreparationSettingWrapper>
  );
}
export default injectIntl(OpenTimeSetting);
