import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { fetchAPI } from 'utils/fetchAPI';
import { WORKING_HOURS_SETTING } from 'containers/App/urls';
import { PlusOutlined, CalendarOutlined } from '@ant-design/icons';
import messages from '../I18t/messages';
import messagesGlobal from 'translations/messages';
import {
  Typography,
  Select,
  Button,
  Form,
  Divider,
  Input,
  Tooltip,
  Modal,
  Space,
} from 'antd';
import BREAKTIME_IC from 'images/breaktime-ic.svg';
import DELETE_ICON from '../../../images/ic-delete.svg';
import { isValidateTime, validateTimeFormatNoSec } from "utils/validation";
import { FormatTimeInput } from 'components/FormatInput';
import { timeDigits } from 'utils/number';
import { injectIntl } from 'react-intl';
import { RemoveSettingCharacter } from 'styles/icon-components';
import useDynamicRefs from 'use-dynamic-refs';
import FloatLabel from 'components/FormatInput/FloatLabel';
import { getTotalMinutesOfTime } from "../../../utils/common";

const PreparationSettingWrapper = styled.div`
  margin-bottom: 20px;
  padding: 20px;
  background-color: #ffffff;
  .setting-menu {
    display: flex;
    justify-content: space-between;
    .form-action {
      display: flex;
      width: 8%;
      align-items: center;
    }
    .form-action.working-action {
      display: flex;
      width: 12%;
      align-items: center;
      > button {
        margin-left: calc(20% + 25px);
      }
    }
  }
  .working {
    .ant-row.dayOfWeeks-select {
      width: 25%;
    }
    .title-breaktime,
    .form-breaktime {
      width: 44%;
      display: flex;
      .ant-row {
        width: 50%;
      }
    }
    .title-breaktime {
      margin-top: 11px;
    }

    .form-action {
      display: flex;
      width: 12%;
      align-items: center;
    }
    display: flex;
    justify-content: space-between;
    align-items: flex-start;
    padding-right: 10px;
    img:nth-child(1) {
      cursor: pointer;
      width: 18px;
      height: 21px;
      margin-right: 8px;
    }
    img:nth-child(2) {
      cursor: pointer;
      width: 25.2px;
      height: 24px;
    }
    .ant-form-item {
      margin-bottom: unset !important;
      .ant-form-item-control {
        margin-right: 10px;
      }
    }
    .ant-picker {
      border-radius: 22px;
    }
    .form-action {
      align-self: center;
    }
  }
  .sub-list {
    margin-top: 10px;
  }
  .sub-last-list,
  .sub-working-list {
    margin-bottom: 10px;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  input {
    height: 44px;
  }
  .setting-menu {
    > h4 {
      width: calc(88% - 9px);
    }
  }
`;

const CreateShiftWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 16px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
  .ant-input-group-wrapper {
    .ant-input-group {
      input {
        border-right: none;
      }
      .ant-input-group-addon:last-child {
        border-radius: 22px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
        width: 53px;
        background: white;
        border-left: none;
      }
    }
  }
`;
const { Title } = Typography;

function OpenTimeSetting(props) {
  const { intl, handleChangeStart, form } = props;
  const [getRef, setRef] = useDynamicRefs() as any;

  const handleClickAddShift = addCallback => {
    const modal = Modal.confirm({});
    modal.update({
      content: addShiftBody(addCallback, modal),
      icon: null,
      okText: null,
      cancelText: null,
      maskClosable: true,
      className: 'modal-shift',
    });
  };
  const addShiftBody = (addCallback, modal) => (
    <Form
      name="horizontal_login"
      onFinish={values => {
        addCallback({
          name: values.name,
          items: [
            { fromDay: null, toDay: null, startTime: null, endTime: null },
          ],
        });
        modal.destroy();
      }}
      layout="horizontal"
      size="middle"
    >
      <CreateShiftWrapper>
        <Space direction="vertical" style={{ width: '100%' }}>
          <Title level={4} className="modal-edit__menu--title">
            {intl.formatMessage(messagesGlobal.addShift)}
          </Title>
          <Form.Item
            colon={false}
            name="name"
            rules={[
              {
                required: true,
                message: intl.formatMessage(messagesGlobal.requiredInput),
              },
            ]}
            style={{ width: '100%', marginBottom: '11px' }}
          >
            <FloatLabel label={`${intl.formatMessage(messagesGlobal.shift)}`} />
          </Form.Item>
          <Button type="primary" htmlType="submit" style={{ width: '100%' }}>
            {intl.formatMessage(messagesGlobal.save)}
          </Button>
        </Space>
      </CreateShiftWrapper>
    </Form>
  );
  return (
    <PreparationSettingWrapper>
      <Form.List name="workingTimes">
        {(fields, { add, remove }) => (
          <div>
            <div className="setting-menu working-first">
              <Title level={4} className="setting-menu-title">
                {intl.formatMessage(messages.timeToWork)}
              </Title>
              <div className="form-action working-action">
                {/* <div className="remove-ic"></div> */}
                <Button
                  type="primary"
                  shape="circle"
                  icon={<PlusOutlined />}
                  size="large"
                  onClick={() => handleClickAddShift(add)}
                />
              </div>
            </div>
            {fields.map((field, index) => (
              <>
                {fields.length > 0 && <Divider />}
                <div className="setting-menu">
                  <Title level={4} className="setting-menu-title">
                    {form.getFieldValue(['workingTimes', index, 'name'])}
                  </Title>
                  <div className="form-action">
                    <span onClick={() => remove(index)} className="remove-ic">
                      <RemoveSettingCharacter />
                    </span>
                    <Button
                      type="primary"
                      shape="circle"
                      icon={<PlusOutlined />}
                      size="large"
                      onClick={() =>
                        (getRef(`w${index.toString()}`).current as any).click()
                      }
                    />
                  </div>
                </div>
                <Form.List name={[field.name, 'items']}>
                  {(subWorkingtimes, { add, remove }) => (
                    <>
                      {subWorkingtimes.map(
                        (subWorkingtimeField, subWorkingIndex) => (
                          <>
                            <div className="working sub-working-list">
                              <div className="form-breaktime">
                                <Form.Item
                                  name={
                                    subWorkingtimeField
                                      ? [subWorkingtimeField.name, 'fromDay']
                                      : ['workingHours', '0', 'fromDay']
                                  }
                                  rules={[
                                    {
                                      required: true,
                                      message: intl.formatMessage(
                                        messagesGlobal.requiredInput,
                                      ),
                                    },
                                  ]}
                                >
                                  <FloatLabel
                                    size="large"
                                    label={intl.formatMessage(
                                      messages.fromDate,
                                    )}
                                    suffixIcon={<CalendarOutlined />}
                                    onSelect={handleChangeStart}
                                    items={[
                                      {
                                        id: 1,
                                        name: intl.formatMessage(
                                          messages.monday,
                                        ),
                                      },
                                      {
                                        id: 2,
                                        name: intl.formatMessage(
                                          messages.tuesday,
                                        ),
                                      },
                                      {
                                        id: 3,
                                        name: intl.formatMessage(
                                          messages.wednesday,
                                        ),
                                      },
                                      {
                                        id: 4,
                                        name: intl.formatMessage(
                                          messages.thursday,
                                        ),
                                      },
                                      {
                                        id: 5,
                                        name: intl.formatMessage(
                                          messages.friday,
                                        ),
                                      },
                                      {
                                        id: 6,
                                        name: intl.formatMessage(
                                          messages.saturday,
                                        ),
                                      },
                                      {
                                        id: 0,
                                        name: intl.formatMessage(
                                          messages.sunday,
                                        ),
                                      },
                                    ]}
                                    typeInput="selectMutil"
                                  />
                                </Form.Item>
                                <Form.Item
                                  name={[subWorkingtimeField.name, 'toDay']}
                                >
                                  <FloatLabel
                                    size="large"
                                    label={intl.formatMessage(messages.toDate)}
                                    suffixIcon={<CalendarOutlined />}
                                    onSelect={handleChangeStart}
                                    items={[
                                      {
                                        id: 1,
                                        name: intl.formatMessage(
                                          messages.monday,
                                        ),
                                      },
                                      {
                                        id: 2,
                                        name: intl.formatMessage(
                                          messages.tuesday,
                                        ),
                                      },
                                      {
                                        id: 3,
                                        name: intl.formatMessage(
                                          messages.wednesday,
                                        ),
                                      },
                                      {
                                        id: 4,
                                        name: intl.formatMessage(
                                          messages.thursday,
                                        ),
                                      },
                                      {
                                        id: 5,
                                        name: intl.formatMessage(
                                          messages.friday,
                                        ),
                                      },
                                      {
                                        id: 6,
                                        name: intl.formatMessage(
                                          messages.saturday,
                                        ),
                                      },
                                      {
                                        id: 0,
                                        name: intl.formatMessage(
                                          messages.sunday,
                                        ),
                                      },
                                    ]}
                                    typeInput="selectMutil"
                                  />
                                </Form.Item>
                              </div>
                              <div className="form-breaktime">
                                <Form.Item
                                  name={[subWorkingtimeField.name, 'startTime']}
                                  rules={[
                                    {
                                      required: true,
                                      message: intl.formatMessage(
                                        messagesGlobal.requiredChoose,
                                      ),
                                    },
                                    validateTimeFormatNoSec(
                                      form,
                                      intl.formatMessage(
                                        messagesGlobal.requireFormatTime,
                                        {
                                          format: 'HH:MM',
                                        },
                                      ),
                                    ),
                                    {
                                      validator : (rule, value, callback) =>{
                                        const endTime = form.getFieldValue(['workingTimes',index,"items",subWorkingIndex,"endTime"]);
                                        if(isValidateTime(endTime) && isValidateTime(value)){
                                          if(getTotalMinutesOfTime(endTime) <= getTotalMinutesOfTime(value)){
                                            callback(intl.formatMessage(messagesGlobal.requireInputValueLessThan).replace("{value}",endTime))
                                          }
                                        }
                                        callback();
                                      }
                                    },

                                  ]}
                                >
                                  <FormatTimeInput
                                    formatter={timeDigits}
                                    placeholder={intl.formatMessage(
                                      messages.fromTime,
                                    )}
                                    className="fw"
                                    maxLength={5}
                                    showSecond={false}
                                  />
                                </Form.Item>
                                <Form.Item
                                  name={[subWorkingtimeField.name, 'endTime']}
                                  rules={[
                                    {
                                      required: true,
                                      message: intl.formatMessage(
                                        messagesGlobal.requiredInput,
                                      ),
                                    },
                                    validateTimeFormatNoSec(
                                      form,
                                      intl.formatMessage(
                                        messagesGlobal.requireFormatTime,
                                        {
                                          format: 'HH:MM',
                                        },
                                      ),
                                    ),
                                    {
                                      validator : (rule, value, callback) =>{
                                        const fromTime = form.getFieldValue(['workingTimes',index,"items",subWorkingIndex,"startTime"]);
                                        if(isValidateTime(fromTime) && isValidateTime(value)){
                                          if(getTotalMinutesOfTime(fromTime) >= getTotalMinutesOfTime(value)){
                                            callback(intl.formatMessage(messagesGlobal.requireInputValueGreaterThan).replace("{value}",fromTime))
                                          }
                                        }
                                        callback();
                                      }
                                    },
                                  ]}
                                >
                                  <FormatTimeInput
                                    formatter={timeDigits}
                                    placeholder={intl.formatMessage(
                                      messages.toTime,
                                    )}
                                    className="fw"
                                    maxLength={5}
                                    showSecond={false}
                                  />
                                </Form.Item>
                              </div>
                              <div className="form-action">
                                <span
                                  onClick={() =>
                                    remove(subWorkingtimeField.name)
                                  }
                                  className="remove-ic"
                                >
                                  <RemoveSettingCharacter />
                                </span>
                                <Tooltip
                                  placement="top"
                                  title={intl.formatMessage(
                                    messagesGlobal.breaktimes,
                                  )}
                                  key={subWorkingIndex}
                                >
                                  <img
                                    src={BREAKTIME_IC}
                                    onClick={() =>{
                                      (getRef(`w${index.toString()}_s${subWorkingIndex.toString()}`).current as any).click();
                                    }}
                                  />
                                </Tooltip>
                              </div>
                            </div>
                            <Form.List
                              name={[subWorkingtimeField.name, 'breaktimes']}
                            >
                              {(subBreaktimes, { add, remove }) => (
                                <>
                                  {subBreaktimes.map(
                                    (subBreaktimeField, subBreakIndex) => (
                                      <div
                                        className={`working${
                                          subBreakIndex > 0 ? ' sub-list' : ''
                                        }${
                                          subBreakIndex ===
                                          subBreaktimes.length - 1
                                            ? ' sub-last-list'
                                            : ''
                                        }`}
                                      >
                                        <div className="title-breaktime">
                                          {subBreakIndex === 0 && (
                                            <span>
                                              {intl.formatMessage(
                                                messagesGlobal.breaktimes,
                                              )}
                                            </span>
                                          )}
                                        </div>
                                        <div className="form-breaktime">
                                          <Form.Item
                                            name={[
                                              subBreaktimeField.name,
                                              'startTime',
                                            ]}
                                            rules={[
                                              {
                                                required: true,
                                                message: intl.formatMessage(
                                                  messagesGlobal.requiredInput,
                                                ),
                                              },
                                              validateTimeFormatNoSec(
                                                form,
                                                intl.formatMessage(
                                                  messagesGlobal.requireFormatTime,
                                                  {
                                                    format: 'HH:MM',
                                                  },
                                                ),
                                              ),
                                            ]}
                                          >
                                            <FormatTimeInput
                                              formatter={timeDigits}
                                              placeholder={intl.formatMessage(
                                                messages.fromTime,
                                              )}
                                              className="fw"
                                              maxLength={5}
                                              showSecond={false}
                                            />
                                          </Form.Item>
                                          <Form.Item
                                            name={[
                                              subBreaktimeField.name,
                                              'endTime',
                                            ]}
                                            rules={[
                                              {
                                                required: true,
                                                message: intl.formatMessage(
                                                  messagesGlobal.requiredInput,
                                                ),
                                              },
                                              validateTimeFormatNoSec(
                                                form,
                                                intl.formatMessage(
                                                  messagesGlobal.requireFormatTime,
                                                  {
                                                    format: 'HH:MM',
                                                  },
                                                ),
                                              ),
                                            ]}
                                          >
                                            <FormatTimeInput
                                              formatter={timeDigits}
                                              placeholder={intl.formatMessage(
                                                messages.toTime,
                                              )}
                                              className="fw"
                                              maxLength={5}
                                              showSecond={false}
                                            />
                                          </Form.Item>
                                        </div>
                                        <div className="form-action">
                                          <span
                                            onClick={() =>
                                              remove(subBreaktimeField.name)
                                            }
                                            className="remove-ic"
                                          >
                                            <RemoveSettingCharacter />
                                          </span>
                                        </div>
                                      </div>
                                    ),
                                  )}
                                  <Button
                                    type="primary"
                                    shape="circle"
                                    onClick={() => add()}
                                    style={{ display: 'none' }}
                                    ref={
                                      setRef(
                                        `w${index.toString()}_s${subWorkingIndex.toString()}`,
                                      ) as any
                                    }
                                  />
                                </>
                              )}
                            </Form.List>
                          </>
                        ),
                      )}
                      <Button
                        type="primary"
                        shape="circle"
                        onClick={() => add()}
                        style={{ display: 'none' }}
                        ref={setRef(`w${index.toString()}`) as any}
                      />
                    </>
                  )}
                </Form.List>
              </>
            ))}
          </div>
        )}
      </Form.List>
    </PreparationSettingWrapper>
  );
}
export default injectIntl(OpenTimeSetting);
