import React, { useState } from 'react';
import styled from 'styled-components';
import { PayrollModel, OptionPayrollModel } from '../Store/types';
import { Space, Divider, Col, Modal, Typography, notification } from 'antd';
import { EditFilled, DeleteFilled } from '@ant-design/icons';
import CreateEditPayrollCategory from './createEditPayRollCategory';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';

const CardPayroll = styled.div`
  margin: 0px 5px;
  border-radius: 16px;
  width: 100%;
  height: 32px;
  display: flex;
  padding: 0px 5px;
  align-items: center;
  justify-content: center;
  :hover {
    width: 100%;
  }
`;

const HovereddCard = styled.div`
  // .anticon:hover {
  //   cursor: pointer;
  //   color: #dc5454;
  // }
`;
const { Title } = Typography;

interface Props {
  payroll: OptionPayrollModel;
  onOpenCreatePayrollModal?: any;
  handleChangePayroll?: any;
  payrollIdx?: any;
  payrollList?: PayrollModel;
  intl?: any;
}

const HoveredExpand = injectIntl((props: Props) => {
  const { payroll, onOpenCreatePayrollModal, handleChangePayroll, payrollList, payrollIdx, intl } = props;
  const handleOnClickDelete = async () => {
    Modal.confirm({
      title: (
        <Title level={4}>
          {intl.formatMessage(messages.titleConfirmDeleted, { item: `${payroll.name}` })}
        </Title>
      ),
      content: (
        intl.formatMessage(messages.contentConfirmDeleted, { item: `${payroll.name}` })
      ),
      okText: (
        intl.formatMessage(messages.deleteBtn)
      ),
      cancelText: (
        intl.formatMessage(messages.cancelBtn)
      ),
      keyboard: true,
      onOk: () => {
        let options = payrollList?.options ? payrollList?.options : [];
        const indexOp = ((payrollIdx?.subIndex) + 4 * ( payrollIdx?.index));
        options.splice(options.findIndex((op, index )=> index === indexOp), 1);
        handleChangePayroll({...payrollList, options: options});
      },
    });
  };
  return (
    <HovereddCard>
      <Space size={-5}>
        <EditFilled onClick={() => onOpenCreatePayrollModal()} />
        <Divider type="vertical" />
        <DeleteFilled onClick={() => handleOnClickDelete()} />
      </Space>
    </HovereddCard>
  );
})

export function PayrollCard(props: Props) {
  const { payroll, handleChangePayroll, payrollIdx = {index: 0, subIndex: 0}, payrollList } = props;
  const [isHovered, setHovered] = useState(false);
  const [openEditPayrollModal, setOpenEditPayrollModal] = useState(false);

  return (
    <Col>
      <CardPayroll
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
        // 1: cộng thêm, 2: giảm trừ
        className={payroll.type === 1 ? 'payroll': 'no-payroll'}
      >
        <Space>
          <div>{payroll.name}</div>
          {isHovered && (
            <HoveredExpand
              payrollList={payrollList}
              payroll={payroll}
              payrollIdx={payrollIdx}
              onOpenCreatePayrollModal={() => setOpenEditPayrollModal(true)}
              handleChangePayroll={handleChangePayroll}
            />
          )}
        </Space>
      </CardPayroll>
      {openEditPayrollModal && (
        <CreateEditPayrollCategory
          payrollList={payrollList}
          visible={openEditPayrollModal}
          onCancel={() => setOpenEditPayrollModal(false)}
          handleChangePayroll={handleChangePayroll}
          isCreate={false}
          payroll={payroll}
          payrollIdx={payrollIdx}
        />
      )}
    </Col>
  );
}
