import React, { useState, useRef } from 'react';
import {
  Modal,
  Button,
  Input,
  Form,
  notification,
  Typography,
  Space,
  Select,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import messagesLocal from '../I18t/messages';
import styled from 'styled-components';
import { PayrollModel, OptionPayrollModel } from '../Store/types';
import FloatLabel from 'components/FormatInput/FloatLabel';

const CreatePayrollCategoryWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 15px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
  .ant-input-group-wrapper {
    .ant-input-group {
      input {
        border-right: none;
      }
      .ant-input-group-addon:last-child {
        border-radius: 22px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
        width: 53px;
        background: white;
        border-left: none;
      }
    }
  }
`;
const { Title, Text } = Typography;
interface Props {
  visible: boolean;
  onCancel(): any;
  handleChangePayroll: any;
  isCreate: boolean;
  payroll?: OptionPayrollModel;
  intl: any;
  payrollList?: PayrollModel;
  payrollIdx?: any;
}

function CreateEditPayRollCategory(props: Props) {
  const {
    visible,
    onCancel,
    handleChangePayroll,
    isCreate,
    payroll,
    intl,
    payrollList = {} as PayrollModel,
    payrollIdx
  } = props;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState<boolean>(false);
  const onFinish = values => {
    setLoading(true);
    let options = payrollList.options ? payrollList.options : [values];
    if (isCreate) {
      options.push(values);
    } else {
      const indexOp = ((payrollIdx?.subIndex) + 4 * ( payrollIdx?.index));
      options = options.map((op, index) => {
        if (index === indexOp) {
          return { id: index, name: values.name, type: values.type};
        }
        return op;
      });
    }
    handleChangePayroll({...payrollList, options: options});
    onCancel();
    setLoading(false);
  };

  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      layout="horizontal"
      size="middle"
      initialValues={payroll ? payroll : {}}
    >
      <Modal
        visible={visible}
        onCancel={onCancel}
        width={330}
        centered
        footer={null}
      >
        <CreatePayrollCategoryWrapper>
          <Space direction="vertical" style={{ width: '100%' }}>
            <Title level={4} className="modal-edit__menu--title">
              {isCreate ? (
                <FormattedMessage {...messages.addPayrollCategory} />
              ) : (
                <FormattedMessage {...messages.editPayrollCategory} />
              )}
            </Title>
            <Form.Item
              colon={false}
              name="name"
              rules={[
                {
                  required: true,
                  message: <FormattedMessage {...messages.requiredInput} />,
                },
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messages.name)}`} />
            </Form.Item>
            <Form.Item
              colon={false}
              name="type"
              rules={[
                {
                  pattern: new RegExp('^\\d+(\\.\\d{1,2})?$'),
                  message: intl.formatMessage(messages.requiredInputNumber),
                },
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel
                size="large"
                label={intl.formatMessage(messages.payrollType)}
                items={[{id: 1, name: intl.formatMessage(messagesLocal.income)}, {id:2 , name: intl.formatMessage(messagesLocal.deduction)}]}
                typeInput="selectMutil"
              />
            </Form.Item>
            <Form.Item>
              <Button
                type="primary"
                htmlType="submit"
                style={{ width: '100%' }}
                loading={loading}
                onClick={() => {
                  form
                    .validateFields()
                    .then(values => {
                      onFinish(values);
                    })
                    .catch(info => {
                      console.log('Validate Failed:', info);
                    });
                }}
              >
                <FormattedMessage {...messages.save} />
              </Button>
            </Form.Item>
          </Space>
        </CreatePayrollCategoryWrapper>
      </Modal>
    </Form>
  );
}
export default injectIntl(CreateEditPayRollCategory);
