/*
 *
 * CustomerList reducer
 *
 */

import ActionTypes from './constants';
import { ContainerState, ContainerActions } from './types';
import _ from 'lodash';

export const initialState: ContainerState = {
  message: '',
  isFetching: true,
  config: {
    setting: {},
    categories: [],
    measureUnits: [],
    ingredients: [],
    cookingRequestGroups: [],
    merchantOpenTimes: [],
    merchantWorkingTimes: [],
    merchantCloseTimes: [],
    payrollSetting: {
      payPeriod: 1,
      options: [],
    },
    taxes: [],
    shippingFees: [],
    commission: { list: [], options: [] },
  },
  measureUnits: [],
};

function settingReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.GET_CATEGORIES_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_CATEGORIES_CONFIG_SUCCESS:
      return {
        ...state,
        isFetching: false,
      };
    case ActionTypes.GET_CATEGORIES_CONFIG_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_INGREDIENT_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.SET_MERCHANT_SETTING:
      return { ...state, isFetching: true };
    case ActionTypes.SET_MERCHANT_SETTING_SUCCESS:
      return {
        ...state,
        isFetching: false,
        config: state.config
          ? Object.assign(state.config, action.payload)
          : initialState.config,
      };
    case ActionTypes.SET_MERCHANT_SETTING_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_INGREDIENT_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_CATEGORIES_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_CATEGORIES_CONFIG_SUCCESS:
      return {
        ...state,
        isFetching: false,
      };
    case ActionTypes.GET_CATEGORIES_CONFIG_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_INGREDIENT_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_INGREDIENT_CONFIG_SUCCESS:
      return {
        ...state,
        isFetching: false,
      };
    case ActionTypes.GET_INGREDIENT_CONFIG_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_MEASURE_UNITS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_MEASURE_UNITS_SUCCESS:
      return {
        ...state,
        isFetching: false,
        measureUnits: action.payload,
      };
    case ActionTypes.GET_MEASURE_UNITS_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_PREPARATION_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PREPARATION_CONFIG_SUCCESS:
      return {
        ...state,
        isFetching: false,
      };
    case ActionTypes.GET_PREPARATION_CONFIG_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_GENERAL_CONFIG:
      return { ...state, isFetching: true };
    case ActionTypes.GET_GENERAL_CONFIG_SUCCESS:
      return { ...state, isFetching: false, config: action.payload };
    case ActionTypes.GET_GENERAL_CONFIG_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.GET_MERCHANT_SETTING:
      return { ...state, isFetching: true };
    case ActionTypes.GET_MERCHANT_SETTING_SUCCESS:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              setting: action.payload.setting,
              categories: action.payload.menuCategories
                ? action.payload.menuCategories
                : initialState.config?.categories,
              ingredients: action.payload.ingredients
                ? action.payload.ingredients
                : initialState.config?.ingredients,
              cookingRequestGroups: action.payload.cookingRequestGroups
                ? action.payload.cookingRequestGroups
                : initialState.config?.cookingRequestGroups,
              merchantOpenTimes: action.payload.merchantOpenTimes
                ? action.payload.merchantOpenTimes
                : initialState.config?.merchantOpenTimes,
              merchantWorkingTimes: action.payload.merchantWorkingTimes
                ? action.payload.merchantWorkingTimes
                : initialState.config?.merchantWorkingTimes,
              merchantCloseTimes: action.payload.merchantCloseTimes
                ? action.payload.merchantCloseTimes
                : initialState.config?.merchantCloseTimes,
              payrollSetting: action.payload.payrollSetting
                ? action.payload.payrollSetting
                : initialState.config?.payrollSetting,
              commission: action.payload.commission
                ? action.payload.commission
                : initialState.config?.commission,
              shippingFees: action.payload.shippingFees
                ? action.payload.shippingFees
                : initialState.config?.shippingFees,
              taxes: action.payload.taxes
                ? action.payload.taxes
                : initialState.config?.taxes,
            }
          : initialState.config,
      };
    case ActionTypes.GET_MERCHANT_SETTING_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.SET_CATEGORIES:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              categories: action.payload.categories,
            }
          : initialState.config,
      };
    case ActionTypes.ADD_CATEGORY:
      (state?.config?.categories ? state?.config?.categories : []).push(
        action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, categories: state?.config?.categories }
          : initialState.config,
      };
    case ActionTypes.UPDATE_CATEGORY:
      const categories = state?.config?.categories
        ? state?.config?.categories
        : [];
      const newCategories = categories.map((cat, index) =>
        index === action.payload.index ? action.payload.category : cat,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, categories: newCategories }
          : initialState.config,
      };
    case ActionTypes.REMOVE_CATEGORY:
      _.remove(
        state?.config?.categories ? state?.config?.categories : [],
        (category, index) => index === action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, categories: state?.config?.categories }
          : initialState.config,
      };
    case ActionTypes.ADD_TAX:
      (state?.config?.taxes ? state?.config?.taxes : []).push(action.payload);
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, taxes: state?.config?.taxes }
          : initialState.config,
      };
    case ActionTypes.UPDATE_TAX:
      const taxes = state?.config?.taxes ? state?.config?.taxes : [];
      const newTaxes = taxes.map((cat, index) =>
        index === action.payload.index ? action.payload.tax : cat,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, taxes: newTaxes }
          : initialState.config,
      };
    case ActionTypes.SET_COMMISSION_OPT:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              commission: {
                ...state.config?.commission,
                options: action.payload,
              },
            }
          : initialState.config,
      };
    case ActionTypes.REMOVE_COMMISSION:
      const listRemove = state?.config?.commission?.list
        ? state?.config?.commission?.list
        : [];
      _.remove(listRemove, (category, index) => index === action.payload);
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              commission: { list: listRemove, options: action.payload.options },
            }
          : initialState.config,
      };
    case ActionTypes.ADD_COMMISSION:
      const listAdd = state?.config?.commission?.list
        ? state?.config?.commission?.list
        : [];
      listAdd.push(action.payload);
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              commission: {
                list: listAdd,
                options: state?.config?.commission.options,
              },
            }
          : initialState.config,
      };
    case ActionTypes.UPDATE_COMMISSION:
      const listUpdate = state?.config?.commission?.list
        ? state?.config?.commission?.list
        : [];
      const listCommission = listUpdate.map((cat, index) =>
        index === action.payload.index ? action.payload.commission : cat,
      );
      const newCommission = {
        ...state?.config?.commission,
        list: listCommission,
      };
      console.log('comparre ', newCommission === state?.config?.commission);
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, commission: newCommission }
          : initialState.config,
      };
    case ActionTypes.REMOVE_TAX:
      _.remove(
        state?.config?.taxes ? state?.config?.taxes : [],
        (category, index) => index === action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, taxes: state?.config?.taxes }
          : initialState.config,
      };
    case ActionTypes.SET_INGREDIENTS:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              ingredients: action.payload.ingredients,
            }
          : initialState.config,
      };
    case ActionTypes.ADD_INGREDIENT:
      (state?.config?.ingredients ? state?.config?.ingredients : []).push(
        action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, ingredients: state?.config?.ingredients }
          : initialState.config,
      };
    case ActionTypes.UPDATE_INGREDIENT:
      const ingredients = state?.config?.ingredients
        ? state?.config?.ingredients
        : [];
      const newIngredients = ingredients.map((ing, index) =>
        index === action.payload.index ? action.payload.ingredient : ing,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, ingredients: newIngredients }
          : initialState.config,
      };
    case ActionTypes.REMOVE_INGREDIENT:
      _.remove(
        state?.config?.ingredients ? state?.config?.ingredients : [],
        (ingredient, index) => index === action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, ingredients: state?.config?.ingredients }
          : initialState.config,
      };
    case ActionTypes.SET_COOKING_REQUEST_GROUPS:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              cookingRequestGroups: action.payload.cookingRequestGroups,
            }
          : initialState.config,
      };
    case ActionTypes.ADD_COOKING_REQUEST_GROUP:
      (state?.config?.cookingRequestGroups
        ? state?.config?.cookingRequestGroups
        : []
      ).push(action.payload);
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              cookingRequestGroups: state?.config?.cookingRequestGroups,
            }
          : initialState.config,
      };
    case ActionTypes.UPDATE_COOKING_REQUEST_GROUP:
      const cookingRequestGroups = state?.config?.cookingRequestGroups
        ? state?.config?.cookingRequestGroups
        : [];
      const newCookingRequestGroups = cookingRequestGroups.map((ing, index) =>
        index === action.payload.index
          ? action.payload.cookingRequestGroup
          : ing,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? { ...state.config, cookingRequestGroups: newCookingRequestGroups }
          : initialState.config,
      };
    case ActionTypes.REMOVE_COOKING_REQUEST_GROUP:
      _.remove(
        state?.config?.cookingRequestGroups
          ? state?.config?.cookingRequestGroups
          : [],
        (cookingRequestGroup, index) => index === action.payload,
      );
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              cookingRequestGroups: state?.config?.cookingRequestGroups,
            }
          : initialState.config,
      };
    case ActionTypes.SET_SETTING:
      return {
        ...state,
        isFetching: false,
        config: state?.config
          ? {
              ...state.config,
              setting: action.payload.setting,
            }
          : initialState.config,
      };
    default:
      return state;
  }
}
export default settingReducer;
