import { callApi } from 'utils/apiUtils';
import { put, takeLatest, select } from 'redux-saga/effects';
import _ from 'lodash';
import {
  getMenuConfigSuccess,
  getMenuConfigFail,
  getIngredientConfigSuccess,
  getIngredientConfigFail,
  getMeasureConfigSuccess,
  getMeasureConfigFail,
  getPreparationConfigSuccess,
  getPreparationConfigFail,
  getMerchantSettingFail,
  getMerchantSettingSuccess,
  setMerchantSettingFail,
  setMerchantSettingSuccess
  } from './actions';
import { apiError, apiSuccess } from '../../App/actions';
import { makeSelectLocale } from '../../LanguageProvider/selectors';
import ActionTypes from './constants';

const messages = [
  {"vi": "Cập nhật cài đặt thành công",
  "en": "Update successfully"},
  {"vi": "Cập nhật cài đặt thất bại",
  "en": "Update failed"},
]
export function* getCategories() {
  try {
    const result = yield callApi(
      `/menus/menu-categories`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getMenuConfigSuccess(result.data));
    } else {
      yield put(getMenuConfigFail(result.success));
    }
  } catch (error) {
    yield put(getMenuConfigFail(error.message));
  }
}

export function* getIngredients() {
  try {
    const result = yield callApi(
      `/products/ingredients`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getIngredientConfigSuccess(result.data));
    } else {
      yield put(getIngredientConfigFail(result.success));
    }
  } catch (error) {
    yield put(getIngredientConfigFail(error.message));
  }
}

export function* getMeasureUnits() {
  try {
    const result = yield callApi(
      `/products/measure-units`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getMeasureConfigSuccess(result.data));
    } else {
      yield put(getMeasureConfigFail(result.success));
    }
  } catch (error) {
    yield put(getMeasureConfigFail(error.message));
  }
}

export function* getPreparations() {
  try {
    const result = yield callApi(
      `/products/cooking-request-groups`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getPreparationConfigSuccess(result.data));
    } else {
      yield put(getPreparationConfigFail(result.success));
    }
  } catch (error) {
    yield put(getPreparationConfigFail(error.message));
  }
}

export function* getMerchantSetting() {
  try {
    const result = yield callApi(
      `/admin/setting/merchant`,
      'GET',
    );
    if (result.message === "success") {
      yield put(getMerchantSettingSuccess(result.data));
    } else {
      yield put(getMerchantSettingFail(result.success));
    }
  } catch (error) {
    yield put(getMerchantSettingFail(error.message));
  }
}

export function* setMerchantSetting({payload}) {
  const language = yield select(makeSelectLocale());
  try {
    const result = yield callApi(
      `/admin/setting/merchant`,
      'PUT',
      {...payload},
    );
    if (result.message === "success") {
      yield put(apiSuccess(messages[0][language]));
      yield put(setMerchantSettingSuccess(result.data));
    } else {
      yield put(apiError(messages[1][language]));
      yield put(setMerchantSettingFail(result.success));
    }
  } catch (error) {
    yield put(apiError(messages[1][language]));
    yield put(setMerchantSettingFail(error.message));
  }
}

export default function* watchSetting() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_CATEGORIES_CONFIG, getCategories);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_INGREDIENT_CONFIG, getIngredients);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_MEASURE_UNITS, getMeasureUnits);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PREPARATION_CONFIG, getPreparations);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_MERCHANT_SETTING, getMerchantSetting);
  // @ts-ignore
  yield takeLatest(ActionTypes.SET_MERCHANT_SETTING, setMerchantSetting);
}

