import { createSelector } from 'reselect';
import { ApplicationRootState } from 'types';
import { initialState } from './reducer';

/**
 * Direct selector to the customerList state domain
 */

const selectSettingDomain = (state: ApplicationRootState) =>
  state || initialState;

/**
 * Other specific selectors
 */

/**
 * Default selector used by CustomerList
 */

const makeSelectMerchantSetting = () =>
  createSelector(selectSettingDomain, substate => substate.setting);

const makeSelectSetting = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.setting : null,
  );

const makeSelectCategories = () =>
  createSelector(
    selectSettingDomain,
    substate => substate?.setting?.config?.categories,
  );

const makeSelectIngredients = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.ingredients : null,
  );

const makeSelectCookingRequestGroups = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config
      ? substate.setting.config.cookingRequestGroups
      : null,
  );

const makeSelectOpenTimes = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.merchantOpenTimes : null,
  );

const makeSelectWorkingTimes = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config
      ? substate.setting.config.merchantWorkingTimes
      : null,
  );

const makeSelectMeasureUnits = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting ? substate.setting.measureUnits : null,
  );

const makeSelectCloseTimes = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.merchantCloseTimes : null,
  );

const makeSelectPayrollSetting = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.payrollSetting : null,
  );

const makeSelectCommissionSetting = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.commission : null,
  );

const makeSelectTaxes = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.taxes : null,
  );
const makeSelectShippingFees = () =>
  createSelector(selectSettingDomain, substate =>
    substate.setting.config ? substate.setting.config.shippingFees : null,
  );

const makeSelectFletch = () =>
  createSelector(selectSettingDomain, substate => substate.setting.isFetching);

export {
  selectSettingDomain,
  makeSelectSetting,
  makeSelectCategories,
  makeSelectFletch,
  makeSelectIngredients,
  makeSelectCookingRequestGroups,
  makeSelectOpenTimes,
  makeSelectWorkingTimes,
  makeSelectCloseTimes,
  makeSelectPayrollSetting,
  makeSelectTaxes,
  makeSelectShippingFees,
  makeSelectMeasureUnits,
  makeSelectMerchantSetting,
  makeSelectCommissionSetting,
};
