import { CategoryModel } from './../../Menu/MenuList/menuListMenuModels';
import { ActionType } from 'typesafe-actions';
import * as actions from './actions';

export interface ConfigSettingModel {
  setting: MerchantSettingModel;
  general?: GeneralModel;
  categories?: CategoryModel[];
  ingredients?: IngredientModel[];
  cookingRequestGroups?: PreparationGroupModel[];
  merchantOpenTimes: any[];
  merchantWorkingTimes: any[];
  merchantCloseTimes: any[];
  payrollSetting: PayrollModel;
  commission: CommissionModel;
  taxes: any[];
  shippingFees: any[];
  measureUnits: MeasureUnitModel[];
}

export interface MerchantSettingModel {
  merchantId?: number;
  moneyExchanged?: number;
  pointExchanged?: number;
  serveDuration?: number;
  warningPercent?: number;
  taxPercent?: number;
  languageId?: number;
  hasOrderFee?: boolean;
  option1Distant?: number;
  option1Fee?: number;
  option2DistantFrom?: number;
  option2DistantTo?: number;
  option2Fee?: number;
  option3Distant?: number;
  option3Fee?: number;
  tip?: any;
}

export interface MeasureUnitModel {
  id: string | number;
  name: string;
}

export interface MenuModel {
  id?: number;
  name?: string;
  index?: number;
}

export interface OptionPayrollModel {
  id: number;
  name: string;
  type: number;
}

export interface PayrollModel {
  id?: number;
  merchantId?: number;
  payPeriod?: number;
  options?: OptionPayrollModel[];
}

export interface CommissionModel {
  list?: any[];
  options?: any[];
}

export interface TaxModel {
  id?: number;
  name?: string;
  percent?: string | number;
}
export interface ShippingFeesModel {
  id?: number;
  from?: number;
  to?: number;
  feeAmount?: string;
}

export interface IngredientModel {
  id?: number;
  name?: string;
  measureUnitId?: string;
}

export interface GeneralModel {
  serveDuration?: number;
  warningPercent?: number;
}

export interface CommissionModel {
  id?: number;
  name?: string;
  percent?: string | number;
}

export interface PreparationGroupModel {
  id?: number;
  name: string;
  cookingRequests: [PreparationItemModel];
}

export interface PreparationItemModel {
  id?: number;
  name: string;
}

interface SettingState {
  readonly message: string;
  readonly isFetching: boolean;
  readonly config: ConfigSettingModel | null;
  readonly measureUnits: MeasureUnitModel[];
}

/* --- ACTIONS --- */
type SettingActions = ActionType<typeof actions>;

/* --- EXPORTS --- */
type ContainerState = SettingState;
type ContainerActions = SettingActions;

export { ContainerState, ContainerActions };
