import React, { useEffect } from 'react';
import {
  Row,
  Col,
  Form,
  Button,
  Spin,
} from 'antd';
import { injectIntl } from 'react-intl';
import messagesGlobal from 'translations/messages';
import { LANGUAGE, LANGUAGE_API } from 'utils/constants';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from '../Store/reducer';
import saga from '../Store/saga';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { setMerchantSetting } from '../Store/actions';
import { makeSelectSetting, makeSelectFletch } from '../Store/selectors';
import { changeLocale } from '../../LanguageProvider/actions'
import LanguageSetting from './languageSetting';
import TimeUsingSetting from './timeUsingSetting';
import cacheUtils from 'utils/cacheUtils';
const stateSelector = createStructuredSelector({
  setting: makeSelectSetting(),
  isFletching: makeSelectFletch(),
});

function System(props) {
  const { intl } = props;
  useInjectReducer({ key: 'setting', reducer: reducer });
  useInjectSaga({ key: 'setting', saga: saga });
  const dispatch = useDispatch();
  const { setting, isFletching } = useSelector(stateSelector);
  const [form] = Form.useForm();
  useEffect(() => {
    // dispatch(getAdminConfig());
  }, []);
  useEffect(() => {
    if (setting) {
      form.setFieldsValue(setting);
    }
  }, [setting]);

  const onFinish = values => {
    dispatch(changeLocale(LANGUAGE[values.languageId]));
    const userInfo = cacheUtils.getUserInfo();
    if (userInfo) {
      const userInfoJson = JSON.parse(userInfo);
      cacheUtils.setUserInfo(
        JSON.stringify({
          ...userInfoJson,
          profile: {
            ...userInfoJson.profile,
            merchant: {
              ...userInfoJson.profile.merchant,
              setting: {
                ...userInfoJson.profile.merchant.setting,
                language: {
                  id: values.languageId,
                  code: LANGUAGE_API[values.languageId],
                },
                currency: values.currency,
              },
            },
          },
        }),
      );
    }
    dispatch(setMerchantSetting({setting: {...values}}))
  };

  return (
    <div
      style={{ paddingTop: 'unset' }}
      className="setting__group setting__group-third system-tab"
    >
      <Spin spinning={isFletching}>
        <Form form={form} onFinish={onFinish}>
        <div className="group">
            <Row gutter={12}>
              <Col xl={8} lg={10} md={12} sm={24} xs={24} className="language-card">
                <Row>
                  <div className="first-box">
                    <LanguageSetting />
                  </div>
                </Row>
              </Col>
              <Col
                xl={9} lg={11} md={11} sm={24} xs={24} 
                className="config-col-setting"
              >
                <div className="first-box">
                  <TimeUsingSetting />
                </div>
              </Col>
            </Row>
          </div>
          <div className="row setting__group-third__item">
            <div className="col-11 col-md-11">
              <div className="setting__group-third__content setting__group-third__content-second">
                <Button
                  type="primary"
                  className="custormButton"
                  htmlType="submit"
                >
                  {intl.formatMessage(messagesGlobal.save)}
                </Button>
              </div>
            </div>
          </div>
        </Form>
      </Spin>
    </div>
  );
}
export default injectIntl(System);
