import React from 'react';
import {
  Radio,
  Space,
  Row,
  Typography,
  Form,
  AutoComplete,
  Divider,
} from 'antd';
import { injectIntl } from 'react-intl';
import messages from '../I18t/messages';
import messagesGlobal from 'translations/messages';
import { currencies } from 'utils/constants';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import reducer from '../Store/reducer';
import saga from '../Store/saga';
import styled from 'styled-components';
import FloatLabel from 'components/FormatInput/FloatLabel';
const { Title, Paragraph } = Typography;
const LanguageSettingWrapper = styled.div`
  width: 100%;
  padding: 20px 20px 28px 20px;
  background-color: #ffffff;
  // height: 250px;
  .ant-divider.ant-divider-horizontal {
    margin: 15px 0;
  }
  .ant-form-item {
    margin-bottom: 0px !important;
    ant-select-selector {
      .ant-select-selection-search {
        top: 12px !important;
        font-size: 13px !important;
      }
    }
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  .ant-select-selection-search-input {
    height: unset!important; 
}
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
  .label-input {
    margin-top: 0.75em;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
  }
  .no-payroll {
    color: white;
    background-color: #dd3880;
  }
  .payroll {
    color: white;
    background-color: #00aaf6;
  }
  .tax-label {
    width: 100px;
  }
  .tax-label-currency {
    width: 100px;
    margin-bottom: 0px;
  }
  .currency-system {
    width: 100%;
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        width: 75%;
      }
      .ant-space-item:nth-child(2) {
        width: calc(70% + 8px);
      }
      @media only screen and (max-width: 402px) {
        display: inline;
        .ant-space-item:nth-child(1) {
          width: 100%;
          margin-bottom: 15px;
        }
        .ant-space-item:nth-child(2) {
          width: 100%;
        }
      }
    }
  }
`;

function LanguageSetting(props) {
  const { intl } = props;
  useInjectReducer({ key: 'setting', reducer: reducer });
  useInjectSaga({ key: 'setting', saga: saga });
  return (
    <LanguageSettingWrapper>
      <div className="group">
        <Row>
          <Title level={4} className="setting-menu-title">
            {intl.formatMessage(messagesGlobal.system)}
          </Title>
        </Row>
        <Row>
          {/* <Paragraph className="setting-label-language">
              {intl.formatMessage(messagesGlobal.language)}
          </Paragraph> */}
          <Form.Item
            name="languageId"
            rules={[
              {
                required: true,
                message: intl.formatMessage(messagesGlobal.requiredChoose),
              },
            ]}
            className="formItem-language"
          >
            <Radio.Group name="languageId" defaultValue={'2'}>
              <Space size="small">
                <Radio value={'2'}>
                  {intl.formatMessage(messages.vietnamese)}
                </Radio>
                <Radio value={'1'}>
                  {intl.formatMessage(messages.english)}
                </Radio>
              </Space>
            </Radio.Group>
          </Form.Item>
        </Row>
        <Divider />
        <Row className="currency-system">
          <Space align="center">
          <Paragraph className="">
              {intl.formatMessage(messagesGlobal.currency)}
          </Paragraph>
            <Form.Item
              name="currency"
              rules={[
                {
                  required: true,
                  message: intl.formatMessage(messagesGlobal.requiredInput),
                },
              ]}
            >
              <FloatLabel
                className="autocomplete"
                style={{ minWidth: 100 }}
                options={currencies}
                // label={intl.formatMessage(messagesGlobal.currency)}
                typeInput="autocomplete"
                showArrow
              />
            </Form.Item>
          </Space>
        </Row>
      </div>
    </LanguageSettingWrapper>
  );
}
export default injectIntl(LanguageSetting);
