import React from 'react';
import styled from 'styled-components';
import { Typography, Form, Row, Col, Input, Radio, Space, Divider } from 'antd';
import { injectIntl } from 'react-intl';
import messagesGlobal from 'translations/messages';
import FloatLabel from 'components/FormatInput/FloatLabel';
const MenuSettingWrapper = styled.div`
  width: 100%;
  padding: 20px;
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 15px 0;
    margin-top: 55px;
  }
  .ant-form-item {
    margin-bottom: 0px;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
  .label-input {
    margin-top: 0.75em;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
  }
  .no-payroll {
    color: white;
    background-color: #dd3880;
  }
  .payroll {
    color: white;
    background-color: #00aaf6;
  }
  .form-item-timeUsing {
    margin-bottom: 26px;
  }
  .ant-input {
    padding: 0px 0px 0px 11px !important; 
  }
  .currency-system {
    width: 100%;
    .ant-space {
      width: 100%;
      .ant-space-item:nth-child(1) {
        width: 75%;
      }
      .ant-space-item:nth-child(2) {
        width: calc(70% + 8px);
      }
      @media only screen and (max-width: 402px) {
        display: inline;
        .ant-space-item:nth-child(1) {
          width: 100%;
          margin-bottom: 15px;
        }
        .ant-space-item:nth-child(2) {
          width: 100%;
        }
      }
    }
  }
`;
const { Title, Paragraph } = Typography;
function TimeUsingSetting({ intl }) {
  return (
    <MenuSettingWrapper>
      <Title level={4} className="setting-config">
        {intl.formatMessage(messagesGlobal.timeUsing)}
      </Title>
      <Row className="currency-system">
        <Space align="center">
          <Paragraph className="">
            {intl.formatMessage(messagesGlobal.titleTimeUsing)}
          </Paragraph>
          <Form.Item
            name="serveDuration"
            rules={[
              {
                pattern: new RegExp('^[0-9]*$'),
                message: intl.formatMessage(messagesGlobal.requiredInputNumber),
              },
            ]}
            className="form-item-timeUsing"
          >
            <FloatLabel
              addonAfter={intl.formatMessage(messagesGlobal.day)}
            />
          </Form.Item>
        </Space>
      </Row>
      <Row className="currency-system">
        <Space align="center">
          <Paragraph className="">
            {intl.formatMessage(messagesGlobal.giftUsing)}
          </Paragraph>
          <Form.Item
            name="giftCardDuration"
            rules={[
              {
                pattern: new RegExp('^[0-9]*$'),
                message: intl.formatMessage(messagesGlobal.requiredInputNumber),
              },
            ]}
          >
            <FloatLabel
              addonAfter={intl.formatMessage(messagesGlobal.day)}
            />
          </Form.Item>
        </Space>
      </Row>
    </MenuSettingWrapper>
  );
}
export default injectIntl(TimeUsingSetting);
