import React, { useState } from 'react';
import styled from 'styled-components';
import { TaxModel } from '../Store/types';
import { Space, Divider, Col, Modal, Typography, notification } from 'antd';
import Icon, { EditFilled, DeleteFilled } from '@ant-design/icons';
import CreateEditTaxCategory from './createEditTaxCategory';
import { injectIntl } from 'react-intl';
import messages from 'translations/messages';
import { removeTax } from '../Store/actions';
import { useDispatch } from 'react-redux';

const CardTax = styled.div`
  margin: 0px 5px;
  border-radius: 16px;
  border: 1px solid #dddddd;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  width: 100%;
  height: 32px;
  display: flex;
  padding: 0px 5px;
  align-items: center;
  justify-content: center;
  color: white;
  background-color: #4A4A4A;
  :hover {
    width: 100%;
  }
`;

const HovereddCard = styled.div`
  // .anticon:hover {
  //   cursor: pointer;
  //   color: #dc5454;
  // }
`;
const { Title } = Typography;

interface Props {
  tax: TaxModel;
  onOpenCreateMenuModal?: any;
  getTaxList?: any;
  intl?: any;
  taxes: any[] | null;
  handleChangeTax?: any;
  index?: any;
}

const HoveredExpand = injectIntl((props: Props) => {
  const { tax, onOpenCreateMenuModal, taxes, handleChangeTax, index, intl } = props;
  const dispatch = useDispatch();
  const handleOnClickDelete = async () => {
    Modal.confirm({
      title: (
        <Title level={4}>
          {intl.formatMessage(messages.titleConfirmDeleted, { item: `${tax.name}` })}
        </Title>
      ),
      content: (
        intl.formatMessage(messages.contentConfirmDeleted, { item: `${tax.name}` })
      ),
      okText: (
        intl.formatMessage(messages.deleteBtn)
      ),
      cancelText: (
        intl.formatMessage(messages.cancelBtn)
      ),
      keyboard: true,
      onOk: async () => {
        dispatch(removeTax(index));
      },
    });
  };
  return (
    <HovereddCard>
      <Space size={-5}>
        <EditFilled onClick={() => onOpenCreateMenuModal()} />
        <Divider type="vertical" />
        <DeleteFilled onClick={() => handleOnClickDelete()} />
      </Space>
    </HovereddCard>
  );
})

export function TaxCard(props: Props) {
  const { tax, handleChangeTax, taxes, index } = props;
  const [isHovered, setHovered] = useState(false);
  const [openEditMenuModal, setOpenEditMenuModal] = useState(false);

  return (
    <Col>
      <CardTax
        onMouseOver={() => setHovered(true)}
        onMouseLeave={() => setHovered(false)}
      >
        <Space>
          <div>{`${tax.name} - ${tax.percent}%`}</div>
          {isHovered && (
            <HoveredExpand
              tax={tax}
              onOpenCreateMenuModal={() => setOpenEditMenuModal(true)}
              taxes={taxes}
              handleChangeTax={handleChangeTax}
              index={index}
            />
          )}
        </Space>
      </CardTax>
      {openEditMenuModal && (
        <CreateEditTaxCategory
          visible={openEditMenuModal}
          onCancel={() => setOpenEditMenuModal(false)}
          taxes={taxes}
          isCreate={false}
          tax={tax}
          handleChangeTax={handleChangeTax}
          index={index}
        />
      )}
    </Col>
  );
}
