import React, { useState, useRef } from 'react';
import {
  Modal,
  Button,
  Input,
  Form,
  notification,
  Typography,
  Space,
} from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import messages from 'translations/messages';
import messagesLocal from '../I18t/messages';
import styled from 'styled-components';
import { validatePercent } from 'utils/validation';
import { TaxModel } from '../Store/types';
import { addTax, updateTax } from '../Store/actions';
import { useSelector, useDispatch } from 'react-redux';
import { makeSelectFletch } from '../Store/selectors';
import { createStructuredSelector } from 'reselect';
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  isFletching: makeSelectFletch(),
});

const CreateTaxCategoryWrapper = styled.div`
  display: flex;
  justify-content: center;
  .modal-edit {
    &__menu {
      &--title {
        font-size: 15px;
        line-height: 19px;
        text-align: center;
      }
    }
  }
  .ant-input-group-wrapper {
    .ant-input-group {
      input {
        border-right: none;
      }
      .ant-input-group-addon:last-child {
        border-radius: 22px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
        width: 53px;
        background: white;
        border-left: none;
      }
    }
  }
`;
const { Title, Text } = Typography;
interface Props {
  visible: boolean;
  onCancel(): any;
  getTaxList: any;
  isCreate: boolean;
  tax?: TaxModel;
  intl: any;
  index?: any;
}

function CreateTaxCategory(props: Props) {
  const { visible, onCancel, isCreate, tax, intl, index } = props;
  const [form] = Form.useForm();
  const { isFletching } = useSelector(stateSelector);
  const dispatch = useDispatch();
  const onFinish = async values => {
    if (tax) {
      dispatch(updateTax({id: tax.id, ...values}, index))
    } else {
      dispatch(addTax(values))
    }
    onCancel();
  };

  return (
    <Form
      form={form}
      name="horizontal_login"
      onFinish={onFinish}
      layout="horizontal"
      size="middle"
      initialValues={tax ? tax : {}}
    >
      <Modal
        visible={visible}
        onCancel={onCancel}
        width={330}
        centered
        footer={null}
      >
        <CreateTaxCategoryWrapper>
          <Space direction="vertical" style={{ width: '100%' }}>
            <Title level={4} className="modal-edit__menu--title">
              {isCreate ? (
                <FormattedMessage {...messages.addTaxCategory} />
              ) : (
                <FormattedMessage {...messages.editTaxCategory} />
              )}
            </Title>
            <Form.Item
              colon={false}
              name="name"
              rules={[
                { required: true, message: <FormattedMessage {...messages.requiredInput} />},
              ]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messages.taxName)}`} />
            </Form.Item>
            <Form.Item
              colon={false}
              name="percent"
              rules={[
                {
                  pattern: new RegExp("^\\d+(\\.\\d{1,2})?$"),
                  message: intl.formatMessage(messages.requiredInputNumber) 
                },
                validatePercent]}
              style={{ width: '100%', marginBottom: '11px' }}
            >
              <FloatLabel label={`${intl.formatMessage(messagesLocal.percent)}`} addonAfter="%"/>
            </Form.Item>
            <Form.Item>
            <Button
            type="primary"
            htmlType="submit"
            style={{width: '100%'}}
            loading={isFletching}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onFinish(values);
                })
                .catch(info => {
                  console.log('Validate Failed:', info);
                });
            }}><FormattedMessage {...messages.save} /></Button>
            </Form.Item>
          </Space>
        </CreateTaxCategoryWrapper>
      </Modal>
    </Form>
  );
}
export default injectIntl(CreateTaxCategory);