import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { TaxModel } from '../Store/types';
import { PlusOutlined } from '@ant-design/icons';
import { Typography, Row, Button, Spin } from 'antd';
import { TaxCard } from './cardTax';
import CreateTaxCategory from './createEditTaxCategory';
import { injectIntl } from 'react-intl';
import messagesGlobal from 'translations/messages';
import { setMerchantSetting } from '../Store/actions';
import {
  makeSelectTaxes,
  makeSelectFletch,
  makeSelectMerchantSetting,
} from '../Store/selectors';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
const stateSelector = createStructuredSelector({
  merchantSetting: makeSelectMerchantSetting(),
  taxes: makeSelectTaxes(),
  isFletching: makeSelectFletch(),
});
const TaxSettingWrapper = styled.div`
  margin-bottom: 20px;
  width: 100%;
  padding: 20px;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1);
  background-color: #ffffff;
  .ant-divider.ant-divider-horizontal {
    margin: 3px 0;
  }
  .setting-menu {
    display: flex;
    justify-content: space-between;
  }
  button {
    span {
      display: inline-flex;
    }
  }
  h4 {
    flex: 1;
  }
  @media only screen and (min-width: 992px) {
    width: 60%;
  }
  @media only screen and (min-width: 786px) {
    width: 70%;
  }
  @media only screen and (min-width: 1200px) {
    width: 30%;
  }
`;
const { Title } = Typography;
function TaxSetting({ intl }) {
  const [openCreateMenuModal, setOpenCreateMenuModal] = useState(false);
  const { taxes, isFletching } = useSelector(stateSelector);
  const dispatch = useDispatch();
  const onFinish = () => {
    dispatch(setMerchantSetting({ taxes: taxes }));
  };
  return (
    <>
      <Spin spinning={isFletching}>
        <TaxSettingWrapper>
          <div className="setting-menu">
            <Title level={4} className="setting-menu-title">
              {intl.formatMessage(messagesGlobal.tax)}
            </Title>
            <Button
              type="primary"
              shape="circle"
              icon={<PlusOutlined />}
              size="large"
              onClick={() => setOpenCreateMenuModal(true)}
            />
          </div>
          <Row gutter={[10, 10]}>
            {(taxes ? taxes : []).map((tax, index) => (
              <TaxCard tax={tax} key={index} taxes={taxes} index={index} />
            ))}
          </Row>
          {openCreateMenuModal && (
            <CreateTaxCategory
              visible={openCreateMenuModal}
              onCancel={() => setOpenCreateMenuModal(false)}
              axes={taxes}
              isCreate={true}
            />
          )}
        </TaxSettingWrapper>
      </Spin>
      <div className="row">
        <div className="col-11 col-md-11">
          <div className="setting__group-third__content setting__group-third__content-second">
            <Button
              type="primary"
              className="custormButton"
              htmlType="submit"
              onClick={onFinish}
              size="large"
            >
              {intl.formatMessage(messagesGlobal.save)}
            </Button>
          </div>
        </div>
      </div>
    </>
  );
}
export default injectIntl(TaxSetting);
