import React, { useEffect } from 'react';
import { Tabs } from 'antd';
import "./index.scss"
import styled from 'styled-components';
import reducer from './Store/reducer';
import saga from './Store/saga';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import Menu from './Menu';
import OperationTime from './OperationTime';
import ShippingFee from './ShippingFee/ShippingSetting';
import PayrollSetting from './PayRoll/payrollSetting';
import TaxSetting from './Tax/taxSetting';
import CommissionSetting from './Commission/commissionSetting';
import System from './System';
import CustomerServiceSetting from './CustomerService/customerServiceSetting';
import { getMeasureConfig, getMerchantSetting } from './Store/actions'
import { useDispatch } from 'react-redux';
const { TabPane } = Tabs;
const SettingWrapper = styled.div`
  .ant-switch-handle {
    top: -7px;
  }
  .setting {
    padding-left: 30px;
    padding-right: 30px;
  }
`;
function callback(key) {
  console.log(key);
}

export default function Setting(props) {
  useInjectReducer({ key: 'setting', reducer: reducer });
  useInjectSaga({ key: 'setting', saga: saga });
  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(getMerchantSetting())
    dispatch(getMeasureConfig());
  }, []);
  return (
    <SettingWrapper>
      <div className="setting">
        <Tabs className="tabCustorm" defaultActiveKey="1" onChange={callback}>
          <TabPane tab={<FormattedMessage {...messages.productAndService} />} key="1">
            <Menu />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.openTime} />} key="2">
            <OperationTime />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.deliveryFee} />} key="3">
            <ShippingFee />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.payroll} />} key="4">
            <PayrollSetting />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.tax} />} key="5">
            <TaxSetting />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.customerService} />} key="6">
            <CustomerServiceSetting />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.commission} />} key="7">
            <CommissionSetting />
          </TabPane>
          <TabPane tab={<FormattedMessage {...messages.system} />} key="8">
            <System />
          </TabPane>
        </Tabs>
      </div>
    </SettingWrapper>
  )
}
