import React, { useState, useEffect } from 'react';
import { useHistory } from 'react-router-dom';
import { Button, Form, DatePicker, Row, Col } from 'antd';
import { FormattedMessage, injectIntl } from 'react-intl';
import { PayrollHistoryHeaderWrapper } from '../../styles';
import messages from 'translations/messages';
import messagesLocal from '../../messages';
import moment from 'moment';
import { disabledDate } from 'utils/common';
import { DATE_FORMAT } from 'utils/constants';
import FloatLabel from 'components/FormatInput/FloatLabel';

function Header(props) {
  const { onClickSearch, search, total, intl } = props;
  const onChangeFrom = (date, dateString) => {
    const date1 = moment(date).toISOString();
    onClickSearch({ ...search, fromDate: date1 });
  };
  const onChangeTo = (date, dateString) => {
    const date1 = moment(date).toISOString();
    onClickSearch({ ...search, toDate: date1 });
  };
  return (
    <PayrollHistoryHeaderWrapper>
      <Row className="header-row">
        <Col xl={12} lg={8} md={5} sm={6} xs={5}>
          <div className="tabs">
            <h3 className="header__title">
              {intl.formatMessage(messages.history)}
            </h3>
          </div>
        </Col>
        <Col xl={12} lg={16} md={19} sm={18} xs={19}>
          <Form className="form">
            <div className="filter">
              <Row className="filter__common" gutter={[12, 0]}>
                <Col span={9}>
                  <Form.Item className="filter__from-date" name="restaurant">
                    <FloatLabel
                      label={intl.formatMessage(messages.fromDate)}
                      format={DATE_FORMAT}
                      disabledDate={disabledDate}
                      onChange={onChangeFrom}
                      defaultValue={
                        search.fromDate ? moment(search.fromDate) : undefined
                      }
                      typeInput="datepicker"
                    />
                  </Form.Item>
                </Col>
                <Col span={9}>
                  <Form.Item className="filter__to-date" name="category">
                    <FloatLabel
                      label={intl.formatMessage(messages.toDate)}
                      format={DATE_FORMAT}
                      disabledDate={disabledDate}
                      onChange={onChangeTo}
                      defaultValue={
                        search.toDate ? moment(search.toDate) : undefined
                      }
                      typeInput="datepicker"
                    />
                  </Form.Item>
                </Col>
                <Col span={6}>
                  <Row className="filter__total">
                    <span className="title">{`${intl.formatMessage(
                      messages.workedHour,
                    )} `}</span>
                    <span className="total">{total ? total : 0}</span>
                  </Row>
                </Col>
              </Row>
            </div>
          </Form>
        </Col>
      </Row>
    </PayrollHistoryHeaderWrapper>
  );
}
export default injectIntl(Header);
