import React, { useState } from "react";
import { Table, Typography } from "antd";
import Header from './header'
import { injectIntl } from "react-intl";
import { WorkingHistoryWrapper } from "../../styles";
import NumberFormat from 'react-number-format';
import messages from "../../messages";
import moment from "moment";
import messagesGlobal from "translations/messages";
import IMG_INVENTORY_EDIT from 'images/information-ic.svg';
import { useDispatch } from 'react-redux';
import {
  getStaffCommissionHistory
} from '../../actions';

function CommissionHistory(props) {
  const { commissionHistory, search, intl, onClickSearch, staff } = props;
  const { list, count, total } = commissionHistory;
  const dispatch = useDispatch();
  const handleClickPageNumber = (page, pageSize) => {
    const newSearchCommisson= { ...search, page: page, limit:  pageSize};
    dispatch(getStaffCommissionHistory( staff.id, newSearchCommisson ));
  };
  const config = {
    pagination: {
      total: count
    },
  };
  const columns = [
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.date)}</Typography.Text>,
      dataIndex: 'createdTime',
      key: 'createdTime',
      width: '15%',
      className: 'first-col',
      render: text => <div>{text ? moment.utc(text).local().format('DD/MM/YYYY') : '-'}</div>
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.service)} / {intl.formatMessage(messagesGlobal.product)}</Typography.Text>,
      dataIndex: 'name',
      key: 'name',
      width: '45%',
      render: (text, row, index) => {
        return {
          children: (
            <span>
              {text}
            </span>
          ),
        };
      },
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.amount)}</Typography.Text>,
      dataIndex: 'amount',
      key: 'amount',
      width: '20%',
      render: (text, row, index) => {
        return {
          children: (
            <span>
              <NumberFormat
                value={text}
                displayType={'text'}
                thousandSeparator={true}
                renderText={value => value}
              />
            </span>
          ),
        };
      },
    },
    {
      title: <Typography.Text ellipsis> {intl.formatMessage(messagesGlobal.commission)}</Typography.Text>,
      dataIndex: 'commissionAmount',
      key: 'commissionAmount',
      width: '20%',
      className: 'checkout-col',
      render: (text, row, index) => {
        return {
          children: (
            <span>
              <NumberFormat
                value={text}
                displayType={'text'}
                thousandSeparator={true}
                renderText={value => value}
              />
            </span>
          ),
        };
      },
    },
  ]
  return (
    <WorkingHistoryWrapper style={{height: '100%'}}>
      <div className="working-history_header">
          <Header onClickSearch={onClickSearch} search={search} total={total}/>
      </div>
      <div className="working-history_main">
        <Table dataSource={list} columns={columns} onChange={handleClickPageNumber} pagination={config.pagination}/>
      </div>
    </WorkingHistoryWrapper>
  )
}

export default injectIntl(CommissionHistory)
