import React, { useEffect, useState } from 'react';

import { Form, Select, Typography, Row, Col, Button } from 'antd';
import { useDispatch, useSelector } from 'react-redux';
import { FormattedMessage, injectIntl } from 'react-intl';
import _ from 'lodash';

import { useParams } from 'react-router-dom';

import { StaffPayrollWrapper } from '../styles';
import CommissionHistory from './CommissionHistory';
import messages from '../messages';
import messagesGlobal from 'translations/messages';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import { formatCurrency } from 'utils/common';
import {
  getStaffCommissionHistory,
  setSearchCommission,
  updateStaff
} from '../actions';
import { createStructuredSelector } from 'reselect';
import makeSelectStaffDetail from '../selectors';
import FloatLabel from 'components/FormatInput/FloatLabel';

const stateSelector = createStructuredSelector({
  staffDetail: makeSelectStaffDetail(),
});

function Commission(props) {
  const dispatch = useDispatch();
  const { staffDetail } = useSelector(stateSelector);
  const {
    searchCommission,
    commissions,
    commissionHistory
  } = staffDetail;
  const { staff, intl } = props;
  const [form] = Form.useForm();
  // @ts-ignore
  const { id } = useParams();

  const onClickSearch = (filterValues) => {
    // @ts-ignore
    const newSearch = Object.assign(searchCommission, filterValues);
    dispatch(getStaffCommissionHistory(id, newSearch));
    dispatch(setSearchCommission(newSearch))
  }
  const onFinish = values => {
    values = formatCurrency(values);
    if (values.paySetting) {
      values.paySetting.commissionId =
        values.paySetting.commissionId !== 0
          ? values.paySetting.commissionId
          : null;
    }
    values.paySetting = Object.assign({...staff.paySetting}, {...values.paySetting});
    values.paySetting = JSON.stringify(values.paySetting);
    dispatch(updateStaff({ id, staff: {paySetting: values.paySetting, workingTimeIds: staff.workingTimeIds}}));
  };

  useEffect(() => {
    if (staff) {
      form.setFieldsValue(staff);
    }
  }, [staff]);

  return (
    <Form form={form} onFinish={onFinish}>
      <StaffPayrollWrapper>
        <Row>
          <Col xl={6} lg={7} md={8} sm={24} xs={24}>
            <div>
              <h3 className="title-global">
                {intl.formatMessage(messagesGlobal.commission)}
              </h3>
              <div className="section">
                <Form.Item
                  name={["paySetting", "commissionId"]}
                  className="section__item--small"
                  rules={[
                    {
                      pattern: new RegExp('^[0-9]*$'),
                      message: intl.formatMessage(
                        messagesGlobal.requiredInputNumber,
                      ),
                    },
                  ]}
                >
                  <FloatLabel
                    size="large"
                    label={intl.formatMessage(messagesGlobal.commission)}
                    items={commissions}
                    typeInput="selectMutil"
                  />
                </Form.Item>
                <Button className="btn" type="primary" htmlType="submit">
                  <FormattedMessage {...messages.save} />
                </Button>
              </div>
            </div>
          </Col>
          <Col xl={18} lg={17} md={16} sm={24} xs={24}>
            <div>
              <CommissionHistory commissionHistory={commissionHistory} search={searchCommission} onClickSearch={onClickSearch} staff={staff}/>
            </div>
          </Col>
        </Row>
      </StaffPayrollWrapper>
    </Form>
  );
}
export default injectIntl(Commission);