import React, { useState } from "react";
import { Popover } from "antd";
import { DeactiveIcon, LockIcon, ThreeDotsIcon } from "styles/icon-components";
import { blockStaff, unBlockStaff } from "../../actions";
import { useDispatch } from "react-redux";
import ChangePasswordModal from "components/ChangePasswordModal";
import { ActionListWrapper } from "../../styles";
import { FormattedMessage } from "react-intl";
import messages from "../../messages";

const actionContent = (props) => {
  const dispatch = useDispatch();
  const { id, status, handleVisibleChange } = props;
  const [showModal, setShowModal] = useState(false);
  const handleClickChangePassword = () => {
    setShowModal(true);
  }
  const handleClickDeactive = () => {
    dispatch(blockStaff(id));
  }
  const handleClickActive = () => {
    dispatch(unBlockStaff(id));
  }
  const handleCancel = () => {
    setShowModal(false);
  }
  const handleOk = () => {
    setShowModal(false);
  }
  return (
   <ActionListWrapper>
      <div className="staff-info-action">
        <div className="staff-info-action__edit" onClick={handleClickChangePassword}>
          <LockIcon/> <FormattedMessage {...messages.changePassword} />
        </div>
        {
          status && status.statusId === 3 ? (
            <div className="staff-info-action__delete" onClick={handleClickActive}>
              <DeactiveIcon /> <FormattedMessage {...messages.unlockAccount} />
            </div>
          ) : (
            <div className="staff-info-action__delete" onClick={handleClickDeactive}>
              <DeactiveIcon /> <FormattedMessage {...messages.lockAccount} />
            </div>
          )
        }
      </div>
     <ChangePasswordModal id={id} visible={showModal} onOk={handleOk} onCancel={handleCancel} />
   </ActionListWrapper>
  )
}

export default function Actions(props) {
  return (
    <Popover content={actionContent({...props})} trigger="click">
      <div><ThreeDotsIcon/></div>
    </Popover>
  )
}
