import React, { useEffect, useState } from 'react';

import {
  Button,
  DatePicker,
  Form,
  Input,
  Select,
  Upload,
  notification,
  Typography,
  Row,
  Col,
} from 'antd';
import { FormatInput } from 'components/FormatInput';
import { useDispatch } from 'react-redux';
import { FormattedMessage, injectIntl } from 'react-intl';

import moment from 'moment';
import _ from 'lodash';

import { PUBLIC_API } from 'containers/App/urls';
import { useParams } from 'react-router-dom';
import ChangePasswordModal from 'components/ChangePasswordModal';

import Actions from './Actions';
import { NewStaffInfosWrapper } from '../styles';
import messages from '../messages';
import messagesStaff from '../../StaffAddNew/messages';
import messagesGlobal from 'translations/messages';
import { updateStaff } from '../actions';
import { disabledDate, formatCurrency } from 'utils/common';
import { validateRequiredSpace, fileValidation } from 'utils/validation';
import { useCurrencyHook } from '../../../components/CustomHook/useCurrencyHook';
import { extractPhoneNumber } from 'utils/common';
import FloatLabel from 'components/FormatInput/FloatLabel';

const { Option } = Select;
const { Title, Paragraph } = Typography;
function Information(props) {
  const dispatch = useDispatch();
  const { staff, roles, restaurants, intl, prefixSelector } = props;
  const [form] = Form.useForm();
  // @ts-ignore
  const { id } = useParams();
  const [showPopup, setShowPopup] = useState(false);

  const dateFormat = 'DD/MM/YYYY';

  const onClickCancelChangePassword = () => {
    setShowPopup(false);
  };

  const onFinish = values => {
    values = formatCurrency(values);
    if (values.paySetting) {
      values.paySetting.commissionId =
        values.paySetting.commissionId !== 0
          ? values.paySetting.commissionId
          : null;
      values.paySetting = JSON.stringify(values.paySetting);
    }

    const { dateOfBirth, restaurantIds } = values;
    let { files } = values;
    values.dateOfBirth = dateOfBirth
      ? dateOfBirth.format(dateFormat)
      : dateOfBirth;
    if (files) {
      values.files = files.file;
    }
    if (values.phoneNumber) {
      values.phoneNumber = values.phoneCountryCode + values.phoneNumber;
    }
    delete values.restaurantIds;
    if (restaurantIds) {
      values.restaurantId = restaurantIds;
    }
    dispatch(updateStaff({ id, staff: values }));
  };

  useEffect(() => {
    if (staff.dateOfBirth) {
      staff.dateOfBirth = moment(staff.dateOfBirth);
    }
    if (staff.paySetting) {
      if (staff.paySetting.extraAmount) {
        staff.paySetting.extraAmount = parseInt(staff.paySetting.extraAmount);
      }
      if (staff.paySetting.payAmount) {
        staff.paySetting.payAmount = parseInt(staff.paySetting.payAmount);
      }
    }
    if (staff.phone) {
      const [code, number] = extractPhoneNumber(
        staff.phone,
        staff.phoneCountryCode,
      );
      staff.phoneNumber = number;
    }
    form.setFieldsValue(staff);
  }, [staff, restaurants]);
  return (
    <>
      <NewStaffInfosWrapper>
        <Row>
          <Col xl={9} lg={12} md={12} sm={24} xs={24} className="information-body">
            <Form form={form} onFinish={onFinish}>
              <div className="infor-card">
                <div className="header">
                  <h3 className="title-global">
                    {intl.formatMessage(messagesGlobal.general)}
                  </h3>
                </div>
                <div className="content">
                  <div className="content__info">
                    <div className="name">
                      <Form.Item
                        name="lastName"
                        rules={[
                          {
                            required: true,
                            message: intl.formatMessage(messages.requireStaffFirstName),
                          },
                        ]}
                      >
                        <FloatLabel
                          label={`${intl.formatMessage(messagesStaff.firstName)}*`}
                          maxLength={100}
                        />
                      </Form.Item>
                      <Form.Item
                        name="firstName"
                        rules={[
                          {
                            required: true,
                            message: intl.formatMessage(messagesStaff.requireName),
                          },
                        ]}
                      >
                        <FloatLabel
                          label={`${intl.formatMessage(messagesStaff.lastName)}*`}

                          maxLength={100}
                        />
                      </Form.Item>
                    </div>
                    <div className="ur">
                      <Form.Item name="gender">
                        <FloatLabel
                          className="padding-mutil-select"
                          label={intl.formatMessage(messages.gender)}
                          items={[{id: "male", name: intl.formatMessage(messages.male)},
                          {id: "female", name: intl.formatMessage(messages.female)},]}
                          typeInput="selectMutil"
                        />
                      </Form.Item>
                      <Form.Item
                        name="roleIds"
                        rules={[
                          {
                            required: true,
                            message: intl.formatMessage(messages.requireRole),
                          },
                        ]}
                        className="mutil-select"
                      >
                        <FloatLabel
                          className="padding-mutil-select"
                          size={40}
                          mode="multiple"
                          label={intl.formatMessage(
                            messages.roleAsterisk,
                          )}
                          showArrow
                          items={roles}
                          typeInput="selectMutil"
                        />
                      </Form.Item>
                    </div>
                    <Form.Item
                      name="username"
                      rules={[
                        {
                          required: true,
                          message: intl.formatMessage(messages.requireUsername),
                        },
                      ]}
                    >
                      <FloatLabel
                        // label={intl.formatMessage(messages.username)}
                        label={`${intl.formatMessage(messages.username)}*`}

                        maxLength={100}
                      />
                    </Form.Item>
                    <div className="pd">
                      <Form.Item
                        name="phoneNumber"
                        rules={[
                          {
                            message: intl.formatMessage(
                              messages.invalidPhoneNumber,
                            ),
                            pattern: /^[\d]+$/,
                          },
                          () => ({
                            validator(rule, value) {
                              if (value.length > 10) {
                                return Promise.reject(
                                  intl.formatMessage(messagesGlobal.invalidPhoneNumber),
                                );
                              } else {
                                return Promise.resolve();
                              }
                            },
                          }),
                        ]}
                      >
                        <FloatLabel
                          addonBefore={prefixSelector}
                          label={intl.formatMessage(messages.phoneNumber)}
                          maxLength={100}
                        />
                      </Form.Item>
                      <Form.Item name="dateOfBirth">
                        <FloatLabel
                          label={intl.formatMessage(messages.dob)}
                          format={dateFormat}
                          style={{ width: '100%' }}
                          disabledDate={disabledDate}
                          typeInput="datepicker"
                        />
                      </Form.Item>
                    </div>
                    <Form.Item name="address">
                      <FloatLabel
                        label={intl.formatMessage(messages.address)}
                        maxLength={150}
                      />
                    </Form.Item>
                    <Form.Item style={{ marginBottom: 0 }}>
                      <Form.Item
                        name="email"
                        rules={[
                          {
                            message: intl.formatMessage(messages.invalidEmail),
                            type: 'email',
                          },
                        ]}
                        style={{
                          display: 'inline-block',
                          width: 'calc(50% - 5px)',
                        }}
                      >
                        <FloatLabel label="Email" maxLength={100} />
                      </Form.Item>
                      <Form.Item
                        name="mst"
                        style={{
                          display: 'inline-block',
                          width: 'calc(50% - 5px)',
                          margin: '0 0 0 10px',
                        }}
                      >
                        <FloatLabel
                          label={intl.formatMessage(
                            messagesGlobal.mst,
                          )}
                          maxLength={100}
                        />
                      </Form.Item>
                    </Form.Item>
                  </div>
                </div>
              </div>
              <Button className="btn" type="primary" htmlType="submit">
                <FormattedMessage {...messages.save} />
              </Button>
              <Button
                type="primary"
                className="btn-pass"
                onClick={() => setShowPopup(true)}
              >
                {intl.formatMessage(messages.changePassword)}
              </Button>
            </Form>
          </Col>
        </Row>
        <ChangePasswordModal
          id={staff.id}
          visible={showPopup}
          onOk={onClickCancelChangePassword}
          onCancel={onClickCancelChangePassword}
        />
      </NewStaffInfosWrapper>
    </>
  );
}

export default injectIntl(Information);
