import React from 'react';
import {
  Divider,
  Row,
  Col,
  Modal,
} from 'antd';
import styled from 'styled-components';
import messages from 'translations/messages';
import { injectIntl } from 'react-intl';
import NumberFormat from 'react-number-format';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
const ModalWrapper = styled.div`
  .container {
    display: flex;
    flex-direction: column;
    flex-wrap: nowrap;
    justify-content: space-between;
    align-items: baseline;
    align-content: stretch;
    margin: auto;
    .ant-row {
      width: 100%;
    }
    div.ant-picker {
      border-radius: 22px;
    }
    .ant-divider {
      margin: 0 0 15px 0;
    }
    .ant-input-group-wrapper {
      .ant-input-group {
        input {
          border-right: none;
        }
        .ant-input-group-addon:last-child {
          border-radius: 22px;
          border-top-left-radius: 0;
          border-bottom-left-radius: 0;
          width: 53px;
          background: white;
          border-left: none;
        }
        .ant-input-disabled + .ant-input-group-addon{
          background: #f5f5f5;
        }
      }
    }
    .header {
      @media screen and (max-width: 576px) {
        .header {
          &__desc {
            display: inline-block;
          }
          &__img {
            margin-right: 0px;
            margin: auto;
          }
        }
      }
      &__desc {
        display: flex;
        flex-direction: row;
        justify-content: space-between;
        align-items: start;
        .quantity {
          width: 53px;
          height: 44px;
          display: flex;
          align-items: center;
          border-radius: 22px;
          background-color: #dc3b7f;
          span {
            margin: auto;
            color: white;
          }
        }
        &__right {
          display: flex;
          flex-direction: row;
          padding-top: 20px;
          .payPeriod {
            padding-right: 20px;
            text-align: end;
            &__title {
              color: #9c9696;
              margin-bottom: 13px;
            }
            &__time {
              font-weight: 600;
            }
          }
          .hours {
            &__title {
              color: #9c9696;
              margin-bottom: 13px;
            }
            &__number {
              text-align: end;
              font-weight: 600;
            }
          }
        }
      }
      &__infor {
        padding-top: 20px;
        &__staff {
          display: flex;
          align-items: center;
          margin-bottom: 13px;
        }
        &__name {
          font-weight: 600;
          font-size: 15px;
          color: #333333;
          line-height: 15px;
        }
        &__tax {
          margin-left: 15px;
          font-size: 10px;
          color: #9c9696;
          border-radius: 22px;
          border: solid 1px #9c9696;
          padding: 5px;
        }
        &__sku {
          color: #9c9696;
          line-height: 13px;
        }
        &__spa {
          text-align: start;
          font-size: 13px;
          &--name {
            color: #9c9696;
          }
          &--role {
            font-style: italic;
            color: #9cd339;
          }
        }
      }
      &__img {
        border-radius: 4px;
        height: 100px;
        width: 100px;
        text-align: center;
        margin-right: 20px;
        background-color: #ececec;
        img {
          border-radius: 4px;
          height: 100px;
          width: 100px;
          object-fit: cover;
        }
      }
    }
    .body-modal {
      > .ant-col {
        .elements-row {
          @media screen and (max-width: 576px) {
            margin-top: 20px;
          }
          padding: 18px;
          border-top-left-radius: 10px;
          border-top-right-radius: 10px;
          .ant-row {
            padding-bottom: 15px;
            .ant-col {
              font-size: 13px;
              line-height: 13px;
            }
            .amount-row {
              font-weight: 600;
              text-align: end;
            }
          }
          .header {
            &__modal, &__title {
              justify-content: center;
            }
            &__modal {
              margin-bottom: 20px;
            }
            &__title {
              font-size: 18px;
              font-weight: 500;
              margin-bottom: 10px;
            }
            
          }
        }
        .amount-row-last {

          padding: 18px;
          background: rgba(220,84,84,0.10);
          font-size: 14px;
          color: #DC5454;
          line-height: 14px;
          box-shadow: 0 0 2px 0 rgba(0, 0, 0, 0.2);
          border-bottom-left-radius: 10px;
          border-bottom-right-radius: 10px;
          .amount-row {
            font-weight: 600;
            text-align: end;
          }
        }
        .amount-row-first {
          padding-top 15px;
          border-top: solid 1px #e6e6e6;
        }
      }
    }
    .title {
      color: #333333;
      font-size: 16px;
      font-weight: 700;
      line-height: 19px;
      text-align: center;
      padding-bottom: 20px;
    }
    .btn-wrapper {
      width: 100%;
      text-align: center;
      .add-button {
        width: 70%;
        height: 44px;
        margin-top: 20px;
        font-weight: 600;
      }
    }
  }

  .first-row-input {
    border-top: solid 1px #e6e6e6;
    padding-top: 20px;
    margin-bottom: 0px;
  }
  .element-input-wrapper {
    width: 100%;
    input.element-input,
    div.element-input {
      width: 100%;
      height: 44px;
      border-radius: 22px;
      border: solid 1px #e6e6e6;
    }
  }

  .form-field {
    width: 100%;
    &__row {
      display: flex;
      flex-direction: row;
    }
    &__col {
      display: flex;
      flex-direction: row;
      flex: 0 1 90%;
      .ant-row {
        &:nth-child(1) {
          flex: 0 1 25%;
          margin-right: 2%;
        }
        &:nth-child(2) {
          flex: 0 1 70%;
        }
      }
    }
    &__plus {
      flex: 0 1 10%;
    }
  }
  .table {
    margin: auto;
    width: 100%;
    .ant-typography-ellipsis-single-line {
      font-size: 15px;
      font-weight: 600;
      overflow: unset;
      white-space: normal;
    }
    @media screen and (max-width: 576px) {
      .ant-table-thead > tr > th,
      .ant-table-tbody > tr > td,
      .ant-table tfoot > tr > th,
      .ant-table tfoot > tr > td {
        padding: 10px 10px;
      }
    }
    .txt_green {
      color: #35a211;
      text-align: center;
    }
    .txt_red {
      color: #dc5454;
      text-align: center;
    }
  }
`;

function Detail(props) {
  const { showPopup, payroll, onClose, intl } = props;
  const currencyMemoi = useCurrencyHook();
  const handleCancel = () => {
    onClose();
  };

  return (
      <Modal
        visible={showPopup}
        onCancel={handleCancel}
        centered
        footer={null}
        width={400}
      >
        <ModalWrapper>
          <div className="container">
            <Row className="body-modal" gutter={[12, 0]}>
            <Col>
                <Row className="elements-row">
                  <Row  className="header__modal">
                    <div>
                    {intl.formatMessage(messages.serviceCare)}
                  </div>
                  </Row>
                  <Row className="title-global">
                    <div>
                    {`${intl.formatMessage(messages.periodPayroll)} ${payroll.payPeriod}`}
                  </div>
                  </Row>
                  <Row className="amount-row-first">
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.basicSalary)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(payroll.payAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.commission)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(payroll.commissionAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.allowance)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(payroll.extraAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  {payroll.options.filter(op => op.type ===1).map(op => <Row>
                    <Col className="title-row" span={14}>
                      {op.name}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(op.amount ? op.amount : 0)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>)}
                  <Divider dashed={true}/>
                  <Row>
                    <Col className="title-row" span={14}>
                      {intl.formatMessage(messages.totalEarnings)}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(payroll.subAmount)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>
                  {payroll.options.filter(op => op.type === 2).map(op => <Row>
                    <Col className="title-row" span={14}>
                      {op.name}
                    </Col>
                    <Col className="amount-row" span={10}>
                      <NumberFormat
                        value={Math.round(op.amount ? op.amount : 0)}
                        displayType={'text'}
                        thousandSeparator={true}
                        renderText={value => `${value !== "0" ? '-' + value : 0} ${currencyMemoi}`}
                      />
                    </Col>
                  </Row>)}
                </Row>
                <Row className="amount-row-last">
                  <Col className="title-row" span={14}>
                    {intl.formatMessage(messages.netPay)}
                  </Col>
                  <Col className="amount-row" span={10}>
                    <NumberFormat
                      value={Math.round(payroll.totalAmount)}
                      displayType={'text'}
                      thousandSeparator={true}
                      renderText={value => `${value} ${currencyMemoi}`}
                    />
                  </Col>
                </Row>
              </Col>
            </Row>
          </div>
        </ModalWrapper>
      </Modal>
  );
}

export default injectIntl(Detail);