import React, { useState } from "react";
import { Table, Typography } from "antd";
import Header from './header'
import { injectIntl } from "react-intl";
import Detail from './detail'
import { WorkingHistoryWrapper } from "../../styles";
import NumberFormat from 'react-number-format';
import messages from "../../messages";
import messagesGlobal from "translations/messages";
import IMG_INVENTORY_EDIT from 'images/inventory-edit.svg';
import { useDispatch } from 'react-redux';
import {
  getPayrolls
} from '../../actions';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';

function PayrollHistory(props) {
  const { payrolls, search, intl, onClickSearch, staff } = props;
  const { list, count } = payrolls;
  const [showPopup, setShowPopup] = useState(false);
  const [payroll, setPayroll] = useState();
  const dispatch = useDispatch();
  const currencyMemoi = useCurrencyHook();
  const handleClick = key => {
    // dispatch(getPayroll(key.id));
    setShowPopup(true);
    setPayroll(list.find(p => p.id == key.id));
  };
  const handleClickPageNumber = (page, pageSize) => {
    const newSearchPayroll = { ...search, page: page, limit:  pageSize};
    dispatch(getPayrolls( staff.id, newSearchPayroll ));
  };
  const config = {
    pagination: {
      total: count
    },
  };
  const columns = [
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.periodPayroll)}</Typography.Text>,
      dataIndex: 'payPeriod',
      key: 'payPeriod',
      className: 'first-col'
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.workedHour)}</Typography.Text>,
      dataIndex: 'totalHours',
      key: 'totalHours'
    },
    {
      title: <Typography.Text ellipsis> {intl.formatMessage(messagesGlobal.earnings)}</Typography.Text>,
      dataIndex: 'subAmount',
      key: 'subAmount',
      render: (text, row, index) => {
        return {
          children: (
            <span>
              <NumberFormat
                value={text}
                displayType={'text'}
                thousandSeparator={true}
                renderText={value => `${value} ${currencyMemoi}`}
              />
            </span>
          ),
        };
      },
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.netPay)}</Typography.Text>,
      dataIndex: 'totalAmount',
      key: 'totalAmount',
      render: (text, row, index) => {
        return {
          children: (
            <span>
              <NumberFormat
                value={text}
                displayType={'text'}
                thousandSeparator={true}
                renderText={value => `${value} ${currencyMemoi}`}
              />
            </span>
          ),
        };
      },
    },
    {
      title: <></>,
      dataIndex: 'action',
      key: 'action',
      width: '15%',
      className: 'action-row',
      render: (text, row, index) => (
        <span className="wrapper-group-btn">
          <div className="wrapper-btn">
            <img
              src={IMG_INVENTORY_EDIT}
              alt=""
              onClick={e => handleClick(row)}
              className="detail-btn list-pro"
            />
          </div>
        </span>
      ),
    },
  ]
  return (
    <WorkingHistoryWrapper style={{height: '100%'}}>
      <div className="working-history_header">
          <Header onClickSearch={onClickSearch} search={search}/>
      </div>
      <div className="working-history_main">
        <Table dataSource={list} columns={columns} onChange={handleClickPageNumber} pagination={config.pagination}/>
      </div>
      {showPopup && <Detail payroll={payroll} showPopup={showPopup} onClose={() => setShowPopup(false)}/>}
    </WorkingHistoryWrapper>
  )
}

export default injectIntl(PayrollHistory)
