import React, { useEffect, useState } from 'react';

import { Form, Select, Typography, Row, Col, Button } from 'antd';
import { FormatInput } from 'components/FormatInput';
import { useDispatch, useSelector } from 'react-redux';
import { FormattedMessage, injectIntl } from 'react-intl';
import _ from 'lodash';

import { useParams } from 'react-router-dom';

import { digits } from 'utils/number';
import { StaffPayrollWrapper } from '../styles';
import PayrollHistory from './PayrollHistory';
import messages from '../messages';
import messagesGlobal from 'translations/messages';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import { formatCurrency } from 'utils/common';
import { getPayrolls, setSearchPayrolls, updateStaff } from '../actions';
import { createStructuredSelector } from 'reselect';
import makeSelectStaffDetail from '../selectors';
import FloatLabel from 'components/FormatInput/FloatLabel';

const { Option } = Select;
const { Title, Paragraph } = Typography;
const stateSelector = createStructuredSelector({
  staffDetail: makeSelectStaffDetail(),
});

function Payroll(props) {
  const dispatch = useDispatch();
  const { staffDetail } = useSelector(stateSelector);
  const { searchPayroll } = staffDetail;
  const currencyMemory = useCurrencyHook();
  const { staff, intl, payrolls } = props;
  const [form] = Form.useForm();
  // @ts-ignore
  const { id } = useParams();

  const onClickSearch = filterValues => {
    // @ts-ignore
    const newSearch = Object.assign(searchPayroll, filterValues);
    console.log('filterValues ', newSearch);
    dispatch(getPayrolls(id, newSearch));
    dispatch(setSearchPayrolls(newSearch));
  };
  const onFinish = values => {
    values = formatCurrency(values);
    if (values.paySetting) {
      values.paySetting.commissionId =
        values.paySetting.commissionId !== 0
          ? values.paySetting.commissionId
          : null;
    }
    values.paySetting = Object.assign(
      { ...staff.paySetting },
      { ...values.paySetting },
    );
    values.paySetting = JSON.stringify(values.paySetting);
    dispatch(
      updateStaff({
        id,
        staff: {
          paySetting: values.paySetting,
          workingTimeIds: staff.workingTimeIds,
        },
      }),
    );
  };

  useEffect(() => {
    if (staff) {
      form.setFieldsValue(staff);
      console.log(staff);
    }
  }, [staff]);

  return (
    <Form form={form} onFinish={onFinish}>
      <StaffPayrollWrapper>
        <Row>
          <Col xl={6} lg={7} md={8} sm={24} xs={24}>
            <div>
              <h3 className="title-global">
                {intl.formatMessage(messagesGlobal.payroll)}
              </h3>
              <div className="section">
                <Form.Item
                  className="section__item ex-money"
                  name={['paySetting', 'type']}
                >
                  <FloatLabel
                    size="large"
                    label={intl.formatMessage(messagesGlobal.payBy)}
                    items={[
                      { id: 1, name: intl.formatMessage(messagesGlobal.hour) },
                      { id: 2, name: intl.formatMessage(messagesGlobal.week) },
                      { id: 3, name: intl.formatMessage(messagesGlobal.month) },
                      { id: 4, name: intl.formatMessage(messagesGlobal.year) },
                    ]}
                    typeInput="selectMutil"
                  />
                </Form.Item>
                <Form.Item
                  className="section__item exchange-point"
                  name={['paySetting', 'payAmount']}
                  rules={[
                    {
                      pattern: new RegExp('^[0-9,]*$'),
                      message: intl.formatMessage(messages.requireNumberInput),
                    },
                  ]}
                >
                  <FormatInput
                    formatter={digits}
                    addonAfter={currencyMemory}
                    placeholder={`${intl.formatMessage(
                      messagesGlobal.basicSalary,
                    )}`}
                  />
                </Form.Item>
                <Form.Item
                  className="tax-col-input"
                  name={['paySetting', 'extraAmount']}
                  rules={[
                    {
                      pattern: new RegExp('^[0-9,]*$'),
                      message: intl.formatMessage(messages.requireNumberInput),
                    },
                  ]}
                >
                  <FormatInput
                    formatter={digits}
                    addonAfter={currencyMemory}
                    placeholder={`${intl.formatMessage(
                      messagesGlobal.allowance,
                    )}`}
                  />
                </Form.Item>
                <Form.Item
                  className="tax-col-input"
                  name={['paySetting', 'note']}
                >
                  <FloatLabel
                    label={intl.formatMessage(messagesGlobal.note)}
                    className="note-input"
                    typeInput="TextArea"
                  />
                </Form.Item>
                <Button className="btn" type="primary" htmlType="submit">
                  <FormattedMessage {...messages.save} />
                </Button>
              </div>
            </div>
          </Col>
          <Col xl={18} lg={17} md={16} sm={24} xs={24}>
            <div>
              <PayrollHistory
                payrolls={payrolls}
                search={searchPayroll}
                onClickSearch={onClickSearch}
                staff={staff}
              />
            </div>
          </Col>
        </Row>
      </StaffPayrollWrapper>
    </Form>
  );
}
export default injectIntl(Payroll);
