import React, { useState } from "react";
import { Table, Typography } from "antd";
import Header from './header'
import { injectIntl } from "react-intl";
import Detail from './detail'
import { WorkingHistoryWrapper } from "../../styles";
import NumberFormat from 'react-number-format';
import messages from "../../messages";
import moment from "moment";
import messagesGlobal from "translations/messages";
import IMG_INVENTORY_EDIT from 'images/information-ic.svg';
import { useDispatch } from 'react-redux';
import {
  getStaffWorkingHistory
} from '../../actions';

function TimesheetHistory(props) {
  const { workingHistory, search, intl, onClickSearch, staff } = props;
  const { list, count, hours } = workingHistory;
  const [showPopup, setShowPopup] = useState(false);
  const [timesheet, setTimesheet] = useState();
  const dispatch = useDispatch();
  const handleClick = key => {
    // dispatch(getPayroll(key.id));
    setShowPopup(true);
    setTimesheet(list.find(p => p.id == key.id));
  };
  const handleClickPageNumber = (page, pageSize) => {
    const newSearchPayroll = { ...search, page: page, limit:  pageSize};
    dispatch(getStaffWorkingHistory( staff.id, newSearchPayroll ));
  };
  const config = {
    pagination: {
      total: count
    },
  };
  const rowClass = (record, index) => {
    return !!record.approvedBy ? '' : 'not-approved';
  }
  const columns = [
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.date)}</Typography.Text>,
      dataIndex: 'createdTime',
      key: 'createdTime',
      width: '12%',
      className: 'first-col',
      render: text => <div>{text ? moment.utc(text).local().format('DD/MM/YYYY') : '-'}</div>
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.checkin)}</Typography.Text>,
      dataIndex: 'startTime',
      key: 'startTime',
      width: '12%',
      className: 'center-col',
      render: text => <div>{text ? moment.utc(text).local().format('HH:mm') : '-'}</div>
    },
    {
      title: <Typography.Text ellipsis> {intl.formatMessage(messagesGlobal.checkout)}</Typography.Text>,
      dataIndex: 'endTime',
      key: 'endTime',
      width: '50%',
      className: 'checkout-col',
      render: text => <div>{text ? moment.utc(text).local().format('HH:mm') : '-'}</div>
    },
    {
      title: <Typography.Text ellipsis>{intl.formatMessage(messagesGlobal.totalHours)}</Typography.Text>,
      dataIndex: 'hours',
      key: 'hours',
      width: '15%',
      className: 'center-col',
      // render: (text, row, index) => {
      //   const start = moment(row.startTime);
      //   const end = moment(row.endTime);
      //   const diff = end.diff(start, 'hours', true);
      //   return {
      //     children: (
      //       <span className={!!row.approvedBy ? 'total-approved' : ''}>
      //         {!!!diff.toFixed(0) ? 0 : diff.toFixed(1)}
      //       </span>
      //     ),
      //   };
      // },
    },
    {
      title: <></>,
      dataIndex: 'action',
      key: 'action',
      width: '10%',
      className: 'action-row',
      render: (text, row, index) => (
        (!!row.note) && <span className="wrapper-group-btn">
          <div className="wrapper-btn">
            <img
              src={IMG_INVENTORY_EDIT}
              alt=""
              onClick={e => handleClick(row)}
              className="dtail-btn list-pro"
            />
          </div>
        </span>
      ),
    },
  ]
  return (
    <WorkingHistoryWrapper style={{height: '100%'}}>
      <div className="working-history_header">
          <Header onClickSearch={onClickSearch} search={search} hours={hours}/>
      </div>
      <div className="working-history_main">
        <Table dataSource={list} columns={columns} onChange={handleClickPageNumber} pagination={config.pagination} rowClassName={rowClass}/>
      </div>
      {showPopup && <Detail timesheet={timesheet} showPopup={showPopup} onClose={() => setShowPopup(false)}/>}
    </WorkingHistoryWrapper>
  )
}

export default injectIntl(TimesheetHistory)
