import React, { useEffect, useState } from 'react';

import { Form, Select, Typography, Row, Col, Button } from 'antd';
import { FormatInput } from 'components/FormatInput';
import { useDispatch, useSelector } from 'react-redux';
import { FormattedMessage, injectIntl } from 'react-intl';
import _ from 'lodash';

import { useParams } from 'react-router-dom';

import { digits } from 'utils/number';
import { StaffPayrollWrapper } from '../styles';
import TimesheetHistory from './TimesheetHistory';
import messages from '../messages';
import messagesGlobal from 'translations/messages';
import { useCurrencyHook } from 'components/CustomHook/useCurrencyHook';
import { formatCurrency } from 'utils/common';
import {
  getStaffWorkingHistory,
  setSearchTimesheet,
  updateStaff
} from '../actions';
import { createStructuredSelector } from 'reselect';
import makeSelectStaffDetail from '../selectors';
import { makeSelectRestaurants } from "../../App/selectors";
import FloatLabel from 'components/FormatInput/FloatLabel';

const { Option } = Select;
const { Title, Paragraph } = Typography;
const stateSelector = createStructuredSelector({
  staffDetail: makeSelectStaffDetail(),
});

const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
});
function Timesheet(props) {
  const dispatch = useDispatch();
  const { staffDetail } = useSelector(stateSelector);
    const { restaurants } = useSelector(globalSelector);
  const {
    searchPayroll,
    shifts
  } = staffDetail;
  const currencyMemory = useCurrencyHook();
  const { staff, intl, workingHistory } = props;
  const [form] = Form.useForm();
  // @ts-ignore
  const { id } = useParams();

  const onClickSearch = (filterValues) => {
    // @ts-ignore
    const newSearch = Object.assign(searchPayroll, filterValues);
    console.log("filterValues ", newSearch);
    dispatch(getStaffWorkingHistory(id, newSearch));
    dispatch(setSearchTimesheet(newSearch))
  }
  const onFinish = values => {
    dispatch(updateStaff({ id, staff: values}));
  };

  useEffect(() => {
    if (staff) {
      form.setFieldsValue(staff);
    }
  }, [staff]);

  return (
    <Form form={form} onFinish={onFinish}>
      <StaffPayrollWrapper>
        <Row>
          <Col xl={6} lg={7} md={8} sm={24} xs={24}>
            <div>
              <h3 className="title-global">
                {intl.formatMessage(messagesGlobal.roster)}
              </h3>
              <div className="section">
                <Form.Item name="restaurantIds" >
                  <FloatLabel label={intl.formatMessage(messages.store)} size="large" items={restaurants} typeInput="selectMutil" />
                </Form.Item>
                <Form.Item
                  className="section__item ex-money mutil-select"
                  name='workingTimeIds'
                >
                  <FloatLabel
                    className="padding-mutil-select"
                    size={14}
                    label={intl.formatMessage(messagesGlobal.shift)}
                    mode="multiple"
                    showArrow
                    items={shifts} 
                    typeInput="selectMutil" 
                  />
                </Form.Item>
                <Button className="btn" type="primary" htmlType="submit">
                  <FormattedMessage {...messages.save} />
                </Button>
              </div>
            </div>
          </Col>
          <Col xl={18} lg={17} md={16} sm={24} xs={24}>
            <div>
              <TimesheetHistory workingHistory={workingHistory} search={searchPayroll} onClickSearch={onClickSearch} staff={staff}/>
            </div>
          </Col>
        </Row>
      </StaffPayrollWrapper>
    </Form>
  );
}
export default injectIntl(Timesheet);