import React, { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';

import makeSelectStaffDetail from './selectors';
import reducer from './reducer';
import saga from './saga';
import { useParams } from 'react-router-dom';
import Reputation from './Reputation';
import { FormattedMessage } from 'react-intl';
import messages from 'translations/messages';
import Information from './Information';
import Payroll from './Payroll';
import Timesheet from './Timesheet';
import Commission from './Commission';
import { usePhoneAddon } from '../../components/CustomHook/usePhoneAddon';
import { NewStaffDetailsWrapper } from './styles';
// import Service from "./Service";
// import Gift from "./Gift";
// import Orders from "./Orders";
import {
  getStaff,
  getStaffWorkingHistory,
  getStaffWorkingHours,
  getCommissions,
  getStaffCommissionHistory,
  getStaffAdjustmentHistory,
  resetStaff,
  getPayrolls
} from './actions';
import {
  makeSelectRestaurants,
  makeSelectRoles,
  makeSelectPhoneCountries,
} from '../App/selectors';
import { Spin, Tabs } from 'antd';
const { TabPane } = Tabs;
const stateSelector = createStructuredSelector({
  staffDetail: makeSelectStaffDetail(),
});
const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
  roles: makeSelectRoles(),
  phoneCountries: makeSelectPhoneCountries(),
});

interface Props {}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function StaffDetail(props: Props) {
  useInjectReducer({ key: 'staffDetail', reducer: reducer });
  useInjectSaga({ key: 'staffDetail', saga: saga });

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const { staffDetail } = useSelector(stateSelector);
  const { restaurants, roles, phoneCountries } = useSelector(globalSelector);
  const {
    isFetching,
    staff,
    workingHistory,
    payrolls,
    searchPayroll,
    searchTimesheet,
    searchCommission
  } = staffDetail;
  const prefixSelector = usePhoneAddon(phoneCountries);
  const dispatch = useDispatch(); // eslint-disable-line @typescript-eslint/no-unused-vars
  // @ts-ignore
  const { id } = useParams();

  useEffect(() => {
    dispatch(getStaff(id));
    dispatch(getStaffWorkingHours(id, searchTimesheet));
    dispatch(getStaffWorkingHistory(id, searchTimesheet));
    dispatch(getStaffCommissionHistory(id, searchCommission));
    dispatch(getCommissions());
    dispatch(getPayrolls(id, searchPayroll));
    dispatch(getStaffAdjustmentHistory({ id: id, limit: 5, page: 1 }));
    return () => {
      dispatch(resetStaff());
    };
  }, []);

  return (
    <NewStaffDetailsWrapper>
      <Spin spinning={isFetching}>
        {staff && (
          <>
            <Reputation staff={staff} />
            <div className="staff-tab">
              <Tabs className="tabCustorm" defaultActiveKey="1">
                <TabPane
                  tab={<FormattedMessage {...messages.information} />}
                  key="1"
                >
                  <Information
                    staff={staff}
                    prefixSelector={prefixSelector}
                    roles={roles}
                  />
                </TabPane>
                <TabPane
                  tab={<FormattedMessage {...messages.payroll} />}
                  key="2"
                >
                  <Payroll staff={staff} payrolls={payrolls} />
                </TabPane>
                <TabPane tab={<FormattedMessage {...messages.Timesheet} />} key="3">
                  <Timesheet staff={staff} workingHistory={workingHistory}/>
                </TabPane>
                <TabPane tab={<FormattedMessage {...messages.commission} />} key="4">
                  <Commission staff={staff}/>
                </TabPane>
              </Tabs>
            </div>
          </>
        )}
      </Spin>
    </NewStaffDetailsWrapper>
  );
}

export default StaffDetail;
