/*
 *
 * StaffDetail reducer
 *
 */

import ActionTypes from './constants';
import { ContainerActions, ContainerState } from './types';

export const initialState: ContainerState = {
  default: null,
  isFetching: false,
  staff: {},
  message: '',
  workingHistory: [],
  workingHours: [],
  restaurants: [],
  showModal: false,
  commissions: [],
  commissionHistory: {count: 0, list: <any>[], total: null},
  shifts: {count: 0, list: <any>[], hours: null},
  payrolls: {count: 0, list: <any>[], total: null},
  searchPayroll: { page: 1, limit: 10 },
  searchTimesheet: { page: 1, limit: 10 },
  searchCommission: { page: 1, limit: 10 },
  adjustmentHitories: {count: 0, list: <any>[]}
};

function staffDetailReducer(
  state: ContainerState = initialState,
  action: ContainerActions,
): ContainerState {
  switch (action.type) {
    case ActionTypes.DEFAULT_ACTION:
      return state;
    case ActionTypes.OPEN_MODAL:
      return { ...state, showModal: !state.showModal };
    case ActionTypes.GET_STAFF:
      return { ...state, isFetching: true };
    case ActionTypes.GET_STAFF_SUCCESS:
      return { ...state, isFetching: false, staff: action.payload };
    case ActionTypes.GET_STAFF_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_COMMISSIONS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_COMMISSIONS_SUCCESS:
      return { ...state, isFetching: false, commissions: action.payload };
    case ActionTypes.GET_SHIFTS_SUCCESS:
      return { ...state, isFetching: false, shifts: action.payload };
    case ActionTypes.GET_COMMISSIONS_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.UPDATE_STAFF:
      return { ...state, isFetching: true };
    case ActionTypes.UPDATE_STAFF_SUCCESS:
      return { ...state, isFetching: false, staff: action.payload };
    case ActionTypes.UPDATE_STAFF_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.BLOCK_STAFF:
      return { ...state, isFetching: true };
    case ActionTypes.BLOCK_STAFF_SUCCESS:
      return { ...state, isFetching: false, staff: action.payload };
    case ActionTypes.BLOCK_STAFF_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.UNBLOCK_STAFF:
      return { ...state, isFetching: true };
    case ActionTypes.UNBLOCK_STAFF_SUCCESS:
      return { ...state, isFetching: false, staff: action.payload };
    case ActionTypes.UNBLOCK_STAFF_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_STAFF_WORKING_HOURS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_STAFF_WORKING_HOURS_SUCCESS:
      return { ...state, isFetching: false, workingHours: action.payload };
    case ActionTypes.GET_STAFF_WORKING_HOURS_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_STAFF_ADJUSTMENTS_HISTORY:
      return { ...state, isFetching: true };
    case ActionTypes.GET_STAFF_ADJUSTMENTS_HISTORY_SUCCESS:
      return { ...state, isFetching: false, adjustmentHitories: action.payload };
    case ActionTypes.GET_STAFF_ADJUSTMENTS_HISTORY_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_STAFF_WORKING_HISTORY:
      return { ...state, isFetching: true };
    case ActionTypes.GET_STAFF_WORKING_HISTORY_SUCCESS:
      return { ...state, isFetching: false, workingHistory: action.payload };
    case ActionTypes.GET_STAFF_WORKING_HISTORY_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.GET_STAFF_COMMISION_HISTORY:
      return { ...state, isFetching: true };
    case ActionTypes.GET_STAFF_COMMISION_HISTORY_SUCCESS:
      return { ...state, isFetching: false, commissionHistory: action.payload };
    case ActionTypes.GET_STAFF_COMMISION_HISTORY_FAIL:
      return { ...state, message: action.payload, isFetching: false };
    case ActionTypes.RESET_STAFF:
      return { ...state, staff: {} };
    case ActionTypes.GET_PAYROLLS:
      return { ...state, isFetching: true };
    case ActionTypes.GET_PAYROLLS_SUCCESS:
      return { ...state, isFetching: false, payrolls: action.payload};
    case ActionTypes.GET_PAYROLLS_FAIL:
      return { ...state, isFetching: false, message: action.payload };
    case ActionTypes.SET_SEARCH_PAYROLL:
    return {
      ...state,
      searchPayroll: action.payload
    };
    case ActionTypes.SET_TIMESHEET:
      return {
        ...state,
        searchTimesheet: action.payload
      };
    case ActionTypes.SET_SEARCH_COMMISSION:
      return {
        ...state,
        searchCommission: action.payload
      };
    default:
      return state;
  }
}

export default staffDetailReducer;
