import { put, all, takeLatest, select } from 'redux-saga/effects';
import { callApi, success } from '../../utils/apiUtils';
import {
  blockStaffFail,
  blockStaffSuccess,
  getStaffFail,
  getStaffSuccess,
  getStaffWorkingHistoryFail,
  getStaffWorkingHistorySuccess,
  getStaffWorkingHoursFail,
  getStaffWorkingHoursSuccess,
  unBlockStaffFail,
  unBlockStaffSuccess,
  updateStaffFail,
  updateStaffSuccess,
  getCommissionSuccess,
  getCommissionFail,
  getStaffAdjustmentHistorySuccess,
  getStaffAdjustmentHistoryFail,
  getPayrollsFail,
  getPayrollsSuccess,
  getShiftsFail,
  getShiftsSuccess,
  getStaffCommissionHistoryFail,
  getStaffCommissionHistorySuccess,
} from './actions';
import ActionTypes from './constants';
import { push } from 'connected-react-router';
import { RoutePaths } from '../App/routes';
import { apiError, apiSuccess } from '../App/actions';
import { makeSelectLocale } from '../LanguageProvider/selectors';
import moment from 'moment';

const messages = [
  {"vi": "Cập nhật nhân viên thành công",
  "en": "Update staff successfully"},
  {"vi": "Cập nhật nhân viên thất bại",
  "en": "Update failed"},
]

export function* getStaff({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/staff-user/${id}`,
      'GET',
    );
    if (success(code)) {
      yield put(getStaffSuccess(data));
    } else {
      yield put(getStaffFail(message));
    }
  } catch (error) {
    yield put(getStaffFail(error.message));
  }
}

export function* getWorkingHistory({ payload: { staffId, searchTimesheet } }) {
      // to be refactored
      const searchParams = new URLSearchParams();
      if (+staffId > 0) {
        searchParams.append('userId', staffId);
      }
      searchParams.append('page', searchTimesheet.page);
      searchParams.append('limit', searchTimesheet.limit);
  try {
    const { code, data, message } = yield callApi(
      `/users/working-hours?${searchParams.toString()}${
        searchTimesheet.fromDate ? '&from=' + searchTimesheet.fromDate : ''
      }${searchTimesheet.toDate ? '&to=' + searchTimesheet.toDate : ''}`,
      'GET',
    );
    if (success(code)) {
      yield put(getStaffWorkingHistorySuccess(data));
    } else {
      yield put(getStaffWorkingHistoryFail(message));
    }
  } catch (error) {
    yield put(getStaffWorkingHistoryFail(error.message));
  }
}

export function* getCommissionHistory({ payload: { staffId, searchTimesheet } }) {
  // to be refactored
  const searchParams = new URLSearchParams();
  if (+staffId > 0) {
    searchParams.append('userId', staffId);
  }
  searchParams.append('page', searchTimesheet.page);
  searchParams.append('limit', searchTimesheet.limit);
try {
const { code, data, message } = yield callApi(
  `/users/commissions?${searchParams.toString()}${
    searchTimesheet.fromDate ? '&fromDate=' + searchTimesheet.fromDate : ''
  }${searchTimesheet.toDate ? '&fromDate=' + searchTimesheet.toDate : ''}`,
  'GET',
);
if (success(code)) {
  yield put(getStaffCommissionHistorySuccess(data));
} else {
  yield put(getStaffCommissionHistoryFail(message));
}
} catch (error) {
yield put(getStaffCommissionHistoryFail(error.message));
}
}

export function* getWorkingHours({ payload: { staffId, searchTimesheet } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/working-hours?userId=${staffId}`,
      'GET',
    );
    if (success(code)) {
      yield put(getStaffWorkingHoursSuccess(data));
    } else {
      yield put(getStaffWorkingHoursFail(message));
    }
  } catch (error) {
    yield put(getStaffWorkingHoursFail(error.message));
  }
}


export function* updateStaff({ payload: { id, staff } }) {
  const language = yield select(makeSelectLocale());
  try {
    const { code, data, message } = yield callApi(
      `/users/staff-user/${id}`,
      'PUT',
      staff,
      { isFormData: true },
    );
    if (success(code)) {
      yield put(updateStaffSuccess(data));
      yield put(apiSuccess(messages[0][language]));
    } else {
      yield put(updateStaffFail(message));
      yield put(apiError(message));
    }
  } catch (error) {
    yield put(updateStaffFail(error.message));
    yield put(apiError(messages[1][language]));
  }
}

export function* blockStaff({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/block-user/${id}`,
      'DELETE',
    );
    if (success(code)) {
      yield put(blockStaffSuccess(data));
    } else {
      yield put(blockStaffFail(message));
    }
  } catch (error) {
    yield put(blockStaffFail(error.message));
  }
}

export function* unBlockStaff({ payload: id }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/unblock-user/${id}`,
      'PUT',
    );
    if (success(code)) {
      yield put(unBlockStaffSuccess(data));
    } else {
      yield put(unBlockStaffFail(message));
    }
  } catch (error) {
    yield put(unBlockStaffFail(error.message));
  }
}

export function* getCommissions() {
  try {
    const { code, data, message } = yield callApi(
      `/admin/setting/merchant`,
      'GET',
    );
    if (success(code)) {
      yield put(
        getCommissionSuccess(data.commission ? data.commission.list : []),
      );
      yield put(
        getShiftsSuccess(data.merchantWorkingTimes ? data.merchantWorkingTimes : []),
      );
      
    } else {
      yield put(getCommissionFail(message));
    }
  } catch (error) {
    yield put(getCommissionFail(error.message));
  }
}


// export function* getShifts() {
//   try {
//     const { code, data, message } = yield callApi(
//       `/admin/setting/merchant`,
//       'GET',
//     );
//     if (success(code)) {
//       yield put(
//         getShiftsSuccess(data.commission ? data.commission.list : []),
//       );
//     } else {
//       yield put(getShiftsFail(message));
//     }
//   } catch (error) {
//     yield put(getShiftsFail(error.message));
//   }
// }
export function* getAdjustmentHistories({ payload: { id, page, limit } }) {
  try {
    const { code, data, message } = yield callApi(
      `/users/${id}/pay-setting?page=${page}&limit=${limit}`,
      'GET',
    );
    if (success(code)) {
      yield put(getStaffAdjustmentHistorySuccess(data));
    } else {
      yield put(getStaffAdjustmentHistoryFail(message));
    }
  } catch (error) {
    yield put(getStaffAdjustmentHistoryFail(error.message));
  }
}

export function* getPayrolls({ payload: { staffId, searchPayroll } }) {
  try {
    // to be refactored
    const searchParams = new URLSearchParams();

    console.log('saga values param ', { staffId, searchPayroll });
    if (+staffId > 0) {
      searchParams.append('userId', staffId);
    }
    searchParams.append('page', searchPayroll.page);
    searchParams.append('limit', searchPayroll.limit);
    const { code, data, message } = yield callApi(
      `/users/payrolls?${searchParams.toString()}${
        searchPayroll.fromDate ? '&fromDate=' + searchPayroll.fromDate : ''
      }${searchPayroll.toDate ? '&toDate=' + searchPayroll.toDate : ''}`,
      'GET',
    );

    if (success(code)) {
      data.list = data.list.map(d => {
        d.fullName = `${d.user.firstName ? d.user.firstName : ''}${
          d.user.lastName ? ' ' + d.user.lastName : ''
        }`;
        d.roleName = d.user.roles.map(r => r.name).join('/');
        d.payPeriod = `${
          d.startPayTime ? moment(d.startPayTime).format('DD/MM') : 'N/A'
        } - ${
          d.endPayTime ? moment(d.endPayTime).format('DD/MM/YYYY') : 'N/A'
        }`;
        delete d.startPayTime;
        delete d.endPayTime;
        return d;
      });
      yield put(getPayrollsSuccess({ ...data }));
    } else {
      yield put(getPayrollsFail(message));
    }
  } catch (error) {
    yield put(getPayrollsFail(error.message));
  }
}

// Individual exports for testing
export default function* staffDetailSaga() {
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFF, getStaff);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_COMMISSIONS, getCommissions);
  // // @ts-ignore
  // yield takeLatest(ActionTypes.GET_SHIFTS, getShifts);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_PAYROLLS, getPayrolls);
  // @ts-ignore
  yield takeLatest( ActionTypes.GET_STAFF_ADJUSTMENTS_HISTORY,
    getAdjustmentHistories,
  );
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFF_WORKING_HOURS, getWorkingHours);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFF_WORKING_HISTORY, getWorkingHistory);
  // @ts-ignore
  yield takeLatest(ActionTypes.GET_STAFF_COMMISION_HISTORY, getCommissionHistory);
  // @ts-ignore
  yield takeLatest(ActionTypes.UPDATE_STAFF, updateStaff);
  // @ts-ignore
  yield takeLatest(ActionTypes.BLOCK_STAFF, blockStaff);
  // @ts-ignore
  yield takeLatest(ActionTypes.UNBLOCK_STAFF, unBlockStaff);
}
