import React, { useEffect } from 'react';
import styled from 'styled-components';
import Card from './Card';
import Header from './Header/index';
import { Spin } from 'antd';
import { useDispatch, useSelector } from "react-redux";
import { useInjectReducer, useInjectSaga } from 'utils/redux-injectors';
import { deleteStaff, getStaffs } from "./actions";
import staffsReducer from './reducer';
import staffsSaga from './saga';
import { createStructuredSelector } from "reselect";
import { makeIsFetching, makeStaffs } from "./selectors";
import cacheUtils from "../../utils/cacheUtils";
import { makeSelectRestaurants, makeSelectRoles } from "../App/selectors";

const StaffListWrapper = styled.div`
  padding: 30px 10px;
  .ant-input-affix-wrapper > input.ant-input {
    padding-top: 0;
    padding-bottom: 0;
  }
  .list {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(260px, 1fr));
    .card {
      list-style: none;
      padding: 10px;
    }
  }
  .image {
    width: 70px !important;
    height: 70px !important;
  }
`;

const stateSelector = createStructuredSelector({
  staffs: makeStaffs(),
  isFetching: makeIsFetching(),
});

const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
  roles: makeSelectRoles()
});

export default function StaffList() {
  // injected reducer and saga
  useInjectReducer({ key: 'staffs', reducer: staffsReducer });
  useInjectSaga({ key: 'staffs', saga: staffsSaga});

  const dispatch = useDispatch();
  const { staffs, isFetching } = useSelector(stateSelector);
  const { restaurants, roles } = useSelector(globalSelector);
  const userInfoString = cacheUtils.getUserInfo();
  const userInfo = JSON.parse(userInfoString!);
  const { merchantId } = userInfo.profile!;

  useEffect(() => {
    // @ts-ignore
    dispatch(getStaffs({ page: 1, limit: 100 }));
  }, [])

  const onClickSearch = (filterValues) => {
    const { restaurant, search, role } = filterValues;
    // @ts-ignore
    dispatch(getStaffs({ restaurantId: restaurant, roleIds: role, searchText: search ? search.trim() : '', page: 1, limit: 100 }));
  }

  const onClickRemove = (id) => {
    dispatch(deleteStaff(id));
  }

  return (
    <StaffListWrapper>
      <Header filter={{stores: restaurants, roles}} onClickSearch={onClickSearch} />
      <Spin spinning={isFetching}>
        <div className="list">
          {
            (staffs).map(staff => (
              <div className="card">
                <Card staff={staff} roles={roles} onClickRemove={onClickRemove} />
              </div>
            ))
          }
        </div>
      </Spin>
    </StaffListWrapper>
  )
}
