import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import _ from 'lodash';
import {
  Button,
  Modal,
  Form,
  Input,
  Select,
  Divider,
  DatePicker,
} from 'antd';
import { StorageModel } from '../types';
import { getInvent } from '../actions';
import messages from 'translations/messages';
import { useSelector } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { FormattedMessage, injectIntl } from 'react-intl';
import { validatePrice, validateMaxTime } from 'utils/validation';
import { PUBLIC_API } from 'containers/App/urls';
import { useDispatch } from 'react-redux';
import { addInvent } from '../actions';
import { digits } from 'utils/number';
import { makeSelectRestaurants } from '../../App/selectors';
import { closeAddModal } from "../actions";
import moment from 'moment';
import { PlusCharacter, RemoveCharacter } from 'styles/icon-components';
import { makeStorage, makeShowModal, makeShowModalInventory } from '../selectors';
import { FormatInput } from 'components/FormatInput';
import { MenuItemIcon } from 'styles/icon-components';
import FloatLabel from 'components/FormatInput/FloatLabel';
interface Props {
  inventory: StorageModel;
  onClickRemove: any;
  roles: any;
  intl?: any;
  visibleDetail: boolean;
  setVisibleDetail: any;
}

const stateSelector = createStructuredSelector({
  inventory: makeStorage(),
  showModal: makeShowModal(),
});

const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
});

const dateFormat = 'DD/MM/YYYY';

const ModalWrapper = styled.div`
  .container {
    display: flex;
    flex-direction: column;
    flex-wrap: nowrap;
    justify-content: space-between;
    align-items: baseline;
    align-content: stretch;
    padding-left: 50px;
    @media screen and (max-width: 400px) {
      padding-left: 0px;
    }
    .header {
      width: 100%;
      &__title {
        font-size: 18px;
        font-weight: 500;
        margin-bottom: 20px;
        text-align: center;
      }
      &__desc {
        display: flex;
        flex-direction: row;
        justify-content: justify;
        align-items: start;
      }
      &__infor {
        padding-top: 15px;
        &__name {
          font-size: 13px;
          font-weight: 600;
          margin-bottom: 20px;
        }
        &__sku {
          color: #9c9696;
          line-height: 13px;
        }
      }
      &__img {
        height: 70px;
        width: 120px;
        text-align: center;
        margin-right: 20px;
        background-color: #ececec;
        img {
          height: 70px;
          width: 120px;
          object-fit: cover;
        }
      }
    }
    .title {
      color: #333333;
      font-size: 16px;
      font-weight: 700;
      line-height: 19px;
      text-align: center;
      padding-bottom: 20px;
    }
    .btn-wrapper {
      width: 100%;
      text-align: center;
      .add-button {
        width: 70%;
        height: 44px;
        margin-top: 20px;
        font-weight: 600;
      }
    }
  }

  .element-input-wrapper {
    width: 100%;
    input.element-input,
    div.element-input {
      width: 90%;
      height: 44px;
      border-radius: 22px;
    }
  }

  .form-field {
    width: 100%;
    &__row {
      display: flex;
      flex-direction: row;
    }
    &__col {
      display: flex;
      flex-direction: row;
      flex: 0 1 90%;
      .ant-row {
        &:nth-child(1) {
          flex: 0 1 25%;
          margin-right: 2%;
        }
        &:nth-child(2) {
          flex: 0 1 70%;
        }
      }
    }
    &__plus {
      flex: 0 1 10%;
    }
  }
`;

export const Detail = injectIntl((props: Props) => {
  const { restaurants } = useSelector(globalSelector);
  const { inventory, showModal } = useSelector(stateSelector);
  const { intl } = props;
  const [loading, setLoading] = useState(false);
  const dispatch = useDispatch();

  const [form] = Form.useForm();

  const handleCancel = () => {
    dispatch(closeAddModal());
  };

  const handleAddSizes = async add => {
    const sizes = form.getFieldValue('items');
    if (
      sizes.findIndex(
        size =>
          !size ||
          (size &&
            !size.id &&
            (!size.quantity || size.quantity === '') &&
            !size.restaurant_id),
      ) === -1
    ) {
      add();
    }
  };
  useEffect(() => {
    if (restaurants && restaurants.length > 0) {
      form.setFieldsValue({
        items: [{ quantity: '', restaurant_id: restaurants[0].id }],
      });
    }
  }, [restaurants]);
  const handleOk = async values => {
    setLoading(true);
    for (var key in values) {
      if (typeof values[key] === 'string') {
        values[key] = values[key].trim();
        if (/^[0-9,]+$/.test(values[key])) {
          values[key] = values[key].replace(/,/g, '');
        }
      }
    }
    const newValues = values.items.map(item => {
      return {
        ...item,
        price: values.priceImport,
        code: values.code,
        product_id: inventory.productId,
        product_size_id: inventory.productSizeId,
      };
    });
    dispatch(addInvent(newValues));
    setLoading(false);
  };

  const opt = restaurants
    ? restaurants.map(res => {
        return { label: res.name, value: res.id };
      })
    : [];
  return (
    inventory && (
      <Modal
        visible={showModal}
        onOk={handleOk}
        onCancel={handleCancel}
        okText="Thêm"
        centered
        footer={null}
        width={500}
      >
        <ModalWrapper>
          <Form form={form}>
            <div className="container">
              <div className="header">
                <div className="header__title title-global">{intl.formatMessage(messages.importInventory)}</div>
                <div className="header__desc">
                  <div className="header__img" style={{paddingTop: inventory.productPhoto ? '0px' : '10px'}}>
                    {inventory.productPhoto ? <img src={`${PUBLIC_API}/${inventory.productPhoto}`} /> : <MenuItemIcon />}
                  </div>
                  <div className="header__infor">
                    <div className="header__infor__name">
                      {`${inventory.productName ? inventory.productName : 'N/A'} - ${inventory.size ? inventory.size : 'N/A'}`}
                    </div>
                    <div className="header__infor__sku">{inventory.productSku ? inventory.productSku : 'N/A'}</div>
                  </div>
                </div>
              </div>
              <Divider />
              <Form.List name="items">
                {(fields, { add, remove }) => (
                  <div className="form-field">
                    {fields.map((field, index) => (
                      <div className="form-field__row" key={field.key}>
                        <div className="form-field__col">
                          <Form.Item
                            name={
                              field
                                ? [field.name, 'quantity']
                                : ['items', '0', 'quantity']
                            }
                            rules={[
                              {
                                required: true,
                                message: (
                                  <FormattedMessage
                                    {...messages.requiredInput}
                                  />
                                ),
                              },
                              {
                                pattern: new RegExp('^[0-9]*$'),
                                message: (
                                  <FormattedMessage
                                    {...messages.requiredInputNumber}
                                  />
                                ),
                              },
                              validateMaxTime(10000),
                            ]}
                          >
                            <FormatInput
                              placeholder={`${intl.formatMessage(messages.titleItemTableQuantity)}*`}
                            />
                          </Form.Item>
                          <Form.Item
                            className="product-units-select orgin-select"
                            name={
                              field
                                ? [field.name, 'restaurant_id']
                                : ['items', '0', 'restaurant_id']
                            }
                            rules={[
                              {
                                required: true,
                                message: (
                                  <FormattedMessage
                                    {...messages.requiredChoose}
                                  />
                                ),
                              },
                            ]}
                            initialValue={(restaurants && restaurants.length > 0) ? restaurants[0].id : ''}
                          >
                            <Select options={opt}>
                              {restaurants.map((value, index) => (
                                <Select.Option value={value.id} key={value.id}>
                                  {value.name}
                                </Select.Option>
                              ))}
                            </Select>
                          </Form.Item>
                        </div>
                        <div className="form-field__plus">
                          {fields.length - 1 !== index ? (
                            <Button
                              size="large"
                              type="primary"
                              shape="circle"
                              style={{
                                padding: 0,
                                background: 'none',
                                borderColor: 'white',
                                width: '40px',
                              }}
                              onClick={() => {
                                remove(field.name);
                              }}
                            >
                              {' '}
                              <RemoveCharacter />{' '}
                            </Button>
                          ) : (
                            <Button
                              size="large"
                              type="primary"
                              shape="circle"
                              style={{ padding: 0 }}
                              onClick={() => {
                                handleAddSizes(add);
                              }}
                            >
                              {' '}
                              <PlusCharacter />{' '}
                            </Button>
                          )}
                        </div>
                      </div>
                    ))}
                  </div>
                )}
              </Form.List>
              <Form.Item
                name="priceImport"
                className="element-input-wrapper"
                rules={[
                  {
                    pattern: new RegExp('^[0-9,]*$'),
                    message: (
                      <FormattedMessage {...messages.requiredInputNumber} />
                    ),
                  },
                ]}
              >
                <FloatLabel
                  formatter={digits}
                  label={`${intl.formatMessage(messages.priceImport)}`}
                  className="element-input"
                ></FloatLabel>
              </Form.Item>
              <Form.Item
                name="code"
                className="element-input-wrapper"
              >
                <FloatLabel label={`${intl.formatMessage(messages.storageCd)}`} className="element-input" />
              </Form.Item>
              <Form.Item name="dateImport" className="element-input-wrapper">
                <FloatLabel
                  className="element-input"
                  label={`${intl.formatMessage(messages.importDate)}*`}
                  format={dateFormat}
                  defaultValue={moment()}
                  typeInput="datepicker"
                />
              </Form.Item>
              <div className="btn-wrapper">
                <Button
                  className="add-button"
                  type="primary"
                  loading={loading}
                  onClick={() => {
                    form
                      .validateFields()
                      .then(values => {
                        handleOk(values);
                      })
                      .catch(info => {
                        console.log('Validate Failed:', info);
                      });
                  }}
                >
                 {intl.formatMessage(messages.save)}
                </Button>
              </div>
            </div>
          </Form>
        </ModalWrapper>
      </Modal>
    )
  );
});
