import React from 'react';
import styled from 'styles/styled-components';
import { useHistory } from 'react-router-dom';
import { Select, Input, Button, Space, Form } from 'antd';
import { SearchOutlined } from '@ant-design/icons';
import { RoutePaths } from 'containers/App/routes';
import { PlusCharacter } from 'styles/icon-components';
import { FormattedMessage, injectIntl } from "react-intl";
import FloatLabel from 'components/FormatInput/FloatLabel';
import messages from "translations/messages";

const StaffListHeaderWrapper = styled.div`
  .form {
    @media screen and (min-width: 768px) {
      display: flex;
      justify-content: space-between;
      .ant-form-item {
        margin-bottom: 12px !important;
      }
      padding: 0px 10px;
    }
  }
  .ant-select-selection-item {
    line-height: 24px !important;
  }
  .title {
    font-size: 19px;
    font-weight: 600;
    color: #333333;
  }
  .filter {
    margin-top: 20px;
    @media screen and (min-width: 768px) {
      display: flex;
      flex: 0 1 70%;
      justify-content: flex-start;
      margin-top: 0px;
    }
    &__common {
      display: flex;
      flex: 1;
      > * {
        flex: 1;
      }
      @media screen and (min-width: 768px) {
        flex: 2.2;
      }
    }
    &__restaurant {
      flex: 1;
      @media screen and (min-width: 768px) {
        flex: 1;
        margin-right: 10px;
      }
    }
    &__role {
      flex: 1;
      margin-left: 10px;
      @media screen and (min-width: 768px) {
        margin-left: 0px;
        margin-right: 10px;
      }
    }
    &__search {
      display: flex;
      flex: 2;
      &__input {
        flex: 1;
        margin-right: 10px;
      }
      &__submit {
        margin-right: 10px;
      }
    }
  }
`;

function Header(props) {
  const { filter, onClickSearch, intl } = props;
  const { stores = [], categories } = filter;
  const history = useHistory();
  const [ form ] = Form.useForm();

  const handleOnClickAdd = () => history.push(RoutePaths.staffAddNew);
  const handleOnClickSearch = (values) => {
    onClickSearch(values);
  }
  return (
    <StaffListHeaderWrapper>
      <Form className="form" form={form} onFinish={handleOnClickSearch}>
      <h3 className="title-global-header"><FormattedMessage {...messages.storage}/></h3>
        <div className="filter">
          <div className="filter__common">
            <Form.Item  className="filter__restaurant" name="restaurant">
              <FloatLabel defaultValue="0" className="staff-filters__restaurant padding-item-select" size="large"
                items={[...stores, {id: "0", name: `${intl.formatMessage(messages.allSelect)} ${intl.formatMessage(messages.restaurant).toLowerCase()}`}]}
                typeInput="selectMutil"
                label={<FormattedMessage {...messages.restaurant}/>}
              />
            </Form.Item>
            <Form.Item className="filter__role" name="category">
              <FloatLabel defaultValue={0} size="large" onChange={handleOnClickSearch}
                items={categories ? [...categories, {id: 0, name: intl.formatMessage(messages.allSelectCategories)}] : []}
                typeInput="selectMutil"
                label={intl.formatMessage(messages.category)}
                className="padding-item-select"
              />
            </Form.Item>
          </div>
          <div className="filter__search">
            <Form.Item className="filter__search__input" name="search">
              <FloatLabel  size="large" width={300} label={intl.formatMessage(messages.search)} prefix={<SearchOutlined />} />
            </Form.Item>
            <Button className="filter__search__submit" size="large" type="primary" htmlType="submit"><FormattedMessage {...messages.search}/></Button>
          </div>
        </div>
      </Form>
    </StaffListHeaderWrapper>
  )
}
export default injectIntl(Header);