import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import Header from './Header/index';
import { Spin } from 'antd';
import moment from 'moment';
import { useDispatch, useSelector } from "react-redux";
import { useInjectReducer, useInjectSaga } from 'utils/redux-injectors';
import { getInvents, getCategories, setSearch } from "./actions";
import storagesReducer from './reducer';
import storagesSaga from './saga';
import { createStructuredSelector } from "reselect";
import { makeIsFetching, makeStorages, makeCategories, makeShowModal, makeSearch, makeShowModalInventory } from "./selectors";
import cacheUtils from "../../utils/cacheUtils";
import { makeSelectRestaurants } from "../App/selectors";
import { InventoryList } from './InventoryList';
import { Detail } from './Add';
import ProductStorage from './ProductStorage';
const StorageListWrapper = styled.div`
  padding: 30px 10px;
  .ant-input-affix-wrapper > input.ant-input {
    padding-top: 0;
    padding-bottom: 0;
  }
  .list {
    display: grid;
    .card {
      list-style: none;
      padding: 10px;
    }
  }
  .image {
    width: 70px !important;
    height: 70px !important;
  }
`;

const stateSelector = createStructuredSelector({
  isFetching: makeIsFetching(),
  categories: makeCategories(),
  showModal: makeShowModal(),
  searchGl: makeSearch(),
  showModalInventory: makeShowModalInventory(),
});

const globalSelector = createStructuredSelector({
  restaurants: makeSelectRestaurants(),
});

export default function StaffList() {
  // injected reducer and saga
  useInjectReducer({ key: 'storage', reducer: storagesReducer });
  useInjectSaga({ key: 'storage', saga: storagesSaga});

  const dispatch = useDispatch();
  const { isFetching, categories, showModal, searchGl, showModalInventory } = useSelector(stateSelector);
  const { restaurants } = useSelector(globalSelector);
  const userInfoString = cacheUtils.getUserInfo();

  useEffect(() => {
    // @ts-ignore
    dispatch(getInvents({ page: 1, limit: 10 }));
    // @ts-ignore
    dispatch(setSearch({ page: 1, limit: 10 }))
    dispatch(getCategories());
  }, [])

  const onClickSearch = (filterValues) => {
    const { restaurant, search, category } = filterValues;
    // @ts-ignore
    dispatch(getInvents({ restaurantId: restaurant, categoryId: category, searchText: search ? search.trim() : '', page: 1, limit: searchGl.limit ? searchGl.limit : 10 }));
    dispatch(setSearch({ restaurantId: restaurant, categoryId: category, searchText: search ? search.trim() : '', page: 1, limit: searchGl.limit ? searchGl.limit : 10 }))
  }

  return (
    <StorageListWrapper>
      <Header filter={{stores: restaurants, categories}} onClickSearch={onClickSearch} />
      <Spin spinning={isFetching}>
        <div className="list">
         <InventoryList search={searchGl}/>
        </div>
      </Spin>
      {showModal && <Detail/>}
      {showModalInventory && <ProductStorage search={searchGl}/>}
    </StorageListWrapper>
  )
}
