import _ from 'lodash';
import { InventsReducerState } from './types';
import {
  GET_CATEGORIES,
  GET_CATEGORIES_SUCCESS,
  GET_CATEGORIES_FAIL,
  ADD_INVENT,
  ADD_INVENT_FAIL,
  ADD_INVENT_SUCCESS,
  GET_INVENTS,
  GET_INVENTS_FAIL,
  GET_INVENTS_SUCCESS,
  GET_INVENT,
  GET_INVENT_FAIL,
  GET_INVENT_SUCCESS,
  SHOW_ADD_MODAL,
  CLOSE_ADD_MODAL,
  SHOW_LIST_MODAL,
  CLOSE_LIST_MODAL,
  GET_HISTORIES,
  GET_HISTORIES_FAIL,
  GET_HISTORIES_SUCCESS,
  SET_SEARCH
} from './constants';

export const initialState: InventsReducerState = {
  inventories: {count: 0, list: <any>[]},
  categories: [],
  histories: {count: 0, list: <any>[]},
  inventory: null,
  restaurants: [],
  isFetching: null,
  message: '',
  search: {page: 1, limit: 100},
  showModalAdd: false,
  showModalInventory: false,
};

export default (state = initialState, action) => {
  switch (action.type) {
    case GET_INVENTS:
      return {
        ...state,
        isFetching: true,
      };
    case GET_INVENTS_SUCCESS:
      return {
        ...state,
        inventories: action.inventories,
        isFetching: false,
      };
    case GET_INVENTS_FAIL:
      return {
        ...state,
        message: action.message,
        isFetching: false,
      };
    case GET_CATEGORIES:
      return {
        ...state,
        isFetching: true,
      };
    case GET_CATEGORIES_SUCCESS:
      return {
        ...state,
        categories: action.categories,
        isFetching: false,
      };
    case GET_CATEGORIES_FAIL:
      return {
        ...state,
        message: action.message,
        isFetching: false,
      };
    case GET_HISTORIES:
      return {
        ...state,
        isFetching: true,
      };
    case GET_HISTORIES_SUCCESS:
      return {
        ...state,
        histories: action.histories,
        isFetching: false,
      };
    case GET_HISTORIES_FAIL:
      return {
        ...state,
        message: action.message,
        isFetching: false,
      };
    case SET_SEARCH:
      return {
        ...state,
        search: action.payload
      };
    case GET_INVENT:
      return {
        ...state,
        inventory: state.inventories.list.find(i => i.productId === action.productId && i.productSizeId === action.productSizeId),
        // isFetching: true,
      };
    case GET_INVENT_SUCCESS:
      return {
        ...state,
        inventory: action.inventory,
        isFetching: false,
      };
    case GET_INVENT_FAIL:
      return {
        ...state,
        message: action.message,
        isFetching: false,
      };
    case ADD_INVENT:
      return {
        ...state,
        isFetching: true,
      };
    case ADD_INVENT_SUCCESS: {
      return {
        ...state,
        isFetching: false,
      };
    }
    case ADD_INVENT_FAIL:
      return {
        ...state,
        isFetching: false,
      };
    case SHOW_ADD_MODAL:
      return { ...state, showModalAdd: true };
    case CLOSE_ADD_MODAL:
      return { ...state, showModalAdd: false, inventory: null };
    case SHOW_LIST_MODAL:
      return { ...state, showModalInventory: true };
    case CLOSE_LIST_MODAL:
      return { ...state, showModalInventory: false };
    default:
      return state;
  }
};
