import { takeLatest, put, select } from 'redux-saga/effects';
import {
  GET_INVENTS,
  GET_INVENT,
  ADD_INVENT,
  GET_CATEGORIES,
  GET_HISTORIES,
  CLOSE_ADD_MODAL
} from './constants';
import {
  getInventsFail,
  getInventsSuccess,
  getHistoriesFail,
  getHistoriesSuccess,
  getInventFail,
  getInventSuccess,
  addInventFail,
  addInventSuccess,
  getCategoriesFail,
  getCategoriesSuccess,
} from './actions';
import { callApi, success } from '../../utils/apiUtils';
import { makeSearch } from './selectors';
import { apiError, apiSuccess } from '../App/actions';
import { HTTP_STATUS_ACCEPTED } from '../../utils/constants';

export function* getStorages({
  restaurantId,
  categoryId,
  searchText,
  page,
  limit,
}) {
  try {
    // to be refactored
    const searchParams = new URLSearchParams();
    if (+restaurantId > 0) {
      searchParams.append('restaurantId', restaurantId);
    }
    if (+categoryId > 0) {
      searchParams.append('categoryId', categoryId);
    }
    if (searchText) {
      searchParams.append('searchText', searchText);
    }
    searchParams.append('page', page);
    searchParams.append('limit', limit);
    const { code, data, message } = yield callApi(
      `/products/storage-items?${searchParams.toString()}`,
      'GET',
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      let newData = data;
        newData.list = data.list.map(d => {
          d.size = `${d.productSizeName ? d.productSizeName : 'N/A'} ${
            d.productUnitName ? d.productUnitName : 'N/A'
          }`;
        return d;
      });
      yield put(getInventsSuccess(newData)); // should be remove list
    } else {
      yield put(getInventsFail(message));
    }
  } catch (error) {
    yield put(getInventsFail(error.message));
  }
}

export function* getCategories() {
  try {
    const { code, data, message } = yield callApi(
      `/menus/menu-categories?productType=1`,
      'GET',
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      yield put(getCategoriesSuccess(data)); // should be remove list
    } else {
      yield put(getCategoriesFail(message));
    }
  } catch (error) {
    yield put(getCategoriesFail(error.message));
  }
}

export function* getProductHistories({ productId, sizeId, limit, page, restaurantId }) {
  try {
    const restaurantParam  = restaurantId && restaurantId != 0 ? `&restaurantId=${restaurantId}` : '';
    const { code, data, message } = yield callApi(
      `/products/storage-item-histories?productId=${productId}&productSizeId=${sizeId}&limit=${limit}&page=${page}${restaurantParam}`,
      'GET',
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      yield put(getHistoriesSuccess(data)); // should be remove list
    } else {
      yield put(getHistoriesFail(message));
    }
  } catch (error) {
    yield put(getHistoriesFail(error.message));
  }
}

export function* addStorage({ inventory, setVisibleDetail }) {
  try {
    const { code, data, message } = yield callApi(
      `/products/storage-items/import`,
      'POST',
      inventory,
    );
    if (success(code)) {
      yield put(addInventSuccess(data));
      yield put(apiSuccess('Import inventory success!'));
      const payload = yield select(makeSearch());
      yield put({
        type: GET_INVENTS,
        restaurantId: payload.restaurantId,
        categoryId: payload.categoryId,
        searchText: payload.searchText,
        page: payload.page,
        limit: payload.limit,
      });
      yield put({ type: CLOSE_ADD_MODAL });
    } else {
      yield put(apiError(message));
      yield put(addInventFail(message));
    }
  } catch (error) {
    yield put(apiError(error.message));
    yield put(addInventFail(error.message));
  }
}

export function* getStorage({ id }) {
  try {
    let { code, data, message } = yield callApi(
      `/products/storage-items/${id}`,
      'GET',
    );
    if (code === HTTP_STATUS_ACCEPTED) {
      if (data.product) {
        const product = data.product;
        data = { ...data, ...product };
        data.size = `${product.sizeName} ${product.unitName}`;
      }
      yield put(getInventSuccess(data)); // should be remove list
    } else {
      yield put(getInventFail(message));
    }
  } catch (error) {
    yield put(getInventFail(error.message));
  }
}

export default function* watchStorage() {
  // @ts-ignore
  yield takeLatest(GET_INVENTS, getStorages);
  // @ts-ignore
  // yield takeLatest(GET_INVENT, getStorage);
  // @ts-ignore
  yield takeLatest(ADD_INVENT, addStorage);
  // @ts-ignore
  yield takeLatest(GET_CATEGORIES, getCategories);
  // @ts-ignore
  yield takeLatest(GET_HISTORIES, getProductHistories);
}
