import React from 'react';
import styled from 'styled-components';
import { CARD_HEIGHT, BLACK_COLOR, PRIMARY_COLOR } from "./constants";
import { EditIcon, BackIcon } from './icon-components';
import { HEADER_HEIGHT } from 'styles/constants';
import { PUBLIC_API } from 'containers/App/urls';
import IMG_DEFAULT_GIFT from '../images/default-gift-bg.svg';

interface CardProps {
  isHovered?: boolean;
  height?: string;
}

export const Card = styled.div`
  background-color: ${(props: CardProps) => props.isHovered ? 'rgba(0, 0, 0, 0.20000000298023224)' : '#fff'};
  border-radius: 8px;
  box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
  width: 100%;
  height: ${(props: CardProps) => props.height ? `${props.height}` : CARD_HEIGHT};
  padding: 15px 0 15px 15px;
  .restaurant-card {
    &__header {
      display: flex;
      .image {
        border-radius: 100%;
        width: 60px;
        height: 60px;
        margin-right: 15px;
        object-fit: cover;
      }
      .title {
        font-size: 15px;
      }
      .name {
        color: ${BLACK_COLOR};
        font-family: Muli;
        font-weight: 600;
        line-height: 22px;
        text-align: left;
        align-self: center;
        min-height: 15px;
        display: -webkit-box;
        max-width: 150px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
      }
      .default-menu {
        border: 1px solid #c7c7c7;
        border-radius: 50%;
        width: 60px;
        height: 60px;
        text-align: center;
        padding-top: 5px;
        margin-right: 15px;
      }
      .name-note {
        font-size: 15px;
        font-weight: 600;
        line-height: 22px;
        color: ${BLACK_COLOR};
        margin-top: 5px;
        margin-bottom: 6px;
      }
      .time {
        color: #646464;
        font-size: 14px;
      }
      .role, .score {
        min-height: 14px;
        color: #dc3b7f;
      }
      .phone {
        min-height: 14px;
        display: -webkit-box;
        max-width: 150px;
        -webkit-line-clamp: 1;
        -webkit-box-orient: vertical;
        overflow: hidden;
        text-overflow: ellipsis;
      }
    }
    &__row {
      display: flex;
      margin-bottom: 13px;
      &--info {
        margin-left: 11px;
      }
      &--note{
      }
    }
    &__dot {
      height: 11px;
      width: 11px;
      border-radius: 50%;
      display: inline-block;
      margin-right: 10px;
      position: absolute;
      right: 4px;
      top: 8px;
    }
    &__dot2{
      height: 11px;
      width: 11px;
      border-radius: 50%;
      display: inline-block;
      position: absolute;
      right: 18px;
      top: 8px;
    }
  }
  hr {
    border: none;
    border-top: solid 1px #F0F0F0;
    margin: 13px 0px;
  }
`;

export const Hr = styled.hr`
  border: none;
  border-top: solid 1px #F0F0F0;
  margin: 13px 0px;
`;

const EditButtonWrapper = styled.div`
  margin: 5px;
  width: 50px;
  height: 50px;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  &:hover {
    cursor: pointer;
    background: #E0E0E0;
  }
`;

const BackButtonIconWrapper = styled.div`
  margin: 5px;
  width: 40px;
  height: 44px;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  &:hover {
    cursor: pointer;
    background: #E0E0E0;
  }
`;

export const EditButtonIcon = () => {
  return (
    <EditButtonWrapper>
      <EditIcon />
    </EditButtonWrapper>
  )
}

export const InputWrapper = styled.div`
  .ant-input-number {
    width: 100%;
  }
  .ant-input-group-addon:last-child {
    border-radius: 22px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    width: 53px;
  }
`;

interface ContainerImgProps {
  imgLink?: string;
  imgBase64?: any;
  children?: any;
  height: number;
}
export const ContainerImg = styled.div`
  background-image: url(${(props: ContainerImgProps) =>
    props.imgLink ? PUBLIC_API + '/' + props.imgLink : props.imgBase64 ? props.imgBase64 : IMG_DEFAULT_GIFT});
  height: ${(props: ContainerImgProps) => props.height ? `${props.height}` : 200}px;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  border-radius: 8px;
  .promo-header {
    &__upload {
      background: none !important;
    }
  }
  .edit-upload-image-amount {
    text-align: center;
    margin-bottom: 20px;
    font-size: 30px;
    line-height: 28px;
    span {
      border-radius: 16px;
      padding: 0px 8px;

      background: rgba(255,255,255,0.4);
    }
  }
  .edit-upload-image-icon {
    position: absolute;
    top: 15px;
    right: 10px;
  }
  .edit-upload-image-time {
    text-align: center;
    font-size: 14px;
    margin-bottom: 15px;
    span {
      border-radius: 22px;
      padding: 5px 10px;
      background: rgba(255,255,255,0.4);
    }
  }
  .edit-upload-image-status {
    display: flex;
    padding-bottom: 10px;
    justify-content: center;
    align-items: center;
    color: #9cd339;
  }
  .edit-upload-image-status:before {
    content: "•";
    color: #9cd339;
    font-size: 30px;
    margin: 0 10px 5px 0;
}
  .edit-upload-image-shop {
    padding:20px 0 15px 20px;
    .user {
      &__name {
        justify-self: end;
        line-height: ${HEADER_HEIGHT};
        padding-right: 10px;
        &--name {
          margin-left: 10px;
          font-size: 14px;
          line-height: 28px;
        }
      }
      &__avatar {
        border-radius: 100%;
        height: 30px;
        width: 30px;
        object-fit: cover;
      }
    }
  }
`;

export const ContainerEditImg = styled.div`
height: ${(props: ContainerImgProps) => props.height ? `${props.height}` : 200}px;
border-radius: 8px;
.promo-header {
  &__upload {
    background: none !important;
    background-image: url(${(props: ContainerImgProps) =>
      props.imgLink ? PUBLIC_API + '/' + props.imgLink : props.imgBase64 ? props.imgBase64 : IMG_DEFAULT_GIFT})  !important;
    background-position: center;
    background-repeat: no-repeat;
    background-size: cover !important;
  }
}
.ant-upload.ant-upload-select-picture-card > .ant-upload {
  vertical-align: top;
  text-align: start;
}
.edit-upload-image-amount {
  text-align: center;
  margin-bottom: 20px;
  font-size: 30px;
  line-height: 28px;
  span {
    border-radius: 16px;
    padding: 0px 8px;

    background: rgba(255,255,255,0.4);
  }
}
.edit-upload-image-icon {
  position: absolute;
  top: 15px;
  right: 10px;
  display: block !important;
}
.edit-upload-image-time {
  text-align: center;
  font-size: 13px;
  margin-bottom: 15px;
  span {
    border-radius: 22px;
    padding: 5px 10px;
    background: rgba(255,255,255,0.4);
  }
}
.edit-upload-image-status {
  display: flex;
  padding-bottom: 10px;
  justify-content: center;
  align-items: center;
  color: #9cd339;
}
.edit-upload-image-status:before {
  content: "•";
  color: #9cd339;
  font-size: 30px;
  margin: 0 10px 5px 0;
}
.edit-upload-image-shop {
  padding:10px 0 10px 10px;
  .user {
    &__name {
      justify-self: end;
      line-height: ${HEADER_HEIGHT};
      padding-right: 10px;
      &--name {
        margin-left: 10px;
        font-size: 14px;
        line-height: 28px;
      }
    }
    &__avatar {
      border-radius: 100%;
      height: 30px;
      width: 30px;
      object-fit: cover;
    }
  }
}
`;

export const BackButtonIcon = (props: { onClick: () => void }) => {
  return (
    <BackButtonIconWrapper onClick={props.onClick}>
      <BackIcon />
    </BackButtonIconWrapper>
  )
}
