import { Reducer, Store } from 'redux';
import { RouterState } from 'connected-react-router';
import { Saga } from 'redux-saga';
import { SagaInjectionModes } from 'redux-injectors';

import { ContainerState as LanguageProviderState } from 'containers/LanguageProvider/types';
import { AuthReducerState } from 'containers/Auth/authReducer';
import { RestaurantReducerModel } from 'containers/Restaurant/Store';
import { StaffsReducerModel } from 'containers/StaffList/reducer';
import { ContainerState as StaffDetailState } from 'containers/StaffDetail/types';
import { ContainerState as StaffAddNewState } from 'containers/StaffAddNew/types';
import { ContainerState as PromotionListState } from 'containers/PromotionList/types';
import { ContainerState as AddPromotionState } from 'containers/AddPromotion/types';
import { ContainerState as PromotionDetailState } from 'containers/PromotionDetail/types';
import { ContainerState as GiftDetailState } from 'containers/GiftCardDetail/types';
import { ContainerState as CustomerListState } from 'containers/CustomerList/types';
import { ContainerState as CustomerDetailState } from 'containers/CustomerDetail/types';
import { ContainerState as PaymentListState } from 'containers/PaymentList/types';
import { ContainerState as DashboardState } from 'containers/Dashboard/types';
import { ContainerState as ReportState } from 'containers/Report/types';
import { ContainerState as MenuState } from 'containers/Menu/Store/types';
import { ContainerState as ServiceState } from 'containers/Service/Store/types';
import { ContainerState as StorageState } from 'containers/Storage/types';
import { ContainerState as PayrollState } from 'containers/Payroll/types';
import { ContainerState as SettingState } from 'containers/Setting/Store/types';
// [IMPORT NEW CONTAINERSTATE ABOVE] < Needed for generating containers seamlessly

export interface InjectedStore extends Store {
  injectedReducers: any;
  injectedSagas: any;
  runSaga(saga: Saga<any[]> | undefined, args: any | undefined): any;
}

export interface InjectReducerParams {
  key: keyof ApplicationRootState;
  reducer: Reducer<any, any>;
}

export interface InjectSagaParams {
  key: keyof ApplicationRootState;
  saga: Saga;
  mode?: SagaInjectionModes;
}

// Your root reducer type, which is your redux state types also
export interface ApplicationRootState {
  readonly router: RouterState;
  readonly language: LanguageProviderState;
  readonly auth: AuthReducerState;
  readonly restaurant: RestaurantReducerModel;
  readonly staffs: StaffsReducerModel;
  readonly staffDetail: StaffDetailState;
  readonly staffAddNew: StaffAddNewState;
  readonly app: any;
  readonly promotionList: PromotionListState;
  readonly addPromotion: AddPromotionState;
  readonly promotionDetail: PromotionDetailState;
  readonly giftDetail: GiftDetailState;
  readonly customerList: CustomerListState;
  readonly customerDetail: CustomerDetailState;
  readonly paymentList: PaymentListState;
  readonly dashboard: DashboardState;
  readonly report: ReportState;
  readonly menu: MenuState;
  readonly service: ServiceState;
  readonly storage: StorageState;
  readonly payroll: PayrollState;
  readonly setting: SettingState;
  // [INSERT NEW REDUCER KEY ABOVE] < Needed for generating containers seamlessly

  // for testing purposes
  readonly test: any;
}
