const chai = require('chai');
const chaiHttp = require('chai-http');
const expect = chai.expect;

const mocha = require('mocha');
const describe = mocha.describe;
const should = require('chai').should();
const testConstants = require('../../constants');
const {checkResponseStatus, getStandardMenuItem, getStandardProductId, getStandardSizeId} = require('../../common');


const domainTest = testConstants.baseUrl;
const token = testConstants.token.staff.token;
const merchantcode = testConstants.merchantcode;
const restaurantId = testConstants.envData.restaurant.id;
const floorId = testConstants.envData.floorId;

async function loadOrderDetail(orderId) {
  return new Promise((resolve, reject) => {
    chai
      .request(`${domainTest}`)
      .get(`/orders/order/${orderId}`)
      .set({
        Authorization: `Bearer ${testConstants.token.mobile.token}`,
        merchantcode: merchant.code,
      })
      .end((err, res) => {
        expect(res).to.have.status(200);
        resolve(res.body.data);
      });
  });
}

async function loadStaffOrderDetail(orderId) {
  return new Promise((resolve, reject) => {
    chai
      .request(`${domainTest}`)
      .get(`/orders/order/${orderId}`)
      .set({
        Authorization: `Bearer ${token}`,
        merchantcode: merchantcode,
      })
      .end((err, res) => {
        expect(res).to.have.status(200);
        resolve(res.body.data);
      });
  });
}

async function loadMenus() {
  return new Promise((resolve, reject) => {
    chai
      .request(domainTest)
      .get(`/menus/menu-items?restaurantId=${restaurantId}`)
      .set({
        Authorization: `Bearer ${token}`,
        merchantcode: merchantcode,
      })
      .end((err, res) => {
        if (err) return reject(err);
        const menus = res.body.data;
        checkResponseStatus(res, 200);
        resolve(menus);
      });
  });
}

async function getSeats() {
  return new Promise((resolve, reject) => {
    chai
      .request(domainTest)
      .get(`/restaurants/tables/get-tables-with-order-info?floorId=${floorId}`)
      .set({
        Authorization: `Bearer ${token}`,
      })
      .end((err, res) => {
        if (err) return reject(err);
        const seats = res.body.data;
        checkResponseStatus(res, 200);
        resolve(seats);
      });
  });
}

async function loadmenus() {
  return new Promise((resolve, reject) => {
    chai
      .request(domainTest)
      .get(`/menus/menu-items-merchant`)
      .set({
        Authorization: `Bearer ${token}`,
        merchantcode: merchantcode,
      })
      .end((err, res) => {
        const menus = res.body.data;
        checkResponseStatus(res, 200);
        resolve(menus);
      });
  });
}

async function staffPlaceOrder() {
  return new Promise(async (resolve, reject) => {

    const menus = await  loadmenus();
    let menuItem = getStandardMenuItem(menus);
    let productId = getStandardProductId(menuItem);
    let sizeId = getStandardSizeId(menuItem);

    let requestParams = {
      "restaurantId": restaurantId,
      "orderTypeId": 3,
      "firstName": "John",
      "lastName": "Lennon",
      "phoneNumber": "0182028230",
      items: [
        {
          quantity: 1,
          addons: [],
          products: [
            {
              product_id: productId,
              cooking_requests: [],
              sizes: [
                {
                  id: sizeId,
                  quantity: 1,
                },
              ],
            },
          ],
          menu_item_id: menuItem.id,
          is_take_out: true,
        },
      ],
    };
    chai
      .request(domainTest)
      .post(`/orders/order/staff-place-order`)
      .set({
        Authorization: `Bearer ${token}`,
      })
      .send(requestParams)
      .end((err, res) => {
        if (err) return reject(err);
        const order = res.body.data;
        checkResponseStatus(res, 200);
        resolve(order);
      });
  });
}

module.exports = {
  loadOrderDetail,
  loadStaffOrderDetail,
  loadMenus,
  getSeats,
  staffPlaceOrder,
};
