const chai = require('chai');
const chaiHttp = require('chai-http');
const expect = chai.expect;
chai.should();
const OrderFunctions = require('../order/functions');

const { token, merchantcode, baseUrl, envData } = require('../../constants');
const {
  getStandardMenuItem,
  getStandardSizeId,
  getStandardSize,
  getNotStandardMenuItem,
  getNotStandardSizeId,
  getComboMenuItem,
  getNormalMenuItem,
  getMenuItemHasAddon,
  getAddon,
  getManyStandardMenuItem,
  getRedeemablePromotion,
  getCashAmountPromotion,
  getPercentagePromotion,
  checkResponseStatus,
  getCashAmountGroupItemPromotion,
  getPercentageGroupItemPromotion,
  getMenuItemById,
  getStandardProductId,
  checkProperty,
} = require('../../common');

chai.use(chaiHttp);

let menus = [];
let promotions = [];

async function loadmenus() {
  return new Promise((resolve, reject) => {
    chai
      .request(`${baseUrl}`)
      .get(`/menus/menu-items-merchant`)
      .set({
        Authorization: `Bearer ${token.mobile.token}`,
        merchantcode: merchantcode,
      })
      .end((err, res) => {
        menus = res.body.data;
        checkResponseStatus(res, 200);
        resolve(menus);
      });
  });
}

describe('Test order trên mobile', function() {
  this.timeout(15000);

  before(done => {
    new Promise(async function(resolve, reject) {
      const [_menus ] = await Promise.all([loadmenus()]);
      resolve();
    }).then(() => done());
  });

  describe('Đặt hàng qua mobile', function() {
    it('Đặt hàng size tiêu chuẩn', done => {
      let menuItem = getStandardMenuItem(menus);
      let productId = getStandardProductId(menuItem);
      let sizeId = getStandardSizeId(menuItem);
      let requestParams = {
        orderTypeId: 2,
        deliveryAddress: 'Gmg Building, Lý Thường Kiệt, phường 8, Tân Bình, Hồ Chí Minh, Việt Nam',
        items: [
          {
            quantity: 1,
            addons: [],
            products: [
              {
                product_id: productId,
                cooking_requests: [],
                sizes: [
                  {
                    id: sizeId,
                    quantity: 1,
                  },
                ],
              },
            ],
            menu_item_id: menuItem.id,
            is_take_out: true,
          },
        ],
        discountCode: '',
      };
      chai
        .request(`${baseUrl}`)
        .post(`/orders/order/user-place-order`)
        .set({
          Authorization: `Bearer ${token.mobile.token}`,
          merchantcode: merchantcode,
        })
        .send(requestParams)
        .end((err, res) => {
          checkResponseStatus(res, 200);
          checkProperty(res.body,'data','object');
          checkProperty(res.body.data, 'id', 'number');
          done();
        });
    });
  });

});
