const chai = require('chai');
const chaiHttp = require('chai-http');
const moment = require('moment');
const expect = chai.expect;

function getCashAmountPromotion(promotions) {
  for (var i = 0; i < promotions.length; i++) {
    let promotion = promotions[i];
    if (promotion.discountTypeId === 2 && promotion.menuItems.length === 0 && promotion.discountRedeemTypeId === 1) {
      return promotion;
    }
  }
  return undefined;
}

function getPercentagePromotion(promotions) {
  for (var i = 0; i < promotions.length; i++) {
    let promotion = promotions[i];
    if (
      promotion.discountTypeId === 1 &&
      promotion.menuItems.length === 0 &&
      promotion.discountRedeemTypeId === 1 &&
      promotion.subjectsId === 1
    ) {
      return promotion;
    }
  }
  return undefined;
}

function getRedeemablePromotion(promotions) {
  for (var i = 0; i < promotions.length; i++) {
    let promotion = promotions[i];
    if (promotion.discountRedeemTypeId === 2) {
      return promotion;
    }
  }
  return undefined;
}

function getPercentageGroupItemPromotion(promotions) {
  for (var i = 0; i < promotions.length; i++) {
    let promotion = promotions[i];
    if (promotion.discountRedeemTypeId === 1 && promotion.discountTypeId === 1 && promotion.menuItems.length > 0) {
      return promotion;
    }
  }
  return undefined;
}

function getCashAmountGroupItemPromotion(promotions) {
  for (var i = 0; i < promotions.length; i++) {
    let promotion = promotions[i];
    if (promotion.discountRedeemTypeId === 1 && promotion.discountTypeId === 2 && promotion.menuItems.length > 0) {
      return promotion;
    }
  }
  return undefined;
}

function getMenuItemById(menus, menuId) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.id == menuId) {
          return menuItem;
        }
      }
    }
  }
  return undefined;
}
function getNormalMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          return menuItem;
        }
      }
    }
  }
  return undefined;
}

function getComboMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 1) {
          return menuItem;
        }
      }
    }
  }
  return undefined;
}

function getMenuItemHasAddon(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.addons.length > 0) {
          return menuItem;
        }
      }
    }
  }
  return undefined;
}

function getManyStandardMenuItem(menus, number) {
  if (number === 0) {
    number = 1;
  }
  let menuItems = [];
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          for (var i = 0; i < menuItem.products.length; i++) {
            let product = menuItem.products[i];
            if (product.sizes.length > 0) {
              menuItems.push(menuItem);
              if (menuItems.length === number) {
                return menuItems;
              }
            }
          }
        }
      }
    }
  }
  return undefined;
}

function getServiceMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          if (menuItem.products.length == 1) {
            for (var k = 0; k < menuItem.products.length; k++) {
              let product = menuItem.products[k];
              if (product.type == 2) {
                return menuItem;
              }
            }
          }
        }
      }
    }
  }
  return undefined;
}

function getProductMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          if (menuItem.products.length == 1) {
            for (var k = 0; k < menuItem.products.length; k++) {
              let product = menuItem.products[k];
              if (product.type == 1) {
                return menuItem;
              }
            }
          }
        }
      }
    }
  }
  return undefined;
}

function getStandardMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          for (var i = 0; i < menuItem.products.length; i++) {
            let product = menuItem.products[i];
            if (product.sizes.length > 0) {
              return menuItem;
            }
          }
        }
      }
    }
  }
  return undefined;
}

function getNotStandardMenuItem(menus) {
  for (var i = 0; i < menus.length; i++) {
    let menu = menus[i];
    if (menu.menuItems.length > 0) {
      for (var j = 0; j < menu.menuItems.length; j++) {
        let menuItem = menu.menuItems[j];
        if (menuItem.products.length > 0) {
          for (var i = 0; i < menuItem.products.length; i++) {
            let product = menuItem.products[i];
            if (product.sizes.length > 1) {
              return menuItem;
            }
          }
        }
      }
    }
  }
  return undefined;
}

function getAddon(menuItem) {
  if (menuItem.addons.length > 0) {
    return menuItem.addons[0];
  }
  return undefined;
}

function getStandardSize(menuItem) {
  if (menuItem.products.length > 0) {
    for (var i = 0; i < menuItem.products.length; i++) {
      let product = menuItem.products[i];
      if (product.sizes.length > 0) {
        return product.sizes[0];
      }
    }
  }
  return undefined;
}

function getSize(menuItem, sizeIndex) {
  if (menuItem.products.length > 0) {
    for (var i = 0; i < menuItem.products.length; i++) {
      let product = menuItem.products[i];
      if (product.sizes.length >= sizeIndex) {
        return product.sizes[sizeIndex];
      }
    }
  }
  return undefined;
}

function getSizeById(menuItem, sizeId) {
  if (menuItem.products.length > 0) {
    for (var i = 0; i < menuItem.products.length; i++) {
      let product = menuItem.products[i];
      for (var i = 0; i < product.sizes.length; i++) {
        let size = product.sizes[i];
        if (size.id * 1 === sizeId * 1) {
          return size;
        }
      }
    }
  }
  return undefined;
}

function getStandardSizeId(menuItem) {
  if (menuItem.products.length > 0) {
    for (var i = 0; i < menuItem.products.length; i++) {
      let product = menuItem.products[i];
      if (product.sizes.length > 0) {
        return product.sizes[0].id;
      }
    }
  }
  return undefined;
}

function getNotStandardSizeId(menuItem) {
  if (menuItem.products.length > 0) {
    for (var i = 0; i < menuItem.products.length; i++) {
      let product = menuItem.products[i];
      if (product.sizes.length > 1) {
        return product.sizes[1].id;
      }
    }
  }
  return undefined;
}

function getStandardProductId(menuItem) {
  if (menuItem.products.length > 0) {
    return menuItem.products[0].id;
  }
  return undefined;
}

function checkResponseStatus(res, expected) {
  if (res.body.code !== expected) {
    console.log('========Request=======');
    console.log(res.request.url);
    console.log(res.request.method);
    console.log(res.request._header);
    console.log(res.request._data);
    console.log('========Response======');
    console.log(res.body);
  }
  expect(res).to.have.status(expected);
}
function checkProperty(data, name, type) {
  expect(data).to.have.property(name);
  if(type && type !== ''){
    expect(data[name]).to.be.an(type);
  }
}

function getServeMenuItemId(serviceItems) {
  return serviceItems[0].orderItems[0].menuItemId;
}
function getServeProductId(serviceItems) {
  return serviceItems[0].orderItems[0].products[0].id;
}
function getServeSizeId(serviceItems) {
  return serviceItems[0].orderItems[0].products[0].sizes[0].id;
}
function getMenuItemTypeService(menus) {
  return (menus.find(menu => menu.menuItems.find(mi => mi.products.find(p => p.type == 2))) || { menuItems: [] })
    .menuItems[0];
}
function getProductIdTypeService(menuItem) {
  return (menuItem.products.find(p => p.type == 2) || {}).id;
}
function getSizeIdTypeService(menuItem) {
  return (menuItem.products.find(p => p.type == 2) || { sizes: [{ id: null }] }).sizes[0].id;
}

const formatMomentMaxDate = date =>
  moment(date)
    .set({ hour: 23, minute: 59, second: 59, millisecond: 999 })
    .format('YYYY-MM-DDTHH:mm:ss');
const formatMomentMinDate = date =>
  moment(date)
    .set({ hour: 0, minute: 0, second: 0, millisecond: 0 })
    .format('YYYY-MM-DDTHH:mm:ss');


module.exports = {
  getMenuItemById,
  getStandardMenuItem,
  getManyStandardMenuItem,
  getStandardSizeId,
  getStandardSize,
  getSize,
  getSizeById,
  getNotStandardMenuItem,
  getNotStandardSizeId,
  getComboMenuItem,
  getNormalMenuItem,
  getMenuItemHasAddon,
  getAddon,
  getRedeemablePromotion,
  getCashAmountPromotion,
  getPercentagePromotion,
  checkResponseStatus,
  getPercentageGroupItemPromotion,
  getCashAmountGroupItemPromotion,
  getStandardProductId,
  getServeMenuItemId,
  getServeProductId,
  getServeSizeId,
  getMenuItemTypeService,
  getProductIdTypeService,
  getSizeIdTypeService,
  getProductMenuItem,
  getServiceMenuItem,
  checkProperty,
  formatMomentMaxDate,
  formatMomentMinDate
};
